<?php
declare(strict_types = 1);

return [
    'authorName' => '@graffica_info',
    'authorUrl' => 'https://twitter.com/graffica_info',
    'cms' => null,
    'code' => null,
    'description' => 'El lenguaje, sea cual sea el idioma, siempre esconde entre los orígenes de sus palabras muchas curiosidades. Este es el caso del origen del ampersand.',
    'favicon' => 'https://graffica.info/favicon.ico',
    'feeds' => [
        'https://graffica.info/wp-json/wp/v2/posts/290566',
        'https://graffica.info/feed/'
    ],
    'icon' => null,
    'image' => 'https://graffica.info/wp-content/uploads/2020/02/el-origen-de-la-Ampersand-destacado.jpg',
    'keywords' => [],
    'language' => 'es',
    'languages' => [],
    'license' => null,
    'providerName' => 'Gràffica',
    'providerUrl' => 'https://graffica.info',
    'publishedTime' => '2020-02-20 09:30:00',
    'redirect' => null,
    'title' => 'El origen del ampersand que desconocen muchos diseñadores',
    'url' => 'https://graffica.info/sabes-cual-es-el-origen-del-ampersand/',
    'linkedData' => [
        'url' => 'https://graffica.info',
        'name' => 'Gràffica',
        '@id' => '#organization',
        '@context' => 'http://schema.org',
        '@type' => 'Organization'
    ],
    'oEmbed' => [],
    'allLinkedData' => [
        [
            'url' => 'https://graffica.info',
            'name' => 'Gràffica',
            '@id' => '#organization',
            '@context' => 'http://schema.org',
            '@type' => 'Organization'
        ],
        [
            'isPartOf' => [
                '@id' => '#website',
                '@context' => 'http://schema.org',
                '@type' => 'WebSite'
            ],
            'name' => '¿Sabes cuál es el origen del ampersand?',
            '@id' => '#webpage',
            '@context' => 'http://schema.org',
            '@type' => 'WebPage'
        ],
        [
            'potentialAction' => [
                'target' => 'https://graffica.info?s={search_term_string}',
                'query-input' => 'required name=search_term_string',
                '@context' => 'http://schema.org',
                '@type' => 'SearchAction'
            ],
            'url' => 'https://graffica.info',
            'name' => 'Gràffica',
            'description' => 'Revista de noticias del mundo del diseño, en especial del diseño gráfico, la creatividad y la cultura visual. Tipografía, ilustración, branding y mucho más.',
            'publisher' => [
                '@id' => '#organization',
                '@context' => 'http://schema.org',
                '@type' => 'Organization'
            ],
            '@id' => '#website',
            '@context' => 'http://schema.org',
            '@type' => 'WebSite'
        ],
        [
            'dateModified' => '2020-11-16T11:54:05+01:00',
            'author' => [
                'url' => 'https://graffica.info/author/anagamontessgmail-com/',
                'name' => 'Ana García Montes',
                '@context' => 'http://schema.org',
                '@type' => 'Person'
            ],
            'mainEntityOfPage' => [
                '@id' => '#webpage',
                '@context' => 'http://schema.org',
                '@type' => 'WebPage'
            ],
            'description' => 'El lenguaje, sea cual sea el idioma, siempre esconde entre los orígenes de sus palabras muchas curiosidades que resultan realmente fascinantes y que nos ayudan a entender el porqué de muchas formaciones lingüísticas. Este es el caso del origen del ampersand, el signo & —que en español su nombre es et y en inglés ampersand— […]',
            'datePublished' => '2020-02-20T10:30:00+01:00',
            'headline' => '¿Sabes cuál es el origen del ampersand?',
            'publisher' => [
                '@id' => '#organization',
                '@context' => 'http://schema.org',
                '@type' => 'Organization'
            ],
            'image' => [
                'https://graffica.info/wp-content/uploads/2020/02/el-origen-de-la-Ampersand-destacado.jpg',
                'https://please-enter-a-fallback-url.here'
            ],
            '@context' => 'http://schema.org',
            '@type' => 'Article'
        ]
    ]
];
