<?php
declare(strict_types = 1);

return [
    'headers' => [
        'server' => [
            'nginx'
        ],
        'date' => [
            'Mon, 10 Jun 2024 15:59:22 GMT'
        ],
        'content-type' => [
            'application/json; charset=UTF-8'
        ],
        'vary' => [
            'Accept-Encoding',
            'accept, content-type'
        ],
        'x-hacker' => [
            'Want root?  Visit join.a8c.com/hacker and mention this header.'
        ],
        'host-header' => [
            'WordPress.com'
        ],
        'content-encoding' => [
            'br'
        ],
        'x-ac' => [
            '2.mad _dca BYPASS'
        ],
        'strict-transport-security' => [
            'max-age=31536000'
        ],
        'alt-svc' => [
            'h3=":443"; ma=86400'
        ],
        'Content-Location' => [
            'https://public-api.wordpress.com/oembed/?format=json&url=https%3A%2F%2Fwordpress.tv%2F2013%2F09%2F06%2Fdave-ross-optimize-image-files-like-a-pro%2F&for=wpcom-auto-discovery'
        ],
        'X-Request-Time' => [
            '0.340 ms'
        ]
    ],
    'statusCode' => 200,
    'reasonPhrase' => 'OK',
    'body' => '{"version":"1.0","provider_name":"WordPress.tv","provider_url":"http:\\/\\/wordpress.tv","author_name":"WordPress.tv","author_url":"https:\\/\\/wordpress.tv\\/author\\/anonvideoupload\\/","title":"Dave Ross: Optimize Image Files Like a&nbsp;Pro","html":"<blockquote class=\\"wp-embedded-content\\" data-secret=\\"yWYIA6Qj0W\\"><a href=\\"https:\\/\\/wordpress.tv\\/2013\\/09\\/06\\/dave-ross-optimize-image-files-like-a-pro\\/\\">Dave Ross: Optimize Image Files Like a&nbsp;Pro<\\/a><\\/blockquote><iframe sandbox=\\"allow-scripts\\" security=\\"restricted\\" src=\\"https:\\/\\/wordpress.tv\\/2013\\/09\\/06\\/dave-ross-optimize-image-files-like-a-pro\\/embed\\/#?secret=yWYIA6Qj0W\\" width=\\"440\\" height=\\"248\\" title=\\"&#8220;Dave Ross: Optimize Image Files Like a&nbsp;Pro&#8221; &#8212; WordPress.tv\\" data-secret=\\"yWYIA6Qj0W\\" frameborder=\\"0\\" marginwidth=\\"0\\" marginheight=\\"0\\" scrolling=\\"no\\" class=\\"wp-embedded-content\\"><\\/iframe><script type=\\"text\\/javascript\\">\\n\\/* <![CDATA[ *\\/\\n\\/*! This file is auto-generated *\\/\\n!function(d,l){\\"use strict\\";l.querySelector&&d.addEventListener&&\\"undefined\\"!=typeof URL&&(d.wp=d.wp||{},d.wp.receiveEmbedMessage||(d.wp.receiveEmbedMessage=function(e){var t=e.data;if((t||t.secret||t.message||t.value)&&!\\/[^a-zA-Z0-9]\\/.test(t.secret)){for(var s,r,n,a=l.querySelectorAll(\'iframe[data-secret=\\"\'+t.secret+\'\\"]\'),o=l.querySelectorAll(\'blockquote[data-secret=\\"\'+t.secret+\'\\"]\'),c=new RegExp(\\"^https?:$\\",\\"i\\"),i=0;i<o.length;i++)o[i].style.display=\\"none\\";for(i=0;i<a.length;i++)s=a[i],e.source===s.contentWindow&&(s.removeAttribute(\\"style\\"),\\"height\\"===t.message?(1e3<(r=parseInt(t.value,10))?r=1e3:~~r<200&&(r=200),s.height=r):\\"link\\"===t.message&&(r=new URL(s.getAttribute(\\"src\\")),n=new URL(t.value),c.test(n.protocol))&&n.host===r.host&&l.activeElement===s&&(d.top.location.href=t.value))}},d.addEventListener(\\"message\\",d.wp.receiveEmbedMessage,!1),l.addEventListener(\\"DOMContentLoaded\\",function(){for(var e,t,s=l.querySelectorAll(\\"iframe.wp-embedded-content\\"),r=0;r<s.length;r++)(t=(e=s[r]).getAttribute(\\"data-secret\\"))||(t=Math.random().toString(36).substring(2,12),e.src+=\\"#?secret=\\"+t,e.setAttribute(\\"data-secret\\",t)),e.contentWindow.postMessage({message:\\"ready\\",secret:t},\\"*\\")},!1)))}(window,document);\\n\\/* ]]> *\\/\\n<\\/script>\\n","type":"rich"}'
];
