<?php
declare(strict_types = 1);

return [
    'authorName' => 'nvanderklippe',
    'authorUrl' => 'https://www.chirbit.com/nvanderklippe',
    'cms' => null,
    'code' => [
        'html' => '<iframe height="120" frameborder="0" width="380" scrolling="NO" src="https://chirb.it/wp/7A9L9B">This browser does not show iframe content. Listen to this chirbit here <a href="https://chirb.it/7A9L9B">https://chirb.it/7A9L9B</a></iframe>',
        'width' => 380,
        'height' => 120,
        'ratio' => 31.579
    ],
    'description' => 'Audio: - social audio',
    'favicon' => 'https://chirb.it/favicon.ico',
    'feeds' => [],
    'icon' => null,
    'image' => 'https://chirb.it/chirbit_oembedpic.jpg',
    'keywords' => [
        'chirbit',
        'social audio',
        '#conference'
    ],
    'language' => null,
    'languages' => [],
    'license' => null,
    'providerName' => 'chirbit',
    'providerUrl' => 'https://www.chirbit.com/',
    'publishedTime' => null,
    'redirect' => null,
    'title' => 'Encana conference call',
    'url' => 'https://chirb.it/7A9L9B',
    'linkedData' => [],
    'oEmbed' => [
        'version' => '1.0',
        'type' => 'rich',
        'provider_name' => 'chirbit',
        'provider_url' => 'https://www.chirbit.com/',
        'thumbnail_url' => 'https://chirb.it/chirbit_oembedpic.jpg',
        'thumbnail_width' => 120,
        'thumbnail_height' => 120,
        'width' => '380',
        'height' => '120',
        'title' => 'Encana conference call',
        'author_name' => 'nvanderklippe',
        'author_url' => 'https://www.chirbit.com/nvanderklippe',
        'html' => '<iframe height="120" frameborder="0" width="380" scrolling="NO" src="https://chirb.it/wp/7A9L9B">This browser does not show iframe content. Listen to this chirbit here <a href="https://chirb.it/7A9L9B">https://chirb.it/7A9L9B</a></iframe>'
    ],
    'allLinkedData' => []
];
