<?php
declare(strict_types = 1);

return [
    'authorName' => 'He-who-photographs-rather-OK',
    'authorUrl' => 'https://he-who-photographs-rather-ok.tumblr.com/',
    'cms' => null,
    'code' => [
        'html' => '<div class="tumblr-post" data-href="https://embed.tumblr.com/embed/post/3sZLmGKnNg-4n8G7mNtxOA/165326273724" data-did="da39a3ee5e6b4b0d3255bfef95601890afd80709" ><a href="https://he-who-photographs-rather-ok.tumblr.com/post/165326273724">https://he-who-photographs-rather-ok.tumblr.com/post/165326273724</a></div><script async src="https://assets.tumblr.com/post.js"></script>',
        'width' => 540,
        'height' => null,
        'ratio' => null
    ],
    'description' => 'Usually minimal editing. Also effort',
    'favicon' => 'https://64.media.tumblr.com/avatar_235be11f6ae4_128.pnj',
    'feeds' => [
        'https://he-who-photographs-rather-ok.tumblr.com/rss'
    ],
    'icon' => 'https://64.media.tumblr.com/avatar_235be11f6ae4_128.pnj',
    'image' => 'https://64.media.tumblr.com/0a0fac1ef8faa0c466d9224567af06aa/tumblr_ow8r0nMybA1spmyulo1_1280.jpg',
    'keywords' => [
        'panda',
        'aesthetic photography',
        'furry',
        'photography',
        'photographers on tumblr'
    ],
    'language' => null,
    'languages' => [],
    'license' => null,
    'providerName' => 'Tumblr',
    'providerUrl' => 'https://www.tumblr.com/',
    'publishedTime' => null,
    'redirect' => null,
    'title' => 'He-who-photographs-rather-OK',
    'url' => 'https://he-who-photographs-rather-ok.tumblr.com/post/165326273724',
    'linkedData' => [
        '@type' => 'SocialMediaPosting',
        'url' => 'https://he-who-photographs-rather-ok.tumblr.com/post/165326273724',
        'mainEntityOfPage' => true,
        'datePublished' => '2017-09-14T10:20:35-04:00',
        'author' => 'he-who-photographs-rather-ok',
        'image' => 'https://64.media.tumblr.com/0a0fac1ef8faa0c466d9224567af06aa/tumblr_ow8r0nMybA1spmyulo1_1280.jpg',
        '@context' => 'http://schema.org'
    ],
    'oEmbed' => [
        'cache_age' => 3600,
        'url' => 'https://he-who-photographs-rather-ok.tumblr.com/post/165326273724',
        'provider_url' => 'https://www.tumblr.com',
        'provider_name' => 'Tumblr',
        'author_name' => 'He-who-photographs-rather-OK',
        'version' => '1.0',
        'author_url' => 'https://he-who-photographs-rather-ok.tumblr.com/',
        'type' => 'rich',
        'html' => '<div class="tumblr-post" data-href="https://embed.tumblr.com/embed/post/3sZLmGKnNg-4n8G7mNtxOA/165326273724" data-did="da39a3ee5e6b4b0d3255bfef95601890afd80709"  ><a href="https://he-who-photographs-rather-ok.tumblr.com/post/165326273724">https://he-who-photographs-rather-ok.tumblr.com/post/165326273724</a></div><script async src="https://assets.tumblr.com/post.js"></script>',
        'height' => null,
        'width' => 540
    ],
    'allLinkedData' => [
        [
            '@type' => 'SocialMediaPosting',
            'url' => 'https://he-who-photographs-rather-ok.tumblr.com/post/165326273724',
            'mainEntityOfPage' => true,
            'datePublished' => '2017-09-14T10:20:35-04:00',
            'author' => 'he-who-photographs-rather-ok',
            'image' => 'https://64.media.tumblr.com/0a0fac1ef8faa0c466d9224567af06aa/tumblr_ow8r0nMybA1spmyulo1_1280.jpg',
            '@context' => 'http://schema.org'
        ]
    ]
];
