<?php
declare(strict_types = 1);

return [
    'authorName' => 'ToddGilbert',
    'authorUrl' => 'https://imageshack.com/ToddGilbert',
    'cms' => null,
    'code' => null,
    'description' => null,
    'favicon' => 'http://imagizer.imageshack.com/favicon.ico',
    'feeds' => [],
    'icon' => null,
    'image' => 'http://imagizer.imageshack.com/img673/0/imagizer.imageshack.com/img673/9643/7wO0v7.jpg',
    'keywords' => [],
    'language' => null,
    'languages' => [],
    'license' => null,
    'providerName' => 'ImageShack',
    'providerUrl' => 'http://imagizer.imageshack.com',
    'publishedTime' => '2015-06-29 22:13:36',
    'redirect' => null,
    'title' => 'Kisses',
    'url' => 'http://imagizer.imageshack.com/img673/0/7wO0v7.jpg',
    'linkedData' => [],
    'oEmbed' => [],
    'api' => [
        'id' => 'ip7wO0v7j',
        'server' => 673,
        'bucket' => 9643,
        'filename' => '7wO0v7.jpg',
        'original_filename' => '249738f8eead6a9fa0cd4a17244ba418.jpg',
        'direct_link' => 'imagizer.imageshack.com/img673/9643/7wO0v7.jpg',
        'title' => 'Kisses',
        'description' => '',
        'tags' => [],
        'likes' => 0,
        'liked' => false,
        'views' => 0,
        'moderated' => false,
        'adult_content' => false,
        'album' => [
            'id' => '',
            'title' => '',
            'public' => false
        ],
        'comments_count' => 0,
        'comments_disabled' => false,
        'filter' => 0,
        'filesize' => 54,
        'creation_date' => 1435616016,
        'width' => 500,
        'height' => 500,
        'public' => true,
        'block_downloading' => false,
        'featured' => false,
        'copyright' => '',
        'is_owner' => false,
        'owner' => [
            'username' => 'ToddGilbert',
            'avatar' => [
                'id' => '59urlsij',
                'filename' => 'urlsi.jpg',
                'server' => 189,
                'cropped' => false,
                'x_pos' => 0,
                'y_pos' => 0,
                'x_length' => 0,
                'y_length' => 0
            ],
            'membership' => 'free',
            'featured_photographer' => false
        ],
        'next_images' => [],
        'prev_images' => []
    ],
    'allLinkedData' => []
];
