<?php
declare(strict_types = 1);

return [
    'authorName' => null,
    'authorUrl' => null,
    'cms' => null,
    'code' => null,
    'description' => null,
    'favicon' => 'https://app-content.photobucket.com/favicon-32x32.png',
    'feeds' => [],
    'icon' => 'https://app-content.photobucket.com/apple-touch-icon.png',
    'image' => 'https://hosting.photobucket.com/albums/h235/Ignwar/SunflowerFieldposter2.jpg',
    'keywords' => [],
    'language' => 'en',
    'languages' => [],
    'license' => null,
    'providerName' => 'Photobucket.com, Inc.',
    'providerUrl' => 'https://app.photobucket.com',
    'publishedTime' => null,
    'redirect' => null,
    'title' => 'My Library',
    'url' => 'https://app.photobucket.com/u/Ignwar?filters%5Bterm%5D=sunsets&filters%5Bprimary%5D=images',
    'linkedData' => [],
    'oEmbed' => [],
    'allLinkedData' => []
];
