<?php
declare(strict_types = 1);

return [
    'authorName' => 'Zeds Dead',
    'authorUrl' => 'https://soundcloud.com/zedsdead',
    'cms' => null,
    'code' => [
        'html' => '<iframe width="100%" height="400" scrolling="no" frameborder="no" src="https://w.soundcloud.com/player/?visual=true&url=https%3A%2F%2Fapi.soundcloud.com%2Ftracks%2F150745932&show_artwork=true"></iframe>',
        'width' => null,
        'height' => 400,
        'ratio' => null
    ],
    'description' => 'MUSIC VIDEO : https://www.youtube.com/watch?v=VJm7IPrBmLY Zeds Dead www.facebook.com/zedsdead www.twitter.com/whoszed www.instagram.com/zedsdeadofficial Twin Shadow www.facebook.com/twnshdw www.twitter.com/twinshadow www.instagram.com/thetwinshadow',
    'favicon' => 'https://a-v2.sndcdn.com/assets/images/sc-icons/favicon-2cadd14bdb.ico',
    'feeds' => [],
    'icon' => 'https://a-v2.sndcdn.com/assets/images/sc-icons/ios-a62dfc8fe7.png',
    'image' => 'https://i1.sndcdn.com/artworks-oWdjh9aVcb1y-0-t500x500.jpg',
    'keywords' => [
        'record',
        'sounds',
        'share',
        'sound',
        'audio',
        'tracks',
        'music',
        'soundcloud'
    ],
    'language' => 'en',
    'languages' => [],
    'license' => null,
    'providerName' => 'SoundCloud',
    'providerUrl' => 'https://soundcloud.com/',
    'publishedTime' => null,
    'redirect' => null,
    'title' => 'Lost You (feat. Twin Shadow & D\'Angelo Lacy) by Zeds Dead',
    'url' => 'https://soundcloud.com/zedsdead/zeds-dead-twin-shadow-lost-you-feat-dangelo-lacy',
    'linkedData' => [],
    'oEmbed' => [
        'version' => 1.0,
        'type' => 'rich',
        'provider_name' => 'SoundCloud',
        'provider_url' => 'https://soundcloud.com',
        'height' => 400,
        'width' => '100%',
        'title' => 'Lost You (feat. Twin Shadow & D\'Angelo Lacy) by Zeds Dead',
        'description' => 'MUSIC VIDEO : https://www.youtube.com/watch?v=VJm7IPrBmLY

Zeds Dead
www.facebook.com/zedsdead
www.twitter.com/whoszed
www.instagram.com/zedsdeadofficial

Twin Shadow
www.facebook.com/twnshdw
www.twitter.com/twinshadow
www.instagram.com/thetwinshadow

',
        'thumbnail_url' => 'https://i1.sndcdn.com/artworks-oWdjh9aVcb1y-0-t500x500.jpg',
        'html' => '<iframe width="100%" height="400" scrolling="no" frameborder="no" src="https://w.soundcloud.com/player/?visual=true&url=https%3A%2F%2Fapi.soundcloud.com%2Ftracks%2F150745932&show_artwork=true"></iframe>',
        'author_name' => 'Zeds Dead',
        'author_url' => 'https://soundcloud.com/zedsdead'
    ],
    'allLinkedData' => []
];
