<?php
declare(strict_types = 1);

return [
    'authorName' => 'WordPress.tv',
    'authorUrl' => 'https://wordpress.tv/author/anonvideoupload/',
    'cms' => 'wordpress',
    'code' => [
        'html' => 'Images, even small ones, can be the biggest files that make up your site. Learn the tools, plugins, and theming techniques you’ll want to start using to shrink your page load times and save your mobile users a few bucks without sacrificing image quality. <a href="http://slides.davidmichaelross.com/image_optimization/#/" target="_blank">Presentation Slides &raquo;</a>',
        'width' => null,
        'height' => null,
        'ratio' => null
    ],
    'description' => 'Images, even small ones, can be the biggest files that make up your site. Learn the tools, plugins, and theming techniques you’ll want to start using to shrink your page load times and save your mo…',
    'favicon' => 'https://s0.wp.com/i/favicon.ico',
    'feeds' => [
        'https://wordpress.tv/feed/'
    ],
    'icon' => 'https://s0.wp.com/i/webclip.png',
    'image' => 'https://videos.files.wordpress.com/TqDCJmoq/optimize-image-files_scruberthumbnail_0.jpg',
    'keywords' => [],
    'language' => 'en',
    'languages' => [],
    'license' => null,
    'providerName' => 'WordPress.tv',
    'providerUrl' => 'http://wordpress.tv/',
    'publishedTime' => '2013-09-06 10:43:21',
    'redirect' => null,
    'title' => 'Dave Ross: Optimize Image Files Like a Pro',
    'url' => 'https://wordpress.tv/2013/09/06/dave-ross-optimize-image-files-like-a-pro/',
    'linkedData' => [
        '@context' => 'https://schema.org',
        '@graph' => [
            [
                '@type' => 'VideoObject',
                'actor' => [
                    [
                        '@type' => 'Person',
                        'name' => 'Dave Ross',
                        'url' => 'https://wordpress.tv/speakers/dave-ross/'
                    ]
                ],
                'name' => 'Dave Ross: Optimize Image Files Like a Pro',
                'url' => 'https://wordpress.tv/2013/09/06/dave-ross-optimize-image-files-like-a-pro/',
                'contentUrl' => [
                    'https://videos.files.wordpress.com/TqDCJmoq/optimize-image-files_hd.mp4',
                    'https://videos.files.wordpress.com/TqDCJmoq/optimize-image-files_dvd.mp4',
                    'https://videos.files.wordpress.com/TqDCJmoq/optimize-image-files_std.mp4'
                ],
                'description' => 'Images, even small ones, can be the biggest files that make up your site. Learn the tools, plugins, and theming techniques you’ll want to start using to shrink your page load times and save your mobile users a few bucks without sacrificing image quality.

Presentation Slides »',
                'duration' => 'P0DT00H29M20S',
                'height' => '1080',
                'inLanguage' => 'en',
                'isFamilyFriendly' => true,
                'thumbnailUrl' => 'https://videos.files.wordpress.com/TqDCJmoq/optimize-image-files_scruberthumbnail_0.jpg',
                'uploadDate' => '2013-09-06',
                'width' => '1920'
            ]
        ]
    ],
    'oEmbed' => [
        'version' => '1.0',
        'provider_name' => 'WordPress.tv',
        'provider_url' => 'http://wordpress.tv',
        'author_name' => 'WordPress.tv',
        'author_url' => 'https://wordpress.tv/author/anonvideoupload/',
        'title' => 'Dave Ross: Optimize Image Files Like a&nbsp;Pro',
        'type' => 'link',
        'html' => 'Images, even small ones, can be the biggest files that make up your site. Learn the tools, plugins, and theming techniques you’ll want to start using to shrink your page load times and save your mobile users a few bucks without sacrificing image quality.

<a href="http://slides.davidmichaelross.com/image_optimization/#/" target="_blank">Presentation Slides &raquo;</a>'
    ],
    'allLinkedData' => [
        [
            '@context' => 'https://schema.org',
            '@graph' => [
                [
                    '@type' => 'VideoObject',
                    'actor' => [
                        [
                            '@type' => 'Person',
                            'name' => 'Dave Ross',
                            'url' => 'https://wordpress.tv/speakers/dave-ross/'
                        ]
                    ],
                    'name' => 'Dave Ross: Optimize Image Files Like a Pro',
                    'url' => 'https://wordpress.tv/2013/09/06/dave-ross-optimize-image-files-like-a-pro/',
                    'contentUrl' => [
                        'https://videos.files.wordpress.com/TqDCJmoq/optimize-image-files_hd.mp4',
                        'https://videos.files.wordpress.com/TqDCJmoq/optimize-image-files_dvd.mp4',
                        'https://videos.files.wordpress.com/TqDCJmoq/optimize-image-files_std.mp4'
                    ],
                    'description' => 'Images, even small ones, can be the biggest files that make up your site. Learn the tools, plugins, and theming techniques you’ll want to start using to shrink your page load times and save your mobile users a few bucks without sacrificing image quality.

Presentation Slides »',
                    'duration' => 'P0DT00H29M20S',
                    'height' => '1080',
                    'inLanguage' => 'en',
                    'isFamilyFriendly' => true,
                    'thumbnailUrl' => 'https://videos.files.wordpress.com/TqDCJmoq/optimize-image-files_scruberthumbnail_0.jpg',
                    'uploadDate' => '2013-09-06',
                    'width' => '1920'
                ]
            ]
        ]
    ]
];
