<?php
declare(strict_types = 1);

return [
    'authorName' => 'redsh0es',
    'authorUrl' => 'http://www.ustream.tv/',
    'cms' => null,
    'code' => [
        'html' => '<iframe width="480" height="302" src="http://ustream.tv/embed/11958409" scrolling="no" frameborder="0" style="border: 0px none transparent;"></iframe><br /><a href="http://developers.video.ibm.com/" title="Live streaming API by Ustream" style="padding: 2px 0px 4px; width: 400px; background: #ffffff; display: block; color: #000000; font-weight: normal; font-size: 10px; text-decoration: underline; text-align: left;" target="_blank">Live Streaming Api</a>',
        'width' => 400,
        'height' => 320,
        'ratio' => 80.0
    ],
    'description' => 'Red Shoes Billiards 12009 S. Pulaski Road Alsip, Illinois 60803 708 388-3700 http://www.redshoesbilliards.com pool, billiards, 8 ball, 9 ball, 10 ball, straight pool, 14.1, banks, one pocket, APA, leagues, tournaments, 9 foot tables, bar tables, bar box, ACS,',
    'favicon' => 'http://static-cdn2.ustream.tv/favicon.ico',
    'feeds' => [],
    'icon' => 'http://static-cdn2.ustream.tv/apple-touch-icon.png',
    'image' => 'https://ustvstaticcdn2-a.akamaihd.net/i/channel/picture/1/1/9/5/11958409/11958409,120x90,r:2.jpg',
    'keywords' => [],
    'language' => 'es',
    'languages' => [],
    'license' => null,
    'providerName' => 'IBM Watson Media',
    'providerUrl' => 'http://www.ustream.tv/',
    'publishedTime' => null,
    'redirect' => null,
    'title' => 'Red Shoes Billiards 1pkt,banks camera 1',
    'url' => 'http://www.ustream.tv/channel/red-shoes-billiards-60803-camera-1',
    'linkedData' => [],
    'oEmbed' => [
        'provider_url' => 'http://www.ustream.tv/',
        'html' => '<iframe width="480" height="302" src="http://ustream.tv/embed/11958409" scrolling="no" frameborder="0" style="border: 0px none transparent;"></iframe><br /><a href="http://developers.video.ibm.com/" title="Live streaming API by Ustream" style="padding: 2px 0px 4px; width: 400px; background: #ffffff; display: block; color: #000000; font-weight: normal; font-size: 10px; text-decoration: underline; text-align: left;" target="_blank">Live Streaming Api</a>',
        'title' => 'Red Shoes Billiards 1pkt,banks camera 1',
        'author_name' => 'redsh0es',
        'height' => 320,
        'thumbnail_width' => 120,
        'width' => 400,
        'version' => '1.0',
        'author_url' => 'http://www.ustream.tv',
        'thumbnail_url' => 'https://ustvstaticcdn2-a.akamaihd.net/i/channel/picture/1/1/9/5/11958409/11958409,120x90,r:2.jpg',
        'type' => 'video',
        'thumbnail_height' => 90
    ],
    'allLinkedData' => []
];
