<?php
declare(strict_types = 1);

return [
    'authorName' => '@itmedia_news',
    'authorUrl' => 'https://twitter.com/itmedia_news',
    'cms' => null,
    'code' => null,
    'description' => 'さくらインターネットが、2025年3月期第2四半期累計（24年4月〜9月）の連結決算を発表した。売上高は132億7100万円（前年同期比28.3％増）、営業利益は12億9500万円（同419.4％増）だった。生成AI需要によってGPUクラウドサービスが伸長したという。',
    'favicon' => 'https://www.itmedia.co.jp/favicon.ico',
    'feeds' => ['https://rss.itmedia.co.jp/rss/2.0/news_bursts.xml'],
    'icon' => null,
    'image' => 'https://image.itmedia.co.jp/news/articles/2410/28/cover_news159.jpg',
    'keywords' => ['速報', 'ai', '生成aiニュース', 'クラウドユーザー', 'ロボット・ai'],
    'language' => 'ja',
    'languages' => [],
    'license' => null,
    'providerName' => 'ITmedia NEWS',
    'providerUrl' => 'https://www.itmedia.co.jp',
    'publishedTime' => '2024-10-28 17:55:00',
    'redirect' => null,
    'title' => 'さくらインターネット、営業利益が前年同期比420％増 GPUクラウド伸長で“生成AIフィーバー”？ 上期決算',
    'url' => 'https://www.itmedia.co.jp/news/articles/2410/28/news159.html',
    'linkedData' => [
        '@context' => 'https://schema.org',
        '@type' => 'NewsArticle',
        'mainEntityOfPage' => [
            '@type' => 'WebPage',
            '@id' => 'https://www.itmedia.co.jp/news/articles/2410/28/news159.html',
        ],
        'image' => ['https://image.itmedia.co.jp/images/logo/1200x630_500x500_news.gif'],
        'datePublished' => '2024-10-28T17:55:00Z',
        'dateModified' => '2024-10-28T18:05:00Z',
        'headline' => 'さくらインターネット、営業利益が前年同期比420％増 GPUクラウド伸長で“生成AIフィーバー”？ 上期決算',
        'publisher' => [
            '@type' => 'Organization',
            'name' => 'ITmedia NEWS',
            'url' => 'https://www.itmedia.co.jp/news/',
            'logo' => [
                '@type' => 'ImageObject',
                'url' => 'https://image.itmedia.co.jp/images/logo/amp_publisher_news.gif',
            ],
        ],
        'description' => 'さくらインターネットが、2025年3月期第2四半期累計（24年4月〜9月）の連結決算を発表した。売上高は132億7100万円（前年同期比28.3％増）、営業利益は12億9500万円（同419.4％増）だった。生成AI需要によってGPUクラウドサービスが伸長したという。',
        'articleSection' => 'ニュース',
        'keywords' => '速報,AI,生成AIニュース,クラウドユーザー,ロボット・AI',
    ],
    'oEmbed' => [],
    'allLinkedData' => [
        [
            '@context' => 'https://schema.org',
            '@type' => 'NewsArticle',
            'mainEntityOfPage' => [
                '@type' => 'WebPage',
                '@id' => 'https://www.itmedia.co.jp/news/articles/2410/28/news159.html',
            ],
            'image' => ['https://image.itmedia.co.jp/images/logo/1200x630_500x500_news.gif'],
            'datePublished' => '2024-10-28T17:55:00Z',
            'dateModified' => '2024-10-28T18:05:00Z',
            'headline' => 'さくらインターネット、営業利益が前年同期比420％増 GPUクラウド伸長で“生成AIフィーバー”？ 上期決算',
            'publisher' => [
                '@type' => 'Organization',
                'name' => 'ITmedia NEWS',
                'url' => 'https://www.itmedia.co.jp/news/',
                'logo' => [
                    '@type' => 'ImageObject',
                    'url' => 'https://image.itmedia.co.jp/images/logo/amp_publisher_news.gif',
                ],
            ],
            'description' => 'さくらインターネットが、2025年3月期第2四半期累計（24年4月〜9月）の連結決算を発表した。売上高は132億7100万円（前年同期比28.3％増）、営業利益は12億9500万円（同419.4％増）だった。生成AI需要によってGPUクラウドサービスが伸長したという。',
            'articleSection' => 'ニュース',
            'keywords' => '速報,AI,生成AIニュース,クラウドユーザー,ロボット・AI',
        ]
    ],
];
