<?php
declare(strict_types = 1);

return [
    'authorName' => 'jeanbamin',
    'authorUrl' => 'https://www.dailymotion.com/jeanbamin',
    'cms' => null,
    'code' => [
        'html' => '<iframe frameborder="0" width="480" height="360" src="https://www.dailymotion.com/embed/video/xy0wd" allowfullscreen allow="autoplay"></iframe>',
        'width' => 480,
        'height' => 360,
        'ratio' => 75.0
    ],
    'description' => 'Regardez Chats paresseux - jeanbamin sur Dailymotion',
    'favicon' => 'https://static1.dmcdn.net/images/neon/favicons/android-icon-36x36.png.vef49e2d9e48d19cf2',
    'feeds' => [],
    'icon' => 'https://static1.dmcdn.net/images/neon/favicons/apple-icon-precomposed.png.v668e5fde9462cb3a2',
    'image' => 'https://s2.dmcdn.net/v/63aD1VtIdtBWR7nC/x240',
    'keywords' => [],
    'language' => 'en',
    'languages' => [],
    'license' => null,
    'providerName' => 'Dailymotion',
    'providerUrl' => 'https://www.dailymotion.com/',
    'publishedTime' => '2007-01-08 11:41:29',
    'redirect' => null,
    'title' => 'Chats paresseux',
    'url' => 'https://www.dailymotion.com/video/xy0wd',
    'linkedData' => [],
    'oEmbed' => [
        'type' => 'video',
        'version' => '1.0',
        'provider_name' => 'Dailymotion',
        'provider_url' => 'https://www.dailymotion.com',
        'title' => 'Chats paresseux',
        'description' => '',
        'author_name' => 'jeanbamin',
        'author_url' => 'https://www.dailymotion.com/jeanbamin',
        'width' => 480,
        'height' => 360,
        'html' => '<iframe frameborder="0" width="480" height="360" src="https://www.dailymotion.com/embed/video/xy0wd" allowfullscreen allow="autoplay"></iframe>',
        'thumbnail_url' => 'https://s2.dmcdn.net/v/63aD1VtIdtBWR7nC/x240',
        'thumbnail_width' => 320,
        'thumbnail_height' => 240
    ],
    'allLinkedData' => []
];
