<?php
declare(strict_types = 1);

return [
    'authorName' => null,
    'authorUrl' => null,
    'cms' => null,
    'code' => [
        'html' => '<div id="snipplr_embed_72914" class="snipplr_embed"><a target="blank" href="https://snipplr.com/view/72914">View this snippet</a> on Snipplr</div><script type="text/javascript" src="https://snipplr.com/js/embed.js"></script><script type="text/javascript" src="https://snipplr.com/json/72914"></script>',
        'width' => null,
        'height' => null,
        'ratio' => null
    ],
    'description' => null,
    'favicon' => 'https://snipplr.com/favicon.ico?v3',
    'feeds' => [],
    'icon' => null,
    'image' => null,
    'keywords' => [],
    'language' => 'en',
    'languages' => [],
    'license' => null,
    'providerName' => 'Snipplr',
    'providerUrl' => 'https://snipplr.com',
    'publishedTime' => null,
    'redirect' => null,
    'title' => 'Better HTML 5 basic starter template - HTML Snipplr Social Repository',
    'url' => 'https://snipplr.com/view/72914/better-html-5-basic-starter-template',
    'linkedData' => [],
    'oEmbed' => [],
    'allLinkedData' => []
];
