<?php
declare(strict_types = 1);

return [
    'authorName' => 'Radio Freedom .us',
    'authorUrl' => 'https://www.spreaker.com/user/angelclark',
    'cms' => null,
    'code' => [
        'html' => '<iframe src="https://widget.spreaker.com/player?episode_key=BbMeV2n1A4r3--7657563&amp;theme=light&amp;playlist=false&amp;cover_image_url=https%3A%2F%2Fd3wo5wojvuv7l.cloudfront.net%2Fimages.spreaker.com%2Foriginal%2F07176451fd3625d19c5e5d88d9f1bfbb.jpg" width="640" height="480" frameborder="0"></iframe>',
        'width' => 640,
        'height' => 480,
        'ratio' => 75.0
    ],
    'description' => 'Listen in to popular podcasts and radio shows from around the world or start your own with Spreaker!',
    'favicon' => 'https://d1sojsgu0jwtb7.cloudfront.net/images/favicons/favicon.ico',
    'feeds' => [],
    'icon' => 'https://d1sojsgu0jwtb7.cloudfront.net/images/favicons/apple_touch_114.png',
    'image' => 'https://d3wo5wojvuv7l.cloudfront.net/t_widget_player_cover_medium/images.spreaker.com/original/07176451fd3625d19c5e5d88d9f1bfbb.jpg',
    'keywords' => [],
    'language' => 'en',
    'languages' => [],
    'license' => null,
    'providerName' => 'Spreaker',
    'providerUrl' => 'https://www.spreaker.com/',
    'publishedTime' => null,
    'redirect' => null,
    'title' => 'Angel Clark: Ice Cream Toco\'s - Angel Clark Show',
    'url' => 'https://www.spreaker.com/user/angelclark/angel-clark-ice-cream-tocos',
    'linkedData' => [],
    'oEmbed' => [
        'type' => 'rich',
        'version' => '1.0',
        'provider_name' => 'Spreaker',
        'provider_url' => 'https://www.spreaker.com/',
        'title' => 'Angel Clark: Ice Cream Toco\'s - Angel Clark Show',
        'author_name' => 'Radio Freedom .us',
        'author_url' => 'https://www.spreaker.com/user/angelclark',
        'html' => '<iframe src="https://widget.spreaker.com/player?episode_key=BbMeV2n1A4r3--7657563&amp;theme=light&amp;playlist=false&amp;cover_image_url=https%3A%2F%2Fd3wo5wojvuv7l.cloudfront.net%2Fimages.spreaker.com%2Foriginal%2F07176451fd3625d19c5e5d88d9f1bfbb.jpg" width="640" height="480" frameborder="0"></iframe>',
        'width' => 640,
        'height' => 480,
        'thumbnail_url' => 'https://d3wo5wojvuv7l.cloudfront.net/t_widget_player_cover_medium/images.spreaker.com/original/07176451fd3625d19c5e5d88d9f1bfbb.jpg'
    ],
    'allLinkedData' => []
];
