<?php
declare(strict_types = 1);

return [
    'authorName' => 'Vimeo',
    'authorUrl' => 'https://vimeo.com/vimeomarketing',
    'cms' => null,
    'code' => [
        'html' => '<iframe src="https://player.vimeo.com/video/235352744?app_id=122963" width="640" height="360" frameborder="0" allow="autoplay; fullscreen; picture-in-picture" allowfullscreen title="Vimeo Live is here"></iframe>',
        'width' => 640,
        'height' => 360,
        'ratio' => 56.25
    ],
    'description' => 'Professional live streaming is here. Learn more at vimeo.com/live',
    'favicon' => 'https://f.vimeocdn.com/images_v6/favicon.ico?e6c6fc9ed4e4b0b057ecead0028781d1beb5476c',
    'feeds' => [],
    'icon' => 'https://i.vimeocdn.com/favicon/main-touch_180',
    'image' => 'https://i.vimeocdn.com/video/657162424_640.jpg',
    'keywords' => [],
    'language' => 'en',
    'languages' => [],
    'license' => null,
    'providerName' => 'Vimeo',
    'providerUrl' => 'https://vimeo.com/',
    'publishedTime' => null,
    'redirect' => null,
    'title' => 'Vimeo Live is here',
    'url' => 'https://vimeo.com/235352744',
    'linkedData' => [
        'url' => 'https://vimeo.com/235352744',
        'thumbnailUrl' => 'https://i.vimeocdn.com/filter/overlay?src0=https%3A%2F%2Fi.vimeocdn.com%2Fvideo%2F657162424_1280x720.jpg&src1=https%3A%2F%2Ff.vimeocdn.com%2Fimages_v6%2Fshare%2Fplay_icon_overlay.png',
        'embedUrl' => 'https://player.vimeo.com/video/235352744',
        'name' => 'Vimeo Live is here',
        'description' => 'Professional live streaming is here. Learn more at vimeo.com/live',
        'height' => 1080,
        'width' => 1920,
        'playerType' => 'HTML5 Flash',
        'videoQuality' => 'HD',
        'duration' => 'PT00H01M15S',
        'uploadDate' => '2017-09-25T10:36:56-04:00',
        'dateModified' => '2021-04-04T08:57:58-04:00',
        'thumbnail' => [
            '@type' => 'ImageObject',
            'url' => 'https://i.vimeocdn.com/filter/overlay?src0=https%3A%2F%2Fi.vimeocdn.com%2Fvideo%2F657162424_1280x720.jpg&src1=https%3A%2F%2Ff.vimeocdn.com%2Fimages_v6%2Fshare%2Fplay_icon_overlay.png',
            'width' => 1280,
            'height' => 720
        ],
        'author' => [
            '@type' => 'Person',
            'name' => 'Vimeo',
            'url' => 'https://vimeo.com/vimeomarketing'
        ],
        'potentialAction' => [
            '@type' => 'ViewAction',
            'target' => 'vimeo://app.vimeo.com/videos/235352744'
        ],
        '@type' => 'VideoObject',
        '@context' => 'http://schema.org'
    ],
    'oEmbed' => [
        'type' => 'video',
        'version' => '1.0',
        'provider_name' => 'Vimeo',
        'provider_url' => 'https://vimeo.com/',
        'title' => 'Vimeo Live is here',
        'author_name' => 'Vimeo',
        'author_url' => 'https://vimeo.com/vimeomarketing',
        'is_plus' => '0',
        'account_type' => 'live_premium',
        'html' => '<iframe src="https://player.vimeo.com/video/235352744?app_id=122963" width="640" height="360" frameborder="0" allow="autoplay; fullscreen; picture-in-picture" allowfullscreen title="Vimeo Live is here"></iframe>',
        'width' => 640,
        'height' => 360,
        'duration' => 75,
        'description' => 'Professional live streaming is here. 

Learn more at vimeo.com/live',
        'thumbnail_url' => 'https://i.vimeocdn.com/video/657162424_640.jpg',
        'thumbnail_width' => 640,
        'thumbnail_height' => 360,
        'thumbnail_url_with_play_button' => 'https://i.vimeocdn.com/filter/overlay?src0=https%3A%2F%2Fi.vimeocdn.com%2Fvideo%2F657162424_640.jpg&src1=http%3A%2F%2Ff.vimeocdn.com%2Fp%2Fimages%2Fcrawler_play.png',
        'upload_date' => '2017-09-25 10:36:56',
        'video_id' => 235352744,
        'uri' => '/videos/235352744'
    ],
    'allLinkedData' => [
        [
            'url' => 'https://vimeo.com/235352744',
            'thumbnailUrl' => 'https://i.vimeocdn.com/filter/overlay?src0=https%3A%2F%2Fi.vimeocdn.com%2Fvideo%2F657162424_1280x720.jpg&src1=https%3A%2F%2Ff.vimeocdn.com%2Fimages_v6%2Fshare%2Fplay_icon_overlay.png',
            'embedUrl' => 'https://player.vimeo.com/video/235352744',
            'name' => 'Vimeo Live is here',
            'description' => 'Professional live streaming is here. Learn more at vimeo.com/live',
            'height' => 1080,
            'width' => 1920,
            'playerType' => 'HTML5 Flash',
            'videoQuality' => 'HD',
            'duration' => 'PT00H01M15S',
            'uploadDate' => '2017-09-25T10:36:56-04:00',
            'dateModified' => '2021-04-04T08:57:58-04:00',
            'thumbnail' => [
                '@type' => 'ImageObject',
                'url' => 'https://i.vimeocdn.com/filter/overlay?src0=https%3A%2F%2Fi.vimeocdn.com%2Fvideo%2F657162424_1280x720.jpg&src1=https%3A%2F%2Ff.vimeocdn.com%2Fimages_v6%2Fshare%2Fplay_icon_overlay.png',
                'width' => 1280,
                'height' => 720
            ],
            'author' => [
                '@type' => 'Person',
                'name' => 'Vimeo',
                'url' => 'https://vimeo.com/vimeomarketing'
            ],
            'potentialAction' => [
                '@type' => 'ViewAction',
                'target' => 'vimeo://app.vimeo.com/videos/235352744'
            ],
            '@type' => 'VideoObject',
            '@context' => 'http://schema.org'
        ],
        [
            'itemListElement' => [
                [
                    '@type' => 'ListItem',
                    'position' => 1,
                    'item' => [
                        '@id' => 'https://vimeo.com/vimeomarketing',
                        'name' => 'Vimeo'
                    ]
                ],
                [
                    '@type' => 'ListItem',
                    'position' => 2,
                    'item' => [
                        '@id' => 'https://vimeo.com/vimeomarketing/videos',
                        'name' => 'Videos'
                    ]
                ]
            ],
            '@type' => 'BreadcrumbList',
            '@context' => 'http://schema.org'
        ]
    ]
];
