<?php
declare(strict_types = 1);

return [
    'authorName' => null,
    'authorUrl' => null,
    'cms' => null,
    'code' => null,
    'description' => null,
    'favicon' => 'https://st.deviantart.net/eclipse/icons/da_favicon_v2.ico',
    'feeds' => [],
    'icon' => 'https://st.deviantart.net/eclipse/icons/ios-180.png',
    'image' => 'https://images-wixmp-ed30a86b8c4ca887773594c2.wixmp.com/f/2b5a457d-dde7-459a-badf-774e8e506025/d2enxz7-431ca9c3-987f-4b2d-ae6a-cbbdd1c0e2bf.jpg/v1/fill/w_448,h_672,q_75,strp/cope_by_pachunka_d2enxz7-fullview.jpg?token=eyJ0eXAiOiJKV1QiLCJhbGciOiJIUzI1NiJ9.eyJzdWIiOiJ1cm46YXBwOiIsImlzcyI6InVybjphcHA6Iiwib2JqIjpbW3siaGVpZ2h0IjoiPD02NzIiLCJwYXRoIjoiXC9mXC8yYjVhNDU3ZC1kZGU3LTQ1OWEtYmFkZi03NzRlOGU1MDYwMjVcL2QyZW54ejctNDMxY2E5YzMtOTg3Zi00YjJkLWFlNmEtY2JiZGQxYzBlMmJmLmpwZyIsIndpZHRoIjoiPD00NDgifV1dLCJhdWQiOlsidXJuOnNlcnZpY2U6aW1hZ2Uub3BlcmF0aW9ucyJdfQ.uKXtzi4RcaE2A5UkAveDjAmXMGj3gam4jIvj8BugRo4',
    'keywords' => [],
    'language' => 'en',
    'languages' => [],
    'license' => null,
    'providerName' => 'Deviantart',
    'providerUrl' => 'https://www.deviantart.com',
    'publishedTime' => null,
    'redirect' => null,
    'title' => 'Cope by pachunka on DeviantArt',
    'url' => 'https://www.deviantart.com/pachunka/art/Cope-145564099',
    'linkedData' => [],
    'oEmbed' => [],
    'allLinkedData' => []
];
