<?php
declare(strict_types = 1);

return [
    'authorName' => 'Leslie Carruthers',
    'authorUrl' => 'https://www.pinterest.com/thesearchguru/',
    'cms' => null,
    'code' => [
        'html' => '<iframe src="https://assets.pinterest.com/ext/embed.html?id=106890191127977979&src=oembed" height="663" width="450" frameborder="0" scrolling="no" ></iframe>',
        'width' => 450,
        'height' => 663,
        'ratio' => 147.333
    ],
    'description' => 'Apr 21, 2012 - This Pin was discovered by Leslie Carruthers. Discover (and save!) your own Pins on Pinterest',
    'favicon' => 'https://s.pinimg.com/webapp/favicon-54a5b2af.png',
    'feeds' => [],
    'icon' => 'https://s.pinimg.com/webapp/logo_trans_144x144-5e37c0c6.png',
    'image' => 'https://i.pinimg.com/236x/b5/34/13/b53413787f3a42c8b9d5b08a6fbb2124--jack-nicholson-jack-oconnell.jpg',
    'keywords' => [],
    'language' => 'en',
    'languages' => [],
    'license' => null,
    'providerName' => 'Pinterest',
    'providerUrl' => 'https://www.pinterest.com/',
    'publishedTime' => null,
    'redirect' => null,
    'title' => 'Pourparler',
    'url' => 'https://www.pinterest.com/pin/106890191127977979/',
    'linkedData' => [],
    'oEmbed' => [
        'version' => '1.0',
        'type' => 'rich',
        'provider_name' => 'Pinterest',
        'provider_url' => 'https://www.pinterest.com',
        'width' => 450,
        'height' => 663,
        'title' => 'Pourparler',
        'author_name' => 'Leslie Carruthers',
        'author_url' => 'https://www.pinterest.com/thesearchguru/',
        'html' => '<iframe src="https://assets.pinterest.com/ext/embed.html?id=106890191127977979&src=oembed" height="663" width="450" frameborder="0" scrolling="no" ></iframe>',
        'thumbnail_url' => 'https://i.pinimg.com/236x/b5/34/13/b53413787f3a42c8b9d5b08a6fbb2124--jack-nicholson-jack-oconnell.jpg',
        'thumbnail_width' => 236,
        'thumbnail_height' => 295
    ],
    'allLinkedData' => []
];
