<?php
declare(strict_types = 1);

return [
    'authorName' => '@politico',
    'authorUrl' => 'https://twitter.com/politico',
    'cms' => null,
    'code' => [
        'html' => '<script type="text/javascript" src="https://www.politico.com/story/2013/12/presidents-barack-obama-george-w-bush-second-term-101314?_embed=true&amp;_format=js"></script>',
        'width' => null,
        'height' => null,
        'ratio' => null
    ],
    'description' => 'To veterans of the Bush White House, what Obama is going through is all too predictable.',
    'favicon' => 'https://static.politico.com/cf/05/ee684a274496b04fa20ba2978da1/politico.png',
    'feeds' => [],
    'icon' => 'https://static.politico.com/dims4/default/bd69088/2147483647/legacy_thumbnail/144x144/quality/90/?url=https%3A%2F%2Fstatic.politico.com%2Fcf%2F05%2Fee684a274496b04fa20ba2978da1%2Fpolitico.png',
    'image' => 'http://s3-origin-images.politico.com/2013/12/18/131218_george_w_bush_barack_obama_ap_605.jpg',
    'keywords' => [
        'presidents (110)',
        'barack obama (11857)',
        'white house (2586)',
        'second term (10)',
        'george w. bush (753)'
    ],
    'language' => 'en',
    'languages' => [],
    'license' => null,
    'providerName' => 'POLITICO',
    'providerUrl' => 'https://www.politico.com',
    'publishedTime' => null,
    'redirect' => null,
    'title' => 'Obama 2nd term: Echoes of Bush',
    'url' => 'https://www.politico.com/story/2013/12/presidents-barack-obama-george-w-bush-second-term-101314',
    'linkedData' => [],
    'oEmbed' => [
        'version' => '1.0',
        'type' => 'rich',
        'html' => '<script type="text/javascript" src="https://www.politico.com/story/2013/12/presidents-barack-obama-george-w-bush-second-term-101314?_embed=true&amp;_format=js"></script>'
    ],
    'allLinkedData' => []
];
