<?php
declare(strict_types = 1);

return [
    'authorName' => 'Oliver Ponce and Erin Shotwell',
    'authorUrl' => 'https://www.kickstarter.com/profile/1452363698',
    'cms' => null,
    'code' => [
        'html' => '<iframe src="https://www.kickstarter.com/projects/1452363698/good-seed-craft-veggie-burgers/widget/video.html" height="270.0" width="480" frameborder="0" scrolling="no"></iframe>',
        'width' => 480,
        'height' => 270,
        'ratio' => 56.25
    ],
    'description' => 'Nutrient-dense Real Food! Good Seed hemp patties transform the veggie burger with bold flavor blends & sprouted superfood ingredients.',
    'favicon' => 'https://www.kickstarter.com/favicon.ico',
    'feeds' => [],
    'icon' => null,
    'image' => 'https://ksr-ugc.imgix.net/assets/011/647/643/9e80f11b5b125b5b50d1694cbf7f0ba0_original.jpg?ixlib=rb-2.1.0&crop=faces&w=560&h=315&fit=crop&v=1463686200&auto=format&frame=1&q=92&s=551e5f9430e497f3954a21ab81b30c6a',
    'keywords' => [],
    'language' => 'en',
    'languages' => [],
    'license' => null,
    'providerName' => 'Kickstarter',
    'providerUrl' => 'https://www.kickstarter.com/',
    'publishedTime' => null,
    'redirect' => null,
    'title' => 'Good Seed Craft Veggie Burgers',
    'url' => 'https://www.kickstarter.com/projects/1452363698/good-seed-craft-veggie-burgers',
    'linkedData' => [],
    'oEmbed' => [
        'version' => '1.0',
        'type' => 'rich',
        'provider_name' => 'Kickstarter',
        'provider_url' => 'https://www.kickstarter.com/',
        'title' => 'Good Seed Craft Veggie Burgers',
        'author_name' => 'Oliver Ponce and Erin Shotwell',
        'author_url' => 'https://www.kickstarter.com/profile/1452363698',
        'thumbnail_url' => 'https://ksr-ugc.imgix.net/assets/011/647/643/9e80f11b5b125b5b50d1694cbf7f0ba0_original.jpg?ixlib=rb-2.1.0&crop=faces&w=560&h=315&fit=crop&v=1463686200&auto=format&frame=1&q=92&s=551e5f9430e497f3954a21ab81b30c6a',
        'thumbnail_width' => 560,
        'thumbnail_height' => 315.0,
        'width' => 480,
        'height' => 270.0,
        'html' => '<iframe src="https://www.kickstarter.com/projects/1452363698/good-seed-craft-veggie-burgers/widget/video.html" height="270.0" width="480" frameborder="0" scrolling="no"></iframe>'
    ],
    'allLinkedData' => []
];
