<?php
declare(strict_types = 1);

return [
    'authorName' => null,
    'authorUrl' => null,
    'cms' => null,
    'code' => null,
    'description' => null,
    'favicon' => 'https://500px.com/favicon.ico',
    'feeds' => [],
    'icon' => null,
    'image' => null,
    'keywords' => [],
    'language' => 'en',
    'languages' => [],
    'license' => null,
    'providerName' => '500px',
    'providerUrl' => 'https://500px.com',
    'publishedTime' => null,
    'redirect' => null,
    'title' => '500px',
    'url' => 'https://500px.com/photo/138251239/taganay-park-by-daniel-kordan',
    'linkedData' => [],
    'oEmbed' => [],
    'allLinkedData' => []
];
