<?php
declare(strict_types = 1);

return [
    'authorName' => null,
    'authorUrl' => null,
    'cms' => null,
    'code' => [
        'html' => '<iframe src="https://bandcamp.com/EmbeddedPlayer/v=2/track=2592086951/size=large/tracklist=false/artwork=small/" frameborder="0" width="350" height="467" allowTransparency="true"></iframe>',
        'width' => 350,
        'height' => 467,
        'ratio' => 133.429
    ],
    'description' => 'from the album Symmetry',
    'favicon' => 'https://f4.bcbits.com/img/a3289609405_3.jpg',
    'feeds' => [],
    'icon' => 'https://f4.bcbits.com/img/a3289609405_3.jpg',
    'image' => 'https://f4.bcbits.com/img/a3289609405_5.jpg',
    'keywords' => [
        'rock',
        'ambient',
        'electro-rock',
        'instrumental',
        'interstellar',
        'sept sorts'
    ],
    'language' => null,
    'languages' => [],
    'license' => null,
    'providerName' => 'Bandcamp',
    'providerUrl' => 'https://jeanjean.bandcamp.com',
    'publishedTime' => '2013-09-15 08:45:29',
    'redirect' => null,
    'title' => 'Coquin L\'éléphant, by Jean Jean',
    'url' => 'https://jeanjean.bandcamp.com/track/coquin-l-l-phant',
    'linkedData' => [
        'copyrightNotice' => 'All Rights Reserved',
        '@id' => 'https://jeanjean.bandcamp.com/track/coquin-l-l-phant',
        'inAlbum' => [
            '@id' => 'https://jeanjean.bandcamp.com/album/symmetry',
            '@type' => 'MusicAlbum',
            'name' => 'Symmetry'
        ],
        '@type' => [
            'MusicRecording',
            'Product'
        ],
        'byArtist' => [
            'subjectOf' => [
                [
                    '@type' => 'WebSite',
                    'url' => 'https://jeanjean.bandcamp.com/music',
                    'name' => 'music'
                ],
                [
                    '@type' => 'WebSite',
                    'url' => 'https://jeanjean.bandcamp.com/merch',
                    'name' => 'merch'
                ],
                [
                    '@type' => 'WebSite',
                    'url' => 'https://jeanjean.bandcamp.com/community',
                    'name' => 'community'
                ]
            ],
            '@id' => 'https://jeanjean.bandcamp.com',
            'genre' => 'https://bandcamp.com/tag/rock',
            '@type' => 'MusicGroup',
            'image' => 'https://f4.bcbits.com/img/0012283751_10.jpg',
            'additionalProperty' => [
                [
                    'value' => 1235691216,
                    '@type' => 'PropertyValue',
                    'name' => 'band_id'
                ],
                [
                    'value' => 'EUR',
                    '@type' => 'PropertyValue',
                    'name' => 'currency'
                ]
            ],
            'sameAs' => [
                'http://www.facebook.com/jeanjeanmusic',
                'https://www.instagram.com/wearejeanjean/',
                'http://www.youtube.com/channel/UCOsMtEsuiqbqkFQ9oyqJhHg',
                'http://jeanjeanband.com/',
                'https://twitter.com/jeanjeanband'
            ],
            'name' => 'Jean Jean'
        ],
        '@context' => 'https://schema.org',
        'duration' => 'P00H03M46S',
        'offers' => [
            'priceSpecification' => [
                'minPrice' => 1.0
            ],
            'priceCurrency' => 'EUR',
            '@type' => 'Offer',
            'additionalProperty' => [
                [
                    'value' => 2,
                    '@type' => 'PropertyValue',
                    'name' => 'download_pref'
                ],
                [
                    'value' => 1000.0,
                    '@type' => 'PropertyValue',
                    'name' => 'max_price'
                ],
                [
                    'value' => 1.0,
                    '@type' => 'PropertyValue',
                    'name' => 'min_price'
                ]
            ],
            'url' => 'https://jeanjean.bandcamp.com/track/coquin-l-l-phant#buy',
            'price' => 1.0,
            'availability' => 'OnlineOnly'
        ],
        'additionalProperty' => [
            [
                'value' => 2592086951,
                '@type' => 'PropertyValue',
                'name' => 'track_id'
            ],
            [
                'value' => 226.251,
                '@type' => 'PropertyValue',
                'name' => 'duration_secs'
            ],
            [
                'value' => 'https://t4.bcbits.com/stream/3a7928de52d6fa132b127481f7d9a0ea/mp3-128/2592086951?p=0&ts=1617636205&t=bec14e3e148c574bf56676ba4812a85d61d12561&token=1617636205_d1a065da6309e56a0174b61186b74b9e383f81d3',
                '@type' => 'PropertyValue',
                'name' => 'file_mp3-128'
            ],
            [
                'value' => 'all_rights_reserved',
                '@type' => 'PropertyValue',
                'name' => 'license_name'
            ],
            [
                'value' => true,
                '@type' => 'PropertyValue',
                'name' => 'streaming'
            ]
        ],
        'dateModified' => '13 Sep 2013 18:03:29 GMT',
        'image' => 'https://f4.bcbits.com/img/a3289609405_10.jpg',
        'name' => 'Coquin L\'éléphant',
        'datePublished' => '15 Sep 2013 08:45:29 GMT',
        'keywords' => [
            'Rock',
            'ambient',
            'electro-rock',
            'instrumental',
            'interstellar',
            'Sept Sorts'
        ],
        'sponsor' => [
            [
                '@type' => 'Person',
                'url' => 'https://bandcamp.com/jaredremillard',
                'image' => 'https://f4.bcbits.com/img/0001850798_10.jpg',
                'name' => 'Jared ReMillard'
            ],
            [
                '@type' => 'Person',
                'url' => 'https://bandcamp.com/sheebypanda',
                'image' => 'https://f4.bcbits.com/img/0004764347_10.jpg',
                'name' => 'SheebyPanda'
            ],
            [
                '@type' => 'Person',
                'url' => 'https://bandcamp.com/tylerthornhill',
                'image' => 'https://f4.bcbits.com/img/0001705921_10.jpg',
                'name' => 'Tyler Thornhill'
            ]
        ]
    ],
    'oEmbed' => [],
    'allLinkedData' => [
        [
            'copyrightNotice' => 'All Rights Reserved',
            '@id' => 'https://jeanjean.bandcamp.com/track/coquin-l-l-phant',
            'inAlbum' => [
                '@id' => 'https://jeanjean.bandcamp.com/album/symmetry',
                '@type' => 'MusicAlbum',
                'name' => 'Symmetry'
            ],
            '@type' => [
                'MusicRecording',
                'Product'
            ],
            'byArtist' => [
                'subjectOf' => [
                    [
                        '@type' => 'WebSite',
                        'url' => 'https://jeanjean.bandcamp.com/music',
                        'name' => 'music'
                    ],
                    [
                        '@type' => 'WebSite',
                        'url' => 'https://jeanjean.bandcamp.com/merch',
                        'name' => 'merch'
                    ],
                    [
                        '@type' => 'WebSite',
                        'url' => 'https://jeanjean.bandcamp.com/community',
                        'name' => 'community'
                    ]
                ],
                '@id' => 'https://jeanjean.bandcamp.com',
                'genre' => 'https://bandcamp.com/tag/rock',
                '@type' => 'MusicGroup',
                'image' => 'https://f4.bcbits.com/img/0012283751_10.jpg',
                'additionalProperty' => [
                    [
                        'value' => 1235691216,
                        '@type' => 'PropertyValue',
                        'name' => 'band_id'
                    ],
                    [
                        'value' => 'EUR',
                        '@type' => 'PropertyValue',
                        'name' => 'currency'
                    ]
                ],
                'sameAs' => [
                    'http://www.facebook.com/jeanjeanmusic',
                    'https://www.instagram.com/wearejeanjean/',
                    'http://www.youtube.com/channel/UCOsMtEsuiqbqkFQ9oyqJhHg',
                    'http://jeanjeanband.com/',
                    'https://twitter.com/jeanjeanband'
                ],
                'name' => 'Jean Jean'
            ],
            '@context' => 'https://schema.org',
            'duration' => 'P00H03M46S',
            'offers' => [
                'priceSpecification' => [
                    'minPrice' => 1.0
                ],
                'priceCurrency' => 'EUR',
                '@type' => 'Offer',
                'additionalProperty' => [
                    [
                        'value' => 2,
                        '@type' => 'PropertyValue',
                        'name' => 'download_pref'
                    ],
                    [
                        'value' => 1000.0,
                        '@type' => 'PropertyValue',
                        'name' => 'max_price'
                    ],
                    [
                        'value' => 1.0,
                        '@type' => 'PropertyValue',
                        'name' => 'min_price'
                    ]
                ],
                'url' => 'https://jeanjean.bandcamp.com/track/coquin-l-l-phant#buy',
                'price' => 1.0,
                'availability' => 'OnlineOnly'
            ],
            'additionalProperty' => [
                [
                    'value' => 2592086951,
                    '@type' => 'PropertyValue',
                    'name' => 'track_id'
                ],
                [
                    'value' => 226.251,
                    '@type' => 'PropertyValue',
                    'name' => 'duration_secs'
                ],
                [
                    'value' => 'https://t4.bcbits.com/stream/3a7928de52d6fa132b127481f7d9a0ea/mp3-128/2592086951?p=0&ts=1617636205&t=bec14e3e148c574bf56676ba4812a85d61d12561&token=1617636205_d1a065da6309e56a0174b61186b74b9e383f81d3',
                    '@type' => 'PropertyValue',
                    'name' => 'file_mp3-128'
                ],
                [
                    'value' => 'all_rights_reserved',
                    '@type' => 'PropertyValue',
                    'name' => 'license_name'
                ],
                [
                    'value' => true,
                    '@type' => 'PropertyValue',
                    'name' => 'streaming'
                ]
            ],
            'dateModified' => '13 Sep 2013 18:03:29 GMT',
            'image' => 'https://f4.bcbits.com/img/a3289609405_10.jpg',
            'name' => 'Coquin L\'éléphant',
            'datePublished' => '15 Sep 2013 08:45:29 GMT',
            'keywords' => [
                'Rock',
                'ambient',
                'electro-rock',
                'instrumental',
                'interstellar',
                'Sept Sorts'
            ],
            'sponsor' => [
                [
                    '@type' => 'Person',
                    'url' => 'https://bandcamp.com/jaredremillard',
                    'image' => 'https://f4.bcbits.com/img/0001850798_10.jpg',
                    'name' => 'Jared ReMillard'
                ],
                [
                    '@type' => 'Person',
                    'url' => 'https://bandcamp.com/sheebypanda',
                    'image' => 'https://f4.bcbits.com/img/0004764347_10.jpg',
                    'name' => 'SheebyPanda'
                ],
                [
                    '@type' => 'Person',
                    'url' => 'https://bandcamp.com/tylerthornhill',
                    'image' => 'https://f4.bcbits.com/img/0001705921_10.jpg',
                    'name' => 'Tyler Thornhill'
                ]
            ]
        ]
    ]
];
