<?php
declare(strict_types = 1);

return [
    'authorName' => 'Gabin Aureche',
    'authorUrl' => 'https://codepen.io/Zhouzi/',
    'cms' => null,
    'code' => [
        'html' => '<iframe id="cp_embed_JoRazP" src="https://codepen.io/Zhouzi/embed/preview/JoRazP?height=300&amp;slug-hash=JoRazP&amp;default-tabs=js,result&amp;host=https://codepen.io" title="TheaterJS" scrolling="no" frameborder="0" height="300" allowtransparency="true" class="cp_embed_iframe" style="width: 100%; overflow: hidden;"></iframe>',
        'width' => 800,
        'height' => 300,
        'ratio' => 37.5
    ],
    'description' => null,
    'favicon' => 'https://codepen.io/favicon.ico',
    'feeds' => [],
    'icon' => null,
    'image' => 'https://assets.codepen.io/99102/internal/screenshots/pens/JoRazP.default.png?fit=cover&format=auto&ha=true&height=360&quality=75&v=2&version=1467971314&width=640',
    'keywords' => [],
    'language' => 'en-US',
    'languages' => [],
    'license' => null,
    'providerName' => 'CodePen',
    'providerUrl' => 'https://codepen.io/',
    'publishedTime' => null,
    'redirect' => null,
    'title' => 'TheaterJS',
    'url' => 'https://codepen.io/Zhouzi/pen/JoRazP',
    'linkedData' => [],
    'oEmbed' => [
        'success' => true,
        'type' => 'rich',
        'version' => '1.0',
        'provider_name' => 'CodePen',
        'provider_url' => 'https://codepen.io',
        'title' => 'TheaterJS',
        'author_name' => 'Gabin Aureche',
        'author_url' => 'https://codepen.io/Zhouzi/',
        'height' => '300',
        'width' => '800',
        'thumbnail_width' => '384',
        'thumbnail_height' => '225',
        'thumbnail_url' => 'https://assets.codepen.io/99102/internal/screenshots/pens/JoRazP.default.png?fit=cover&amp;format=auto&amp;ha=true&amp;height=360&amp;quality=75&amp;v=2&amp;version=1467971314&amp;width=640',
        'html' => '<iframe id="cp_embed_JoRazP" src="https://codepen.io/Zhouzi/embed/preview/JoRazP?height=300&amp;slug-hash=JoRazP&amp;default-tabs=js,result&amp;host=https://codepen.io" title="TheaterJS" scrolling="no" frameborder="0" height="300" allowtransparency="true" class="cp_embed_iframe" style="width: 100%; overflow: hidden;"></iframe>'
    ],
    'allLinkedData' => []
];
