<?php
declare(strict_types = 1);

return [
    'authorName' => null,
    'authorUrl' => null,
    'cms' => null,
    'code' => null,
    'description' => 'Get the latest breaking news, sports, entertainment and obituaries in Austin, TX from Hookem.com.',
    'favicon' => 'https://www.gannett-cdn.com/sites/hookem/images/favicon.png',
    'feeds' => [],
    'icon' => null,
    'image' => null,
    'keywords' => [
        'ssts:home',
        'type:front'
    ],
    'language' => 'en',
    'languages' => [],
    'license' => null,
    'providerName' => 'Hookem.com',
    'providerUrl' => 'https://eu.hookem.com',
    'publishedTime' => '2021-04-03 23:43:58',
    'redirect' => null,
    'title' => 'Hookem.com: Local News, Politics & Sports in Austin, TX',
    'url' => 'https://eu.hookem.com/',
    'linkedData' => [
        '@context' => 'http://schema.org',
        '@type' => 'WebPage',
        'author' => [
            '@type' => 'Person',
            'name' => 'Hookem.com Staff'
        ],
        'dateModified' => '2021-04-03T23:43:58Z',
        'datePublished' => '2021-04-03T23:43:58Z',
        'headline' => 'Home',
        'image' => [],
        'keywords' => [
            'ssts:home',
            'type:front'
        ],
        'mainEntityOfPage' => [
            '@type' => 'WebPage',
            '@id' => 'https://www.hookem.com/'
        ],
        'publisher' => [
            '@type' => 'Organization',
            'logo' => [
                '@type' => 'ImageObject',
                'height' => 80,
                'url' => 'https://www.gannett-cdn.com/sites/hookem/images/site-nav-logo@2x.png',
                'width' => 297
            ],
            'name' => 'Hookem.com'
        ],
        'url' => 'https://www.hookem.com/'
    ],
    'oEmbed' => [],
    'allLinkedData' => [
        [
            '@context' => 'http://schema.org',
            '@type' => 'WebPage',
            'author' => [
                '@type' => 'Person',
                'name' => 'Hookem.com Staff'
            ],
            'dateModified' => '2021-04-03T23:43:58Z',
            'datePublished' => '2021-04-03T23:43:58Z',
            'headline' => 'Home',
            'image' => [],
            'keywords' => [
                'ssts:home',
                'type:front'
            ],
            'mainEntityOfPage' => [
                '@type' => 'WebPage',
                '@id' => 'https://www.hookem.com/'
            ],
            'publisher' => [
                '@type' => 'Organization',
                'logo' => [
                    '@type' => 'ImageObject',
                    'height' => 80,
                    'url' => 'https://www.gannett-cdn.com/sites/hookem/images/site-nav-logo@2x.png',
                    'width' => 297
                ],
                'name' => 'Hookem.com'
            ],
            'url' => 'https://www.hookem.com/'
        ]
    ]
];
