<?php
declare(strict_types = 1);

return [
    'authorName' => 'George Monbiot',
    'authorUrl' => 'https://www.ted.com/speakers/george_monbiot',
    'cms' => null,
    'code' => [
        'html' => '<iframe src="https://embed.ted.com/talks/george_monbiot_for_more_wonder_rewild_the_world" width="560" height="316" frameborder="0" scrolling="no" webkitAllowFullScreen mozallowfullscreen allowFullScreen></iframe>',
        'width' => 560,
        'height' => 316,
        'ratio' => 56.429
    ],
    'description' => 'Wolves were once native to the US\' Yellowstone National Park -- until hunting wiped them out. But when, in 1995, the wolves began to come back (thanks to an aggressive management program), something interesting happened: the rest of the park began to find a new, more healthful balance. In a bold thought experiment, George Monbiot imagines a wilder world in which humans work to restore the complex, lost natural food chains that once surrounded us.',
    'favicon' => 'https://pa.tedcdn.com/favicon.ico',
    'feeds' => [],
    'icon' => 'https://pa.tedcdn.com/apple-touch-icon-precomposed.png',
    'image' => 'https://pi.tedcdn.com/r/pe.tedcdn.com/images/ted/b4a648817c1a2102dc53dc2147bb1af2785067f0_1600x1200.jpg?h=316&w=560',
    'keywords' => [
        'ted',
        'talks',
        'animals',
        'biodiversity',
        'deextinction',
        'science',
        'ecology',
        'environment',
        'activism',
        'oceans',
        'community',
        'climate change',
        'sustainability',
        'conservation'
    ],
    'language' => 'en',
    'languages' => [
        'x-default' => 'https://www.ted.com/talks/george_monbiot_for_more_wonder_rewild_the_world',
        'el' => 'https://www.ted.com/talks/george_monbiot_for_more_wonder_rewild_the_world?language=el',
        'en' => 'https://www.ted.com/talks/george_monbiot_for_more_wonder_rewild_the_world?language=en',
        'vi' => 'https://www.ted.com/talks/george_monbiot_for_more_wonder_rewild_the_world?language=vi',
        'it' => 'https://www.ted.com/talks/george_monbiot_for_more_wonder_rewild_the_world?language=it',
        'ar' => 'https://www.ted.com/talks/george_monbiot_for_more_wonder_rewild_the_world?language=ar',
        'pt-BR' => 'https://www.ted.com/talks/george_monbiot_for_more_wonder_rewild_the_world?language=pt-br',
        'cs' => 'https://www.ted.com/talks/george_monbiot_for_more_wonder_rewild_the_world?language=cs',
        'es' => 'https://www.ted.com/talks/george_monbiot_for_more_wonder_rewild_the_world?language=es',
        'ru' => 'https://www.ted.com/talks/george_monbiot_for_more_wonder_rewild_the_world?language=ru',
        'nl' => 'https://www.ted.com/talks/george_monbiot_for_more_wonder_rewild_the_world?language=nl',
        'pt' => 'https://www.ted.com/talks/george_monbiot_for_more_wonder_rewild_the_world?language=pt',
        'zh-Hant' => 'https://www.ted.com/talks/george_monbiot_for_more_wonder_rewild_the_world?language=zh-tw',
        'tr' => 'https://www.ted.com/talks/george_monbiot_for_more_wonder_rewild_the_world?language=tr',
        'zh-Hans' => 'https://www.ted.com/talks/george_monbiot_for_more_wonder_rewild_the_world?language=zh-cn',
        'ro' => 'https://www.ted.com/talks/george_monbiot_for_more_wonder_rewild_the_world?language=ro',
        'pl' => 'https://www.ted.com/talks/george_monbiot_for_more_wonder_rewild_the_world?language=pl',
        'fr' => 'https://www.ted.com/talks/george_monbiot_for_more_wonder_rewild_the_world?language=fr',
        'bg' => 'https://www.ted.com/talks/george_monbiot_for_more_wonder_rewild_the_world?language=bg',
        'de' => 'https://www.ted.com/talks/george_monbiot_for_more_wonder_rewild_the_world?language=de',
        'da' => 'https://www.ted.com/talks/george_monbiot_for_more_wonder_rewild_the_world?language=da',
        'hu' => 'https://www.ted.com/talks/george_monbiot_for_more_wonder_rewild_the_world?language=hu',
        'ja' => 'https://www.ted.com/talks/george_monbiot_for_more_wonder_rewild_the_world?language=ja',
        'he' => 'https://www.ted.com/talks/george_monbiot_for_more_wonder_rewild_the_world?language=he',
        'sr' => 'https://www.ted.com/talks/george_monbiot_for_more_wonder_rewild_the_world?language=sr',
        'ko' => 'https://www.ted.com/talks/george_monbiot_for_more_wonder_rewild_the_world?language=ko',
        'uk' => 'https://www.ted.com/talks/george_monbiot_for_more_wonder_rewild_the_world?language=uk'
    ],
    'license' => null,
    'providerName' => 'TED',
    'providerUrl' => 'https://www.ted.com/',
    'publishedTime' => null,
    'redirect' => null,
    'title' => 'George Monbiot: For more wonder, rewild the world',
    'url' => 'https://www.ted.com/talks/george_monbiot_for_more_wonder_rewild_the_world',
    'linkedData' => [],
    'oEmbed' => [
        'type' => 'video',
        'version' => '1.0',
        'width' => 560,
        'height' => 316,
        'title' => 'George Monbiot: For more wonder, rewild the world',
        'description' => 'Wolves were once native to the US\' Yellowstone National Park -- until hunting wiped them out. But when, in 1995, the wolves began to come back (thanks to an aggressive management program), something interesting happened: the rest of the park began to find a new, more healthful balance. In a bold thought experiment, George Monbiot imagines a wilder world in which humans work to restore the complex, lost natural food chains that once surrounded us.',
        'url' => 'https://www.ted.com/talks/george_monbiot_for_more_wonder_rewild_the_world',
        'author_name' => 'George Monbiot',
        'provider_name' => 'TED',
        'provider_url' => 'https://www.ted.com',
        'cache_age' => 300,
        'thumbnail_url' => 'https://pi.tedcdn.com/r/pe.tedcdn.com/images/ted/b4a648817c1a2102dc53dc2147bb1af2785067f0_1600x1200.jpg?h=316&w=560',
        'thumbnail_width' => 560,
        'thumbnail_height' => 316,
        'author_url' => 'https://www.ted.com/speakers/george_monbiot',
        'html' => '<iframe src="https://embed.ted.com/talks/george_monbiot_for_more_wonder_rewild_the_world" width="560" height="316" frameborder="0" scrolling="no" webkitAllowFullScreen mozallowfullscreen allowFullScreen></iframe>'
    ],
    'allLinkedData' => []
];
