<?php
declare(strict_types = 1);

return [
    'authorName' => null,
    'authorUrl' => null,
    'cms' => null,
    'code' => [
        'html' => '<iframe src="https://www.viddler.com/embed/bdce8c7" frameborder="0" width="1280" height="720" allowTransparency="true"></iframe>',
        'width' => 1280,
        'height' => 720,
        'ratio' => 56.25
    ],
    'description' => 'Viddler is a powerful and easy-to-use video platform that services both small and large companies. We give you the tools to connect with your audience in a unique way and we also help you leverage your videos so that you can make money.',
    'favicon' => 'https://static1.cdn-ec.viddler.com/rails/assets/layout/favicon-a9c9c887d52b5d9a765dd3468a2285b8.png',
    'feeds' => [
        'http://www.viddler.com/rss/viddler'
    ],
    'icon' => null,
    'image' => 'https://thumbs.cdn-ec.viddler.com/thumbnail_2_bdce8c7_v8.jpg',
    'keywords' => [
        'viddler',
        'video sharing',
        'business video hosting'
    ],
    'language' => null,
    'languages' => [],
    'license' => null,
    'providerName' => 'Viddler',
    'providerUrl' => 'https://www.viddler.com',
    'publishedTime' => null,
    'redirect' => null,
    'title' => 'Viddler Platform Overview',
    'url' => 'https://www.viddler.com/v/bdce8c7',
    'linkedData' => [],
    'oEmbed' => [],
    'allLinkedData' => []
];
