<?php
declare(strict_types = 1);

return [
    'authorName' => null,
    'authorUrl' => null,
    'cms' => 'mediawiki',
    'code' => null,
    'description' => 'Albert Einstein ( EYEN-styne; German: [ˈalbɛʁt ˈʔaɪnʃtaɪn] (listen); 14 March 1879 – 18 April 1955) was a German-born theoretical physicist, widely acknowledged to be one of the greatest physicists of all time. Einstein is known widely for developing the theory of relativity, but he also made important contributions to the development of the theory of quantum mechanics. Relativity and quantum mechanics are together the two pillars of modern physics. His mass–energy equivalence formula E = mc2, which arises from relativity theory, has been dubbed "the world\'s most famous equation". His work is also known for its influence on the philosophy of science. He received...',
    'favicon' => 'https://en.wikipedia.org/static/favicon/wikipedia.ico',
    'feeds' => [],
    'icon' => 'https://en.wikipedia.org/static/apple-touch/wikipedia.png',
    'image' => 'https://upload.wikimedia.org/wikipedia/commons/thumb/3/3e/Einstein_1921_by_F_Schmutzer_-_restoration.jpg/1200px-Einstein_1921_by_F_Schmutzer_-_restoration.jpg',
    'keywords' => [],
    'language' => 'en',
    'languages' => [],
    'license' => null,
    'providerName' => 'Wikipedia',
    'providerUrl' => 'https://en.wikipedia.org',
    'publishedTime' => '2001-11-05 18:26:16',
    'redirect' => null,
    'title' => 'Albert Einstein',
    'url' => 'https://en.wikipedia.org/wiki/Albert_Einstein',
    'linkedData' => [
        '@context' => 'https://schema.org',
        '@type' => 'Article',
        'name' => 'Albert Einstein',
        'url' => 'https://en.wikipedia.org/wiki/Albert_Einstein',
        'sameAs' => 'http://www.wikidata.org/entity/Q937',
        'mainEntity' => 'http://www.wikidata.org/entity/Q937',
        'author' => [
            '@type' => 'Organization',
            'name' => 'Contributors to Wikimedia projects'
        ],
        'publisher' => [
            '@type' => 'Organization',
            'name' => 'Wikimedia Foundation, Inc.',
            'logo' => [
                '@type' => 'ImageObject',
                'url' => 'https://www.wikimedia.org/static/images/wmf-hor-googpub.png'
            ]
        ],
        'datePublished' => '2001-11-05T18:26:16Z',
        'dateModified' => '2021-04-04T01:52:51Z',
        'image' => 'https://upload.wikimedia.org/wikipedia/commons/3/3e/Einstein_1921_by_F_Schmutzer_-_restoration.jpg',
        'headline' => 'German-born theoretical physicist; developer of the theory of relativity (1879–1955)'
    ],
    'oEmbed' => [],
    'api' => [
        'pageid' => 736,
        'ns' => 0,
        'title' => 'Albert Einstein',
        'extract' => '<p class="mw-empty-elt">

</p>

<p class="mw-empty-elt">
</p>
<p><b>Albert Einstein</b> (<span></span> <i title="English pronunciation respelling"><span>EYEN</span>-styne</i>; <small>German: </small><span title="Representation in the International Phonetic Alphabet (IPA)">[ˈalbɛʁt ˈʔaɪnʃtaɪn]</span> <span>(<span><span><span></span>listen</span></span>)</span>; 14 March 1879&#160;– 18 April 1955) was a German-born theoretical physicist, widely acknowledged to be one of the greatest physicists of all time. Einstein is known widely for developing the theory of relativity, but he also made important contributions to the development of the theory of quantum mechanics. Relativity and quantum mechanics are together the two pillars of modern physics.  His mass–energy equivalence formula <span><i>E</i> = <i>mc</i><sup>2</sup></span>, which arises from relativity theory, has been dubbed "the world\'s most famous equation". His work is also known for its influence on the philosophy of science. He received</p>...'
    ],
    'allLinkedData' => [
        [
            '@context' => 'https://schema.org',
            '@type' => 'Article',
            'name' => 'Albert Einstein',
            'url' => 'https://en.wikipedia.org/wiki/Albert_Einstein',
            'sameAs' => 'http://www.wikidata.org/entity/Q937',
            'mainEntity' => 'http://www.wikidata.org/entity/Q937',
            'author' => [
                '@type' => 'Organization',
                'name' => 'Contributors to Wikimedia projects'
            ],
            'publisher' => [
                '@type' => 'Organization',
                'name' => 'Wikimedia Foundation, Inc.',
                'logo' => [
                    '@type' => 'ImageObject',
                    'url' => 'https://www.wikimedia.org/static/images/wmf-hor-googpub.png'
                ]
            ],
            'datePublished' => '2001-11-05T18:26:16Z',
            'dateModified' => '2021-04-04T01:52:51Z',
            'image' => 'https://upload.wikimedia.org/wikipedia/commons/3/3e/Einstein_1921_by_F_Schmutzer_-_restoration.jpg',
            'headline' => 'German-born theoretical physicist; developer of the theory of relativity (1879–1955)'
        ]
    ]
];
