<?php
declare(strict_types = 1);

return [
    'headers' => [
        'server' => [
            'nginx/1.16.1 (Ubuntu)'
        ],
        'date' => [
            'Sun, 04 Apr 2021 15:21:44 GMT'
        ],
        'content-type' => [
            'text/html; charset=utf-8'
        ],
        'set-cookie' => [
            'collections=librivoxaudio; expires=Fri, 01-Oct-2021 15:21:44 GMT; Max-Age=15552000; path=/; domain=.archive.org',
            'donation-identifier=274c7691e064ea7415d20dd3223704b2; expires=Mon, 04-Apr-2022 15:21:44 GMT; Max-Age=31536000; path=/; domain=.archive.org',
            'abtest-identifier=6fe8263e2fc82c1eaedc654804e3d81b; expires=Mon, 04-Apr-2022 15:21:44 GMT; Max-Age=31536000; path=/; domain=.archive.org',
            'PHPSESSID=aelqllbh87uhe496id3g8ksto0; path=/; domain=.archive.org'
        ],
        'strict-transport-security' => [
            'max-age=15724800'
        ],
        'referrer-policy' => [
            'no-referrer-when-downgrade'
        ],
        'content-encoding' => [
            'gzip'
        ],
        'Content-Location' => [
            'https://archive.org/details/librivoxaudio'
        ],
        'X-Request-Time' => [
            '1.164 ms'
        ]
    ],
    'statusCode' => 200,
    'reasonPhrase' => 'OK',
    'body' => '<!DOCTYPE html>
<html lang="en">
<!-- __ _ _ _ __| |_ (_)__ _____
    / _` | \'_/ _| \' \\| |\\ V / -_)
    \\__,_|_| \\__|_||_|_| \\_/\\___| -->
  <head data-release=d9060d4a>
    <title>The LibriVox Free Audiobook Collection : Free Audio : Free Download, Borrow and Streaming : Internet Archive</title>

          <meta name="viewport" content="width=device-width, initial-scale=1.0"/>
    
        <meta name="google-site-verification" content="Q2YSouphkkgHkFNP7FgAkc4TmBs1Gmag3uGNndb53B8" />
    <meta name="google-site-verification" content="bpjKvUvsX0lxfmjg19TLblckWkDpnptZEYsBntApxUk" />

    <script>
/* @licstart  The following is the entire license notice for the
 * JavaScript code in this page.
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * @licend  The above is the entire license notice
 * for the JavaScript code in this page.
 */
</script>
        <script>window.archive_setup=[]</script>
    <meta charset="UTF-8">
    <script src="//archive.org/includes/jquery-1.10.2.min.js?v1.10.2" type="text/javascript"></script>
    <script src="//archive.org/includes/build/npm/jquery-ui.min.js?v1.12.1" type="text/javascript"></script>
    <script src="//archive.org/includes/bootstrap.min.js?v3.0.0" type="text/javascript"></script>
    <script src="//archive.org/components/npm/clipboard/dist/clipboard.js?v=d9060d4a" type="text/javascript"></script>
    <script src="//archive.org/components/npm/@babel/polyfill/dist/polyfill.min.js?v=d9060d4a" type="text/javascript"></script>
    <script src="//archive.org/includes/build/js/ie-dom-node-remove-polyfill.min.js?v=d9060d4a" type="text/javascript"></script>
    <script src="//archive.org/includes/build/js/polyfill.min.js?v=d9060d4a" type="text/javascript"></script>
                      <meta property="mediatype" content="collection">
                      <meta property="primary_collection" content="">
            <script src="//archive.org/includes/analytics.js?v=d9060d4a" type="text/javascript"></script>
    <script src="//archive.org/components/npm/@webcomponents/webcomponentsjs/webcomponents-bundle.js?v=d9060d4a" type="text/javascript"></script>
    <script src="//archive.org/includes/build/js/more-facets.min.js?v=d9060d4a" type="text/javascript"></script>
    <script src="//archive.org/includes/build/js/ia-topnav.min.js?v=d9060d4a" type="text/javascript"></script>
    <script src="//archive.org/includes/build/npm/flot/jquery.flot.js?v1.1" type="text/javascript"></script>
    <script src="//archive.org/includes/build/npm/flot/jquery.flot.time.js?v1.1" type="text/javascript"></script>
    <script src="//archive.org/includes/build/npm/flot/jquery.flot.stack.js?v1.1" type="text/javascript"></script>
    <script src="//archive.org/includes/build/npm/react/umd/react.production.min.js?v16.7.0" type="text/javascript"></script>
    <script src="//archive.org/includes/build/npm/react-dom/umd/react-dom.production.min.js?v16.7.0" type="text/javascript"></script>
    <script src="//archive.org/includes/build/js/archive.min.js?v=d9060d4a" type="text/javascript"></script>
    <script src="//archive.org/includes/build/js/playset.min.js?v=d9060d4a" type="text/javascript"></script>
    <script src="//archive.org/includes/build/js/areact.min.js?v=d9060d4a" type="text/javascript"></script>

<meta name="DESCRIPTION" content="LibriVox - founded in 2005 - is a community of volunteers from all over the world who record public domain texts: poetry, short stories, whole books, even dramatic works, in many different languages. All LibriVox recordings are in the public domain in the USA and available as free downloads on..."/>

<link rel="alternate" id="gallery" type="application/rss+xml" title="RSS" href="http://archive.org/services/collection-rss.php?collection=librivoxaudio"/>
    <link href="//archive.org/includes/build/css/archive.min.css?v=d9060d4a" rel="stylesheet" type="text/css"/>
    <link rel="SHORTCUT ICON" href="https://archive.org/images/glogo.jpg"/>
      </head>
  <body class="navia ia-module lists showdetails">
    <a href="#maincontent" class="hidden-for-screen-readers">Skip to main content</a>

    <!-- Wraps all page content -->
    <div id="wrap"
          >
                    <div class="ia-banners">
              <div 
        class="ia-banner hidden new-lending-mechanism"
        data-campaign="new-lending-mechanism">
        <p><a href="http://blog.archive.org/2020/06/10/temporary-national-emergency-library-to-close-2-weeks-early-returning-to-traditional-controlled-digital-lending/" rel="nofollow">See what\'s new with book lending at the Internet Archive</a></p>
        <form class="banner-close" action="" method="get" data-action="ia-banner-close">
          <fieldset>
            <button type="submit"></button>
          </fieldset>
        </form>
      </div>
          </div>
                    
        <div id="topnav">
                              <ia-topnav baseHost="https://archive.org" config="eyJzY3JlZW5OYW1lIjpmYWxzZSwidXNlcm5hbWUiOiIiLCJ1cGxvYWRVUkwiOiJodHRwczpcL1wvYXJjaGl2ZS5vcmdcL2NyZWF0ZSIsImV2ZW50Q2F0ZWdvcnkiOiJUb3BOYXYiLCJ3YXliYWNrUGFnZXNBcmNoaXZlZCI6IjU1MiBiaWxsaW9uIiwiaXNBZG1pbiI6MCwiaGlkZVNlYXJjaCI6ZmFsc2V9" menus=" ">
                                      <noscript class=\'static-content\'>      <style scope="icon-hamburger-1">.icon-hamburger-1 svg.icon-hamburger {
        display: block;
      }

      .icon-hamburger-1 .fill-color.icon-hamburger {
        fill: #fff;
      }</style><!-- Shady DOM styles for login-button --><style scope="login-button-1">.login-button-1 .dropdown-toggle.login-button {
        display: block;
          height: 4rem;
          font-size: 1.6rem;
          text-transform: uppercase;
          text-decoration: none;
          color: #ccc;
          cursor: pointer;
      }

      .login-button-1 .dropdown-toggle.login-button .fill-color.login-button {
        fill: #999;
      }

      .login-button-1 .dropdown-toggle.login-button:active .fill-color.login-button,.login-button-1 .dropdown-toggle.login-button:focus .fill-color.login-button,.login-button-1 .dropdown-toggle.login-button:hover .fill-color.login-button {
        fill: #fff;
      }

      .login-button-1 .active.login-button {
        border-radius: 1rem 1rem 0 0;
          background: #333;
      }

      .login-button-1 .active.login-button .fill-color.login-button {
        fill: #fff;
      }

      .login-button-1 span.login-button {
        display: none;
          font-size: 1.4rem;
          text-transform: uppercase;
          color: #999;
      }

      .login-button-1 span.login-button a.login-button {
        color: inherit;
          text-decoration: none;
      }

      .login-button-1 a.login-button:hover,.login-button-1 a.login-button:active,.login-button-1 a.login-button:focus {
        color: #fff;
      }

      @media (min-width: 890px) {
      .login-button-1 .logged-out-toolbar.login-button {
        transform: translateY(-.5rem);
      }

      .login-button-1 .active.login-button {
        background: transparent;
      }

      .login-button-1 .dropdown-toggle.login-button {
        display: inline-block;
            vertical-align: middle;
      }

      .login-button-1 span.login-button {
        display: inline;
            vertical-align: middle;
      }

      }</style><!-- Shady DOM styles for nav-search --><style scope="nav-search-1">.nav-search-1 input.nav-search:focus {
        outline: none;
      }

      .nav-search-1 button.nav-search {
        background: none;
          color: inherit;
          border: none;
          font: inherit;
          cursor: pointer;
      }

      .nav-search-1 button.nav-search:focus {
        outline: none;
      }

      .nav-search-1 .search.nav-search {
        padding-top: 0;
          margin-right: .5rem;
      }

      .nav-search-1 .search.nav-search svg.nav-search {
        position: relative;
          top: -5px;
          right: -3px;
          fill:;
      }

      .nav-search-1 .search-activated.nav-search {
        display: -webkit-box;
          display: -ms-flexbox;
          display: flex;
          position: absolute;
          top: 0;
          right: 5rem;
          bottom: 0;
          left: 5rem;
          z-index: 3;
          padding: 0.5rem 0.2rem;
          border-radius: 1rem 1rem 0 0;
          background: #333;
      }

      .nav-search-1 .search-inactive.nav-search {
        display: none;
      }

      .nav-search-1 .search-activated.nav-search .highlight.nav-search,.nav-search-1 .search-activated.nav-search .search.nav-search {
        background: #fff;
          border-radius: 0.5rem;
      }

      .nav-search-1 .search-activated.nav-search .highlight.nav-search {
        display: -webkit-box;
          display: -ms-flexbox;
          display: flex;
          width: 100%;
          margin: 0 .5rem;
      }

      .nav-search-1 .search-activated.nav-search .search.nav-search {
        height: 100%;
          padding: 0;
          margin-right: 0;
          -ms-flex-item-align: center;
          -ms-grid-row-align: center;
          align-self: center;
      }

      .nav-search-1 .search-activated.nav-search .search-field.nav-search {
        width: 100%;
          height: 100%;
          box-sizing: border-box;
          padding-left: 1rem;
          border-radius: 0.5rem;
          border: none;
          font-size: 1.6rem;
          text-align: center;
      }

      .nav-search-1 .search-activated.nav-search .search-field.nav-search:focus {
        outline: none;
      }

      @keyframes fade-in-nav-search-1 {
      0% {
        opacity: 0;
      }

      100% {
        opacity: 1;
      }

      }

      .nav-search-1 .fade-in.nav-search {
        animation: fade-in-nav-search-1 .2s forwards;
      }

      @media (min-width: 890px) {
      .nav-search-1 .search.nav-search svg.nav-search {
        display: inline;
            width: 28px;
            height: 28px;
            vertical-align: -14px;
      }

      .nav-search-1 .search.nav-search path.nav-search {
        fill: #333;
      }

      .nav-search-1 .search-inactive.nav-search,.nav-search-1 .search-activated.nav-search {
        display: block;
            position: static;
            padding: 1.2rem .2rem;
            background: transparent;
      }

      .nav-search-1 .search-activated.nav-search .highlight.nav-search {
        width: 13rem;
            height: 2.8rem;
            -webkit-box-orient: horizontal;
            -webkit-box-direction: reverse;
            -ms-flex-direction: row-reverse;
            flex-direction: row-reverse;
      }

      .nav-search-1 .search-activated.nav-search .search-field.nav-search {
        width: calc(100% - 28px);
            height: 100%;
            padding-left: 0;
            font-size: 1.4rem;
            text-align: left;
      }

      .nav-search-1 .search-activated.nav-search .search.nav-search svg.nav-search {
        width: 28px;
            height: 28px;
      }

      }</style><!-- Shady DOM styles for media-button --><style scope="media-button-1">.media-button-1 a.media-button {
        display: inline-block;
          text-decoration: none;
      }

      .media-button-1 .menu-item.media-button {
        display: inline-flex;
          width: 100%;
          padding: 0;
          font-size: 1.6rem;
          text-align: left;
          background: transparent;
          -webkit-box-align: center;
          -ms-flex-align: center;
          align-items: center;
      }

      .media-button-1 .menu-item.media-button:focus {
        outline: none;
      }

      .media-button-1 .label.media-button {
        display: inline-block;
          padding: 0;
          font-weight: 400;
          color: #fff;
          text-align: left;
          vertical-align: middle;
      }

      .media-button-1 .menu-item.media-button > .icon.media-button {
        display: inline-flex;
          width: 42px;
          height: 42px;
          vertical-align: middle;
          -webkit-box-align: center;
          -ms-flex-align: center;
          align-items: center;
          -webkit-box-pack: center;
          -ms-flex-pack: center;
          justify-content: center;
      }

      .media-button-1 .menu-item.selected.media-button .icon.media-button {
        background-color: #333;
          border-radius: 1rem 0 0 1rem;
      }

      .media-button-1 .icon.media-button .fill-color.media-button {
        fill: #999;
      }

      .media-button-1 .icon.active.media-button .fill-color.media-button {
        fill: #fff;
      }

      .media-button-1 .donate.media-button .fill-color.media-button {
        fill: #f00;
      }

      @media (min-width: 890px) {
      .media-button-1 .menu-item.media-button {
        width: auto;
            height: 5rem;
            color: #999;
      }

      .media-button-1 .menu-item.media-button:hover,.media-button-1 .menu-item.media-button:active,.media-button-1 .menu-item.media-button:focus {
        color: #fff;
      }

      .media-button-1 .menu-item.media-button:hover .fill-color.media-button,.media-button-1 .menu-item.media-button:active .fill-color.media-button,.media-button-1 .menu-item.media-button:focus .fill-color.media-button {
        fill: #fff;
      }

      .media-button-1 .label.media-button {
        display: none;
      }

      .media-button-1 .label.media-button,.media-button-1 .web.media-button:after {
        padding-right: 1rem;
            font-size: 1.3rem;
            text-transform: uppercase;
            color: inherit;
      }

      .media-button-1 .web.media-button:after {
        display: none;
            content: "web";
      }

      .media-button-1 .donate.media-button,.media-button-1 .more.media-button {
        display: none;
      }

      .media-button-1 .menu-item.selected.media-button {
        background: #474747;
      }

      .media-button-1 .menu-item.selected.media-button .label.media-button,.media-button-1 .menu-item.selected.web.media-button:after {
        color: #fff;
      }

      .media-button-1 .menu-item.selected.media-button .icon.media-button {
        background: transparent;
      }

      .media-button-1 .web.selected.media-button .fill-color.media-button {
        fill: #ffcd27;
      }

      .media-button-1 .texts.selected.media-button .fill-color.media-button {
        fill: #faab3c;
      }

      .media-button-1 .video.selected.media-button .fill-color.media-button {
        fill: #f1644b;
      }

      .media-button-1 .audio.selected.media-button .fill-color.media-button {
        fill: #00adef;
      }

      .media-button-1 .software.selected.media-button .fill-color.media-button {
        fill: #9ecc4f;
      }

      .media-button-1 .images.selected.media-button .fill-color.media-button {
        fill: #aa99c9;
      }

      }

      @media (min-width: 1300px) {
      .media-button-1 .label.media-button,.media-button-1 .web.media-button:after {
        display: inline;
      }

      .media-button-1 .web.media-button .label.media-button {
        display: none;
      }

      }</style><!-- Shady DOM styles for media-menu --><style scope="media-menu-1">.media-menu-1 {
        outline: none;
      }

      .media-menu-1 .media-menu.media-menu {
        position: absolute;
          z-index: -1;
          top: -100vh;
          width: 100%;
          background-color: #222;
          margin: 0;
          overflow: hidden;
      }

      .media-menu-1 .media-menu.tx-slide.media-menu {
        transition-property: top;
          transition-duration: 0.2s;
          transition-timing-function: ease;
      }

      .media-menu-1 .media-menu.tx-slide.open.media-menu {
        top: 100%;
      }

      .media-menu-1 .media-menu.tx-slide.closed.media-menu {
        top: -100vh;
      }

      .media-menu-1 .media-menu.tx-slide.closed.media-menu {
        transition-duration: 0.2s;
      }

      .media-menu-1 .menu-group.media-menu {
        position: relative;
          line-height: normal;
      }

      @media (min-width: 890px) {
      .media-menu-1 .media-menu.media-menu {
        display: inline-block;
            position: static;
            width: auto;
            height: 5rem;
      }

      .media-menu-1 .media-menu.tx-slide.media-menu {
        transition-property: none;
      }

      .media-menu-1 .media-menu.tx-slide.open.media-menu,.media-menu-1 .media-menu.tx-slide.closed.media-menu {
        top: 0;
      }

      .media-menu-1 .menu-group.media-menu {
        font-size: 0;
      }

      }</style><!-- Shady DOM styles for primary-nav --><style scope="primary-nav-1">.primary-nav-1 button.primary-nav:focus,.primary-nav-1 a.primary-nav:focus,.primary-nav-1 input.primary-nav:focus {
        outline: none;
      }

      .primary-nav-1 nav.primary-nav {
        position: relative;
          display: -ms-grid;
          display: grid;
          height: 4rem;
          grid-template-areas: "hamburger empty search user";
          -ms-grid-columns: 4rem minmax(1rem, 100%) 4.3rem 5rem;
          grid-template-columns: 4rem auto 4.3rem 5rem;
          -ms-grid-rows: 100%;
          grid-template-rows: 100%;
          background: #222;
          border-bottom: 1px solid #333;
      }

      .primary-nav-1 button.primary-nav {
        background: none;
          color: inherit;
          border: none;
          font: inherit;
          cursor: pointer;
      }

      .primary-nav-1 .link-home.primary-nav {
        position: absolute;
          top: 50%;
          left: 50%;
          z-index: 2;
          text-decoration: none;
          -webkit-transform: translate(-50%, -50%);
          -ms-transform: translate(-50%, -50%);
          transform: translate(-50%, -50%);
      }

      .primary-nav-1 media-menu.primary-nav {
        grid-column-start: hamburger-start;
          grid-column-end: user-end;
      }

      .primary-nav-1 .ia-logo.primary-nav {
        display: block;
      }

      .primary-nav-1 .ia-wordmark.primary-nav {
        display: none;
      }

      .primary-nav-1 .hamburger.primary-nav {
        -ms-grid-row: 1;
          -ms-grid-column: 1;
          grid-area: hamburger;
          padding: 0;
      }

      .primary-nav-1 .search-trigger.primary-nav {
        -ms-grid-row: 1;
          -ms-grid-column: 3;
          grid-area: search;
          position: relative;
          padding: 0;
          z-index: 1;
          width: 100%;
          text-align: right;
          -webkit-box-align: center;
          -ms-flex-align: center;
          align-items: center;
      }

      .primary-nav-1 .search-trigger.primary-nav .fill-color.primary-nav {
        fill: #999;
      }

      .primary-nav-1 .search-activated.primary-nav {
        position: relative;
          z-index: 3;
      }

      .primary-nav-1 .upload.primary-nav {
        display: none;
      }

      .primary-nav-1 .upload.primary-nav span.primary-nav {
        display: none;
      }

      .primary-nav-1 .user-info.primary-nav {
        -ms-grid-row: 1;
          -ms-grid-column: 4;
          grid-area: user;
          -ms-grid-row-align: stretch;
          align-self: stretch;
          -ms-grid-column-align: end;
          justify-self: end;
      }

      .primary-nav-1 .username.primary-nav {
        display: none;
          font-size: 1.3rem;
          vertical-align: middle;
          text-transform: uppercase;
      }

      .primary-nav-1 .user-menu.primary-nav {
        height: 100%;
          padding: .5rem 1rem;
          color: #999;
      }

      .primary-nav-1 .user-menu.primary-nav:hover {
        color: #fff;
      }

      .primary-nav-1 .user-menu.active.primary-nav {
        border-radius: 1rem 1rem 0 0;
          background: #333;
      }

      .primary-nav-1 .user-menu.primary-nav img.primary-nav {
        display: block;
          width: 30px;
          height: 30px;
      }

      @media (min-width: 890px) {
      .primary-nav-1 {
        ;
      }

      .primary-nav-1 nav.primary-nav {
        display: block;
            z-index: 2;
            height: 5rem;
            padding-right: 1.5rem;
      }

      .primary-nav-1 .link-home.primary-nav {
        position: static;
            float: left;
            margin-top: 1rem;
            padding: 0 10px 0 13px;
            -webkit-transform: translate(0, 0);
            -ms-transform: translate(0, 0);
            transform: translate(0, 0);
      }

      .primary-nav-1 .ia-logo.primary-nav,.primary-nav-1 .ia-wordmark.primary-nav {
        display: inline-block;
            vertical-align: middle;
      }

      .primary-nav-1 .ia-wordmark.primary-nav {
        margin-left: 1rem;
      }

      .primary-nav-1 .hamburger.primary-nav,.primary-nav-1 .search-trigger.primary-nav {
        display: none;
      }

      .primary-nav-1 .user-info.primary-nav {
        float: right;
            padding-top: 1rem;
      }

      .primary-nav-1 .user-menu.primary-nav {
        padding-top: 0;
      }

      .primary-nav-1 .user-menu.active.primary-nav {
        background: transparent;
      }

      .primary-nav-1 .user-menu.primary-nav img.primary-nav {
        display: inline-block;
            vertical-align: middle;
      }

      .primary-nav-1 .upload.primary-nav {
        display: block;
            float: right;
            margin-top: 1rem;
            font-size: 1.4rem;
            text-transform: uppercase;
            text-decoration: none;
            color: #999;
      }

      .primary-nav-1 .upload.primary-nav:active,.primary-nav-1 .upload.primary-nav:focus,.primary-nav-1 .upload.primary-nav:hover {
        color: #fff;
      }

      .primary-nav-1 .upload.primary-nav svg.primary-nav {
        width: 32px;
            height: 32px;
            vertical-align: middle;
            fill: #999;
      }

      .primary-nav-1 .upload.primary-nav:hover svg.primary-nav,.primary-nav-1 .upload.primary-nav:focus svg.primary-nav,.primary-nav-1 .upload.primary-nav:active svg.primary-nav {
        fill: #fff;
      }

      .primary-nav-1 nav-search.primary-nav {
        float: right;
            margin-left: 1rem;
      }

      .primary-nav-1 login-button.primary-nav {
        display: block;
            margin-right: 1rem;
      }

      }

      @media (min-width: 990px) {
      .primary-nav-1 .username.primary-nav {
        display: inline-block;
      }

      .primary-nav-1 .upload.primary-nav span.primary-nav {
        display: inline;
      }

      }</style><!-- Shady DOM styles for user-menu --><!-- Shady DOM styles for search-menu --><style scope="search-menu-1">.search-menu-1 {
        ;
      }

      .search-menu-1 button.search-menu:focus,.search-menu-1 input.search-menu:focus {
        outline-color: #428bca;
          outline-width: 0.16rem;
          outline-style: auto;
      }

      .search-menu-1 .search-menu.search-menu {
        position: absolute;
          top: -800px;
          right: 0;
          left: 0;
          z-index: 1;
          padding: 0 4.5rem;
          font-size: 1.6rem;
          background-color: #333;
      }

      .search-menu-1 .tx-slide.search-menu {
        overflow: hidden;
          transition-property: top;
          transition-duration: 0.2s;
          transition-timing-function: ease;
      }

      .search-menu-1 .initial.search-menu,.search-menu-1 .closed.search-menu {
        top: -800px;
      }

      .search-menu-1 .closed.search-menu {
        transition-duration: 0.2s;
      }

      .search-menu-1 .open.search-menu {
        top: 4rem;
      }

      .search-menu-1 label.search-menu,.search-menu-1 a.search-menu {
        padding: 1rem;
          display: block;
      }

      .search-menu-1 .advanced-search.search-menu {
        text-decoration: none;
          color: #428bca;
      }

      @media (min-width: 890px) {
      .search-menu-1 .search-menu.search-menu {
        overflow: visible;
            top: -400px;
            right: 2rem;
            left: auto;
            z-index: 5;
            padding: 1rem 2rem;
            transition: opacity .2s ease-in-out;
            font-size: 1.4rem;
            color: #333;
            border-radius: 2px;
            background: #fff;
            box-shadow: 0 1px 2px 1px rgba(0, 0, 0, .15);
      }

      .search-menu-1 .search-menu.search-menu:after {
        position: absolute;
            right: 7px;
            top: -7px;
            width: 12px;
            height: 7px;
            box-sizing: border-box;
            color: #fff;
            content: "";
            border-bottom: 7px solid currentColor;
            border-left: 6px solid transparent;
            border-right: 6px solid transparent;
      }

      .search-menu-1 .initial.search-menu,.search-menu-1 .closed.search-menu {
        opacity: 0;
            transition-duration: .2s;
      }

      .search-menu-1 .open.search-menu {
        top: 5.1rem;
            opacity: 1;
      }

      .search-menu-1 label.search-menu {
        padding: 0;
      }

      .search-menu-1 label.search-menu + label.search-menu {
        padding-top: 7px;
      }

      .search-menu-1 a.search-menu {
        padding: 1rem 0 0 0;
      }

      }</style><!-- Shady DOM styles for wayback-search --><!-- Shady DOM styles for more-slider --><!-- Shady DOM styles for media-subnav --><style scope="media-subnav-1">.media-subnav-1 a.media-subnav {
        text-decoration: none;
          color: #fff;
      }

      .media-subnav-1 img.media-subnav {
        display: block;
          width: 90px;
          height: 90px;
          margin: 0 auto 1rem auto;
          border-radius: 45px;
      }

      .media-subnav-1 h3.media-subnav {
        margin-top: 0;
          font-size: 1.8rem;
      }

      .media-subnav-1 h4.media-subnav {
        font-size: 1.6rem;
      }

      .media-subnav-1 ul.media-subnav {
        padding: 0;
          margin: 0;
          list-style: none;
      }

      .media-subnav-1 li.media-subnav + li.media-subnav {
        padding-top: 1.5rem;
      }

      .media-subnav-1 .icon-links.media-subnav {
        display: -webkit-box;
          display: -ms-flexbox;
          display: flex;
          -webkit-box-pack: space-evenly;
          -ms-flex-pack: space-evenly;
          justify-content: space-evenly;
          text-align: center;
      }

      .media-subnav-1 .icon-links.media-subnav a.media-subnav {
        display: inline-block;
          width: 120px;
          margin-bottom: 1.5rem;
          overflow: hidden;
          white-space: nowrap;
          text-align: center;
          text-overflow: ellipsis;
      }

      .media-subnav-1 .icon-links.media-subnav a.media-subnav + a.media-subnav {
        margin-left: 2rem;
      }

      .media-subnav-1 .featured.media-subnav h4.media-subnav {
        display: none;
      }

      @media (min-width: 890px) {
      .media-subnav-1 {
        display: -ms-grid;
            display: grid;
            -ms-grid-columns: 40% 20% 40%;
            grid-template-columns: 40% 20% 40%;
      }

      .media-subnav-1 .wayback-search.media-subnav {
        -ms-grid-column: 1;
            -ms-grid-column-span: 3;
            grid-column: 1 / 4;
      }

      .media-subnav-1 h3.media-subnav {
        display: none;
      }

      .media-subnav-1 h4.media-subnav {
        margin: 0 0 1rem 0;
            font-weight: 100;
      }

      .media-subnav-1 ul.media-subnav {
        font-size: 1.3rem;
      }

      .media-subnav-1 li.media-subnav {
        padding-bottom: .5rem;
      }

      .media-subnav-1 li.media-subnav + li.media-subnav {
        padding-top: 0;
      }

      .media-subnav-1 li.media-subnav a.media-subnav {
        display: block;
            overflow: hidden;
            white-space: nowrap;
            text-overflow: ellipsis;
      }

      .media-subnav-1 .icon-links.media-subnav {
        -ms-grid-column: 1;
      }

      .media-subnav-1 .icon-links.media-subnav a.media-subnav {
        padding-top: 3.5rem;
            max-width: 160px;
      }

      .media-subnav-1 .links.media-subnav {
        padding: 0 1.5rem;
      }

      .media-subnav-1 .featured.media-subnav {
        -ms-grid-column: 2;
      }

      .media-subnav-1 .featured.media-subnav h4.media-subnav {
        display: block;
      }

      .media-subnav-1 .top.media-subnav {
        -ms-grid-column: 3;
      }

      .media-subnav-1 .top.media-subnav ul.media-subnav {
        display: -ms-grid;
            display: grid;
            -ms-grid-columns: 50% 3rem 50%;
            grid-template-columns: 50% 50%;
            -ms-grid-rows: (auto)[7];
            grid-template-rows: repeat(7, auto);
            grid-column-gap: 3rem;
            grid-auto-flow: column;
      }

      .media-subnav-1 .top.media-subnav ul.media-subnav > *.media-subnav:nth-child(1) {
        -ms-grid-row: 1;
            -ms-grid-column: 1;
      }

      .media-subnav-1 .top.media-subnav ul.media-subnav > *.media-subnav:nth-child(2) {
        -ms-grid-row: 2;
            -ms-grid-column: 1;
      }

      .media-subnav-1 .top.media-subnav ul.media-subnav > *.media-subnav:nth-child(3) {
        -ms-grid-row: 3;
            -ms-grid-column: 1;
      }

      .media-subnav-1 .top.media-subnav ul.media-subnav > *.media-subnav:nth-child(4) {
        -ms-grid-row: 4;
            -ms-grid-column: 1;
      }

      .media-subnav-1 .top.media-subnav ul.media-subnav > *.media-subnav:nth-child(5) {
        -ms-grid-row: 5;
            -ms-grid-column: 1;
      }

      .media-subnav-1 .top.media-subnav ul.media-subnav > *.media-subnav:nth-child(6) {
        -ms-grid-row: 6;
            -ms-grid-column: 1;
      }

      .media-subnav-1 .top.media-subnav ul.media-subnav > *.media-subnav:nth-child(7) {
        -ms-grid-row: 7;
            -ms-grid-column: 1;
      }

      .media-subnav-1 .top.media-subnav ul.media-subnav > *.media-subnav:nth-child(8) {
        -ms-grid-row: 1;
            -ms-grid-column: 3;
      }

      .media-subnav-1 .top.media-subnav ul.media-subnav > *.media-subnav:nth-child(9) {
        -ms-grid-row: 2;
            -ms-grid-column: 3;
      }

      .media-subnav-1 .top.media-subnav ul.media-subnav > *.media-subnav:nth-child(10) {
        -ms-grid-row: 3;
            -ms-grid-column: 3;
      }

      .media-subnav-1 .top.media-subnav ul.media-subnav > *.media-subnav:nth-child(11) {
        -ms-grid-row: 4;
            -ms-grid-column: 3;
      }

      .media-subnav-1 .top.media-subnav ul.media-subnav > *.media-subnav:nth-child(12) {
        -ms-grid-row: 5;
            -ms-grid-column: 3;
      }

      .media-subnav-1 .top.media-subnav ul.media-subnav > *.media-subnav:nth-child(13) {
        -ms-grid-row: 6;
            -ms-grid-column: 3;
      }

      .media-subnav-1 .top.media-subnav ul.media-subnav > *.media-subnav:nth-child(14) {
        -ms-grid-row: 7;
            -ms-grid-column: 3;
      }

      }</style><!-- Shady DOM styles for media-slider --><style scope="media-slider-1">.media-slider-1 .overflow-clip.media-slider {
        display: none;
          position: absolute;
          top: 4rem;
          right: 0;
          left: 4rem;
          height: 368px;
          overflow-x: hidden;
      }

      .media-slider-1 .information-menu.media-slider {
        position: absolute;
          top: 0;
          right: 0;
          left: 0;
          padding: 0;
          height: 368px;
          overflow-x: hidden;
          font-size: 1.4rem;
          background: #333;
      }

      .media-slider-1 .open.media-slider {
        display: block;
      }

      .media-slider-1 .info-box.media-slider {
        padding: 1rem;
      }

      @media (min-width: 890px) {
      .media-slider-1 .overflow-clip.media-slider {
        display: block;
            top: 0;
            left: 0;
            height: auto;
            overflow-x: visible;
            transform: translate(0, -100%);
            transition: transform .2s ease;
      }

      .media-slider-1 .information-menu.media-slider {
        left: 0;
            z-index: 1;
            height: auto;
            min-height: 21rem;
            background: #474747;
            transform: translate(0, -100%);
            transition: transform .2s ease;
      }

      .media-slider-1 .overflow-clip.open.media-slider {
        transform: translate(0, 8rem);
      }

      .media-slider-1 .information-menu.open.media-slider {
        transform: translate(0, 0);
      }

      .media-slider-1 .info-box.media-slider {
        max-width: 1000px;
            padding: 1.5rem 0;
            margin: 0 auto;
      }

      }</style><!-- Shady DOM styles for desktop-subnav --><style scope="desktop-subnav-1">.desktop-subnav-1 ul.desktop-subnav {
        position: relative;
          z-index: 3;
          padding: .8rem 0;
          margin: 0;
          font-size: 1.2rem;
          text-transform: uppercase;
          text-align: center;
          background: #333;
      }

      .desktop-subnav-1 li.desktop-subnav {
        display: inline-block;
          padding: 0 15px;
      }

      .desktop-subnav-1 a.desktop-subnav {
        text-decoration: none;
          color: #aaa;
      }

      .desktop-subnav-1 a.desktop-subnav:hover,.desktop-subnav-1 a.desktop-subnav:active,.desktop-subnav-1 a.desktop-subnav:focus {
        color: #fff;
      }

      .desktop-subnav-1 .donate.desktop-subnav svg.desktop-subnav {
        width: 16px;
          height: 16px;
          vertical-align: -4px;
          fill: #f00;
      }</style><!-- Shady DOM styles for signed-out-dropdown --><style scope="signed-out-dropdown-1">.signed-out-dropdown-1 {
        ;
      }

      .signed-out-dropdown-1 nav.signed-out-dropdown {
        position: absolute;
          top: -1500px;
          right: 0;
          z-index: 1;
          overflow: hidden;
          font-size: 1.6rem;
          background-color: #333;
          transition-property: top;
          transition-duration: 0.2s;
          transition-timing-function: ease;
      }

      .signed-out-dropdown-1 .initial.signed-out-dropdown,.signed-out-dropdown-1 .closed.signed-out-dropdown {
        top: -1500px;
      }

      .signed-out-dropdown-1 .closed.signed-out-dropdown {
        transition-duration: 0.5s;
      }

      .signed-out-dropdown-1 .open.signed-out-dropdown {
        top: 4rem;
          max-width: 100vw;
          overflow: auto;
      }

      .signed-out-dropdown-1 h3.signed-out-dropdown {
        padding: 0.6rem 2rem;
          margin: 0;
          font-size: inherit;
          overflow: hidden;
          text-overflow: ellipsis;
      }

      .signed-out-dropdown-1 ul.signed-out-dropdown {
        padding: 0.4rem 0 0.7rem 0;
          margin: 0;
          list-style: none;
          
          max-height: calc(100vh - 7.2rem + 1px);
          overflow: auto;
          box-sizing: border-box;
      }

      .signed-out-dropdown-1 .divider.signed-out-dropdown {
        margin: .5rem 0;
          border-bottom: 1px solid #666;
      }

      .signed-out-dropdown-1 a.signed-out-dropdown,.signed-out-dropdown-1 .info-item.signed-out-dropdown {
        display: block;
          color: #fff;
          text-decoration: none;
          padding: 1rem 2rem;
      }

      .signed-out-dropdown-1 .info-item.signed-out-dropdown {
        font-size: .8em;
          color: #999;
      }

      @media (min-width: 890px) {
      .signed-out-dropdown-1 nav.signed-out-dropdown {
        overflow: visible;
            top: calc(100% + 7px);
            left: auto;
            z-index: 5;
            transition: opacity .2s ease-in-out;
            font-size: 1.4rem;
            border-radius: 2px;
            background: #fff;
            box-shadow: 0 1px 2px 1px rgba(0, 0, 0, .15);
      }

      .signed-out-dropdown-1 nav.signed-out-dropdown:after {
        position: absolute;
            right: 7px;
            top: -7px;
            width: 12px;
            height: 7px;
            box-sizing: border-box;
            color: #fff;
            content: "";
            border-bottom: 7px solid currentColor;
            border-left: 6px solid transparent;
            border-right: 6px solid transparent;
      }

      .signed-out-dropdown-1 h3.signed-out-dropdown {
        display: none;
      }

      .signed-out-dropdown-1 ul.signed-out-dropdown {
        max-height: calc(100vh - 8.5rem + 1px);
      }

      .signed-out-dropdown-1 .divider.signed-out-dropdown {
        border-bottom-color: #666;
      }

      .signed-out-dropdown-1 a.signed-out-dropdown {
        padding: .5rem 2rem;
            color: #333;
            transition: background .1s ease-out, color .1s ease-out;
      }

      .signed-out-dropdown-1 .info-item.signed-out-dropdown {
        padding: .5rem 2rem;
            font-size: .8em;
      }

      .signed-out-dropdown-1 a.signed-out-dropdown:hover,.signed-out-dropdown-1 a.signed-out-dropdown:active,.signed-out-dropdown-1 a.signed-out-dropdown:focus {
        color: #fff;
            background: #428bca;
      }

      .signed-out-dropdown-1 .initial.signed-out-dropdown,.signed-out-dropdown-1 .closed.signed-out-dropdown {
        opacity: 0;
            transition-duration: .2s;
      }

      .signed-out-dropdown-1 .open.signed-out-dropdown {
        top: 5.1rem;
            opacity: 1;
            overflow: visible;
      }

      }

      @media (min-width: 890px) {
      .signed-out-dropdown-1 .initial.signed-out-dropdown,.signed-out-dropdown-1 .closed.signed-out-dropdown,.signed-out-dropdown-1 .open.signed-out-dropdown {
        right: 33.7rem;
      }

      .signed-out-dropdown-1 .search-hidden.initial.signed-out-dropdown,.signed-out-dropdown-1 .search-hidden.closed.signed-out-dropdown,.signed-out-dropdown-1 .search-hidden.open.signed-out-dropdown {
        right: 18.3rem;
      }

      }

      @media (min-width: 990px) {
      .signed-out-dropdown-1 .initial.signed-out-dropdown,.signed-out-dropdown-1 .closed.signed-out-dropdown,.signed-out-dropdown-1 .open.signed-out-dropdown {
        right: 39.7rem;
      }

      .signed-out-dropdown-1 .search-hidden.initial.signed-out-dropdown,.signed-out-dropdown-1 .search-hidden.closed.signed-out-dropdown,.signed-out-dropdown-1 .search-hidden.open.signed-out-dropdown {
        right: 23.5rem;
      }

      }</style><!-- Shady DOM styles for ia-topnav --><style scope="ia-topnav-1">.ia-topnav-1 {
        ;

          color: #fff;
          font-size: 2rem;
          font-family: \'Helvetica Neue\', Helvetica, Arial, sans-serif;
      }

      .ia-topnav-1 #close-layer.ia-topnav {
        display: none;
          position: fixed;
          top: 0;
          right: 0;
          bottom: 0;
          left: 0;
          z-index: 0;
      }

      .ia-topnav-1 #close-layer.visible.ia-topnav {
        display: block;
      }

      .ia-topnav-1 .topnav.ia-topnav {
        position: relative;
          z-index: 3;
      }

      @media (max-width: 889px) {
      .ia-topnav-1 desktop-subnav.ia-topnav {
        display: none;
      }

      }</style><style>body {transition: opacity ease-in 0.2s; } 
      body[unresolved] {opacity: 0; display: block; overflow: hidden; position: relative; } 
      </style>
          <div class="topnav style-scope ia-topnav">
        <primary-nav class="style-scope ia-topnav x-scope primary-nav-1"><!---->
      <nav class="style-scope primary-nav">
        <a class="link-home style-scope primary-nav" href="https://archive.org" data-event-click-tracking="BetaTopNav|NavHome"><!---->
  <svg class="ia-logo style-scope primary-nav" width="27" height="30" viewBox="0 0 27 30" xmlns="http://www.w3.org/2000/svg" aria-labelledby="logoTitleID logoDescID">
    <title id="logoTitleID" class="style-scope primary-nav">Internet Archive logo</title>
    <desc id="logoDescID" class="style-scope primary-nav">A line drawing of the Internet Archive headquarters building façade.</desc>
    <g stroke="none" stroke-width="1" fill="none" fill-rule="evenodd" class="style-scope primary-nav">
      <mask id="mask-2" fill="white" class="style-scope primary-nav">
        <path d="M26.6666667,28.6046512 L26.6666667,30 L0,30 L0.000283687943,28.6046512 L26.6666667,28.6046512 Z M25.6140351,26.5116279 L25.6140351,28.255814 L1.05263158,28.255814 L1.05263158,26.5116279 L25.6140351,26.5116279 Z M3.62469203,7.6744186 L3.91746909,7.82153285 L4.0639977,10.1739544 L4.21052632,13.9963932 L4.21052632,17.6725617 L4.0639977,22.255044 L4.03962296,25.3421929 L3.62469203,25.4651163 L2.16024641,25.4651163 L1.72094074,25.3421929 L1.55031755,22.255044 L1.40350877,17.6970339 L1.40350877,14.0211467 L1.55031755,10.1739544 L1.68423854,7.80887484 L1.98962322,7.6744186 L3.62469203,7.6744186 Z M24.6774869,7.6744186 L24.9706026,7.82153285 L25.1168803,10.1739544 L25.2631579,13.9963932 L25.2631579,17.6725617 L25.1168803,22.255044 L25.0927809,25.3421929 L24.6774869,25.4651163 L23.2130291,25.4651163 L22.7736357,25.3421929 L22.602418,22.255044 L22.4561404,17.6970339 L22.4561404,14.0211467 L22.602418,10.1739544 L22.7369262,7.80887484 L23.0420916,7.6744186 L24.6774869,7.6744186 Z M9.94042303,7.6744186 L10.2332293,7.82153285 L10.3797725,10.1739544 L10.5263158,13.9963932 L10.5263158,17.6725617 L10.3797725,22.255044 L10.3556756,25.3421929 L9.94042303,25.4651163 L8.47583122,25.4651163 L8.0362015,25.3421929 L7.86556129,22.255044 L7.71929825,17.6970339 L7.71929825,14.0211467 L7.86556129,10.1739544 L8.00005604,7.80887484 L8.30491081,7.6744186 L9.94042303,7.6744186 Z M18.0105985,7.6744186 L18.3034047,7.82153285 L18.449948,10.1739544 L18.5964912,13.9963932 L18.5964912,17.6725617 L18.449948,22.255044 L18.425851,25.3421929 L18.0105985,25.4651163 L16.5460067,25.4651163 L16.1066571,25.3421929 L15.9357367,22.255044 L15.7894737,17.6970339 L15.7894737,14.0211467 L15.9357367,10.1739544 L16.0702315,7.80887484 L16.3753664,7.6744186 L18.0105985,7.6744186 Z M25.6140351,4.53488372 L25.6140351,6.97674419 L1.05263158,6.97674419 L1.05263158,4.53488372 L25.6140351,4.53488372 Z M13.0806755,0 L25.9649123,2.93331338 L25.4484139,3.8372093 L0.771925248,3.8372093 L0,3.1041615 L13.0806755,0 Z" id="path-1" class="style-scope primary-nav"></path>
      </mask>
      <use fill="#FFFFFF" xlink:href="#path-1" class="style-scope primary-nav"></use>
      <g mask="url(#mask-2)" fill="#FFFFFF" class="style-scope primary-nav">
        <path d="M0,0 L26.6666667,0 L26.6666667,30 L0,30 L0,0 Z" id="swatch" class="style-scope primary-nav"></path>
      </g>
    </g>
  </svg>
<!---->
  <svg class="ia-wordmark style-scope primary-nav" height="14" viewBox="0 0 183 14" width="183" xmlns="http://www.w3.org/2000/svg"><g fill="#fff" fill-rule="evenodd" class="style-scope primary-nav"><g transform="translate(107.24177)" class="style-scope primary-nav"><path d="m3.46567087 2.73592273c.09358964-.31350476.26547063-.95793121.26547063-1.08718317 0-.73655285-.57818604-.75488647-1.20271694-.86488814v-.40471447h2.93682509l3.81107838 12.38893815h-1.62387035l-1.17212033-3.82897484h-3.98340931l-1.17167038 3.82897484h-.96784292zm-.7032722 5.33783106h3.4520181l-1.78045302-5.37541496z" class="style-scope primary-nav"></path><path d="m13.7607138 2.88304997c0-1.82281935-.0319465-1.82281935-1.4843858-2.09919855v-.40471447h3.8425749c1.1721204 0 4.4050127 0 4.4050127 3.2954667 0 2.09828187-1.1554722 2.79816749-2.3896856 3.03696279l2.874282 6.05650866h-1.7957513l-2.7649442-5.72512863h-.9687428v5.72512863h-1.7183599zm1.7183599 3.29500836h.8909015c1.0146377 0 2.4364804-.33092169 2.4364804-2.39299467 0-1.98873853-.9687428-2.54103858-2.2812476-2.54103858-1.0461343 0-1.0461343.33138003-1.0461343 1.6573585z" class="style-scope primary-nav"></path><path d="m31.6158204 12.2524422c-.5304913.2768376-1.3903462.6998857-2.9989182.6998857-3.389925 0-4.6083902-2.4113283-4.6083902-6.55334954 0-3.35000921.8742533-6.07530059 4.3582178-6.07530059 1.3903462 0 2.4058839.27592086 3.1240044.55230005l.0940396 3.07500503h-.4530999c-.062543-.9395976-.921948-2.743625-2.6088113-2.743625-2.296096 0-2.6713545 2.88983555-2.6713545 5.19162051 0 2.90816916.8598549 5.52254214 3.0304147 5.52254214 1.4843858 0 2.2497511-.5523 2.7338976-.9386809z" class="style-scope primary-nav"></path><path d="m36.1784975 2.80971552c0-1.45568877-.0935896-1.62114962-1.5626771-1.80448573v-.40563116l3.2805871-.42258975v5.70633665h4.2484299v-5.50420858h1.7183599v12.38893815h-1.7183599v-6.01984144h-4.2484299v6.01984144h-1.71791z" class="style-scope primary-nav"></path><path d="m46.8631973 12.3083598c1.1086774 0 1.3273532-.2759209 1.3273532-1.711901v-7.91645358c0-1.43598014-.2186758-1.71144266-1.3273532-1.71144266v-.46109033h4.3735162v.46109033c-1.093829 0-1.3273532.27546252-1.3273532 1.71144266v7.91645358c0 1.4359801.2335242 1.711901 1.3273532 1.711901v.4597153h-4.3735162z" class="style-scope primary-nav"></path><path d="m56.1269544 2.73592273c-.4998947-1.67569211-.6407291-1.67569211-1.8902409-1.95207131v-.40471447h3.0304147l3.0614614 10.08806985h.0310465l2.9840699-10.08806985h1.0146377l-3.8106284 12.38893815h-1.3588497z" class="style-scope primary-nav"></path><path d="m68.8422796 2.88304997c0-1.82281935-.0467948-1.82281935-1.4839359-2.09919855v-.40471447h7.4826722l.0467949 2.7243747h-.4378016c0-1.47264736-.6555775-1.85948657-1.6868634-1.85948657h-1.2184652c-.7806636 0-.9835912.07333445-.9835912.95747287v3.66351396h1.8902409c1.0767309 0 1.1865187-.80942895 1.2805583-1.41672984h.4369017v3.86518369h-.4369017c0-.9941401-.3437619-1.58356571-1.2805583-1.58356571h-1.8902409v4.10535405c0 1.0308073.2029276 1.0679328.9835912 1.0679328h1.7345581c.8895516 0 1.311155-.3685056 1.4051946-1.8040274h.4378015l-.0476947 2.6689156h-6.2322605z" class="style-scope primary-nav"></path></g><g transform="translate(.24177 .277385)" class="style-scope primary-nav"><path d="m1.57302598 10.3699491v-8.03470531c0-1.45706379-.25962128-1.73802639-1.57302598-1.73802639v-.46659042h5.18252665v.46659042c-1.29540668 0-1.57302597.2809626-1.57302597 1.73802639v8.03470531c0 1.4575222.27761929 1.7366514 1.57302597 1.7366514v.4675071h-5.18252665v-.4675071c1.3134047 0 1.57302598-.2791292 1.57302598-1.7366514z" class="style-scope primary-nav"></path><path d="m10.0331719 2.39116131c0-1.73756805-.25872136-1.66240024-1.85064525-1.98003007v-.41113124h3.90556795l5.830455 10.1641543h.0368959v-10.1641543h1.1662709v12.5741076h-1.7773033l-6.1076243-10.63028642h-.0373459v10.63028642h-1.166271z" class="style-scope primary-nav"></path><path d="m25.9161467.87818h-1.2774087c-1.4618883 0-1.8875412.46704876-1.9991288 1.83198615h-.5178928l.0737919-2.71016615h9.4768516l.0742417 2.76562533h-.5183426c0-1.43873018-.5925845-1.88744533-2.0175768-1.88744533h-1.2580608v11.6959276h-2.0364747z" class="style-scope primary-nav"></path><path d="m36.505907 2.54103859c0-1.84986143-.0562438-1.84986143-1.7593054-2.12990735v-.41113124h8.8658192l.0557938 2.76562533h-.5183426c0-1.49510604-.777064-1.88744533-1.9982289-1.88744533h-1.4443403c-.9255476 0-1.1662709.07516781-1.1662709.97213976v3.71805646h2.2398522c1.2769587 0 1.4060944-.82272082 1.5176821-1.43964686h.5187926v3.92430959h-.5187926c0-1.00880698-.406755-1.60648273-1.5176821-1.60648273h-2.2398522v4.16631328c0 1.0463909.2407233 1.0830581 1.1662709 1.0830581h2.0544728c1.0555832 0 1.554578-.3735473 1.6652657-1.83061113h.5192426l-.0557938 2.70879113h-7.3845831z" class="style-scope primary-nav"></path><path d="m48.7037894 2.54103859c0-1.84986143-.0368959-1.84986143-1.7575055-2.12990735v-.41113124h4.5525963c1.3885464 0 5.2194226 0 5.2194226 3.34450912 0 2.13036568-1.3687486 2.8403348-2.8315368 3.08325515l3.4056733 6.14634333h-2.1287145l-3.2756376-5.81083823h-1.1478231v5.81083823h-2.0364747zm2.0364747 3.34405077h1.0555833c1.202267 0 2.8873305-.33550509 2.8873305-2.42782853 0-2.01898899-1.147823-2.57908083-2.7028509-2.57908083-1.2400629 0-1.2400629.33596344-1.2400629 1.68256722z" class="style-scope primary-nav"></path><path d="m62.1435345 2.39116131c0-1.73756805-.2596213-1.66240024-1.8510952-1.98003007v-.41113124h3.905118l5.830005 10.1641543h.0373458v-10.1641543h1.166271v12.5741076h-1.7764035l-6.1085242-10.63028642h-.0368959v10.63028642h-1.165821z" class="style-scope primary-nav"></path><path d="m75.9895846 2.54103859c0-1.84986143-.0553439-1.84986143-1.7584055-2.12990735v-.41113124h8.8658192l.0557938 2.76562533h-.5183426c0-1.49510604-.777964-1.88744533-1.9991289-1.88744533h-1.4438902c-.9250977 0-1.1658211.07516781-1.1658211.97213976v3.71805646h2.2394023c1.2774087 0 1.4060944-.82272082 1.5176821-1.43964686h.5187926v3.92430959h-.5187926c0-1.00880698-.406755-1.60648273-1.5176821-1.60648273h-2.2394023v4.16631328c0 1.0463909.2407234 1.0830581 1.1658211 1.0830581h2.0544727c1.0555832 0 1.5550279-.3735473 1.6661657-1.83061113h.5183426l-.0557938 2.70879113h-7.385033z" class="style-scope primary-nav"></path><path d="m90.2243917.87818h-1.2765088c-1.4623382 0-1.8879911.46704876-1.9995788 1.83198615h-.5178927l.0742418-2.71016615h9.4759517l.0742418 2.76562533h-.5178928c0-1.43873018-.5921344-1.88744533-2.0180267-1.88744533h-1.2585108v11.6959276h-2.0360247z" class="style-scope primary-nav"></path></g></g></svg>
<!----></a>

      <button class="search-trigger style-scope primary-nav" data-event-click-tracking="BetaTopNav|NavSearchOpen">

  <svg height="40" viewBox="0 0 40 40" width="40" xmlns="http://www.w3.org/2000/svg" aria-labelledby="searchTitleID searchDescID" class="style-scope primary-nav">
    <title id="searchTitleID" class="style-scope primary-nav">Search icon</title>
    <desc id="searchDescID" class="style-scope primary-nav">An illustration of a magnifying glass.</desc>
    <path class="fill-color style-scope primary-nav" d="m32.4526364 29.8875889-8.1719472-7.9751279c1.1046135-1.4876138 1.7652549-3.3102407 1.7652549-5.2846451 0-.101185-.0142895-.1981539-.030573-.2944743.0166158-.0976175.0309053-.196208.0309053-.2990145 0-4.9814145-4.152935-9.0343271-9.2572866-9.0343271-.0907218 0-.1781206.01394537-.2655193.02594487-.0880633-.0119995-.1747974-.02594487-.2655193-.02594487-5.1046839 0-9.25761889 4.0529126-9.25761889 9.0343271 0 .1011849.01395722.1981539.03057294.2947985-.01694804.0976176-.03090525.1958838-.03090525.2986903 0 4.9814145 4.1526027 9.0346514 9.2572866 9.0346514.0907218 0 .1777882-.0139454.2658516-.0262692.0873987.0123238.1741328.0262692.265187.0262692 1.7306942 0 3.3467399-.4747911 4.7338208-1.2852439l8.2882574 8.0886366c.3652137.3564177.843082.53414 1.3212826.53414.4782007 0 .9567336-.1780467 1.3212827-.53414.7294304-.7118622.7294304-1.8660845-.0003323-2.5782711zm-15.9526364-7.8875889c-.0832667-.0118703-.1652765-.0253024-.2513711-.0253024-2.8781993 0-5.2197212-2.3278242-5.2197212-5.1891862 0-.0974612-.013197-.1908615-.0289077-.2836371.0160249-.0940251.0292219-.1889874.0292219-.2880105 0-2.861362 2.3418361-5.1891861 5.2200354-5.1891861.0854662 0 .1677902-.0131198.2510569-.0246777.0826383.0115579.1649623.0246777.2510569.0246777 2.8781993 0 5.2197212 2.3278241 5.2197212 5.1891861 0 .0974612.0135112.1908616.0289077.2839496-.0157107.0940251-.0295361.1886749-.0295361.287698 0 2.861362-2.3415219 5.1891862-5.2197212 5.1891862-.0860946 0-.1684187.0134321-.2507427.0253024z" fill-rule="evenodd"></path>
  </svg>

      </button>
      <nav-search class="style-scope primary-nav x-scope nav-search-1"><!----><div class="search-activated fade-in search-inactive style-scope nav-search">
      <form id="nav-search" class="highlight style-scope nav-search" method="get" action="https://archive.org/search.php" data-event-submit-tracking="BetaTopNav|NavSearchSubmit">
        <input type="text" name="query" class="search-field style-scope nav-search" placeholder="Search" autocomplete="off">
        <input type="hidden" name="sin" class="style-scope nav-search" value="">
        <button type="submit" class="search style-scope nav-search" data-event-click-tracking="BetaTopNav|NavSearchClose">

  <svg height="40" viewBox="0 0 40 40" width="40" xmlns="http://www.w3.org/2000/svg" aria-labelledby="searchTitleID searchDescID" class="style-scope nav-search">
    <title id="searchTitleID" class="style-scope nav-search">Search icon</title>
    <desc id="searchDescID" class="style-scope nav-search">An illustration of a magnifying glass.</desc>
    <path class="fill-color style-scope nav-search" d="m32.4526364 29.8875889-8.1719472-7.9751279c1.1046135-1.4876138 1.7652549-3.3102407 1.7652549-5.2846451 0-.101185-.0142895-.1981539-.030573-.2944743.0166158-.0976175.0309053-.196208.0309053-.2990145 0-4.9814145-4.152935-9.0343271-9.2572866-9.0343271-.0907218 0-.1781206.01394537-.2655193.02594487-.0880633-.0119995-.1747974-.02594487-.2655193-.02594487-5.1046839 0-9.25761889 4.0529126-9.25761889 9.0343271 0 .1011849.01395722.1981539.03057294.2947985-.01694804.0976176-.03090525.1958838-.03090525.2986903 0 4.9814145 4.1526027 9.0346514 9.2572866 9.0346514.0907218 0 .1777882-.0139454.2658516-.0262692.0873987.0123238.1741328.0262692.265187.0262692 1.7306942 0 3.3467399-.4747911 4.7338208-1.2852439l8.2882574 8.0886366c.3652137.3564177.843082.53414 1.3212826.53414.4782007 0 .9567336-.1780467 1.3212827-.53414.7294304-.7118622.7294304-1.8660845-.0003323-2.5782711zm-15.9526364-7.8875889c-.0832667-.0118703-.1652765-.0253024-.2513711-.0253024-2.8781993 0-5.2197212-2.3278242-5.2197212-5.1891862 0-.0974612-.013197-.1908615-.0289077-.2836371.0160249-.0940251.0292219-.1889874.0292219-.2880105 0-2.861362 2.3418361-5.1891861 5.2200354-5.1891861.0854662 0 .1677902-.0131198.2510569-.0246777.0826383.0115579.1649623.0246777.2510569.0246777 2.8781993 0 5.2197212 2.3278241 5.2197212 5.1891861 0 .0974612.0135112.1908616.0289077.2839496-.0157107.0940251-.0295361.1886749-.0295361.287698 0 2.861362-2.3415219 5.1891862-5.2197212 5.1891862-.0860946 0-.1684187.0134321-.2507427.0253024z" fill-rule="evenodd"></path>
  </svg>

        </button>
      </form>
    </div><!----></nav-search>

        <a class="upload style-scope primary-nav" href="https://archive.org/create/">

  <svg width="40" height="41" viewBox="0 0 40 41" xmlns="http://www.w3.org/2000/svg" aria-labelledby="uploadTitleID uploadDescID" class="style-scope primary-nav">
    <title id="uploadTitleID" class="style-scope primary-nav">Upload icon</title>
    <desc id="uploadDescID" class="style-scope primary-nav">An illustration of a horizontal line over an up pointing arrow.</desc>
    <path class="fill-color style-scope primary-nav" d="m20 12.8 8 10.4h-4.8v8.8h-6.4v-8.8h-4.8zm12-4.8v3.2h-24v-3.2z" fill-rule="evenodd"></path>
  </svg>

          <span class="style-scope primary-nav">Upload</span>
        </a>
        <div class="user-info style-scope primary-nav">

      <login-button class="style-scope primary-nav x-scope login-button-1"><!---->
      <div class="logged-out-toolbar style-scope login-button">
        <a class="dropdown-toggle style-scope login-button" data-event-click-tracking="BetaTopNav|NavLoginIcon">

  <svg width="40" height="40" viewBox="0 0 40 40" xmlns="http://www.w3.org/2000/svg" aria-labelledby="userTitleID userDescID" class="style-scope login-button">
    <title id="userTitleID" class="style-scope login-button">User icon</title>
    <desc id="userDescID" class="style-scope login-button">An illustration of a person\'s head and chest.</desc>
    <path class="fill-color style-scope login-button" d="m20.7130435 18.0434783c-3.5658385 0-6.4565218-2.9198821-6.4565218-6.5217392 0-3.60185703 2.8906833-6.5217391 6.4565218-6.5217391s6.4565217 2.91988207 6.4565217 6.5217391c0 3.6018571-2.8906832 6.5217392-6.4565217 6.5217392zm-12.9130435 16.9565217c0-7.9240855 5.7813665-14.3478261 12.9130435-14.3478261s12.9130435 6.4237406 12.9130435 14.3478261z" fill-rule="evenodd"></path>
  </svg>

        </a>
        <span class="style-scope login-button">
          <a class="style-scope login-button" href="https://archive.org/account/signup">Sign up</a>
          |
          <a class="style-scope login-button" href="https://archive.org/account/login">Log in</a>
        </span>
      </div>
    <!----></login-button>

        </div>
        <media-menu class="style-scope primary-nav x-scope media-menu-1" tabindex="-1"><!---->
      <nav class="media-menu tx-slide closed style-scope media-menu" aria-hidden="true" aria-expanded="false">
        <div class="menu-group style-scope media-menu">
          <!---->
        <media-button class="style-scope media-menu x-scope media-button-1" data-mediatype="web"><!---->
      <a class="menu-item web  style-scope media-button" href="https://archive.org/web/" data-event-click-tracking="BetaTopNav|NavMenuWeb">

      <span class="icon  style-scope media-button">

  <svg height="40" viewBox="0 0 40 40" width="40" xmlns="http://www.w3.org/2000/svg" aria-labelledby="webTitleID webDescID" class="style-scope media-button">
    <title id="webTitleID" class="style-scope media-button">Web icon</title>
    <desc id="webDescID" class="style-scope media-button">An illustration of a computer application window</desc>
    <path class="fill-color style-scope media-button" d="m8 28.7585405v-8.1608108-9.3577297h24v9.3577297 8.1608108zm14.2702703-15.8863783h-12.43243246v2.6114594h12.43243246zm7.7837838 14.0365946v-7.0727027-1.8497838h-20.21621626v1.8497838 7.0727027zm-3.7837838-14.0365946h-2.7027027v2.6114594h2.7027027zm4 0h-2.7027027v2.6114594h2.7027027z" fill-rule="evenodd"></path>
  </svg>

      </span>
      <span class="label style-scope media-button"><!---->Wayback Machine<!----></span>

      </a>
    <!----></media-button>
      <!---->
        <media-button class="style-scope media-menu x-scope media-button-1" data-mediatype="texts"><!---->
      <a class="menu-item texts  style-scope media-button" href="https://archive.org/details/texts" data-event-click-tracking="BetaTopNav|NavMenuTexts">

      <span class="icon  style-scope media-button">

  <svg height="40" viewBox="0 0 40 40" width="40" xmlns="http://www.w3.org/2000/svg" aria-labelledby="textsTitleID textsDescID" class="style-scope media-button">
    <title id="textsTitleID" class="style-scope media-button">Texts icon</title>
    <desc id="textsDescID" class="style-scope media-button">An illustration of an open book.</desc>
    <path class="fill-color style-scope media-button" d="m10.3323235 11.0007023h6.9060825c.8851083 0 1.5847122.3064258 2.0988114.9192774v14.4324451h-.6460032c-.1435563-.120323-.3528315-.2434552-.6278257-.3693964-.2749942-.1259413-.5201585-.2191097-.7354929-.2795053l-.3048241-.1081503h-5.7042647c-.3108832 0-.5621067-.0601615-.7536705-.1804846-.0717781-.0599274-.1256117-.1439663-.1615008-.2521166-.0358891-.1081502-.0598928-.2043619-.0720112-.2886348v-13.8741368zm19.1752505 0v13.603761c-.0717781.3361555-.2211606.5943584-.4481473.7746089-.0717781.0599274-.1733862.1079162-.304824.1439663-.1314379.0360501-.2451643.0601615-.3411793.0723343h-5.5965975c-.9568865.2640552-1.5068748.5164059-1.649965.757052h-.6634817v-14.4324451c.5140992-.6128516 1.2076439-.9192774 2.0806339-.9192774h6.92426zm1.3814961.6489017-.1796783 15.2976474c-.0955489 0-1.0342578.0119386-2.8161268.035816-1.7818691.0238773-3.3006293.0898911-4.5562806.1980414-1.2556514.1081503-1.9613144.2884008-2.1169891.5407514-.0955488.1924233-.5439291.273419-1.345141.2429871-.8012118-.0304319-1.3155441-.1776755-1.5429969-.4417308-.334654-.3843783-3.4558378-.5765674-9.36355164-.5765674v-15.3875385l-.96830576.3960828v16.2702977c6.4096947-.2041278 9.7760429-.0840388 10.0990445.3602669.2391051.276228.9864833.414342 2.2421347.414342.1915638 0 .4187835-.0210682.6816593-.0632047s.4810068-.0870821.6543929-.1348367c.1733862-.0477547.2719646-.0838048.2957353-.1081503.0838965-.1563732.9599161-.2675666 2.6280587-.3335805 1.6681426-.0660138 3.3213703-.0931684 4.9596831-.0814638l2.4392915.0182591v-16.2344816z"></path>
  </svg>

      </span>
      <span class="label style-scope media-button"><!---->Books<!----></span>

      </a>
    <!----></media-button>
      <!---->
        <media-button class="style-scope media-menu x-scope media-button-1" data-mediatype="video"><!---->
      <a class="menu-item video  style-scope media-button" href="https://archive.org/details/movies" data-event-click-tracking="BetaTopNav|NavMenuVideo">

      <span class="icon  style-scope media-button">

  <svg height="40" viewBox="0 0 40 40" width="40" xmlns="http://www.w3.org/2000/svg" aria-labelledby="videoTitleID videoDescID" class="style-scope media-button">
    <title id="videoTitleID" class="style-scope media-button">Video icon</title>
    <desc id="videoDescID" class="style-scope media-button">An illustration of two cells of a film strip.</desc>
    <path class="fill-color style-scope media-button" d="m31.0117647 12.0677966c0 .4067797-.2823529.6779661-.7058823.6779661h-1.2705883c-.4235294 0-.7058823-.2711864-.7058823-.6779661v-.6779661c0-.4067797.2823529-.6779661.7058823-.6779661h1.2705883c.4235294 0 .7058823.2711864.7058823.6779661zm0 3.2542373c0 .4067797-.2823529.6779661-.7058823.6779661h-1.2705883c-.4235294 0-.7058823-.2711864-.7058823-.6779661v-.6779661c0-.4067797.2823529-.6779661.7058823-.6779661h1.2705883c.4235294 0 .7058823.2711864.7058823.6779661zm0 3.2542373c0 .4067796-.2823529.6779661-.7058823.6779661h-1.2705883c-.4235294 0-.7058823-.2711865-.7058823-.6779661v-.6779661c0-.4067797.2823529-.6779661.7058823-.6779661h1.2705883c.4235294 0 .7058823.2711864.7058823.6779661zm0 3.3898305c0 .4067797-.2823529.6779661-.7058823.6779661h-1.2705883c-.4235294 0-.7058823-.2711864-.7058823-.6779661v-.6779661c0-.4067797.2823529-.6779661.7058823-.6779661h1.2705883c.4235294 0 .7058823.2711864.7058823.6779661zm0 3.2542373c0 .4067796-.2823529.6779661-.7058823.6779661h-1.2705883c-.4235294 0-.7058823-.2711865-.7058823-.6779661v-.6779661c0-.4067797.2823529-.6779661.7058823-.6779661h1.2705883c.4235294 0 .7058823.2711864.7058823.6779661zm0 3.2542373c0 .4067796-.2823529.6779661-.7058823.6779661h-1.2705883c-.4235294 0-.7058823-.2711865-.7058823-.6779661v-.6779661c0-.4067797.2823529-.6779661.7058823-.6779661h1.2705883c.4235294 0 .7058823.2711864.7058823.6779661zm-4.0941176-10.440678c0 .5423729-.4235295.9491525-.9882353.9491525h-11.5764706c-.5647059 0-.9882353-.4067796-.9882353-.9491525v-6.9152542c0-.5423729.4235294-.9491526.9882353-.9491526h11.5764706c.5647058 0 .9882353.4067797.9882353.9491526zm-.1411765 11.2542373c0 .5423729-.4235294.9491525-.9882353.9491525h-11.5764706c-.5647059 0-.9882353-.4067796-.9882353-.9491525v-6.9152542c0-.5423729.4235294-.9491526.9882353-.9491526h11.5764706c.5647059 0 .9882353.4067797.9882353.9491526zm-14.9647059-17.220339c0 .4067797-.2823529.6779661-.7058823.6779661h-1.27058828c-.42352941 0-.70588236-.2711864-.70588236-.6779661v-.6779661c0-.4067797.28235295-.6779661.70588236-.6779661h1.27058828c.4235294 0 .7058823.2711864.7058823.6779661zm0 3.2542373c0 .4067797-.2823529.6779661-.7058823.6779661h-1.27058828c-.42352941 0-.70588236-.2711864-.70588236-.6779661v-.6779661c0-.4067797.28235295-.6779661.70588236-.6779661h1.27058828c.4235294 0 .7058823.2711864.7058823.6779661zm0 3.2542373c0 .4067796-.2823529.6779661-.7058823.6779661h-1.27058828c-.42352941 0-.70588236-.2711865-.70588236-.6779661v-.6779661c0-.4067797.28235295-.6779661.70588236-.6779661h1.27058828c.4235294 0 .7058823.2711864.7058823.6779661zm0 3.3898305c0 .4067797-.2823529.6779661-.7058823.6779661h-1.27058828c-.42352941 0-.70588236-.2711864-.70588236-.6779661v-.6779661c0-.4067797.28235295-.6779661.70588236-.6779661h1.27058828c.4235294 0 .7058823.2711864.7058823.6779661zm0 3.2542373c0 .4067796-.2823529.6779661-.7058823.6779661h-1.27058828c-.42352941 0-.70588236-.2711865-.70588236-.6779661v-.6779661c0-.4067797.28235295-.6779661.70588236-.6779661h1.27058828c.4235294 0 .7058823.2711864.7058823.6779661zm0 3.2542373c0 .4067796-.2823529.6779661-.7058823.6779661h-1.27058828c-.42352941 0-.70588236-.2711865-.70588236-.6779661v-.6779661c0-.4067797.28235295-.6779661.70588236-.6779661h1.27058828c.4235294 0 .7058823.2711864.7058823.6779661zm20.0470588-20.4745763h-.8470588v.27118644.6779661c0 .40677966-.2823529.6779661-.7058823.6779661h-1.2705883c-.4235294 0-.7058823-.27118644-.7058823-.6779661v-.6779661-.27118644h-16.5176471v.27118644.6779661c0 .40677966-.2823529.6779661-.7058823.6779661h-1.27058828c-.42352941 0-.70588236-.27118644-.70588236-.6779661v-.6779661-.27118644h-1.12941176v24h1.12941176v-.2711864-.6779661c0-.4067797.28235295-.6779661.70588236-.6779661h1.27058828c.4235294 0 .7058823.2711864.7058823.6779661v.6779661.2711864h16.6588235v-.2711864-.6779661c0-.4067797.282353-.6779661.7058824-.6779661h1.2705882c.4235294 0 .7058824.2711864.7058824.6779661v.6779661.2711864h.8470588v-24z" fill-rule="evenodd"></path>
  </svg>

      </span>
      <span class="label style-scope media-button"><!---->Video<!----></span>

      </a>
    <!----></media-button>
      <!---->
        <media-button class="style-scope media-menu x-scope media-button-1" data-mediatype="audio"><!---->
      <a class="menu-item audio  style-scope media-button" href="https://archive.org/details/audio" data-event-click-tracking="BetaTopNav|NavMenuAudio">

      <span class="icon  style-scope media-button">

  <svg width="40px" height="40px" viewBox="0 0 40 40" version="1.1" xmlns="http://www.w3.org/2000/svg" aria-labelledby="audioTitleID audioDescID" class="style-scope media-button">
    <title id="audioTitleID" class="style-scope media-button">Audio icon</title>
    <desc id="audioDescID" class="style-scope media-button">An illustration of an audio speaker.</desc>
    <g stroke="none" stroke-width="1" fill="none" fill-rule="evenodd" class="style-scope media-button">
      <g transform="translate(10, 8)" class="fill-color style-scope media-button">
        <path d="M19.4264564,11.8585048 L19.4264564,20.7200433 C19.4264564,22.3657576 18.8838179,23.2519114 16.8489237,23.2519114 C12.2364969,23.125318 7.75972977,23.125318 3.14730298,23.2519114 C1.24806842,23.2519114 0.569770368,22.492351 0.569770368,20.7200433 L0.569770368,2.74377955 C0.569770368,1.09806526 1.11240881,0.211911416 3.14730298,0.211911416 C7.75972977,0.338504822 12.2364969,0.338504822 16.8489237,0.211911416 C18.7481583,0.211911416 19.4264564,0.971471855 19.4264564,2.74377955 C19.2907967,5.78202131 19.4264564,8.82026306 19.4264564,11.8585048 L19.4264564,11.8585048 Z M10.0659432,2.74377955 C8.16670861,2.74377955 6.67445288,4.13630702 6.67445288,5.90861471 C6.67445288,7.6809224 8.16670861,9.07344988 10.0659432,9.07344988 C11.9651777,9.07344988 13.4574335,7.6809224 13.4574335,5.90861471 C13.4574335,4.13630702 11.8295181,2.74377955 10.0659432,2.74377955 L10.0659432,2.74377955 Z M10.0659432,11.4787246 C7.21709133,11.4787246 5.04653754,13.6308125 5.04653754,16.1626806 C5.04653754,18.8211422 7.35275094,20.8466367 10.0659432,20.8466367 C12.914795,20.8466367 15.0853488,18.6945488 15.0853488,16.1626806 C15.0853488,13.6308125 12.7791354,11.4787246 10.0659432,11.4787246 L10.0659432,11.4787246 Z" class="style-scope media-button"></path>
        <ellipse cx="10.2016028" cy="16.5690777" rx="1.35659611" ry="1.34075134" class="style-scope media-button"></ellipse>
      </g>
    </g>
  </svg>

      </span>
      <span class="label style-scope media-button"><!---->Audio<!----></span>

      </a>
    <!----></media-button>
      <!---->
        <media-button class="style-scope media-menu x-scope media-button-1" data-mediatype="software"><!---->
      <a class="menu-item software  style-scope media-button" href="https://archive.org/details/software" data-event-click-tracking="BetaTopNav|NavMenuSoftware">

      <span class="icon  style-scope media-button">

  <svg width="40" height="40" viewBox="0 0 40 40" xmlns="http://www.w3.org/2000/svg" aria-labelledby="softwareTitleID softwareDescID" class="style-scope media-button">
    <title id="softwareTitleID" class="style-scope media-button">Software icon</title>
    <desc id="softwareDescID" class="style-scope media-button">An illustration of a 3.5" floppy disk.</desc>
    <path class="fill-color style-scope media-button" d="m32 30.6900373v-21.44521088c0-.82988428-.4156786-1.24482642-1.2470357-1.24482642h-21.50592858c-.83135715 0-1.24703572.4221795-1.24703572 1.26653851v21.44521089c0 .8588337.41567857 1.2882506 1.24703572 1.2882506h21.48327168c.8458575 0 1.2687863-.4366542 1.2687863-1.3099627zm-5.9950155-20.4410268v6.114667c0 .6694561-.3428744 1.0041841-1.0286232 1.0041841h-10.1294464c-.2622159 0-.4773054-.0802141-.6452685-.2406423s-.2519447-.3642806-.2519447-.6115572v-6.1363791l.0217506-.1311772h12.0326259zm-4.9437353.8295827v5.0010178h3.0405558v-5.0010178zm-9.7134658 18.8035735v-7.753025c0-.5241057.1604108-.9025595.4812325-1.1353613.1897138-.1453504.4011782-.2180256.6343932-.2180256h14.7451099c.3208217 0 .5905898.1091636.8093044.3274907s.3280719.5023936.3280719.8521995v7.8181612l-.0217506.1094652h-16.9772676z"></path>
  </svg>

      </span>
      <span class="label style-scope media-button"><!---->Software<!----></span>

      </a>
    <!----></media-button>
      <!---->
        <media-button class="style-scope media-menu x-scope media-button-1" data-mediatype="images"><!---->
      <a class="menu-item images  style-scope media-button" href="https://archive.org/details/image" data-event-click-tracking="BetaTopNav|NavMenuImages">

      <span class="icon  style-scope media-button">

  <svg height="40" viewBox="0 0 40 40" width="40" xmlns="http://www.w3.org/2000/svg" aria-labelledby="imagesTitleID imagesDescID" class="style-scope media-button">
    <title id="imagesTitleID" class="style-scope media-button">Images icon</title>
    <desc id="imagesDescID" class="style-scope media-button">An illustration of two photographs.</desc>
    <path class="fill-color style-scope media-button" d="m20.8219178 15.3769871c0 1.1136708-.8767123 1.8932404-1.8630137 1.8932404s-1.9726027-.8909367-1.9726027-1.8932404c0-1.0023038.8767123-1.8932404 1.9726027-1.8932404.9863014 0 1.8630137.8909366 1.8630137 1.8932404zm-5.9178082-3.7864808h15.4520548v6.0138225l-1.9726028-3.3410125-2.6301369 6.3479237-2.1917809-2.67281-6.1369863 5.1228859h-2.5205479zm-1.7534247-1.6705063v14.9231892h18.8493151v-14.9231892zm-2.9589041 7.2388604c.2191781 0 1.9726028-.3341012 1.9726028-.3341012v-2.0046075l-4.1643836.5568354c.43835616 4.7887846.87671233 9.9116704 1.31506849 14.700455 6.02739731-.5568354 13.26027401-1.5591391 19.39726031-2.1159746-.1095891-.5568354-.1095891-2.0046075-.2191781-2.67281-.4383562.1113671-1.4246575 0-1.8630137.1113671v.8909367c-5.1506849.4454683-10.3013699 1.1136708-15.4520548 1.6705062.109589-.111367-.5479452-7.0161262-.9863014-10.8026071z" fill-rule="evenodd"></path>
  </svg>

      </span>
      <span class="label style-scope media-button"><!---->Images<!----></span>

      </a>
    <!----></media-button>
      <!---->
        <media-button class="style-scope media-menu x-scope media-button-1" data-mediatype="donate"><!---->
      <a class="menu-item donate  style-scope media-button" href="https://archive.org/donate/" data-event-click-tracking="BetaTopNav|NavMenuDonate">

      <span class="icon  style-scope media-button">

  <svg width="40" height="40" viewBox="0 0 40 40" xmlns="http://www.w3.org/2000/svg" aria-labelledby="donateTitleID donateDescID" class="style-scope media-button">
    <title id="donateTitleID" class="style-scope media-button">Donate icon</title>
    <desc id="donateDescID" class="style-scope media-button">An illustration of a heart shape</desc>
    <path class="fill-color style-scope media-button" d="m30.0120362 11.0857287c-1.2990268-1.12627221-2.8599641-1.65258786-4.682812-1.57894699-.8253588.02475323-1.7674318.3849128-2.8262192 1.08047869-1.0587873.6955659-1.89622 1.5724492-2.512298 2.63065-.591311-1.0588196-1.4194561-1.9357029-2.4844351-2.63065-1.0649791-.69494706-2.0039563-1.05510663-2.8169316-1.08047869-1.2067699-.04950647-2.318187.17203498-3.3342513.66462439-1.0160643.4925893-1.82594378 1.2002224-2.42963831 2.1228992-.60369453.9226769-.91173353 1.9629315-.92411701 3.1207641-.03715043 1.9202322.70183359 3.7665141 2.21695202 5.5388457 1.2067699 1.4035084 2.912594 3.1606786 5.1174721 5.2715107 2.2048782 2.1108321 3.7565279 3.5356901 4.6549492 4.2745742.8253588-.6646243 2.355647-2.0647292 4.5908647-4.2003145s3.9747867-3.9171994 5.218707-5.3448422c1.502735-1.7723316 2.2355273-3.6186135 2.1983769-5.5388457-.0256957-1.7608832-.6875926-3.2039968-1.9866194-4.3302689z"></path>
  </svg>

      </span>
      <span class="label style-scope media-button"><!---->Donate<!----></span>

      </a>
    <!----></media-button>
      <!---->
        <media-button class="style-scope media-menu x-scope media-button-1" data-mediatype="more"><!---->
      <a class="menu-item more  style-scope media-button" href="https://archive.org/about/" data-event-click-tracking="BetaTopNav|NavMenuMore">

      <span class="icon  style-scope media-button">

  <svg height="40" viewBox="0 0 40 40" width="40" xmlns="http://www.w3.org/2000/svg" aria-labelledby="ellipsesTitleID ellipsesDescID" class="style-scope media-button">
    <title id="ellipsesTitleID" class="style-scope media-button">Ellipses icon</title>
    <desc id="ellipsesDescID" class="style-scope media-button">An illustration of text ellipses.</desc>
    <path class="fill-color style-scope media-button" d="m10.5 17.5c1.3807119 0 2.5 1.1192881 2.5 2.5s-1.1192881 2.5-2.5 2.5c-1.38071187 0-2.5-1.1192881-2.5-2.5s1.11928813-2.5 2.5-2.5zm9.5 0c1.3807119 0 2.5 1.1192881 2.5 2.5s-1.1192881 2.5-2.5 2.5-2.5-1.1192881-2.5-2.5 1.1192881-2.5 2.5-2.5zm9.5 0c1.3807119 0 2.5 1.1192881 2.5 2.5s-1.1192881 2.5-2.5 2.5-2.5-1.1192881-2.5-2.5 1.1192881-2.5 2.5-2.5z" fill-rule="evenodd"></path>
  </svg>

      </span>
      <span class="label style-scope media-button"><!---->More<!----></span>

      </a>
    <!----></media-button>
      <!---->
        </div>
      </nav>
    <!----></media-menu>
        <button class="hamburger style-scope primary-nav" tabindex="1" data-event-click-tracking="BetaTopNav|NavHamburger">
          <icon-hamburger class="style-scope primary-nav x-scope icon-hamburger-1"><!---->
      <svg height="40" viewBox="0 0 40 40" width="40" xmlns="http://www.w3.org/2000/svg" aria-labelledby="hamburgerTitleID hamburgerDescID" class="style-scope icon-hamburger">
        <title id="hamburgerTitleID" class="style-scope icon-hamburger">Hamburger icon</title>
        <desc id="hamburgerDescID" class="style-scope icon-hamburger">An icon used to represent a menu that can be toggled by interacting with this icon.</desc>
        <path d="m30.5 26.5c.8284271 0 1.5.6715729 1.5 1.5s-.6715729 1.5-1.5 1.5h-21c-.82842712 0-1.5-.6715729-1.5-1.5s.67157288-1.5 1.5-1.5zm0-8c.8284271 0 1.5.6715729 1.5 1.5s-.6715729 1.5-1.5 1.5h-21c-.82842712 0-1.5-.6715729-1.5-1.5s.67157288-1.5 1.5-1.5zm0-8c.8284271 0 1.5.6715729 1.5 1.5s-.6715729 1.5-1.5 1.5h-21c-.82842712 0-1.5-.6715729-1.5-1.5s.67157288-1.5 1.5-1.5z" fill="#999" fill-rule="evenodd" class="style-scope icon-hamburger"></path>
      </svg>
    <!----></icon-hamburger>
        </button>
      </nav>
    <!----></primary-nav>
        <media-slider class="style-scope ia-topnav x-scope media-slider-1"><!---->
      <div class="overflow-clip closed style-scope media-slider">
        <div class="information-menu closed style-scope media-slider">
          <div class="info-box style-scope media-slider">
            <media-subnav class="style-scope media-slider x-scope media-subnav-1"><!----><!----></media-subnav>
          </div>
        </div>
      </div>
    <!----></media-slider>
      </div>
      <desktop-subnav class="style-scope ia-topnav x-scope desktop-subnav-1"><!---->
      <ul class="style-scope desktop-subnav">
        <!---->
        <li class="style-scope desktop-subnav">
          <a class="about style-scope desktop-subnav" href="https://archive.org/about/"><!---->About<!----><!----></a>
        </li>
      <!---->
        <li class="style-scope desktop-subnav">
          <a class="blog style-scope desktop-subnav" href="https://blog.archive.org/"><!---->Blog<!----><!----></a>
        </li>
      <!---->
        <li class="style-scope desktop-subnav">
          <a class="projects style-scope desktop-subnav" href="https://archive.org/projects/"><!---->Projects<!----><!----></a>
        </li>
      <!---->
        <li class="style-scope desktop-subnav">
          <a class="help style-scope desktop-subnav" href="https://archive.org/about/faqs.php"><!---->Help<!----><!----></a>
        </li>
      <!---->
        <li class="style-scope desktop-subnav">
          <a class="donate style-scope desktop-subnav" href="https://archive.org/donate/"><!---->Donate<!---->
  <svg width="40" height="40" viewBox="0 0 40 40" xmlns="http://www.w3.org/2000/svg" aria-labelledby="donateTitleID donateDescID" class="style-scope desktop-subnav">
    <title id="donateTitleID" class="style-scope desktop-subnav">Donate icon</title>
    <desc id="donateDescID" class="style-scope desktop-subnav">An illustration of a heart shape</desc>
    <path class="fill-color style-scope desktop-subnav" d="m30.0120362 11.0857287c-1.2990268-1.12627221-2.8599641-1.65258786-4.682812-1.57894699-.8253588.02475323-1.7674318.3849128-2.8262192 1.08047869-1.0587873.6955659-1.89622 1.5724492-2.512298 2.63065-.591311-1.0588196-1.4194561-1.9357029-2.4844351-2.63065-1.0649791-.69494706-2.0039563-1.05510663-2.8169316-1.08047869-1.2067699-.04950647-2.318187.17203498-3.3342513.66462439-1.0160643.4925893-1.82594378 1.2002224-2.42963831 2.1228992-.60369453.9226769-.91173353 1.9629315-.92411701 3.1207641-.03715043 1.9202322.70183359 3.7665141 2.21695202 5.5388457 1.2067699 1.4035084 2.912594 3.1606786 5.1174721 5.2715107 2.2048782 2.1108321 3.7565279 3.5356901 4.6549492 4.2745742.8253588-.6646243 2.355647-2.0647292 4.5908647-4.2003145s3.9747867-3.9171994 5.218707-5.3448422c1.502735-1.7723316 2.2355273-3.6186135 2.1983769-5.5388457-.0256957-1.7608832-.6875926-3.2039968-1.9866194-4.3302689z"></path>
  </svg>
<!----></a>
        </li>
      <!---->
        <li class="style-scope desktop-subnav">
          <a class="contact style-scope desktop-subnav" href="https://archive.org/about/contact.php"><!---->Contact<!----><!----></a>
        </li>
      <!---->
        <li class="style-scope desktop-subnav">
          <a class="jobs style-scope desktop-subnav" href="https://archive.org/about/jobs.php"><!---->Jobs<!----><!----></a>
        </li>
      <!---->
        <li class="style-scope desktop-subnav">
          <a class="volunteer style-scope desktop-subnav" href="https://archive.org/about/volunteerpositions.php"><!---->Volunteer<!----><!----></a>
        </li>
      <!---->
        <li class="style-scope desktop-subnav">
          <a class="people style-scope desktop-subnav" href="https://archive.org/about/bios.php"><!---->People<!----><!----></a>
        </li>
      <!---->
      </ul>
    <!----></desktop-subnav>
      <search-menu class="style-scope ia-topnav x-scope search-menu-1" tabindex="-1"><!---->
      <div class="search-menu tx-slide closed style-scope search-menu" aria-hidden="true" aria-expanded="false">
        <!---->
        <label class="style-scope search-menu">
          <input form="nav-search" type="radio" name="sin" class="style-scope search-menu" value="" checked="">
          Search Metadata
        </label>
      <!---->
        <label class="style-scope search-menu">
          <input form="nav-search" type="radio" name="sin" class="style-scope search-menu" value="TXT">
          Search text contents
        </label>
      <!---->
        <label class="style-scope search-menu">
          <input form="nav-search" type="radio" name="sin" class="style-scope search-menu" value="TV">
          Search TV news captions
        </label>
      <!----><!---->
        <label class="style-scope search-menu">
          <input form="nav-search" type="radio" name="sin" class="style-scope search-menu" value="WEB">
          Search archived websites
        </label>
      <!---->
        <a class="advanced-search style-scope search-menu" href="https://archive.org/advancedsearch.php" data-event-click-tracking="BetaTopNav|NavAdvancedSearch">Advanced Search</a>
      </div>
    <!----></search-menu>

      <signed-out-dropdown class="style-scope ia-topnav x-scope signed-out-dropdown-1" tabindex="-1"><!---->
      <nav class="initial style-scope signed-out-dropdown" aria-hidden="true" aria-expanded="false">
        <ul class="style-scope signed-out-dropdown">
          <!---->
        <li class="style-scope signed-out-dropdown"><!----><a class="style-scope signed-out-dropdown" href="https://archive.org/account/signup" data-event-click-tracking="BetaTopNav|NavSignUpDropdown"><!---->Sign up for free<!----></a><!----></li>
      <!---->
        <li class="style-scope signed-out-dropdown"><!----><a class="style-scope signed-out-dropdown" href="https://archive.org/account/login" data-event-click-tracking="BetaTopNav|NavLogInDropdown"><!---->Log in<!----></a><!----></li>
      <!---->
        </ul>
      </nav>
    <!----></signed-out-dropdown>

    </noscript>                      </ia-topnav>

                  </div>
            <input class="js-tvsearch" type="hidden" value=\'{"ands":[],"minday":"06/04/2009","maxday":"04/04/2021"}\'/>
    
        <!-- Begin page content -->
        <main id="maincontent">
                    <div class="container container-ia">

          <script> if(typeof AJS!=\'undefined\') AJS.lists_v_tiles_setup(\'collection\'); </script>
</div><!--/.container-ia-->
<div class="welcome container container-ia width-max" style="background-color:white;">
  <div class="container">
    <div class="row">
      <div class="col-xs-11 col-sm-10 welcome-left">
              <div class="collection-header">
        <div class="collection-brand">
                      <div id="file-dropper-wrap">
              <div id="file-dropper"> </div>
              <img id="file-dropper-img" class="img-responsive" src="https://ia600300.us.archive.org/30/items/librivoxaudio/oldicon.gif" alt="">
            </div>
                    <div class="collection-titles">
            <h1>The LibriVox Free Audiobook Collection</h1>
                      </div>
        </div>
        <div class="collection-summary">
          <p>LibriVox - founded in 2005 - is a community of volunteers from all over the world who record public domain texts: poetry, short stories, whole books, even dramatic works, in many different languages. 

All LibriVox recordings are in the public domain in the USA and available as free downloads on the internet. If you are not in the USA, please check your country\'s copyright law before downloading.

</p>        </div>
      </div>
          </div><!--/.col-xs-11-->
      <div class="col-xs-1 col-sm-2 welcome-right">
        <button class="action-button stealth"
          onclick="return AJS.modal_go(this,{ignore_lnk:1,shown:AJS.embed_codes_adjust})"
          data-target="#cher-modal"><span class="iconochive-share"  aria-hidden="true"></span><span class="sr-only">share</span>          <span class="hidden-xs-span"> Share</span>
        </button><br/>

        <button
          class="action-button stealth js-manage-toggle_list_status"
          data-href="/bookmarks.php?add_bookmark=1&amp;mediatype=collection&amp;identifier=librivoxaudio&amp;title=The+LibriVox+Free+Audiobook+Collection"
          data-target="#favorite-modal"
          data-id="librivoxaudio"
          data-fav-collection="fav-"
          rel="nofollow">
          <span class="iconochive-No_Favorite"  aria-hidden="true"></span><span class="sr-only">No_Favorite</span>          <span class="hidden-xs-span">Favorite</span>
        </button><br/>

                  <a class="stealth topinblock ghost80" href="/services/collection-rss.php?collection=librivoxaudio">
            <span class="iconochive-rss"  aria-hidden="true"></span><span class="sr-only">rss</span>            <span class="hidden-xs-span">RSS</span>
          </a><br/>
        
        
        <div id="editlink" style="display:none">
          <a id="edlink" class="stealth" href="/edit/librivoxaudio"><span class="iconochive-edit"  aria-hidden="true"></span><span class="sr-only">edit</span><span
            class="hidden-xs-span"> Edit</span></a><br/>
                    <a class="stealth" href="//catalogd.archive.org/history/librivoxaudio"><span class="iconochive-time"  aria-hidden="true"></span><span class="sr-only">time</span><span
            class="hidden-xs-span"> History</span></a><br/>
        </div>
      </div><!--/.col-xs-1-->
    </div><!--/.row-->

        <div class="tabbys ">
              <div class="tabby">
          <div>
            <a id="tabby-about-finder"
              class="stealth"
              href="/details/librivoxaudio?tab=about"
              onclick="return AJS.tabby(this,\'tabby-about\')">
                              <span class="tabby-text">ABOUT</span>
                          </a>
          </div>
        </div>
              <div class="tabby in">
          <div>
            <a id="tabby-collection-finder"
              class="stealth tabby-default-finder"
              href="/details/librivoxaudio?tab=collection"
              onclick="return AJS.tabby(this,\'tabby-collection\')">
                              <span class="tabby-text">COLLECTION</span>
                          </a>
          </div>
        </div>
              <div class="tabby">
          <div>
            <a id="tabby-forum-finder"
              class="stealth"
              href="/details/librivoxaudio?tab=forum"
              onclick="return AJS.tabby(this,\'tabby-forum\')">
                              <span class="tabby-text">FORUM</span>
                          </a>
          </div>
        </div>
          <div class="clearfix"> </div>
    </div>
      </div><!--/.container-->
</div><!--/.welcome-->

      <div id="cher-modal" class="modal fade" role="dialog" aria-hidden="true">
      <div class="modal-dialog modal-lg">
        <div class="modal-content" style="padding:10px;">
          <div class="modal-header">
            <button
              type="button"
              class="close"
              data-dismiss="modal"
              aria-hidden="true">
              <span class="iconochive-remove-circle"  aria-hidden="true"></span><span class="sr-only">remove-circle</span>            </button>
            <h3 class="modal-title">Share This Collection</h3>
          </div><!--/.modal-header-->
          <div id="cher-body">
            <div style="text-align:center;margin:50px auto;">
              <div class="topinblock">
                    <div id="sharer">
            <a href="https://twitter.com/intent/tweet?url=https://archive.org/details/librivoxaudio&amp;via=internetarchive&amp;text=The+LibriVox+Free+Audiobook+Collection" target="_blank">
        <div class="sharee iconochive-twitter" data-toggle="tooltip" data-placement="bottom" title="Share to Twitter"></div>
      </a>
      <a href="https://www.facebook.com/sharer/sharer.php?u=https://archive.org/details/librivoxaudio" target="_blank">
        <div class="sharee iconochive-facebook" data-toggle="tooltip" data-placement="bottom" title="Share to Facebook"></div>
      </a>
      <a href="http://www.reddit.com/submit?url=https://archive.org/details/librivoxaudio&amp;title=The+LibriVox+Free+Audiobook+Collection" target="_blank">
        <div class="sharee iconochive-reddit" data-toggle="tooltip" data-placement="bottom" title="Share to Reddit"></div>
      </a>
      <a href="https://www.tumblr.com/share/video?embed=%3Ciframe+width%3D%22640%22+height%3D%22480%22+frameborder%3D%220%22+allowfullscreen+src%3D%22https%3A%2F%2Farchive.org%2Fembed%2F%22+webkitallowfullscreen%3D%22true%22+mozallowfullscreen%3D%22true%22%26gt%3B%26lt%3B%2Fiframe%3E&amp;name=The+LibriVox+Free+Audiobook+Collection" target="_blank">
        <div class="sharee iconochive-tumblr" data-toggle="tooltip" data-placement="bottom" title="Share to Tumblr"></div>
      </a>
      <a href="http://www.pinterest.com/pin/create/button/?url=https://archive.org/details/librivoxaudio&amp;description=The+LibriVox+Free+Audiobook+Collection" target="_blank">
        <div class="sharee iconochive-pinterest" data-toggle="tooltip" data-placement="bottom" title="Share to Pinterest"></div>
      </a>
            <a href="mailto:?body=https://archive.org/details/librivoxaudio&amp;subject=The LibriVox Free Audiobook Collection">
        <div class="sharee iconochive-email" data-toggle="tooltip" data-placement="bottom" title="Share via email"></div>
      </a>
                      </div>
                    <br clear="all" class="clearfix"/>
              </div>
            </div>
                                              </div><!--/#cher-body-->
        </div><!--/.modal-content-->
      </div><!--/.modal-dialog-->
    </div><!--/#cher-modal-->
      <div class="container container-ia nopad">
          <div id="tabby-collection" class="tabby-data in">
        

  <div class="row">

    <div class="columns-facets">
          <h3 class="co-top-row collapsed">
        <button data-toggle=\'collapse\' data-target=\'.facets_collapser\' aria-expanded=\'false\' role=\'button\' aria-controls=\'facets_collapser\' class=\'collapsed\'>
          <span class="label-with-border">Filters</span>
        </button>
        <div class="results_count">
          15,308          <div class="topinblock micro-label" style="padding-top:2px">
            RESULTS          </div>
        </div>
        <div class="sortbar-rule"></div>
      </h3>

                  <form
      class="form-inline search-form search-form--inside"
      action=""
      method="get"
      aria-label="Search this Collection"
      role="search"
      data-event-form-tracking="Collection|SearchForm"
    >
      <input
        class="form-control input-sm searchlist"
        name="and[]"
        placeholder="Search this Collection"
        type="search"
                  value=""
                aria-label="Enter search terms. Filters available below."
      >

                  <div
            class="search-options js-search-options is-open"
      aria-expanded="true"
      aria-label="Search Options"
      data-keep-open-when-changed="true"
    >
      <div class="pre-search-options"></div>
      <fieldset>
                      <label>
      <input
        type="radio"
        name="sin"
        value=""
                  checked
                      >
      <span>Metadata</span>
    </label>
                          <label>
      <input
        type="radio"
        name="sin"
        value="TXT"
                      >
      <span>Text contents</span>
    </label>
                  </fieldset>

          </div>
          
      
      
      
      <button title="Search" type="submit" aria-label="Search">
        <span class="iconochive-search" aria-hidden="true"></span>
      </button>
    </form>
            <br/>
      
      
      <div class="facets_collapser collapse">
        <h5><button data-toggle=\'collapse\' data-target=\'.facet_mediatype\' aria-expanded=\'false\' role=\'button\' aria-controls=\'facet_mediatype\' class=\'collapsed\'>Media Type</button><span class=\'hidden-xs\'>Media Type</span></h5>    <div class="facet_mediatype collapse" >
      <div class="fatable facet-mediatype">
                          <div class="loader-lines"
            data-toggle="tooltip"
            data-placement="top"
            title="Checking for search facets..."
          >
            <!-- visual placeholder until XHR later replaces with real data -->
            <input type="checkbox" disabled>
            <div class="line"></div><div class="line"></div>
            <input type="checkbox" disabled>
            <div class="line"></div><div class="line"></div>
            <input type="checkbox" disabled>
            <div class="line"></div><div class="line"></div>
            <input type="checkbox" disabled>
            <div class="line"></div><div class="line"></div>
            <input type="checkbox" disabled>
            <div class="line"></div><div class="line"></div>
          </div>
                      </div>
    </div>
    <h5><button data-toggle=\'collapse\' data-target=\'.facet_year\' aria-expanded=\'false\' role=\'button\' aria-controls=\'facet_year\' class=\'collapsed\'>Year</button><span class=\'hidden-xs\'>Year</span></h5>    <div class="facet_year collapse" >
      <div class="fatable facet-year">
                          <div class="loader-lines"
            data-toggle="tooltip"
            data-placement="top"
            title="Checking for search facets..."
          >
            <!-- visual placeholder until XHR later replaces with real data -->
            <input type="checkbox" disabled>
            <div class="line"></div><div class="line"></div>
            <input type="checkbox" disabled>
            <div class="line"></div><div class="line"></div>
            <input type="checkbox" disabled>
            <div class="line"></div><div class="line"></div>
            <input type="checkbox" disabled>
            <div class="line"></div><div class="line"></div>
            <input type="checkbox" disabled>
            <div class="line"></div><div class="line"></div>
          </div>
                      </div>
    </div>
    <h5><button data-toggle=\'collapse\' data-target=\'.facet_subject\' aria-expanded=\'false\' role=\'button\' aria-controls=\'facet_subject\' class=\'collapsed\'>Topics &amp; Subjects</button><span class=\'hidden-xs\'>Topics &amp; Subjects</span><a href="/details/librivoxaudio&morf=-subject" class="js-more-facets-click" data-switchtoalpha="-subject"><img class="filter-"
                data-toggle="tooltip"
                src="/images/filter-count.png"
                title="Show sorted alphabetically"
                alt="Show sorted alphabetically"></a></h5>    <div class="facet_subject collapse" >
      <div class="fatable facet-subject">
                          <div class="loader-lines"
            data-toggle="tooltip"
            data-placement="top"
            title="Checking for search facets..."
          >
            <!-- visual placeholder until XHR later replaces with real data -->
            <input type="checkbox" disabled>
            <div class="line"></div><div class="line"></div>
            <input type="checkbox" disabled>
            <div class="line"></div><div class="line"></div>
            <input type="checkbox" disabled>
            <div class="line"></div><div class="line"></div>
            <input type="checkbox" disabled>
            <div class="line"></div><div class="line"></div>
            <input type="checkbox" disabled>
            <div class="line"></div><div class="line"></div>
          </div>
                      </div>
    </div>
    <h5><button data-toggle=\'collapse\' data-target=\'.facet_collection\' aria-expanded=\'false\' role=\'button\' aria-controls=\'facet_collection\' class=\'collapsed\'>Collection</button><span class=\'hidden-xs\'>Collection</span></h5>    <div class="facet_collection collapse" >
      <div class="fatable facet-collection">
                          <div class="loader-lines"
            data-toggle="tooltip"
            data-placement="top"
            title="Checking for search facets..."
          >
            <!-- visual placeholder until XHR later replaces with real data -->
            <input type="checkbox" disabled>
            <div class="line"></div><div class="line"></div>
            <input type="checkbox" disabled>
            <div class="line"></div><div class="line"></div>
            <input type="checkbox" disabled>
            <div class="line"></div><div class="line"></div>
            <input type="checkbox" disabled>
            <div class="line"></div><div class="line"></div>
            <input type="checkbox" disabled>
            <div class="line"></div><div class="line"></div>
          </div>
                      </div>
    </div>
    <h5><button data-toggle=\'collapse\' data-target=\'.facet_creator\' aria-expanded=\'false\' role=\'button\' aria-controls=\'facet_creator\' class=\'collapsed\'>Creator</button><span class=\'hidden-xs\'>Creator</span><a href="/details/librivoxaudio&morf=-creator" class="js-more-facets-click" data-switchtoalpha="-creator"><img class="filter-"
                data-toggle="tooltip"
                src="/images/filter-count.png"
                title="Show sorted alphabetically"
                alt="Show sorted alphabetically"></a></h5>    <div class="facet_creator collapse" >
      <div class="fatable facet-creator">
                          <div class="loader-lines"
            data-toggle="tooltip"
            data-placement="top"
            title="Checking for search facets..."
          >
            <!-- visual placeholder until XHR later replaces with real data -->
            <input type="checkbox" disabled>
            <div class="line"></div><div class="line"></div>
            <input type="checkbox" disabled>
            <div class="line"></div><div class="line"></div>
            <input type="checkbox" disabled>
            <div class="line"></div><div class="line"></div>
            <input type="checkbox" disabled>
            <div class="line"></div><div class="line"></div>
            <input type="checkbox" disabled>
            <div class="line"></div><div class="line"></div>
          </div>
                      </div>
    </div>
    <h5><button data-toggle=\'collapse\' data-target=\'.facet_languageSorter\' aria-expanded=\'false\' role=\'button\' aria-controls=\'facet_languageSorter\' class=\'collapsed\'>Language</button><span class=\'hidden-xs\'>Language</span></h5>    <div class="facet_languageSorter collapse" >
      <div class="fatable facet-languageSorter">
                          <div class="loader-lines"
            data-toggle="tooltip"
            data-placement="top"
            title="Checking for search facets..."
          >
            <!-- visual placeholder until XHR later replaces with real data -->
            <input type="checkbox" disabled>
            <div class="line"></div><div class="line"></div>
            <input type="checkbox" disabled>
            <div class="line"></div><div class="line"></div>
            <input type="checkbox" disabled>
            <div class="line"></div><div class="line"></div>
            <input type="checkbox" disabled>
            <div class="line"></div><div class="line"></div>
            <input type="checkbox" disabled>
            <div class="line"></div><div class="line"></div>
          </div>
                      </div>
    </div>
          </div>

        </div><!--/.columns-facets-->
    

    <div class="columns-items more-pages      js-facets-xhr">
      <div class="co-top-row">
                <div class="sortbar">
          <a href="#" class="focus-on-child-only pull-right" onclick="return AJS.tiles_toggle(this,\'collection\')">
            <div class="lists-button topinblock iconochive-list" data-toggle="tooltip"
                 title="Show&nbsp;as&nbsp;list"></div>
          </a>
          <a href="#" class="focus-on-child-only pull-right" onclick="return AJS.tiles_toggle(this,\'collection\')">
            <div class="tiles-button topinblock iconochive-tiles" data-toggle="tooltip"
                 title="Show&nbsp;thumbnails"></div>
          </a>
          <div class="hidden-xs hidden-sm pull-right" style="height:50px;width:30px;"> </div>
          <div class="micro-label pull-right hidden-tiles">
            <input type="checkbox" name="showdetails" onchange="AJS.showdetails_toggle(this,\'collection\')"/>
            <span class="hidden-xs-span">SHOW </span><span>DETAILS</span>
          </div>

                      <a class="stealth" href="/details/librivoxaudio?&sort=week" rel="nofollow"><div class="up-down">
                              <div class="iconochive-up-solid"  aria-hidden="true"></div><span class="sr-only">up-solid</span>                <div class="iconochive-down-solid in"  aria-hidden="true"></div><span class="sr-only">down-solid</span>                          </div></a>
                    <div class="topinblock">
            <div class="hidden-md hidden-lg">
              <select class="ikind-mobile form-control" onchange="AJS.ikind_mobile_change(this)"><option data-id="views" selected="selected">VIEWS</option>
<option data-id="title">TITLE</option>
<option data-id="date-archived">DATE ARCHIVED</option>
<option data-id="date-published">DATE PUBLISHED</option>
<option data-id="date-reviewed">DATE REVIEWED</option>
<option data-id="date-added">DATE ADDED</option>
<option data-id="creator">CREATOR</option>
</select>
            </div>
          </div>
          <div class="topinblock">
            <div class="hidden-xs hidden-sm">
              <div class="sort-by">
                SORT BY
              </div>
              <span class="big-label blue-pop">
                <a class="ikind stealth in" data-id="views" href="/details/librivoxaudio" rel="nofollow">VIEWS</a><div class="iconochive-dot ikind-sep"></div><a class="ikind stealth" data-id="title" href="/details/librivoxaudio?sort=titleSorter" rel="nofollow">TITLE</a><div class="iconochive-dot ikind-sep hidden"></div><a class="ikind stealth hidden" data-id="date-archived" href="/details/librivoxaudio?sort=-publicdate" rel="nofollow">DATE ARCHIVED</a><div class="iconochive-dot ikind-sep hidden"></div><a class="ikind stealth hidden" data-id="date-published" href="/details/librivoxaudio?sort=-date" rel="nofollow">DATE PUBLISHED</a><div class="iconochive-dot ikind-sep"></div><a class="ikind stealth" id="date_switcher" data-id="date-reviewed" href="/details/librivoxaudio?sort=-reviewdate" rel="nofollow">DATE REVIEWED</a><div class="iconochive-dot ikind-sep hidden"></div><a class="ikind stealth hidden" data-id="date-added" href="/details/librivoxaudio?sort=-addeddate" rel="nofollow">DATE ADDED</a><div class="iconochive-dot ikind-sep"></div><a class="ikind stealth" data-id="creator" href="/details/librivoxaudio?sort=creatorSorter" rel="nofollow">CREATOR</a>              </span>
            </div>
          </div>
        </div><!--/.sortbar-->
        <div class="sortbar-rule"> </div>
      </div><!--/.co-top-row-->


      <div style="position:relative">
                <div id="ikind--week" class="ikind in">
          <div class="results">        <div class="item-ia mobile-header hidden-tiles" data-id="__mobile_header__">
          <div class="views C C1">
            <span class="iconochive-eye"  aria-hidden="true"></span><span class="sr-only">eye</span>          </div>
          <div class="C234">
            <div class="C C2">Title</div>
            <div class="pubdate C C3"><div><div>Date Reviewed</div></div></div>
            <div class="by C C4">Creator</div>
          </div>
          <div class="C C5"></div>
        </div>
        

    <div class="item-ia" data-id="alice_in_wonderland_librivox"
      data-mediatype="audio"
       data-year="2006">

            <a class="stealth" tabindex="-1" href="/details/librivoxaudio">
        <div class="item-parent">
          <div class="item-parent-img" style="background-image: url(\'/services/img/librivoxaudio\')"></div>
          <div class="item-parent-ttl">The LibriVox Free Audiobook Collection</div>
        </div><!--/.item-parent-->
      </a>
      

      <div class="hidden-tiles views C C1" title="all-time views">
                  <nobr class="hidden-xs">14.1<small>M</small></nobr>
          <nobr class="hidden-sm hidden-md hidden-lg">14M</nobr>
              </div>



      
      <div class="C234">
                  <div
            class="
              item-ttl
                                          C C2
            "
          >
            <a href="/details/alice_in_wonderland_librivox" title="Alice\'s Adventures in Wonderland, by Lewis Carroll"
              data-event-click-tracking="GenericNonCollection|ItemTile">
                              <div class="tile-img">
                  <img class="item-img "
                    alt="Alice\'s Adventures in Wonderland, by Lewis Carroll"
                    source=/services/img/alice_in_wonderland_librivox                     style="height:180px">
                </div><!--/.tile-img-->
              
                            
              
              <div class="ttl">
                Alice\'s Adventures in Wonderland, by Lewis Carroll              </div>
            </a>
          </div>
                <div class="hidden-tiles pubdate C C3">
          <nobr class="hidden-xs">Jun 9, 2020</nobr>
          <nobr class="hidden-sm hidden-md hidden-lg">06/20</nobr>
        </div>
        <div class="by C C4">
                                                <span class="hidden-lists">by</span>
              <span class="byv"
                    title="Lewis Carroll">Lewis Carroll</span>
                                          </div><!--/.C4-->
      </div><!--/.C234-->

      <div class="statbar ">
        <div class="mt-icon C C5">
                                <span class="iconochive-audio"  aria-hidden="true"></span><span class="sr-only">audio</span>                  </div>

                  <h6 class="stat " title="all-time views">
            <span class="iconochive-eye"  aria-hidden="true"></span><span class="sr-only">eye</span>            <nobr>14.1<small>M</small></nobr>
          </h6>
        
                  <h6 class="stat">
            <span class="iconochive-favorite"  aria-hidden="true"></span><span class="sr-only">favorite</span>            214          </h6>

                      <h6 class="stat">
              <span class="iconochive-comment"  aria-hidden="true"></span><span class="sr-only">comment</span>              4            </h6>
                                  </div><!--/.statbar-->

          </div><!--/.item-ia-->


    <div class="details-ia hidden-tiles">
      <div class="C1"></div>
              <div class="C234">
          <span>Librivox recording of Alice\'s Adventures in Wonderland, by Lewis Carroll. A children\'s classic! Read by: Chapter 01 Kristen McQuillin Chapter 02 Brad Bush Chapter 03 Roger W. Barnett Chapter 04 Miette Chapter 05 Mark Bradford Chapter 06 Raza Shah Chapter 07 Kara Shallenberg Chapter 08 Kristen McQuillin Chapter 09 MarinaMechanical Chapter 10 Roger W. Barnett Chapter 11 R. Francis Smith Chapter 12 Chris Goringe For further information, including links to online text, reader information, RSS...</span><br/>          <span alt="4.00 out of 5 stars" title="4.00 out of 5 stars"><span class="iconochive-favorite"  aria-hidden="true"></span><span class="sr-only">favorite</span><span class="iconochive-favorite"  aria-hidden="true"></span><span class="sr-only">favorite</span><span class="iconochive-favorite"  aria-hidden="true"></span><span class="sr-only">favorite</span><span class="iconochive-favorite"  aria-hidden="true"></span><span class="sr-only">favorite</span></span> ( 4 reviews )<br/>          Topics: literature, children, audiobook, librivox<br/>          Source: Librivox recording of Gutenberg e-text #11<br/>                  </div>
            <div class="C5"></div>
    </div>

    

    <div class="item-ia" data-id="art_of_war_librivox"
      data-mediatype="audio"
       data-year="2006">

            <a class="stealth" tabindex="-1" href="/details/librivoxaudio">
        <div class="item-parent">
          <div class="item-parent-img" style="background-image: url(\'/services/img/librivoxaudio\')"></div>
          <div class="item-parent-ttl">The LibriVox Free Audiobook Collection</div>
        </div><!--/.item-parent-->
      </a>
      

      <div class="hidden-tiles views C C1" title="all-time views">
                  <nobr class="hidden-xs">13.9<small>M</small></nobr>
          <nobr class="hidden-sm hidden-md hidden-lg">14M</nobr>
              </div>



      
      <div class="C234">
                  <div
            class="
              item-ttl
                                          C C2
            "
          >
            <a href="/details/art_of_war_librivox" title="The Art of War"
              data-event-click-tracking="GenericNonCollection|ItemTile">
                              <div class="tile-img">
                  <img class="item-img "
                    alt="The Art of War"
                    source=/services/img/art_of_war_librivox                     style="height:180px">
                </div><!--/.tile-img-->
              
                            
              
              <div class="ttl">
                The Art of War              </div>
            </a>
          </div>
                <div class="hidden-tiles pubdate C C3">
          <nobr class="hidden-xs">Mar 1, 2021</nobr>
          <nobr class="hidden-sm hidden-md hidden-lg">03/21</nobr>
        </div>
        <div class="by C C4">
                                                <span class="hidden-lists">by</span>
              <span class="byv"
                    title="Sun Tzu">Sun Tzu</span>
                                          </div><!--/.C4-->
      </div><!--/.C234-->

      <div class="statbar ">
        <div class="mt-icon C C5">
                                <span class="iconochive-audio"  aria-hidden="true"></span><span class="sr-only">audio</span>                  </div>

                  <h6 class="stat " title="all-time views">
            <span class="iconochive-eye"  aria-hidden="true"></span><span class="sr-only">eye</span>            <nobr>13.9<small>M</small></nobr>
          </h6>
        
                  <h6 class="stat">
            <span class="iconochive-favorite"  aria-hidden="true"></span><span class="sr-only">favorite</span>            817          </h6>

                      <h6 class="stat">
              <span class="iconochive-comment"  aria-hidden="true"></span><span class="sr-only">comment</span>              24            </h6>
                                  </div><!--/.statbar-->

          </div><!--/.item-ia-->


    <div class="details-ia hidden-tiles">
      <div class="C1"></div>
              <div class="C234">
          <span>Librivox recording of The Art of War by Sun Tzu, translated by Lionel Giles. Read by Moira Fogarty. &quot;The Art of War is a Chinese military treatise written during the 6th century BC by Sun Tzu. Composed of 13 chapters, each of which is devoted to one aspect of warfare, it has long been praised as the definitive work on military strategies and tactics of its time. The Art of War is one of the oldest and most famous studies of strategy and has had a huge influence on both military planning...</span><br/>          <span alt="4.65 out of 5 stars" title="4.65 out of 5 stars"><span class="iconochive-favorite"  aria-hidden="true"></span><span class="sr-only">favorite</span><span class="iconochive-favorite"  aria-hidden="true"></span><span class="sr-only">favorite</span><span class="iconochive-favorite"  aria-hidden="true"></span><span class="sr-only">favorite</span><span class="iconochive-favorite"  aria-hidden="true"></span><span class="sr-only">favorite</span><span class="iconochive-favorite"  aria-hidden="true"></span><span class="sr-only">favorite</span></span> ( 24 reviews )<br/>          Topics: librivox, audiobook, literature, war, Sun Tzu, Sunzi, Lionel Giles<br/>          Source: Librivox recording of a public-domain text<br/>                  </div>
            <div class="C5"></div>
    </div>

    

    <div class="item-ia" data-id="adventures_holmes"
      data-mediatype="audio"
       data-year="2007">

            <a class="stealth" tabindex="-1" href="/details/librivoxaudio">
        <div class="item-parent">
          <div class="item-parent-img" style="background-image: url(\'/services/img/librivoxaudio\')"></div>
          <div class="item-parent-ttl">The LibriVox Free Audiobook Collection</div>
        </div><!--/.item-parent-->
      </a>
      

      <div class="hidden-tiles views C C1" title="all-time views">
                  <nobr class="hidden-xs">11.6<small>M</small></nobr>
          <nobr class="hidden-sm hidden-md hidden-lg">12M</nobr>
              </div>



      
      <div class="C234">
                  <div
            class="
              item-ttl
                                          C C2
            "
          >
            <a href="/details/adventures_holmes" title="The Adventures of Sherlock Holmes"
              data-event-click-tracking="GenericNonCollection|ItemTile">
                              <div class="tile-img">
                  <img class="item-img "
                    alt="The Adventures of Sherlock Holmes"
                    source=/services/img/adventures_holmes                     style="height:180px">
                </div><!--/.tile-img-->
              
                            
              
              <div class="ttl">
                The Adventures of Sherlock Holmes              </div>
            </a>
          </div>
                <div class="hidden-tiles pubdate C C3">
          <nobr class="hidden-xs">Aug 2, 2020</nobr>
          <nobr class="hidden-sm hidden-md hidden-lg">08/20</nobr>
        </div>
        <div class="by C C4">
                                                <span class="hidden-lists">by</span>
              <span class="byv"
                    title="Doyle, Sir Arthur Conan">Doyle, Sir Arthur Conan</span>
                                          </div><!--/.C4-->
      </div><!--/.C234-->

      <div class="statbar ">
        <div class="mt-icon C C5">
                                <span class="iconochive-audio"  aria-hidden="true"></span><span class="sr-only">audio</span>                  </div>

                  <h6 class="stat " title="all-time views">
            <span class="iconochive-eye"  aria-hidden="true"></span><span class="sr-only">eye</span>            <nobr>11.6<small>M</small></nobr>
          </h6>
        
                  <h6 class="stat">
            <span class="iconochive-favorite"  aria-hidden="true"></span><span class="sr-only">favorite</span>            361          </h6>

                      <h6 class="stat">
              <span class="iconochive-comment"  aria-hidden="true"></span><span class="sr-only">comment</span>              25            </h6>
                                  </div><!--/.statbar-->

          </div><!--/.item-ia-->


    <div class="details-ia hidden-tiles">
      <div class="C1"></div>
              <div class="C234">
          <span>Librivox recording of the Adventures of Sherlock Holmes. The Adventures of Sherlock Holmes is a collection of twelve stories by Arthur Conan Doyle, featuring his famous detective. They were originally published in the Strand Magazine from July 1891 to June 1892. The title character was named after famous American poet Oliver Wendell Holmes, Sr. (Summary from Wikipedia) For further information, including links to online text, reader information, RSS feeds, CD cover,m4b or other formats (if...</span><br/>          <span alt="3.26 out of 5 stars" title="3.26 out of 5 stars"><span class="iconochive-favorite"  aria-hidden="true"></span><span class="sr-only">favorite</span><span class="iconochive-favorite"  aria-hidden="true"></span><span class="sr-only">favorite</span><span class="iconochive-favorite"  aria-hidden="true"></span><span class="sr-only">favorite</span></span> ( 25 reviews )<br/>          Topics: librivox, audiobook, literature, Holmes, adventure, Doyle<br/>          Source: Librivox recording of a public-domain text<br/>                  </div>
            <div class="C5"></div>
    </div>

    

    <div class="item-ia" data-id="tom_sawyer_librivox"
      data-mediatype="audio"
       data-year="2006">

            <a class="stealth" tabindex="-1" href="/details/librivoxaudio">
        <div class="item-parent">
          <div class="item-parent-img" style="background-image: url(\'/services/img/librivoxaudio\')"></div>
          <div class="item-parent-ttl">The LibriVox Free Audiobook Collection</div>
        </div><!--/.item-parent-->
      </a>
      

      <div class="hidden-tiles views C C1" title="all-time views">
                  <nobr class="hidden-xs">11.8<small>M</small></nobr>
          <nobr class="hidden-sm hidden-md hidden-lg">12M</nobr>
              </div>



      
      <div class="C234">
                  <div
            class="
              item-ttl
                                          C C2
            "
          >
            <a href="/details/tom_sawyer_librivox" title="The Adventures of Tom Sawyer"
              data-event-click-tracking="GenericNonCollection|ItemTile">
                              <div class="tile-img">
                  <img class="item-img "
                    alt="The Adventures of Tom Sawyer"
                    source=/services/img/tom_sawyer_librivox                     style="height:180px">
                </div><!--/.tile-img-->
              
                            
              
              <div class="ttl">
                The Adventures of Tom Sawyer              </div>
            </a>
          </div>
                <div class="hidden-tiles pubdate C C3">
          <nobr class="hidden-xs">Mar 15, 2021</nobr>
          <nobr class="hidden-sm hidden-md hidden-lg">03/21</nobr>
        </div>
        <div class="by C C4">
                                                <span class="hidden-lists">by</span>
              <span class="byv"
                    title="Mark Twain">Mark Twain</span>
                                          </div><!--/.C4-->
      </div><!--/.C234-->

      <div class="statbar ">
        <div class="mt-icon C C5">
                                <span class="iconochive-audio"  aria-hidden="true"></span><span class="sr-only">audio</span>                  </div>

                  <h6 class="stat " title="all-time views">
            <span class="iconochive-eye"  aria-hidden="true"></span><span class="sr-only">eye</span>            <nobr>11.8<small>M</small></nobr>
          </h6>
        
                  <h6 class="stat">
            <span class="iconochive-favorite"  aria-hidden="true"></span><span class="sr-only">favorite</span>            276          </h6>

                      <h6 class="stat">
              <span class="iconochive-comment"  aria-hidden="true"></span><span class="sr-only">comment</span>              24            </h6>
                                  </div><!--/.statbar-->

          </div><!--/.item-ia-->


    <div class="details-ia hidden-tiles">
      <div class="C1"></div>
              <div class="C234">
          <span>LibriVox recording of The Adventures of Tom Sawyer by Mark Twain. Read by John Greenman. The Adventures of Tom Sawyer (published 1876) is a very well-known and popular story concerning American youth. Mark Twain\'s lively tale of the scrapes and adventures of boyhood is set in St. Petersburg, Missouri, where Tom Sawyer and his friend Huckleberry Finn have the kinds of adventures many boys can imagine: racing bugs during class, impressing girls, with fights and stunts in the schoolyard, getting...</span><br/>          <span alt="4.92 out of 5 stars" title="4.92 out of 5 stars"><span class="iconochive-favorite"  aria-hidden="true"></span><span class="sr-only">favorite</span><span class="iconochive-favorite"  aria-hidden="true"></span><span class="sr-only">favorite</span><span class="iconochive-favorite"  aria-hidden="true"></span><span class="sr-only">favorite</span><span class="iconochive-favorite"  aria-hidden="true"></span><span class="sr-only">favorite</span><span class="iconochive-favorite"  aria-hidden="true"></span><span class="sr-only">favorite</span></span> ( 24 reviews )<br/>          Topics: librivox, audiobook, literature<br/>          Source: Librivox recording of a public-domain text<br/>                  </div>
            <div class="C5"></div>
    </div>

    

    <div class="item-ia" data-id="adventures_sherlockholmes_1007_librivox"
      data-mediatype="audio"
       data-year="2010">

            <a class="stealth" tabindex="-1" href="/details/librivoxaudio">
        <div class="item-parent">
          <div class="item-parent-img" style="background-image: url(\'/services/img/librivoxaudio\')"></div>
          <div class="item-parent-ttl">The LibriVox Free Audiobook Collection</div>
        </div><!--/.item-parent-->
      </a>
      

      <div class="hidden-tiles views C C1" title="all-time views">
                  <nobr class="hidden-xs">5.4<small>M</small></nobr>
          <nobr class="hidden-sm hidden-md hidden-lg">5.4M</nobr>
              </div>



      
      <div class="C234">
                  <div
            class="
              item-ttl
                                          C C2
            "
          >
            <a href="/details/adventures_sherlockholmes_1007_librivox" title="The Adventures of Sherlock Holmes"
              data-event-click-tracking="GenericNonCollection|ItemTile">
                              <div class="tile-img">
                  <img class="item-img "
                    alt="The Adventures of Sherlock Holmes"
                    source=/services/img/adventures_sherlockholmes_1007_librivox                     style="height:180px">
                </div><!--/.tile-img-->
              
                            
              
              <div class="ttl">
                The Adventures of Sherlock Holmes              </div>
            </a>
          </div>
                <div class="hidden-tiles pubdate C C3">
          <nobr class="hidden-xs">Mar 1, 2021</nobr>
          <nobr class="hidden-sm hidden-md hidden-lg">03/21</nobr>
        </div>
        <div class="by C C4">
                                                <span class="hidden-lists">by</span>
              <span class="byv"
                    title="Sir Arthur Conan Doyle">Sir Arthur Conan Doyle</span>
                                          </div><!--/.C4-->
      </div><!--/.C234-->

      <div class="statbar ">
        <div class="mt-icon C C5">
                                <span class="iconochive-audio"  aria-hidden="true"></span><span class="sr-only">audio</span>                  </div>

                  <h6 class="stat " title="all-time views">
            <span class="iconochive-eye"  aria-hidden="true"></span><span class="sr-only">eye</span>            <nobr>5.4<small>M</small></nobr>
          </h6>
        
                  <h6 class="stat">
            <span class="iconochive-favorite"  aria-hidden="true"></span><span class="sr-only">favorite</span>            181          </h6>

                      <h6 class="stat">
              <span class="iconochive-comment"  aria-hidden="true"></span><span class="sr-only">comment</span>              7            </h6>
                                  </div><!--/.statbar-->

          </div><!--/.item-ia-->


    <div class="details-ia hidden-tiles">
      <div class="C1"></div>
              <div class="C234">
          <span>LibriVox recording of The Adventures of Sherlock Holmes, by Sir Arthur Conan Doyle. Read by Mark F. Smith. Dr. Watson chronicles here some of the more interesting detective cases that he and his good friend, Mr. Sherlock Holmes, have encountered during their association. We see the cases unfold as he does, scratch our heads as does he while the evidence is collected, and then marvel at the impeccable observations, remarkable insight, and doggedness which Holmes displays as he teases apart the...</span><br/>          <span alt="4.86 out of 5 stars" title="4.86 out of 5 stars"><span class="iconochive-favorite"  aria-hidden="true"></span><span class="sr-only">favorite</span><span class="iconochive-favorite"  aria-hidden="true"></span><span class="sr-only">favorite</span><span class="iconochive-favorite"  aria-hidden="true"></span><span class="sr-only">favorite</span><span class="iconochive-favorite"  aria-hidden="true"></span><span class="sr-only">favorite</span><span class="iconochive-favorite"  aria-hidden="true"></span><span class="sr-only">favorite</span></span> ( 7 reviews )<br/>          Topics: librivox, audiobook, doyle, mystery, sherlock holmes, literature, adventure<br/>          Source: Librivox recording of a public-domain text<br/>                  </div>
            <div class="C5"></div>
    </div>

    

    <div class="item-ia" data-id="thought_vibration_ap_librivox"
      data-mediatype="audio"
       data-year="2010">

            <a class="stealth" tabindex="-1" href="/details/librivoxaudio">
        <div class="item-parent">
          <div class="item-parent-img" style="background-image: url(\'/services/img/librivoxaudio\')"></div>
          <div class="item-parent-ttl">The LibriVox Free Audiobook Collection</div>
        </div><!--/.item-parent-->
      </a>
      

      <div class="hidden-tiles views C C1" title="all-time views">
                  <nobr class="hidden-xs">359,825</nobr>
          <nobr class="hidden-sm hidden-md hidden-lg">360K</nobr>
              </div>



      
      <div class="C234">
                  <div
            class="
              item-ttl
                                          C C2
            "
          >
            <a href="/details/thought_vibration_ap_librivox" title="Thought Vibration, or The Law of Attraction in the Thought"
              data-event-click-tracking="GenericNonCollection|ItemTile">
                              <div class="tile-img">
                  <img class="item-img "
                    alt="Thought Vibration, or The Law of Attraction in the Thought"
                    source=/services/img/thought_vibration_ap_librivox                     style="height:180px">
                </div><!--/.tile-img-->
              
                            
              
              <div class="ttl">
                Thought Vibration, or The Law of Attraction in the Thought              </div>
            </a>
          </div>
                <div class="hidden-tiles pubdate C C3">
          <nobr class="hidden-xs">Mar 17, 2021</nobr>
          <nobr class="hidden-sm hidden-md hidden-lg">03/21</nobr>
        </div>
        <div class="by C C4">
                                                <span class="hidden-lists">by</span>
              <span class="byv"
                    title="William Walker Atkinson">William Walker Atkinson</span>
                                          </div><!--/.C4-->
      </div><!--/.C234-->

      <div class="statbar ">
        <div class="mt-icon C C5">
                                <span class="iconochive-audio"  aria-hidden="true"></span><span class="sr-only">audio</span>                  </div>

                  <h6 class="stat " title="all-time views">
            <span class="iconochive-eye"  aria-hidden="true"></span><span class="sr-only">eye</span>            <nobr>359,825</nobr>
          </h6>
        
                  <h6 class="stat">
            <span class="iconochive-favorite"  aria-hidden="true"></span><span class="sr-only">favorite</span>            65          </h6>

                      <h6 class="stat">
              <span class="iconochive-comment"  aria-hidden="true"></span><span class="sr-only">comment</span>              1            </h6>
                                  </div><!--/.statbar-->

          </div><!--/.item-ia-->


    <div class="details-ia hidden-tiles">
      <div class="C1"></div>
              <div class="C234">
          <span>LibriVox recording of Thought Vibration, or The Law of Attraction in the Thought, by William Walker Atkinson. Read by Algy Pug. William Walker Atkinson (December 5, 1862 – November 22, 1932) was an attorney, merchant, publisher, and author, as well as an occultist and an American pioneer of the New Thought movement. Atkinson was a prolific writer, and his many books achieved wide circulation among New Thought devotees and occult practitioners. He published under several pen names, including...</span><br/>          <span alt="5.00 out of 5 stars" title="5.00 out of 5 stars"><span class="iconochive-favorite"  aria-hidden="true"></span><span class="sr-only">favorite</span><span class="iconochive-favorite"  aria-hidden="true"></span><span class="sr-only">favorite</span><span class="iconochive-favorite"  aria-hidden="true"></span><span class="sr-only">favorite</span><span class="iconochive-favorite"  aria-hidden="true"></span><span class="sr-only">favorite</span><span class="iconochive-favorite"  aria-hidden="true"></span><span class="sr-only">favorite</span></span> ( 1 reviews )<br/>          Topics: librivox, literature, audiobook, William Walker Atkinson, Thought Vibration<br/>          Source: Librivox recording of a public-domain text<br/>                  </div>
            <div class="C5"></div>
    </div>

    

    <div class="item-ia" data-id="moby_dick_librivox"
      data-mediatype="audio"
       data-year="2007">

            <a class="stealth" tabindex="-1" href="/details/librivoxaudio">
        <div class="item-parent">
          <div class="item-parent-img" style="background-image: url(\'/services/img/librivoxaudio\')"></div>
          <div class="item-parent-ttl">The LibriVox Free Audiobook Collection</div>
        </div><!--/.item-parent-->
      </a>
      

      <div class="hidden-tiles views C C1" title="all-time views">
                  <nobr class="hidden-xs">8.7<small>M</small></nobr>
          <nobr class="hidden-sm hidden-md hidden-lg">8.7M</nobr>
              </div>



      
      <div class="C234">
                  <div
            class="
              item-ttl
                                          C C2
            "
          >
            <a href="/details/moby_dick_librivox" title="Moby Dick, or the Whale"
              data-event-click-tracking="GenericNonCollection|ItemTile">
                              <div class="tile-img">
                  <img class="item-img "
                    alt="Moby Dick, or the Whale"
                    source=/services/img/moby_dick_librivox                     style="height:180px">
                </div><!--/.tile-img-->
              
                            
              
              <div class="ttl">
                Moby Dick, or the Whale              </div>
            </a>
          </div>
                <div class="hidden-tiles pubdate C C3">
          <nobr class="hidden-xs">Mar 23, 2021</nobr>
          <nobr class="hidden-sm hidden-md hidden-lg">03/21</nobr>
        </div>
        <div class="by C C4">
                                                <span class="hidden-lists">by</span>
              <span class="byv"
                    title="Herman Melville">Herman Melville</span>
                                          </div><!--/.C4-->
      </div><!--/.C234-->

      <div class="statbar ">
        <div class="mt-icon C C5">
                                <span class="iconochive-audio"  aria-hidden="true"></span><span class="sr-only">audio</span>                  </div>

                  <h6 class="stat " title="all-time views">
            <span class="iconochive-eye"  aria-hidden="true"></span><span class="sr-only">eye</span>            <nobr>8.7<small>M</small></nobr>
          </h6>
        
                  <h6 class="stat">
            <span class="iconochive-favorite"  aria-hidden="true"></span><span class="sr-only">favorite</span>            395          </h6>

                      <h6 class="stat">
              <span class="iconochive-comment"  aria-hidden="true"></span><span class="sr-only">comment</span>              26            </h6>
                                  </div><!--/.statbar-->

          </div><!--/.item-ia-->


    <div class="details-ia hidden-tiles">
      <div class="C1"></div>
              <div class="C234">
          <span>Librivox recording of Moby Dick, or the Whale, by Herman Melville. Read by Stewart Wills Few things, even in literature, can really be said to be unique -- but Moby Dick is truly unlike anything written before or since. The novel is nominally about the obsessive hunt by the crazed Captain Ahab of the book\'s eponymous white whale. But interspersed in that story are digressions, paradoxes, philosophical riffs on whaling and life, and a display of techniques so advanced for its time that some have...</span><br/>          <span alt="4.73 out of 5 stars" title="4.73 out of 5 stars"><span class="iconochive-favorite"  aria-hidden="true"></span><span class="sr-only">favorite</span><span class="iconochive-favorite"  aria-hidden="true"></span><span class="sr-only">favorite</span><span class="iconochive-favorite"  aria-hidden="true"></span><span class="sr-only">favorite</span><span class="iconochive-favorite"  aria-hidden="true"></span><span class="sr-only">favorite</span><span class="iconochive-favorite"  aria-hidden="true"></span><span class="sr-only">favorite</span></span> ( 26 reviews )<br/>          Topics: librivox, audiobook, literature<br/>          Source: Librivox recording of a public-domain text<br/>                  </div>
            <div class="C5"></div>
    </div>

    

    <div class="item-ia" data-id="goldenbullet_1105_librivox"
      data-mediatype="audio"
       data-year="2011">

            <a class="stealth" tabindex="-1" href="/details/librivoxaudio">
        <div class="item-parent">
          <div class="item-parent-img" style="background-image: url(\'/services/img/librivoxaudio\')"></div>
          <div class="item-parent-ttl">The LibriVox Free Audiobook Collection</div>
        </div><!--/.item-parent-->
      </a>
      

      <div class="hidden-tiles views C C1" title="all-time views">
                  <nobr class="hidden-xs">67,543</nobr>
          <nobr class="hidden-sm hidden-md hidden-lg">68K</nobr>
              </div>



      
      <div class="C234">
                  <div
            class="
              item-ttl
                                          C C2
            "
          >
            <a href="/details/goldenbullet_1105_librivox" title="The Case of the Golden Bullet"
              data-event-click-tracking="GenericNonCollection|ItemTile">
                              <div class="tile-img">
                  <img class="item-img "
                    alt="The Case of the Golden Bullet"
                    source=/services/img/goldenbullet_1105_librivox                     style="height:180px">
                </div><!--/.tile-img-->
              
                            
              
              <div class="ttl">
                The Case of the Golden Bullet              </div>
            </a>
          </div>
                <div class="hidden-tiles pubdate C C3">
          <nobr class="hidden-xs">Mar 19, 2021</nobr>
          <nobr class="hidden-sm hidden-md hidden-lg">03/21</nobr>
        </div>
        <div class="by C C4">
                                                <span class="hidden-lists">by</span>
              <span class="byv"
                    title="Grace Isabel Colbron and Augusta Groner">Grace Isabel Colbron and Augusta Groner</span>
                                          </div><!--/.C4-->
      </div><!--/.C234-->

      <div class="statbar ">
        <div class="mt-icon C C5">
                                <span class="iconochive-audio"  aria-hidden="true"></span><span class="sr-only">audio</span>                  </div>

                  <h6 class="stat " title="all-time views">
            <span class="iconochive-eye"  aria-hidden="true"></span><span class="sr-only">eye</span>            <nobr>67,543</nobr>
          </h6>
        
                  <h6 class="stat">
            <span class="iconochive-favorite"  aria-hidden="true"></span><span class="sr-only">favorite</span>            1          </h6>

                      <h6 class="stat">
              <span class="iconochive-comment"  aria-hidden="true"></span><span class="sr-only">comment</span>              5            </h6>
                                  </div><!--/.statbar-->

          </div><!--/.item-ia-->


    <div class="details-ia hidden-tiles">
      <div class="C1"></div>
              <div class="C234">
          <span>LibriVox recording of The Case of the Golden Bullet by Grace Isabel Colbron and Augusta Groner. Read by Dawn Larsen Joseph Muller, quiet mannered detective, tries to solve the mystery of a man who died in his study, by a bullet hole in the chest. But all windows and doors were locked, from the inside. (summary by Dawn Larsen) For further information, including links to online text, reader information, RSS feeds, CD cover or other formats (if available), please go to the LibriVox catalog page...</span><br/>          <span alt="4.33 out of 5 stars" title="4.33 out of 5 stars"><span class="iconochive-favorite"  aria-hidden="true"></span><span class="sr-only">favorite</span><span class="iconochive-favorite"  aria-hidden="true"></span><span class="sr-only">favorite</span><span class="iconochive-favorite"  aria-hidden="true"></span><span class="sr-only">favorite</span><span class="iconochive-favorite"  aria-hidden="true"></span><span class="sr-only">favorite</span></span> ( 5 reviews )<br/>          Topics: librivox, audiobooks, mystery, detective stories, Austria, Joseph Muller<br/>          Source: Librivox recording of a public-domain text<br/>                  </div>
            <div class="C5"></div>
    </div>

    

    <div class="item-ia" data-id="pride_and_prejudice_librivox"
      data-mediatype="audio"
       data-year="2006">

            <a class="stealth" tabindex="-1" href="/details/librivoxaudio">
        <div class="item-parent">
          <div class="item-parent-img" style="background-image: url(\'/services/img/librivoxaudio\')"></div>
          <div class="item-parent-ttl">The LibriVox Free Audiobook Collection</div>
        </div><!--/.item-parent-->
      </a>
      

      <div class="hidden-tiles views C C1" title="all-time views">
                  <nobr class="hidden-xs">7.4<small>M</small></nobr>
          <nobr class="hidden-sm hidden-md hidden-lg">7.4M</nobr>
              </div>



      
      <div class="C234">
                  <div
            class="
              item-ttl
                                          C C2
            "
          >
            <a href="/details/pride_and_prejudice_librivox" title="Pride and Prejudice"
              data-event-click-tracking="GenericNonCollection|ItemTile">
                              <div class="tile-img">
                  <img class="item-img "
                    alt="Pride and Prejudice"
                    source=/services/img/pride_and_prejudice_librivox                     style="height:180px">
                </div><!--/.tile-img-->
              
                            
              
              <div class="ttl">
                Pride and Prejudice              </div>
            </a>
          </div>
                <div class="hidden-tiles pubdate C C3">
          <nobr class="hidden-xs">May 31, 2020</nobr>
          <nobr class="hidden-sm hidden-md hidden-lg">05/20</nobr>
        </div>
        <div class="by C C4">
                                                <span class="hidden-lists">by</span>
              <span class="byv"
                    title="Jane Austen">Jane Austen</span>
                                          </div><!--/.C4-->
      </div><!--/.C234-->

      <div class="statbar ">
        <div class="mt-icon C C5">
                                <span class="iconochive-audio"  aria-hidden="true"></span><span class="sr-only">audio</span>                  </div>

                  <h6 class="stat " title="all-time views">
            <span class="iconochive-eye"  aria-hidden="true"></span><span class="sr-only">eye</span>            <nobr>7.4<small>M</small></nobr>
          </h6>
        
                  <h6 class="stat">
            <span class="iconochive-favorite"  aria-hidden="true"></span><span class="sr-only">favorite</span>            200          </h6>

                      <h6 class="stat">
              <span class="iconochive-comment"  aria-hidden="true"></span><span class="sr-only">comment</span>              6            </h6>
                                  </div><!--/.statbar-->

          </div><!--/.item-ia-->


    <div class="details-ia hidden-tiles">
      <div class="C1"></div>
              <div class="C234">
          <span>Librivox recording of Pride and Prejudice , by Jane Austen. For more information on our readers, see our catalog page: http://librivox.org/pride-and-prejudice-by-jane-austen/ Pride and Prejudice is the most famous of Jane Austen\'s novels, and its opening is one of the most famous lines in English literature - &quot;It is a truth universally acknowledged, that a single man in possession of a good fortune, must be in want of a wife.&quot; Its manuscript was first written between 1796 and 1797,...</span><br/>          <span alt="4.83 out of 5 stars" title="4.83 out of 5 stars"><span class="iconochive-favorite"  aria-hidden="true"></span><span class="sr-only">favorite</span><span class="iconochive-favorite"  aria-hidden="true"></span><span class="sr-only">favorite</span><span class="iconochive-favorite"  aria-hidden="true"></span><span class="sr-only">favorite</span><span class="iconochive-favorite"  aria-hidden="true"></span><span class="sr-only">favorite</span><span class="iconochive-favorite"  aria-hidden="true"></span><span class="sr-only">favorite</span></span> ( 6 reviews )<br/>          Topics: librivox, audiobook, literature<br/>          Source: Librivox recording of a public-domain text<br/>                  </div>
            <div class="C5"></div>
    </div>

    

    <div class="item-ia" data-id="LibrivoxM4bCollectionAudiobooksMain"
      data-mediatype="audio"
       data-year="2012">

            <a class="stealth" tabindex="-1" href="/details/librivoxaudiocovers">
        <div class="item-parent">
          <div class="item-parent-img" style="background-image: url(\'/services/img/librivoxaudiocovers\')"></div>
          <div class="item-parent-ttl">Librivoxaudio Covers</div>
        </div><!--/.item-parent-->
      </a>
      

      <div class="hidden-tiles views C C1" title="all-time views">
                  <nobr class="hidden-xs">11.7<small>M</small></nobr>
          <nobr class="hidden-sm hidden-md hidden-lg">12M</nobr>
              </div>



      
      <div class="C234">
                  <div
            class="
              item-ttl
                                          C C2
            "
          >
            <a href="/details/LibrivoxM4bCollectionAudiobooksMain" title="Librivox M4b Collection Audiobooks Main"
              data-event-click-tracking="GenericNonCollection|ItemTile">
                              <div class="tile-img">
                  <img class="item-img "
                    alt="Librivox M4b Collection Audiobooks Main"
                    source=/services/img/LibrivoxM4bCollectionAudiobooksMain                     style="height:180px">
                </div><!--/.tile-img-->
              
                            
              
              <div class="ttl">
                Librivox M4b Collection Audiobooks Main              </div>
            </a>
          </div>
                <div class="hidden-tiles pubdate C C3">
          <nobr class="hidden-xs">Aug 21, 2020</nobr>
          <nobr class="hidden-sm hidden-md hidden-lg">08/20</nobr>
        </div>
        <div class="by C C4">
                                                <span class="hidden-lists">by</span>
              <span class="byv"
                    title="LibriVox Volunteers">LibriVox Volunteers</span>
                                          </div><!--/.C4-->
      </div><!--/.C234-->

      <div class="statbar ">
        <div class="mt-icon C C5">
                                <span class="iconochive-audio"  aria-hidden="true"></span><span class="sr-only">audio</span>                  </div>

                  <h6 class="stat " title="all-time views">
            <span class="iconochive-eye"  aria-hidden="true"></span><span class="sr-only">eye</span>            <nobr>11.7<small>M</small></nobr>
          </h6>
        
                  <h6 class="stat">
            <span class="iconochive-favorite"  aria-hidden="true"></span><span class="sr-only">favorite</span>            33          </h6>

                      <h6 class="stat">
              <span class="iconochive-comment"  aria-hidden="true"></span><span class="sr-only">comment</span>              5            </h6>
                                  </div><!--/.statbar-->

          </div><!--/.item-ia-->


    <div class="details-ia hidden-tiles">
      <div class="C1"></div>
              <div class="C234">
          <span>Index of pages containing M4B files created by LibriVox Volunteers. UPDATE - 22 FEB 2015 Thanks to an improvement by folks at Internet Archive, M4B files can now be stored together with the other Librivox audio files without causing problems. We will not adding to these pages any more. Main ( 1.7 GB) English page 1 ( 74.5 GB) English page 1A (152 GB) English page 1B ( 30.1 GB) English page 2 (112 GB) English page 3 (137 GB) English page 4 ( 76.6 GB) English page 5 ( 30.7 GB) English page 6 (...</span><br/>          <span alt="4.67 out of 5 stars" title="4.67 out of 5 stars"><span class="iconochive-favorite"  aria-hidden="true"></span><span class="sr-only">favorite</span><span class="iconochive-favorite"  aria-hidden="true"></span><span class="sr-only">favorite</span><span class="iconochive-favorite"  aria-hidden="true"></span><span class="sr-only">favorite</span><span class="iconochive-favorite"  aria-hidden="true"></span><span class="sr-only">favorite</span><span class="iconochive-favorite"  aria-hidden="true"></span><span class="sr-only">favorite</span></span> ( 5 reviews )<br/>          Topics: M4B, Librivox, Audiobooks, iPods<br/>                            </div>
            <div class="C5"></div>
    </div>

    

    <div class="item-ia" data-id="el_crimen_de_gramercy_park_2103_librivox"
      data-mediatype="audio"
       data-year="2021">

            <a class="stealth" tabindex="-1" href="/details/librivoxaudio">
        <div class="item-parent">
          <div class="item-parent-img" style="background-image: url(\'/services/img/librivoxaudio\')"></div>
          <div class="item-parent-ttl">The LibriVox Free Audiobook Collection</div>
        </div><!--/.item-parent-->
      </a>
      

      <div class="hidden-tiles views C C1" title="all-time views">
                  <nobr class="hidden-xs">28,671</nobr>
          <nobr class="hidden-sm hidden-md hidden-lg">29K</nobr>
              </div>



      
      <div class="C234">
                  <div
            class="
              item-ttl
                                          C C2
            "
          >
            <a href="/details/el_crimen_de_gramercy_park_2103_librivox" title="El crimen de Gramercy Park"
              data-event-click-tracking="GenericNonCollection|ItemTile">
                              <div class="tile-img">
                  <img class="item-img "
                    alt="El crimen de Gramercy Park"
                    source=/services/img/el_crimen_de_gramercy_park_2103_librivox                     style="height:180px">
                </div><!--/.tile-img-->
              
                            
              
              <div class="ttl">
                El crimen de Gramercy Park              </div>
            </a>
          </div>
                <div class="hidden-tiles pubdate C C3">
          <nobr class="hidden-xs">-</nobr>
          <nobr class="hidden-sm hidden-md hidden-lg">-</nobr>
        </div>
        <div class="by C C4">
                                                <span class="hidden-lists">by</span>
              <span class="byv"
                    title="Anna Katharine Green">Anna Katharine Green</span>
                                          </div><!--/.C4-->
      </div><!--/.C234-->

      <div class="statbar ">
        <div class="mt-icon C C5">
                                <span class="iconochive-audio"  aria-hidden="true"></span><span class="sr-only">audio</span>                  </div>

                  <h6 class="stat " title="all-time views">
            <span class="iconochive-eye"  aria-hidden="true"></span><span class="sr-only">eye</span>            <nobr>28,671</nobr>
          </h6>
        
                  <h6 class="stat">
            <span class="iconochive-favorite"  aria-hidden="true"></span><span class="sr-only">favorite</span>            0          </h6>

                      <h6 class="stat">
              <span class="iconochive-comment"  aria-hidden="true"></span><span class="sr-only">comment</span>              0            </h6>
                                  </div><!--/.statbar-->

          </div><!--/.item-ia-->


    <div class="details-ia hidden-tiles">
      <div class="C1"></div>
              <div class="C234">
          <span>LibriVox recording of El crimen de Gramercy Park by Anna Katharine Green. (Translated by Unknown.) Read in Spanish by Victor Villarraza Obra maestra de la «madre de la novela de detectives», Anna Katharine Green, conocida como la Agatha Christie victoriana. El misterio de Gramercy Park, publicado en 1897, es la décima novela policíaca de Anna K. Green y la primera en la que se introduce el inolvidable personaje de Amelia Butterworth(precursora de la señorita Marple), dama soltera y...</span><br/>                    Topics: librivox, audiobooks, Mystery, miss butterworth, that affair next door<br/>                            </div>
            <div class="C5"></div>
    </div>

    

    <div class="item-ia" data-id="lady_jane_1707_thumbs13"
      data-mediatype="audio"
       data-year="2017">

            <a class="stealth" tabindex="-1" href="/details/librivoxaudiocovers">
        <div class="item-parent">
          <div class="item-parent-img" style="background-image: url(\'/services/img/librivoxaudiocovers\')"></div>
          <div class="item-parent-ttl">Librivoxaudio Covers</div>
        </div><!--/.item-parent-->
      </a>
      

      <div class="hidden-tiles views C C1" title="all-time views">
                  <nobr class="hidden-xs">7.5<small>M</small></nobr>
          <nobr class="hidden-sm hidden-md hidden-lg">7.5M</nobr>
              </div>



      
      <div class="C234">
                  <div
            class="
              item-ttl
                                          C C2
            "
          >
            <a href="/details/lady_jane_1707_thumbs13" title="Thumbs 13"
              data-event-click-tracking="GenericNonCollection|ItemTile">
                              <div class="tile-img">
                  <img class="item-img "
                    alt="Thumbs 13"
                    source=/services/img/lady_jane_1707_thumbs13                     style="height:180px">
                </div><!--/.tile-img-->
              
                            
              
              <div class="ttl">
                Thumbs 13              </div>
            </a>
          </div>
                <div class="hidden-tiles pubdate C C3">
          <nobr class="hidden-xs">-</nobr>
          <nobr class="hidden-sm hidden-md hidden-lg">-</nobr>
        </div>
        <div class="by C C4">
                                                <span class="hidden-lists">by</span>
              <span class="byv"
                    title="LibriVox covermakers">LibriVox covermakers</span>
                                          </div><!--/.C4-->
      </div><!--/.C234-->

      <div class="statbar ">
        <div class="mt-icon C C5">
                                <span class="iconochive-audio"  aria-hidden="true"></span><span class="sr-only">audio</span>                  </div>

                  <h6 class="stat " title="all-time views">
            <span class="iconochive-eye"  aria-hidden="true"></span><span class="sr-only">eye</span>            <nobr>7.5<small>M</small></nobr>
          </h6>
        
                  <h6 class="stat">
            <span class="iconochive-favorite"  aria-hidden="true"></span><span class="sr-only">favorite</span>            2          </h6>

                      <h6 class="stat">
              <span class="iconochive-comment"  aria-hidden="true"></span><span class="sr-only">comment</span>              0            </h6>
                                  </div><!--/.statbar-->

          </div><!--/.item-ia-->


    <div class="details-ia hidden-tiles">
      <div class="C1"></div>
              <div class="C234">
          <span>thumb images for Librivox projects</span><br/>                    Topics: Librivox, covers, thumb images<br/>                            </div>
            <div class="C5"></div>
    </div>

    

    <div class="item-ia" data-id="huck_finn_librivox"
      data-mediatype="audio"
       data-year="2006">

            <a class="stealth" tabindex="-1" href="/details/librivoxaudio">
        <div class="item-parent">
          <div class="item-parent-img" style="background-image: url(\'/services/img/librivoxaudio\')"></div>
          <div class="item-parent-ttl">The LibriVox Free Audiobook Collection</div>
        </div><!--/.item-parent-->
      </a>
      

      <div class="hidden-tiles views C C1" title="all-time views">
                  <nobr class="hidden-xs">7.9<small>M</small></nobr>
          <nobr class="hidden-sm hidden-md hidden-lg">7.9M</nobr>
              </div>



      
      <div class="C234">
                  <div
            class="
              item-ttl
                                          C C2
            "
          >
            <a href="/details/huck_finn_librivox" title="Adventures of Huckleberry Finn"
              data-event-click-tracking="GenericNonCollection|ItemTile">
                              <div class="tile-img">
                  <img class="item-img "
                    alt="Adventures of Huckleberry Finn"
                    source=/services/img/huck_finn_librivox                     style="height:180px">
                </div><!--/.tile-img-->
              
                            
              
              <div class="ttl">
                Adventures of Huckleberry Finn              </div>
            </a>
          </div>
                <div class="hidden-tiles pubdate C C3">
          <nobr class="hidden-xs">Apr 30, 2020</nobr>
          <nobr class="hidden-sm hidden-md hidden-lg">04/20</nobr>
        </div>
        <div class="by C C4">
                                                <span class="hidden-lists">by</span>
              <span class="byv"
                    title="Mark Twain">Mark Twain</span>
                                          </div><!--/.C4-->
      </div><!--/.C234-->

      <div class="statbar ">
        <div class="mt-icon C C5">
                                <span class="iconochive-audio"  aria-hidden="true"></span><span class="sr-only">audio</span>                  </div>

                  <h6 class="stat " title="all-time views">
            <span class="iconochive-eye"  aria-hidden="true"></span><span class="sr-only">eye</span>            <nobr>7.9<small>M</small></nobr>
          </h6>
        
                  <h6 class="stat">
            <span class="iconochive-favorite"  aria-hidden="true"></span><span class="sr-only">favorite</span>            183          </h6>

                      <h6 class="stat">
              <span class="iconochive-comment"  aria-hidden="true"></span><span class="sr-only">comment</span>              13            </h6>
                                  </div><!--/.statbar-->

          </div><!--/.item-ia-->


    <div class="details-ia hidden-tiles">
      <div class="C1"></div>
              <div class="C234">
          <span>Librivox recording of Adventures of Huckleberry Finn , by Mark Twain. Read by Annie Coleman . Adventures of Huckleberry Finn (1884) by Mark Twain is one of the truly great American novels, beloved by children, adults, and literary critics alike. The book tells the story of &quot;Huck&quot; Finn (first introduced as Tom Sawyer\'s sidekick in The Adventures of Tom Sawyer ), his friend Jim, and their journey down the Mississippi River on a raft. Both are on the run, Huck from his drunk and abusive...</span><br/>          <span alt="4.69 out of 5 stars" title="4.69 out of 5 stars"><span class="iconochive-favorite"  aria-hidden="true"></span><span class="sr-only">favorite</span><span class="iconochive-favorite"  aria-hidden="true"></span><span class="sr-only">favorite</span><span class="iconochive-favorite"  aria-hidden="true"></span><span class="sr-only">favorite</span><span class="iconochive-favorite"  aria-hidden="true"></span><span class="sr-only">favorite</span><span class="iconochive-favorite"  aria-hidden="true"></span><span class="sr-only">favorite</span></span> ( 13 reviews )<br/>          Topics: librivox, audiobook, literature, twain, huckleberry, finn<br/>          Source: Librivox recording of a public-domain text<br/>                  </div>
            <div class="C5"></div>
    </div>

    

    <div class="item-ia" data-id="thumbs12"
      data-mediatype="audio"
      >

            <a class="stealth" tabindex="-1" href="/details/librivoxaudiocovers">
        <div class="item-parent">
          <div class="item-parent-img" style="background-image: url(\'/services/img/librivoxaudiocovers\')"></div>
          <div class="item-parent-ttl">Librivoxaudio Covers</div>
        </div><!--/.item-parent-->
      </a>
      

      <div class="hidden-tiles views C C1" title="all-time views">
                  <nobr class="hidden-xs">6.2<small>M</small></nobr>
          <nobr class="hidden-sm hidden-md hidden-lg">6.2M</nobr>
              </div>



      
      <div class="C234">
                  <div
            class="
              item-ttl
                                          C C2
            "
          >
            <a href="/details/thumbs12" title="Thumbs 12"
              data-event-click-tracking="GenericNonCollection|ItemTile">
                              <div class="tile-img">
                  <img class="item-img "
                    alt="Thumbs 12"
                    source=/services/img/thumbs12                     style="height:180px">
                </div><!--/.tile-img-->
              
                            
              
              <div class="ttl">
                Thumbs 12              </div>
            </a>
          </div>
                <div class="hidden-tiles pubdate C C3">
          <nobr class="hidden-xs">Mar 23, 2021</nobr>
          <nobr class="hidden-sm hidden-md hidden-lg">03/21</nobr>
        </div>
        <div class="by C C4">
                                                <span class="hidden-lists">by</span>
              <span class="byv"
                    title="Librivox covermakers">Librivox covermakers</span>
                                          </div><!--/.C4-->
      </div><!--/.C234-->

      <div class="statbar ">
        <div class="mt-icon C C5">
                                <span class="iconochive-audio"  aria-hidden="true"></span><span class="sr-only">audio</span>                  </div>

                  <h6 class="stat " title="all-time views">
            <span class="iconochive-eye"  aria-hidden="true"></span><span class="sr-only">eye</span>            <nobr>6.2<small>M</small></nobr>
          </h6>
        
                  <h6 class="stat">
            <span class="iconochive-favorite"  aria-hidden="true"></span><span class="sr-only">favorite</span>            0          </h6>

                      <h6 class="stat">
              <span class="iconochive-comment"  aria-hidden="true"></span><span class="sr-only">comment</span>              2            </h6>
                                  </div><!--/.statbar-->

          </div><!--/.item-ia-->


    <div class="details-ia hidden-tiles">
      <div class="C1"></div>
              <div class="C234">
          <span>Librivox cover art thumbnails</span><br/>          <span alt="1.00 out of 5 stars" title="1.00 out of 5 stars"><span class="iconochive-favorite"  aria-hidden="true"></span><span class="sr-only">favorite</span></span> ( 2 reviews )<br/>          Topic: thumb images<br/>                            </div>
            <div class="C5"></div>
    </div>

    

    <div class="item-ia" data-id="sabuesodelosbaskerville_1512_librivox"
      data-mediatype="audio"
       data-year="2015">

            <a class="stealth" tabindex="-1" href="/details/librivoxaudio">
        <div class="item-parent">
          <div class="item-parent-img" style="background-image: url(\'/services/img/librivoxaudio\')"></div>
          <div class="item-parent-ttl">The LibriVox Free Audiobook Collection</div>
        </div><!--/.item-parent-->
      </a>
      

      <div class="hidden-tiles views C C1" title="all-time views">
                  <nobr class="hidden-xs">450,146</nobr>
          <nobr class="hidden-sm hidden-md hidden-lg">450K</nobr>
              </div>



      
      <div class="C234">
                  <div
            class="
              item-ttl
                                          C C2
            "
          >
            <a href="/details/sabuesodelosbaskerville_1512_librivox" title="El Sabueso de los Baskerville"
              data-event-click-tracking="GenericNonCollection|ItemTile">
                              <div class="tile-img">
                  <img class="item-img "
                    alt="El Sabueso de los Baskerville"
                    source=/services/img/sabuesodelosbaskerville_1512_librivox                     style="height:180px">
                </div><!--/.tile-img-->
              
                            
              
              <div class="ttl">
                El Sabueso de los Baskerville              </div>
            </a>
          </div>
                <div class="hidden-tiles pubdate C C3">
          <nobr class="hidden-xs">Mar 19, 2021</nobr>
          <nobr class="hidden-sm hidden-md hidden-lg">03/21</nobr>
        </div>
        <div class="by C C4">
                                                <span class="hidden-lists">by</span>
              <span class="byv"
                    title="Sir Arthur Conan Doyle">Sir Arthur Conan Doyle</span>
                                          </div><!--/.C4-->
      </div><!--/.C234-->

      <div class="statbar ">
        <div class="mt-icon C C5">
                                <span class="iconochive-audio"  aria-hidden="true"></span><span class="sr-only">audio</span>                  </div>

                  <h6 class="stat " title="all-time views">
            <span class="iconochive-eye"  aria-hidden="true"></span><span class="sr-only">eye</span>            <nobr>450,146</nobr>
          </h6>
        
                  <h6 class="stat">
            <span class="iconochive-favorite"  aria-hidden="true"></span><span class="sr-only">favorite</span>            1          </h6>

                      <h6 class="stat">
              <span class="iconochive-comment"  aria-hidden="true"></span><span class="sr-only">comment</span>              1            </h6>
                                  </div><!--/.statbar-->

          </div><!--/.item-ia-->


    <div class="details-ia hidden-tiles">
      <div class="C1"></div>
              <div class="C234">
          <span>LibriVox recording of El Sabueso de los Baskerville by Sir Arthur Conan Doyle. (Translated by Arturo Costa Álvarez) Read in Spanish by Victor Villarraza El sabueso de los Baskerville , también traducido como El perro de los Baskerville o El mastín de los Baskerville, es la tercera novela de Arthur Conan Doyle que tiene como protagonista principal a Sherlock Holmes. Fue publicada por entregas en el The Strand Magazine entre 1901 y 1902. La novela está principalmente ambientada en Dartmoor,...</span><br/>          <span alt="5.00 out of 5 stars" title="5.00 out of 5 stars"><span class="iconochive-favorite"  aria-hidden="true"></span><span class="sr-only">favorite</span><span class="iconochive-favorite"  aria-hidden="true"></span><span class="sr-only">favorite</span><span class="iconochive-favorite"  aria-hidden="true"></span><span class="sr-only">favorite</span><span class="iconochive-favorite"  aria-hidden="true"></span><span class="sr-only">favorite</span><span class="iconochive-favorite"  aria-hidden="true"></span><span class="sr-only">favorite</span></span> ( 1 reviews )<br/>          Topics: librivox, audiobooks, Sherlock Holmes, dr watson, baskerville<br/>                            </div>
            <div class="C5"></div>
    </div>

    

    <div class="item-ia" data-id="count_monte_cristo_0711_librivox"
      data-mediatype="audio"
       data-year="2007">

            <a class="stealth" tabindex="-1" href="/details/librivoxaudio">
        <div class="item-parent">
          <div class="item-parent-img" style="background-image: url(\'/services/img/librivoxaudio\')"></div>
          <div class="item-parent-ttl">The LibriVox Free Audiobook Collection</div>
        </div><!--/.item-parent-->
      </a>
      

      <div class="hidden-tiles views C C1" title="all-time views">
                  <nobr class="hidden-xs">5.4<small>M</small></nobr>
          <nobr class="hidden-sm hidden-md hidden-lg">5.4M</nobr>
              </div>



      
      <div class="C234">
                  <div
            class="
              item-ttl
                                          C C2
            "
          >
            <a href="/details/count_monte_cristo_0711_librivox" title="The Count of Monte Cristo"
              data-event-click-tracking="GenericNonCollection|ItemTile">
                              <div class="tile-img">
                  <img class="item-img "
                    alt="The Count of Monte Cristo"
                    source=/services/img/count_monte_cristo_0711_librivox                     style="height:180px">
                </div><!--/.tile-img-->
              
                            
              
              <div class="ttl">
                The Count of Monte Cristo              </div>
            </a>
          </div>
                <div class="hidden-tiles pubdate C C3">
          <nobr class="hidden-xs">Nov 30, 2020</nobr>
          <nobr class="hidden-sm hidden-md hidden-lg">11/20</nobr>
        </div>
        <div class="by C C4">
                                                <span class="hidden-lists">by</span>
              <span class="byv"
                    title="Alexandre Dumas">Alexandre Dumas</span>
                                          </div><!--/.C4-->
      </div><!--/.C234-->

      <div class="statbar ">
        <div class="mt-icon C C5">
                                <span class="iconochive-audio"  aria-hidden="true"></span><span class="sr-only">audio</span>                  </div>

                  <h6 class="stat " title="all-time views">
            <span class="iconochive-eye"  aria-hidden="true"></span><span class="sr-only">eye</span>            <nobr>5.4<small>M</small></nobr>
          </h6>
        
                  <h6 class="stat">
            <span class="iconochive-favorite"  aria-hidden="true"></span><span class="sr-only">favorite</span>            164          </h6>

                      <h6 class="stat">
              <span class="iconochive-comment"  aria-hidden="true"></span><span class="sr-only">comment</span>              20            </h6>
                                  </div><!--/.statbar-->

          </div><!--/.item-ia-->


    <div class="details-ia hidden-tiles">
      <div class="C1"></div>
              <div class="C234">
          <span>Librivox recording of The Count of Monte Cristo , by Alexandre Dumas. The Count of Monte Cristo (French: Le Comte de Monte-Cristo ) is an adventure novel by Alexandre Dumas, père. It is often considered, along with The Three Musketeers , as Dumas\'s most popular work. The writing of the work was completed in 1844. Like many of his novels, it is expanded from the plot outlines suggested by his collaborating ghostwriter Auguste Maquet. The story takes place in France, Italy, islands in the...</span><br/>          <span alt="3.47 out of 5 stars" title="3.47 out of 5 stars"><span class="iconochive-favorite"  aria-hidden="true"></span><span class="sr-only">favorite</span><span class="iconochive-favorite"  aria-hidden="true"></span><span class="sr-only">favorite</span><span class="iconochive-favorite"  aria-hidden="true"></span><span class="sr-only">favorite</span></span> ( 20 reviews )<br/>          Topics: monte cristo, dumas, librivox, audiobook, adventure, romance<br/>          Source: Librivox recording of a public-domain text<br/>                  </div>
            <div class="C5"></div>
    </div>

    

    <div class="item-ia" data-id="prairieblummen_2103_librivox"
      data-mediatype="audio"
       data-year="2021">

            <a class="stealth" tabindex="-1" href="/details/librivoxaudio">
        <div class="item-parent">
          <div class="item-parent-img" style="background-image: url(\'/services/img/librivoxaudio\')"></div>
          <div class="item-parent-ttl">The LibriVox Free Audiobook Collection</div>
        </div><!--/.item-parent-->
      </a>
      

      <div class="hidden-tiles views C C1" title="all-time views">
                  <nobr class="hidden-xs">26,583</nobr>
          <nobr class="hidden-sm hidden-md hidden-lg">27K</nobr>
              </div>



      
      <div class="C234">
                  <div
            class="
              item-ttl
                                          C C2
            "
          >
            <a href="/details/prairieblummen_2103_librivox" title="Prairieblummen"
              data-event-click-tracking="GenericNonCollection|ItemTile">
                              <div class="tile-img">
                  <img class="item-img "
                    alt="Prairieblummen"
                    source=/services/img/prairieblummen_2103_librivox                     style="height:180px">
                </div><!--/.tile-img-->
              
                            
              
              <div class="ttl">
                Prairieblummen              </div>
            </a>
          </div>
                <div class="hidden-tiles pubdate C C3">
          <nobr class="hidden-xs">-</nobr>
          <nobr class="hidden-sm hidden-md hidden-lg">-</nobr>
        </div>
        <div class="by C C4">
                                                <span class="hidden-lists">by</span>
              <span class="byv"
                    title="Nicolas Gonner; Nicolas-Edouard Becker; Jean-Baptiste Nau">Nicolas Gonner; Nicolas-Edouard Becker; Jean-Baptiste Nau</span>
                                          </div><!--/.C4-->
      </div><!--/.C234-->

      <div class="statbar ">
        <div class="mt-icon C C5">
                                <span class="iconochive-audio"  aria-hidden="true"></span><span class="sr-only">audio</span>                  </div>

                  <h6 class="stat " title="all-time views">
            <span class="iconochive-eye"  aria-hidden="true"></span><span class="sr-only">eye</span>            <nobr>26,583</nobr>
          </h6>
        
                  <h6 class="stat">
            <span class="iconochive-favorite"  aria-hidden="true"></span><span class="sr-only">favorite</span>            0          </h6>

                      <h6 class="stat">
              <span class="iconochive-comment"  aria-hidden="true"></span><span class="sr-only">comment</span>              0            </h6>
                                  </div><!--/.statbar-->

          </div><!--/.item-ia-->


    <div class="details-ia hidden-tiles">
      <div class="C1"></div>
              <div class="C234">
          <span>LibriVox recording of Prairieblummen by Nicolas Gonner; Nicolas-Edouard Becker; Jean-Baptiste Nau. Read in Luxembourgish by Sandra Schmit; Sonia Den ëmfangräichste Gedichtband vu Lëtzebuerger, déi am 19. Joerhonnert an d\'USA ausgewandert sinn. Theme sinn Erënnerungen un d\'Heemecht, d\'Liewen an Amerika, d\'Pionéierzäit, d\'Solidaritéit innerhalb vun der Lëtzebuerger Communautéit, d\'Relioun an amerikanesch a lëtzebuergesch Soen a Geschichten. D\'Buch ass 1883 zu Dubuque, Iowa, erauskomm....</span><br/>                    Topics: librivox, audiobooks, poetry, folklore, American history, luxembourg, emigration literature,...<br/>                            </div>
            <div class="C5"></div>
    </div>

    

    <div class="item-ia" data-id="harpers_yp_vol_01_issue_25_2103_librivox"
      data-mediatype="audio"
       data-year="2021">

            <a class="stealth" tabindex="-1" href="/details/librivoxaudio">
        <div class="item-parent">
          <div class="item-parent-img" style="background-image: url(\'/services/img/librivoxaudio\')"></div>
          <div class="item-parent-ttl">The LibriVox Free Audiobook Collection</div>
        </div><!--/.item-parent-->
      </a>
      

      <div class="hidden-tiles views C C1" title="all-time views">
                  <nobr class="hidden-xs">20,907</nobr>
          <nobr class="hidden-sm hidden-md hidden-lg">21K</nobr>
              </div>



      
      <div class="C234">
                  <div
            class="
              item-ttl
                                          C C2
            "
          >
            <a href="/details/harpers_yp_vol_01_issue_25_2103_librivox" title="Harper\'s Young People, Vol. 01, Issue 25, April 20, 1880"
              data-event-click-tracking="GenericNonCollection|ItemTile">
                              <div class="tile-img">
                  <img class="item-img "
                    alt="Harper\'s Young People, Vol. 01, Issue 25, April 20, 1880"
                    source=/services/img/harpers_yp_vol_01_issue_25_2103_librivox                     style="height:180px">
                </div><!--/.tile-img-->
              
                            
              
              <div class="ttl">
                Harper\'s Young People, Vol. 01, Issue 25, April 20, 1880              </div>
            </a>
          </div>
                <div class="hidden-tiles pubdate C C3">
          <nobr class="hidden-xs">-</nobr>
          <nobr class="hidden-sm hidden-md hidden-lg">-</nobr>
        </div>
        <div class="by C C4">
                                                <span class="hidden-lists">by</span>
              <span class="byv"
                    title="Various">Various</span>
                                          </div><!--/.C4-->
      </div><!--/.C234-->

      <div class="statbar ">
        <div class="mt-icon C C5">
                                <span class="iconochive-audio"  aria-hidden="true"></span><span class="sr-only">audio</span>                  </div>

                  <h6 class="stat " title="all-time views">
            <span class="iconochive-eye"  aria-hidden="true"></span><span class="sr-only">eye</span>            <nobr>20,907</nobr>
          </h6>
        
                  <h6 class="stat">
            <span class="iconochive-favorite"  aria-hidden="true"></span><span class="sr-only">favorite</span>            0          </h6>

                      <h6 class="stat">
              <span class="iconochive-comment"  aria-hidden="true"></span><span class="sr-only">comment</span>              0            </h6>
                                  </div><!--/.statbar-->

          </div><!--/.item-ia-->


    <div class="details-ia hidden-tiles">
      <div class="C1"></div>
              <div class="C234">
          <span>LibriVox  reading of Harper\'s Young People, Vol. 01, Issue 25, April 20, 1880, by Various. Read in English by springteacher; mleigh; MaybeCordelia; Dulaney High Key Club; Larry Wilson; Michelle Hannah; Jason Gemenetzis and BettyB Harper\'s Young People is an illustrated weekly publication for children that includes short stories, tales from history, natural history, poetry, puzzles, and other fun. This 25th issue of the serial was published on April 20th, 1880 and in its pages it contains the...</span><br/>                    Topics: librivox, audiobooks, poetry, children, history, sailor, animals, story, books, short stories,...<br/>                            </div>
            <div class="C5"></div>
    </div>

    

    <div class="item-ia" data-id="Thumbs14"
      data-mediatype="audio"
       data-year="2018">

            <a class="stealth" tabindex="-1" href="/details/librivoxaudiocovers">
        <div class="item-parent">
          <div class="item-parent-img" style="background-image: url(\'/services/img/librivoxaudiocovers\')"></div>
          <div class="item-parent-ttl">Librivoxaudio Covers</div>
        </div><!--/.item-parent-->
      </a>
      

      <div class="hidden-tiles views C C1" title="all-time views">
                  <nobr class="hidden-xs">4.4<small>M</small></nobr>
          <nobr class="hidden-sm hidden-md hidden-lg">4.4M</nobr>
              </div>



      
      <div class="C234">
                  <div
            class="
              item-ttl
                                          C C2
            "
          >
            <a href="/details/Thumbs14" title="Thumbs 14"
              data-event-click-tracking="GenericNonCollection|ItemTile">
                              <div class="tile-img">
                  <img class="item-img "
                    alt="Thumbs 14"
                    source=/services/img/Thumbs14                     style="height:180px">
                </div><!--/.tile-img-->
              
                            
              
              <div class="ttl">
                Thumbs 14              </div>
            </a>
          </div>
                <div class="hidden-tiles pubdate C C3">
          <nobr class="hidden-xs">-</nobr>
          <nobr class="hidden-sm hidden-md hidden-lg">-</nobr>
        </div>
        <div class="by C C4">
                                                <span class="hidden-lists">by</span>
              <span class="byv"
                    title="LibriVox Covermakers">LibriVox Covermakers</span>
                                          </div><!--/.C4-->
      </div><!--/.C234-->

      <div class="statbar ">
        <div class="mt-icon C C5">
                                <span class="iconochive-audio"  aria-hidden="true"></span><span class="sr-only">audio</span>                  </div>

                  <h6 class="stat " title="all-time views">
            <span class="iconochive-eye"  aria-hidden="true"></span><span class="sr-only">eye</span>            <nobr>4.4<small>M</small></nobr>
          </h6>
        
                  <h6 class="stat">
            <span class="iconochive-favorite"  aria-hidden="true"></span><span class="sr-only">favorite</span>            1          </h6>

                      <h6 class="stat">
              <span class="iconochive-comment"  aria-hidden="true"></span><span class="sr-only">comment</span>              0            </h6>
                                  </div><!--/.statbar-->

          </div><!--/.item-ia-->


    <div class="details-ia hidden-tiles">
      <div class="C1"></div>
              <div class="C234">
          <span>thumb cover images for Librivox</span><br/>                    Topics: images, librivox<br/>                            </div>
            <div class="C5"></div>
    </div>

    

    <div class="item-ia" data-id="dracula_librivox"
      data-mediatype="audio"
       data-year="2006">

            <a class="stealth" tabindex="-1" href="/details/librivoxaudio">
        <div class="item-parent">
          <div class="item-parent-img" style="background-image: url(\'/services/img/librivoxaudio\')"></div>
          <div class="item-parent-ttl">The LibriVox Free Audiobook Collection</div>
        </div><!--/.item-parent-->
      </a>
      

      <div class="hidden-tiles views C C1" title="all-time views">
                  <nobr class="hidden-xs">6.2<small>M</small></nobr>
          <nobr class="hidden-sm hidden-md hidden-lg">6.2M</nobr>
              </div>



      
      <div class="C234">
                  <div
            class="
              item-ttl
                                          C C2
            "
          >
            <a href="/details/dracula_librivox" title="Dracula"
              data-event-click-tracking="GenericNonCollection|ItemTile">
                              <div class="tile-img">
                  <img class="item-img "
                    alt="Dracula"
                    source=/services/img/dracula_librivox                     style="height:180px">
                </div><!--/.tile-img-->
              
                            
              
              <div class="ttl">
                Dracula              </div>
            </a>
          </div>
                <div class="hidden-tiles pubdate C C3">
          <nobr class="hidden-xs">Sep 21, 2020</nobr>
          <nobr class="hidden-sm hidden-md hidden-lg">09/20</nobr>
        </div>
        <div class="by C C4">
                                                <span class="hidden-lists">by</span>
              <span class="byv"
                    title="Bram Stoker">Bram Stoker</span>
                                          </div><!--/.C4-->
      </div><!--/.C234-->

      <div class="statbar ">
        <div class="mt-icon C C5">
                                <span class="iconochive-audio"  aria-hidden="true"></span><span class="sr-only">audio</span>                  </div>

                  <h6 class="stat " title="all-time views">
            <span class="iconochive-eye"  aria-hidden="true"></span><span class="sr-only">eye</span>            <nobr>6.2<small>M</small></nobr>
          </h6>
        
                  <h6 class="stat">
            <span class="iconochive-favorite"  aria-hidden="true"></span><span class="sr-only">favorite</span>            303          </h6>

                      <h6 class="stat">
              <span class="iconochive-comment"  aria-hidden="true"></span><span class="sr-only">comment</span>              18            </h6>
                                  </div><!--/.statbar-->

          </div><!--/.item-ia-->


    <div class="details-ia hidden-tiles">
      <div class="C1"></div>
              <div class="C234">
          <span>LibriVox recording of Dracula, by Bram Stoker. The classic vampire story by Bram Stoker revolves around a struggle between good and evil, tradition and modernity, and lust versus chastity. The author didn\'t invent vampires, but his novel has so captured the public\'s imagination that he is rightly considered their popularizer. Listen and you will meet not only the Count himself, but heroes Jonathan Harker and Abraham Van Helsing, plus an array of madmen, psychiatrists, and fair maidens who cross...</span><br/>          <span alt="3.24 out of 5 stars" title="3.24 out of 5 stars"><span class="iconochive-favorite"  aria-hidden="true"></span><span class="sr-only">favorite</span><span class="iconochive-favorite"  aria-hidden="true"></span><span class="sr-only">favorite</span><span class="iconochive-favorite"  aria-hidden="true"></span><span class="sr-only">favorite</span></span> ( 18 reviews )<br/>          Topics: librivox, audiobook, literature<br/>          Source: Librivox recording of a public-domain text<br/>                  </div>
            <div class="C5"></div>
    </div>

    

    <div class="item-ia" data-id="memory_rm_librivox"
      data-mediatype="audio"
       data-year="2013">

            <a class="stealth" tabindex="-1" href="/details/librivoxaudio">
        <div class="item-parent">
          <div class="item-parent-img" style="background-image: url(\'/services/img/librivoxaudio\')"></div>
          <div class="item-parent-ttl">The LibriVox Free Audiobook Collection</div>
        </div><!--/.item-parent-->
      </a>
      

      <div class="hidden-tiles views C C1" title="all-time views">
                  <nobr class="hidden-xs">301,707</nobr>
          <nobr class="hidden-sm hidden-md hidden-lg">302K</nobr>
              </div>



      
      <div class="C234">
                  <div
            class="
              item-ttl
                                          C C2
            "
          >
            <a href="/details/memory_rm_librivox" title="Memory: How to Develop, Train and Use It"
              data-event-click-tracking="GenericNonCollection|ItemTile">
                              <div class="tile-img">
                  <img class="item-img "
                    alt="Memory: How to Develop, Train and Use It"
                    source=/services/img/memory_rm_librivox                     style="height:180px">
                </div><!--/.tile-img-->
              
                            
              
              <div class="ttl">
                Memory: How to Develop, Train and Use It              </div>
            </a>
          </div>
                <div class="hidden-tiles pubdate C C3">
          <nobr class="hidden-xs">Mar 17, 2021</nobr>
          <nobr class="hidden-sm hidden-md hidden-lg">03/21</nobr>
        </div>
        <div class="by C C4">
                                                <span class="hidden-lists">by</span>
              <span class="byv"
                    title="William Walker Atkinson">William Walker Atkinson</span>
                                          </div><!--/.C4-->
      </div><!--/.C234-->

      <div class="statbar ">
        <div class="mt-icon C C5">
                                <span class="iconochive-audio"  aria-hidden="true"></span><span class="sr-only">audio</span>                  </div>

                  <h6 class="stat " title="all-time views">
            <span class="iconochive-eye"  aria-hidden="true"></span><span class="sr-only">eye</span>            <nobr>301,707</nobr>
          </h6>
        
                  <h6 class="stat">
            <span class="iconochive-favorite"  aria-hidden="true"></span><span class="sr-only">favorite</span>            37          </h6>

                      <h6 class="stat">
              <span class="iconochive-comment"  aria-hidden="true"></span><span class="sr-only">comment</span>              1            </h6>
                                  </div><!--/.statbar-->

          </div><!--/.item-ia-->


    <div class="details-ia hidden-tiles">
      <div class="C1"></div>
              <div class="C234">
          <span>LibriVox recording of Memory: How to Develop, Train and Use It, by William Walker Atkinson. Read by Roger Melin. An in-depth series of chapters devoted to the use of our memory system; as the title suggests, how to develop our memory system, how to train it to improve it, and how to make the best use of it in our everyday lives, and to improve our positions in life. This is not intended to be a series of chapters to impress friends and colleagues, nor to play \'tricks\' on others, rather it is...</span><br/>          <span alt="5.00 out of 5 stars" title="5.00 out of 5 stars"><span class="iconochive-favorite"  aria-hidden="true"></span><span class="sr-only">favorite</span><span class="iconochive-favorite"  aria-hidden="true"></span><span class="sr-only">favorite</span><span class="iconochive-favorite"  aria-hidden="true"></span><span class="sr-only">favorite</span><span class="iconochive-favorite"  aria-hidden="true"></span><span class="sr-only">favorite</span><span class="iconochive-favorite"  aria-hidden="true"></span><span class="sr-only">favorite</span></span> ( 1 reviews )<br/>          Topics: librivox, audiobook, self help, assistance, memorization, knowledge, self-help, subconscious,...<br/>          Source: Librivox recording of a public-domain text<br/>                  </div>
            <div class="C5"></div>
    </div>

    

    <div class="item-ia" data-id="tomswiftmotorcycle_2103_librivox"
      data-mediatype="audio"
       data-year="2021">

            <a class="stealth" tabindex="-1" href="/details/librivoxaudio">
        <div class="item-parent">
          <div class="item-parent-img" style="background-image: url(\'/services/img/librivoxaudio\')"></div>
          <div class="item-parent-ttl">The LibriVox Free Audiobook Collection</div>
        </div><!--/.item-parent-->
      </a>
      

      <div class="hidden-tiles views C C1" title="all-time views">
                  <nobr class="hidden-xs">18,498</nobr>
          <nobr class="hidden-sm hidden-md hidden-lg">18K</nobr>
              </div>



      
      <div class="C234">
                  <div
            class="
              item-ttl
                                          C C2
            "
          >
            <a href="/details/tomswiftmotorcycle_2103_librivox" title="Tom Swift and His Motorcycle"
              data-event-click-tracking="GenericNonCollection|ItemTile">
                              <div class="tile-img">
                  <img class="item-img "
                    alt="Tom Swift and His Motorcycle"
                    source=/services/img/tomswiftmotorcycle_2103_librivox                     style="height:180px">
                </div><!--/.tile-img-->
              
                            
              
              <div class="ttl">
                Tom Swift and His Motorcycle              </div>
            </a>
          </div>
                <div class="hidden-tiles pubdate C C3">
          <nobr class="hidden-xs">-</nobr>
          <nobr class="hidden-sm hidden-md hidden-lg">-</nobr>
        </div>
        <div class="by C C4">
                                                <span class="hidden-lists">by</span>
              <span class="byv"
                    title="Victor Appleton">Victor Appleton</span>
                                          </div><!--/.C4-->
      </div><!--/.C234-->

      <div class="statbar ">
        <div class="mt-icon C C5">
                                <span class="iconochive-audio"  aria-hidden="true"></span><span class="sr-only">audio</span>                  </div>

                  <h6 class="stat " title="all-time views">
            <span class="iconochive-eye"  aria-hidden="true"></span><span class="sr-only">eye</span>            <nobr>18,498</nobr>
          </h6>
        
                  <h6 class="stat">
            <span class="iconochive-favorite"  aria-hidden="true"></span><span class="sr-only">favorite</span>            2          </h6>

                      <h6 class="stat">
              <span class="iconochive-comment"  aria-hidden="true"></span><span class="sr-only">comment</span>              0            </h6>
                                  </div><!--/.statbar-->

          </div><!--/.item-ia-->


    <div class="details-ia hidden-tiles">
      <div class="C1"></div>
              <div class="C234">
          <span>LibriVox recording of Tom Swift and His Motorcycle by Victor Appleton. Read by LibriVox Volunteers This is the very first Tom Swift adventure. Tom Swift has a newly purchased motorcycle, which he is modifying with his own inventions. He volunteers to use his bike to carry his father\'s new turbine design plans to Albany, testing his motorcycle enhancements at the same time. Set upon by corporate spies out to steal his dad\'s plans, Tom must escape from them, recover the plans, and complete his...</span><br/>                    Topics: librivox, audiobooks, children, fiction, adventure, science fiction, young adult, tom swift, ya,...<br/>                            </div>
            <div class="C5"></div>
    </div>

    

    <div class="item-ia" data-id="secret_garden_librivox"
      data-mediatype="audio"
       data-year="2006">

            <a class="stealth" tabindex="-1" href="/details/librivoxaudio">
        <div class="item-parent">
          <div class="item-parent-img" style="background-image: url(\'/services/img/librivoxaudio\')"></div>
          <div class="item-parent-ttl">The LibriVox Free Audiobook Collection</div>
        </div><!--/.item-parent-->
      </a>
      

      <div class="hidden-tiles views C C1" title="all-time views">
                  <nobr class="hidden-xs">3.8<small>M</small></nobr>
          <nobr class="hidden-sm hidden-md hidden-lg">3.8M</nobr>
              </div>



      
      <div class="C234">
                  <div
            class="
              item-ttl
                                          C C2
            "
          >
            <a href="/details/secret_garden_librivox" title="The Secret Garden"
              data-event-click-tracking="GenericNonCollection|ItemTile">
                              <div class="tile-img">
                  <img class="item-img "
                    alt="The Secret Garden"
                    source=/services/img/secret_garden_librivox                     style="height:180px">
                </div><!--/.tile-img-->
              
                            
              
              <div class="ttl">
                The Secret Garden              </div>
            </a>
          </div>
                <div class="hidden-tiles pubdate C C3">
          <nobr class="hidden-xs">Jun 24, 2020</nobr>
          <nobr class="hidden-sm hidden-md hidden-lg">06/20</nobr>
        </div>
        <div class="by C C4">
                                                <span class="hidden-lists">by</span>
              <span class="byv"
                    title="Frances Hodgson Burnett">Frances Hodgson Burnett</span>
                                          </div><!--/.C4-->
      </div><!--/.C234-->

      <div class="statbar ">
        <div class="mt-icon C C5">
                                <span class="iconochive-audio"  aria-hidden="true"></span><span class="sr-only">audio</span>                  </div>

                  <h6 class="stat " title="all-time views">
            <span class="iconochive-eye"  aria-hidden="true"></span><span class="sr-only">eye</span>            <nobr>3.8<small>M</small></nobr>
          </h6>
        
                  <h6 class="stat">
            <span class="iconochive-favorite"  aria-hidden="true"></span><span class="sr-only">favorite</span>            128          </h6>

                      <h6 class="stat">
              <span class="iconochive-comment"  aria-hidden="true"></span><span class="sr-only">comment</span>              5            </h6>
                                  </div><!--/.statbar-->

          </div><!--/.item-ia-->


    <div class="details-ia hidden-tiles">
      <div class="C1"></div>
              <div class="C234">
          <span>Librivox recording of The Secret Garden, by Frances Hodgson Burnett. Read by Kara Shallenberg Mary Lennox is a spoiled, middle-class, self-centred child who has been recently orphaned. She is accepted into the quiet and remote country house of an uncle, who has almost completely withdrawn into himself after the death of his wife. Mary gradually becomes drawn into the hidden side of the house: why does she hear the crying of a unseen child? Why is there an overgrown, walled garden, its door long...</span><br/>          <span alt="4.80 out of 5 stars" title="4.80 out of 5 stars"><span class="iconochive-favorite"  aria-hidden="true"></span><span class="sr-only">favorite</span><span class="iconochive-favorite"  aria-hidden="true"></span><span class="sr-only">favorite</span><span class="iconochive-favorite"  aria-hidden="true"></span><span class="sr-only">favorite</span><span class="iconochive-favorite"  aria-hidden="true"></span><span class="sr-only">favorite</span><span class="iconochive-favorite"  aria-hidden="true"></span><span class="sr-only">favorite</span></span> ( 5 reviews )<br/>          Topics: literature, audiobook, children, librivox<br/>          Source: Librivox recording of a public-domain text<br/>                  </div>
            <div class="C5"></div>
    </div>

    

    <div class="item-ia" data-id="peter_pan_0707_librivox"
      data-mediatype="audio"
       data-year="2007">

            <a class="stealth" tabindex="-1" href="/details/librivoxaudio">
        <div class="item-parent">
          <div class="item-parent-img" style="background-image: url(\'/services/img/librivoxaudio\')"></div>
          <div class="item-parent-ttl">The LibriVox Free Audiobook Collection</div>
        </div><!--/.item-parent-->
      </a>
      

      <div class="hidden-tiles views C C1" title="all-time views">
                  <nobr class="hidden-xs">3.7<small>M</small></nobr>
          <nobr class="hidden-sm hidden-md hidden-lg">3.7M</nobr>
              </div>



      
      <div class="C234">
                  <div
            class="
              item-ttl
                                          C C2
            "
          >
            <a href="/details/peter_pan_0707_librivox" title="Peter Pan"
              data-event-click-tracking="GenericNonCollection|ItemTile">
                              <div class="tile-img">
                  <img class="item-img "
                    alt="Peter Pan"
                    source=/services/img/peter_pan_0707_librivox                     style="height:180px">
                </div><!--/.tile-img-->
              
                            
              
              <div class="ttl">
                Peter Pan              </div>
            </a>
          </div>
                <div class="hidden-tiles pubdate C C3">
          <nobr class="hidden-xs">Nov 20, 2018</nobr>
          <nobr class="hidden-sm hidden-md hidden-lg">11/18</nobr>
        </div>
        <div class="by C C4">
                                                <span class="hidden-lists">by</span>
              <span class="byv"
                    title="J. M. Barrie">J. M. Barrie</span>
                                          </div><!--/.C4-->
      </div><!--/.C234-->

      <div class="statbar ">
        <div class="mt-icon C C5">
                                <span class="iconochive-audio"  aria-hidden="true"></span><span class="sr-only">audio</span>                  </div>

                  <h6 class="stat " title="all-time views">
            <span class="iconochive-eye"  aria-hidden="true"></span><span class="sr-only">eye</span>            <nobr>3.7<small>M</small></nobr>
          </h6>
        
                  <h6 class="stat">
            <span class="iconochive-favorite"  aria-hidden="true"></span><span class="sr-only">favorite</span>            99          </h6>

                      <h6 class="stat">
              <span class="iconochive-comment"  aria-hidden="true"></span><span class="sr-only">comment</span>              2            </h6>
                                  </div><!--/.statbar-->

          </div><!--/.item-ia-->


    <div class="details-ia hidden-tiles">
      <div class="C1"></div>
              <div class="C234">
          <span>Librivox recording of Peter Pan by J. M. Barrie. Read by Librivox volunteers. Peter Pan is the well-loved story of three children and their adventures in Neverland with the boy who refuses to grow up. Swashbuckling, fairy dust, and flight; mermaid lagoons, ticking crocodiles, and Princess Tiger Lily; second to the right and then straight on till morning. You know the story... and if you don\'t, please start listening immediately! (summary by Meredith Hughes) For further information, including...</span><br/>          <span alt="5.00 out of 5 stars" title="5.00 out of 5 stars"><span class="iconochive-favorite"  aria-hidden="true"></span><span class="sr-only">favorite</span><span class="iconochive-favorite"  aria-hidden="true"></span><span class="sr-only">favorite</span><span class="iconochive-favorite"  aria-hidden="true"></span><span class="sr-only">favorite</span><span class="iconochive-favorite"  aria-hidden="true"></span><span class="sr-only">favorite</span><span class="iconochive-favorite"  aria-hidden="true"></span><span class="sr-only">favorite</span></span> ( 2 reviews )<br/>          Topics: librivox, audiobook, Peter Pan, James Matthew Barrie, children, fantasy, Neverland, Tinkerbell,...<br/>          Source: Librivox recording of a public-domain text<br/>                  </div>
            <div class="C5"></div>
    </div>

    

    <div class="item-ia" data-id="wild_animals_at_home_2103_librivox"
      data-mediatype="audio"
       data-year="2021">

            <a class="stealth" tabindex="-1" href="/details/librivoxaudio">
        <div class="item-parent">
          <div class="item-parent-img" style="background-image: url(\'/services/img/librivoxaudio\')"></div>
          <div class="item-parent-ttl">The LibriVox Free Audiobook Collection</div>
        </div><!--/.item-parent-->
      </a>
      

      <div class="hidden-tiles views C C1" title="all-time views">
                  <nobr class="hidden-xs">17,686</nobr>
          <nobr class="hidden-sm hidden-md hidden-lg">18K</nobr>
              </div>



      
      <div class="C234">
                  <div
            class="
              item-ttl
                                          C C2
            "
          >
            <a href="/details/wild_animals_at_home_2103_librivox" title="Wild Animals At Home"
              data-event-click-tracking="GenericNonCollection|ItemTile">
                              <div class="tile-img">
                  <img class="item-img "
                    alt="Wild Animals At Home"
                    source=/services/img/wild_animals_at_home_2103_librivox                     style="height:180px">
                </div><!--/.tile-img-->
              
                            
              
              <div class="ttl">
                Wild Animals At Home              </div>
            </a>
          </div>
                <div class="hidden-tiles pubdate C C3">
          <nobr class="hidden-xs">-</nobr>
          <nobr class="hidden-sm hidden-md hidden-lg">-</nobr>
        </div>
        <div class="by C C4">
                                                <span class="hidden-lists">by</span>
              <span class="byv"
                    title="Ernest Thompson Seton">Ernest Thompson Seton</span>
                                          </div><!--/.C4-->
      </div><!--/.C234-->

      <div class="statbar ">
        <div class="mt-icon C C5">
                                <span class="iconochive-audio"  aria-hidden="true"></span><span class="sr-only">audio</span>                  </div>

                  <h6 class="stat " title="all-time views">
            <span class="iconochive-eye"  aria-hidden="true"></span><span class="sr-only">eye</span>            <nobr>17,686</nobr>
          </h6>
        
                  <h6 class="stat">
            <span class="iconochive-favorite"  aria-hidden="true"></span><span class="sr-only">favorite</span>            1          </h6>

                      <h6 class="stat">
              <span class="iconochive-comment"  aria-hidden="true"></span><span class="sr-only">comment</span>              0            </h6>
                                  </div><!--/.statbar-->

          </div><!--/.item-ia-->


    <div class="details-ia hidden-tiles">
      <div class="C1"></div>
              <div class="C234">
          <span>LibriVox recording of Wild Animals At Home by Ernest Thompson Seton. Read in English by LibriVox volunteers. Wildlife artist Ernest Thompson Seton shares anecdotes of wild animals that he encountered in Yellowstone Park. &quot;I have aimed to show something of the little aspects of the creatures\' lives, which are those that the ordinary traveller will see; I go with him indeed, pointing out my friends as they chance to pass, adding a few comments that should make for a better acquaintance on...</span><br/>                    Topics: librivox, audiobooks, nature, animals, nonfiction, wildlife<br/>                            </div>
            <div class="C5"></div>
    </div>

    

    <div class="item-ia" data-id="north_west_passage_volume_i_2103_librivox"
      data-mediatype="audio"
       data-year="2021">

            <a class="stealth" tabindex="-1" href="/details/librivoxaudio">
        <div class="item-parent">
          <div class="item-parent-img" style="background-image: url(\'/services/img/librivoxaudio\')"></div>
          <div class="item-parent-ttl">The LibriVox Free Audiobook Collection</div>
        </div><!--/.item-parent-->
      </a>
      

      <div class="hidden-tiles views C C1" title="all-time views">
                  <nobr class="hidden-xs">18,500</nobr>
          <nobr class="hidden-sm hidden-md hidden-lg">19K</nobr>
              </div>



      
      <div class="C234">
                  <div
            class="
              item-ttl
                                          C C2
            "
          >
            <a href="/details/north_west_passage_volume_i_2103_librivox" title="The North West Passage -The Gjöa Expedition 1903-1907 (Volume I)"
              data-event-click-tracking="GenericNonCollection|ItemTile">
                              <div class="tile-img">
                  <img class="item-img "
                    alt="The North West Passage -The Gjöa Expedition 1903-1907 (Volume I)"
                    source=/services/img/north_west_passage_volume_i_2103_librivox                     style="height:180px">
                </div><!--/.tile-img-->
              
                            
              
              <div class="ttl">
                The North West Passage -The Gjöa Expedition 1903-1907 (Volume I)              </div>
            </a>
          </div>
                <div class="hidden-tiles pubdate C C3">
          <nobr class="hidden-xs">Mar 19, 2021</nobr>
          <nobr class="hidden-sm hidden-md hidden-lg">03/21</nobr>
        </div>
        <div class="by C C4">
                                                <span class="hidden-lists">by</span>
              <span class="byv"
                    title="Roald Amundsen">Roald Amundsen</span>
                                          </div><!--/.C4-->
      </div><!--/.C234-->

      <div class="statbar ">
        <div class="mt-icon C C5">
                                <span class="iconochive-audio"  aria-hidden="true"></span><span class="sr-only">audio</span>                  </div>

                  <h6 class="stat " title="all-time views">
            <span class="iconochive-eye"  aria-hidden="true"></span><span class="sr-only">eye</span>            <nobr>18,500</nobr>
          </h6>
        
                  <h6 class="stat">
            <span class="iconochive-favorite"  aria-hidden="true"></span><span class="sr-only">favorite</span>            1          </h6>

                      <h6 class="stat">
              <span class="iconochive-comment"  aria-hidden="true"></span><span class="sr-only">comment</span>              1            </h6>
                                  </div><!--/.statbar-->

          </div><!--/.item-ia-->


    <div class="details-ia hidden-tiles">
      <div class="C1"></div>
              <div class="C234">
          <span>LibriVox recording of The North West Passage -The Gjöa Expedition 1903-1907 (Volume I) by Roald Amundsen. Read in English by Steven Seitel Roald Amundsen and six hearty seafarers tackle the North West Passage in search of the elusive wandering magnetic North Pole. (Summary by Steve Seitel) For further information, including links to online text, reader information, RSS feeds, CD cover or other formats (if available), please go to the LibriVox catalog page for this recording. For more free...</span><br/>          <span alt="5.00 out of 5 stars" title="5.00 out of 5 stars"><span class="iconochive-favorite"  aria-hidden="true"></span><span class="sr-only">favorite</span><span class="iconochive-favorite"  aria-hidden="true"></span><span class="sr-only">favorite</span><span class="iconochive-favorite"  aria-hidden="true"></span><span class="sr-only">favorite</span><span class="iconochive-favorite"  aria-hidden="true"></span><span class="sr-only">favorite</span><span class="iconochive-favorite"  aria-hidden="true"></span><span class="sr-only">favorite</span></span> ( 1 reviews )<br/>          Topics: librivox, audiobooks, polar exploration, north west passage, roald amundsen<br/>                            </div>
            <div class="C5"></div>
    </div>

    

    <div class="item-ia" data-id="londonassurance_2103_librivox"
      data-mediatype="audio"
       data-year="2021">

            <a class="stealth" tabindex="-1" href="/details/librivoxaudio">
        <div class="item-parent">
          <div class="item-parent-img" style="background-image: url(\'/services/img/librivoxaudio\')"></div>
          <div class="item-parent-ttl">The LibriVox Free Audiobook Collection</div>
        </div><!--/.item-parent-->
      </a>
      

      <div class="hidden-tiles views C C1" title="all-time views">
                  <nobr class="hidden-xs">17,326</nobr>
          <nobr class="hidden-sm hidden-md hidden-lg">17K</nobr>
              </div>



      
      <div class="C234">
                  <div
            class="
              item-ttl
                                          C C2
            "
          >
            <a href="/details/londonassurance_2103_librivox" title="London Assurance"
              data-event-click-tracking="GenericNonCollection|ItemTile">
                              <div class="tile-img">
                  <img class="item-img "
                    alt="London Assurance"
                    source=/services/img/londonassurance_2103_librivox                     style="height:180px">
                </div><!--/.tile-img-->
              
                            
              
              <div class="ttl">
                London Assurance              </div>
            </a>
          </div>
                <div class="hidden-tiles pubdate C C3">
          <nobr class="hidden-xs">-</nobr>
          <nobr class="hidden-sm hidden-md hidden-lg">-</nobr>
        </div>
        <div class="by C C4">
                                                <span class="hidden-lists">by</span>
              <span class="byv"
                    title="Dion Boucicault">Dion Boucicault</span>
                                          </div><!--/.C4-->
      </div><!--/.C234-->

      <div class="statbar ">
        <div class="mt-icon C C5">
                                <span class="iconochive-audio"  aria-hidden="true"></span><span class="sr-only">audio</span>                  </div>

                  <h6 class="stat " title="all-time views">
            <span class="iconochive-eye"  aria-hidden="true"></span><span class="sr-only">eye</span>            <nobr>17,326</nobr>
          </h6>
        
                  <h6 class="stat">
            <span class="iconochive-favorite"  aria-hidden="true"></span><span class="sr-only">favorite</span>            1          </h6>

                      <h6 class="stat">
              <span class="iconochive-comment"  aria-hidden="true"></span><span class="sr-only">comment</span>              0            </h6>
                                  </div><!--/.statbar-->

          </div><!--/.item-ia-->


    <div class="details-ia hidden-tiles">
      <div class="C1"></div>
              <div class="C234">
          <span>LibriVox recording of London Assurance by Dion Boucicault. Read in English by LibriVox Volunteers. This fast-paced Victorian farce is at heart a comedy of manners. Dion Bouciault’s witty dialogue ridicules the pretensions of society as the plot sets up the unpleasant initial situation of the aging, vain Sir Harcourt Courtly being set by a special provision of her father’s will to marry 18-year-old Grace Harkaway. The situation quickly escalates upon their arrival at Oak Hall to seal the...</span><br/>                    Topics: librivox, audiobooks, comedy, romance, farce, comedy of manners<br/>                            </div>
            <div class="C5"></div>
    </div>

    

    <div class="item-ia" data-id="librivoxcdcoverart36"
      data-mediatype="audio"
      >

            <a class="stealth" tabindex="-1" href="/details/librivoxaudiocovers">
        <div class="item-parent">
          <div class="item-parent-img" style="background-image: url(\'/services/img/librivoxaudiocovers\')"></div>
          <div class="item-parent-ttl">Librivoxaudio Covers</div>
        </div><!--/.item-parent-->
      </a>
      

      <div class="hidden-tiles views C C1" title="all-time views">
                  <nobr class="hidden-xs">2.1<small>M</small></nobr>
          <nobr class="hidden-sm hidden-md hidden-lg">2.1M</nobr>
              </div>



      
      <div class="C234">
                  <div
            class="
              item-ttl
                                          C C2
            "
          >
            <a href="/details/librivoxcdcoverart36" title="LibrivoxCDCoverArt36"
              data-event-click-tracking="GenericNonCollection|ItemTile">
                              <div class="tile-img">
                  <img class="item-img "
                    alt="LibrivoxCDCoverArt36"
                    source=/services/img/librivoxcdcoverart36                     style="height:180px">
                </div><!--/.tile-img-->
              
                            
              
              <div class="ttl">
                LibrivoxCDCoverArt36              </div>
            </a>
          </div>
                <div class="hidden-tiles pubdate C C3">
          <nobr class="hidden-xs">-</nobr>
          <nobr class="hidden-sm hidden-md hidden-lg">-</nobr>
        </div>
        <div class="by C C4">
                                                <span class="hidden-lists">by</span>
              <span class="byv"
                    title="LibriVox cover makers">LibriVox cover makers</span>
                                          </div><!--/.C4-->
      </div><!--/.C234-->

      <div class="statbar ">
        <div class="mt-icon C C5">
                                <span class="iconochive-audio"  aria-hidden="true"></span><span class="sr-only">audio</span>                  </div>

                  <h6 class="stat " title="all-time views">
            <span class="iconochive-eye"  aria-hidden="true"></span><span class="sr-only">eye</span>            <nobr>2.1<small>M</small></nobr>
          </h6>
        
                  <h6 class="stat">
            <span class="iconochive-favorite"  aria-hidden="true"></span><span class="sr-only">favorite</span>            3          </h6>

                      <h6 class="stat">
              <span class="iconochive-comment"  aria-hidden="true"></span><span class="sr-only">comment</span>              0            </h6>
                                  </div><!--/.statbar-->

          </div><!--/.item-ia-->


    <div class="details-ia hidden-tiles">
      <div class="C1"></div>
              <div class="C234">
          <span>A thirty-sixth collection of CD cover art, created by volunteers for some of our LibriVox Audio Books.  We\'ll add more covers as our volunteers create them, so please check back. Each cover can be downloaded as a .pdf to print out and insert into a jewel case, or as a 300x300px .jpg for your iTunes Album Art. This is just one of many LibriVox cover art pages. You\'ll find a complete list on our top page .</span><br/>                    Topics: Librivox, audiobook, cd cover, cd art<br/>                            </div>
            <div class="C5"></div>
    </div>

    

    <div class="item-ia" data-id="cbc030_2103_librivox"
      data-mediatype="audio"
       data-year="2021">

            <a class="stealth" tabindex="-1" href="/details/librivoxaudio">
        <div class="item-parent">
          <div class="item-parent-img" style="background-image: url(\'/services/img/librivoxaudio\')"></div>
          <div class="item-parent-ttl">The LibriVox Free Audiobook Collection</div>
        </div><!--/.item-parent-->
      </a>
      

      <div class="hidden-tiles views C C1" title="all-time views">
                  <nobr class="hidden-xs">26,494</nobr>
          <nobr class="hidden-sm hidden-md hidden-lg">26K</nobr>
              </div>



      
      <div class="C234">
                  <div
            class="
              item-ttl
                                          C C2
            "
          >
            <a href="/details/cbc030_2103_librivox" title="Coffee Break Collection 30 - Mythical Creatures"
              data-event-click-tracking="GenericNonCollection|ItemTile">
                              <div class="tile-img">
                  <img class="item-img "
                    alt="Coffee Break Collection 30 - Mythical Creatures"
                    source=/services/img/cbc030_2103_librivox                     style="height:180px">
                </div><!--/.tile-img-->
              
                            
              
              <div class="ttl">
                Coffee Break Collection 30 - Mythical Creatures              </div>
            </a>
          </div>
                <div class="hidden-tiles pubdate C C3">
          <nobr class="hidden-xs">-</nobr>
          <nobr class="hidden-sm hidden-md hidden-lg">-</nobr>
        </div>
        <div class="by C C4">
                                                <span class="hidden-lists">by</span>
              <span class="byv"
                    title="Various">Various</span>
                                          </div><!--/.C4-->
      </div><!--/.C234-->

      <div class="statbar ">
        <div class="mt-icon C C5">
                                <span class="iconochive-audio"  aria-hidden="true"></span><span class="sr-only">audio</span>                  </div>

                  <h6 class="stat " title="all-time views">
            <span class="iconochive-eye"  aria-hidden="true"></span><span class="sr-only">eye</span>            <nobr>26,494</nobr>
          </h6>
        
                  <h6 class="stat">
            <span class="iconochive-favorite"  aria-hidden="true"></span><span class="sr-only">favorite</span>            3          </h6>

                      <h6 class="stat">
              <span class="iconochive-comment"  aria-hidden="true"></span><span class="sr-only">comment</span>              0            </h6>
                                  </div><!--/.statbar-->

          </div><!--/.item-ia-->


    <div class="details-ia hidden-tiles">
      <div class="C1"></div>
              <div class="C234">
          <span>LibriVox recording of Coffee Break Collection 30 - Mythical Creatures by Various. Read in English by Colleen McMahon; Michele Fry; Tony Scheinman; Piotr Nater; Joanna Michal Hoyt; Joanna Schreck; Sonia; Vincent Maraldo; Andrea Atwood; Newgatenovelist; Lewis West; Kayty Harrelson; Maddie Ruth This is the 30th Coffee Break Collection, in which Librivox readers select and read stories or poems, fiction or non-fiction pieces of fifteen minutes\' duration or less, suitable for short commutes and...</span><br/>                    Topics: librivox, audiobooks<br/>                            </div>
            <div class="C5"></div>
    </div>

    

    <div class="item-ia" data-id="librivoxcCDCoverArt35"
      data-mediatype="audio"
      >

            <a class="stealth" tabindex="-1" href="/details/librivoxaudiocovers">
        <div class="item-parent">
          <div class="item-parent-img" style="background-image: url(\'/services/img/librivoxaudiocovers\')"></div>
          <div class="item-parent-ttl">Librivoxaudio Covers</div>
        </div><!--/.item-parent-->
      </a>
      

      <div class="hidden-tiles views C C1" title="all-time views">
                  <nobr class="hidden-xs">6.3<small>M</small></nobr>
          <nobr class="hidden-sm hidden-md hidden-lg">6.3M</nobr>
              </div>



      
      <div class="C234">
                  <div
            class="
              item-ttl
                                          C C2
            "
          >
            <a href="/details/librivoxcCDCoverArt35" title="LibrivoxCDCoverArt35"
              data-event-click-tracking="GenericNonCollection|ItemTile">
                              <div class="tile-img">
                  <img class="item-img "
                    alt="LibrivoxCDCoverArt35"
                    source=/services/img/librivoxcCDCoverArt35                     style="height:180px">
                </div><!--/.tile-img-->
              
                            
              
              <div class="ttl">
                LibrivoxCDCoverArt35              </div>
            </a>
          </div>
                <div class="hidden-tiles pubdate C C3">
          <nobr class="hidden-xs">-</nobr>
          <nobr class="hidden-sm hidden-md hidden-lg">-</nobr>
        </div>
        <div class="by C C4">
                                                <span class="hidden-lists">by</span>
              <span class="byv"
                    title="Librivox cover makers">Librivox cover makers</span>
                                          </div><!--/.C4-->
      </div><!--/.C234-->

      <div class="statbar ">
        <div class="mt-icon C C5">
                                <span class="iconochive-audio"  aria-hidden="true"></span><span class="sr-only">audio</span>                  </div>

                  <h6 class="stat " title="all-time views">
            <span class="iconochive-eye"  aria-hidden="true"></span><span class="sr-only">eye</span>            <nobr>6.3<small>M</small></nobr>
          </h6>
        
                  <h6 class="stat">
            <span class="iconochive-favorite"  aria-hidden="true"></span><span class="sr-only">favorite</span>            27          </h6>

                      <h6 class="stat">
              <span class="iconochive-comment"  aria-hidden="true"></span><span class="sr-only">comment</span>              0            </h6>
                                  </div><!--/.statbar-->

          </div><!--/.item-ia-->


    <div class="details-ia hidden-tiles">
      <div class="C1"></div>
              <div class="C234">
          <span>A thirtyfifth collection of CD cover art, created by Availle for some of our LibriVox Audio Books.  We\'ll add more covers as our volunteers create them, so please check back. Each cover can be downloaded as a .pdf to print out and insert into a jewel case, or as a 300x300px .jpg for your iTunes Album Art. This is just one of many LibriVox cover art pages. You\'ll find a complete list on our top page .</span><br/>                    Topics: librivox, audiobooks, cd covers, audiobook, cover art, album art<br/>                            </div>
            <div class="C5"></div>
    </div>

    

    <div class="item-ia" data-id="odyssey_butler_librivox"
      data-mediatype="audio"
       data-year="2007">

            <a class="stealth" tabindex="-1" href="/details/librivoxaudio">
        <div class="item-parent">
          <div class="item-parent-img" style="background-image: url(\'/services/img/librivoxaudio\')"></div>
          <div class="item-parent-ttl">The LibriVox Free Audiobook Collection</div>
        </div><!--/.item-parent-->
      </a>
      

      <div class="hidden-tiles views C C1" title="all-time views">
                  <nobr class="hidden-xs">3.5<small>M</small></nobr>
          <nobr class="hidden-sm hidden-md hidden-lg">3.5M</nobr>
              </div>



      
      <div class="C234">
                  <div
            class="
              item-ttl
                                          C C2
            "
          >
            <a href="/details/odyssey_butler_librivox" title="The Odyssey"
              data-event-click-tracking="GenericNonCollection|ItemTile">
                              <div class="tile-img">
                  <img class="item-img "
                    alt="The Odyssey"
                    source=/services/img/odyssey_butler_librivox                     style="height:180px">
                </div><!--/.tile-img-->
              
                            
              
              <div class="ttl">
                The Odyssey              </div>
            </a>
          </div>
                <div class="hidden-tiles pubdate C C3">
          <nobr class="hidden-xs">Oct 29, 2016</nobr>
          <nobr class="hidden-sm hidden-md hidden-lg">10/16</nobr>
        </div>
        <div class="by C C4">
                                                <span class="hidden-lists">by</span>
              <span class="byv"
                    title="Homer">Homer</span>
                                          </div><!--/.C4-->
      </div><!--/.C234-->

      <div class="statbar ">
        <div class="mt-icon C C5">
                                <span class="iconochive-audio"  aria-hidden="true"></span><span class="sr-only">audio</span>                  </div>

                  <h6 class="stat " title="all-time views">
            <span class="iconochive-eye"  aria-hidden="true"></span><span class="sr-only">eye</span>            <nobr>3.5<small>M</small></nobr>
          </h6>
        
                  <h6 class="stat">
            <span class="iconochive-favorite"  aria-hidden="true"></span><span class="sr-only">favorite</span>            213          </h6>

                      <h6 class="stat">
              <span class="iconochive-comment"  aria-hidden="true"></span><span class="sr-only">comment</span>              5            </h6>
                                  </div><!--/.statbar-->

          </div><!--/.item-ia-->


    <div class="details-ia hidden-tiles">
      <div class="C1"></div>
              <div class="C234">
          <span>Librivox recording of The Odyssey , by Homer (transl. Samuel Butler). The Odyssey is one of the two major ancient Greek epic poems (the other being the Iliad ), attributed to the poet Homer. The poem is commonly dated to between 800 and 600 BC. The poem is, in part, a sequel to the Iliad , and concerns the events that befall the Greek hero Odysseus in his long journey back to his native land Ithaca after the fall of Troy. It takes Odysseus ten years to return to his native land of Ithaca after...</span><br/>          <span alt="4.25 out of 5 stars" title="4.25 out of 5 stars"><span class="iconochive-favorite"  aria-hidden="true"></span><span class="sr-only">favorite</span><span class="iconochive-favorite"  aria-hidden="true"></span><span class="sr-only">favorite</span><span class="iconochive-favorite"  aria-hidden="true"></span><span class="sr-only">favorite</span><span class="iconochive-favorite"  aria-hidden="true"></span><span class="sr-only">favorite</span></span> ( 5 reviews )<br/>          Topics: LibriVox, literature, audiobook, homer, classics, adventure, poetry<br/>          Source: Librivox recording of a public-domain text<br/>                  </div>
            <div class="C5"></div>
    </div>

    

    <div class="item-ia" data-id="1891_collection_bt_librivox"
      data-mediatype="audio"
       data-year="2013">

            <a class="stealth" tabindex="-1" href="/details/librivoxaudio">
        <div class="item-parent">
          <div class="item-parent-img" style="background-image: url(\'/services/img/librivoxaudio\')"></div>
          <div class="item-parent-ttl">The LibriVox Free Audiobook Collection</div>
        </div><!--/.item-parent-->
      </a>
      

      <div class="hidden-tiles views C C1" title="all-time views">
                  <nobr class="hidden-xs">3.3<small>M</small></nobr>
          <nobr class="hidden-sm hidden-md hidden-lg">3.3M</nobr>
              </div>



      
      <div class="C234">
                  <div
            class="
              item-ttl
                                          C C2
            "
          >
            <a href="/details/1891_collection_bt_librivox" title="1891 Collection"
              data-event-click-tracking="GenericNonCollection|ItemTile">
                              <div class="tile-img">
                  <img class="item-img "
                    alt="1891 Collection"
                    source=/services/img/1891_collection_bt_librivox                     style="height:180px">
                </div><!--/.tile-img-->
              
                            
              
              <div class="ttl">
                1891 Collection              </div>
            </a>
          </div>
                <div class="hidden-tiles pubdate C C3">
          <nobr class="hidden-xs">-</nobr>
          <nobr class="hidden-sm hidden-md hidden-lg">-</nobr>
        </div>
        <div class="by C C4">
                                                <span class="hidden-lists">by</span>
              <span class="byv"
                    title="Various">Various</span>
                                          </div><!--/.C4-->
      </div><!--/.C234-->

      <div class="statbar ">
        <div class="mt-icon C C5">
                                <span class="iconochive-audio"  aria-hidden="true"></span><span class="sr-only">audio</span>                  </div>

                  <h6 class="stat " title="all-time views">
            <span class="iconochive-eye"  aria-hidden="true"></span><span class="sr-only">eye</span>            <nobr>3.3<small>M</small></nobr>
          </h6>
        
                  <h6 class="stat">
            <span class="iconochive-favorite"  aria-hidden="true"></span><span class="sr-only">favorite</span>            24          </h6>

                      <h6 class="stat">
              <span class="iconochive-comment"  aria-hidden="true"></span><span class="sr-only">comment</span>              0            </h6>
                                  </div><!--/.statbar-->

          </div><!--/.item-ia-->


    <div class="details-ia hidden-tiles">
      <div class="C1"></div>
              <div class="C234">
          <span>LibriVox recording of 1891 Collection by Various. Read by Bellona Times A look at the year 1891 through literature and non-fiction essays first published that year, including works by Mary E Wilkins, Sir Arthur Conan Doyle, Sara Orne Jewett, and Oscar Wilde. (Summary by BellonaTimes) For further information, including links to online text, reader information, RSS feeds, CD cover, M4B or other formats (if available), please go to the LibriVox catalog page for this recording. For more free audio...</span><br/>                    Topics: Romance, mystery, commentary, Max O\'Rell, Arthur Conan Doyle, Sarah Orne Jewett, A J Payne, Edith...<br/>          Source: Librivox recording of a public-domain text<br/>                  </div>
            <div class="C5"></div>
    </div>

    

    <div class="item-ia" data-id="thirtyninesteps_2103_librivox"
      data-mediatype="audio"
       data-year="2021">

            <a class="stealth" tabindex="-1" href="/details/librivoxaudio">
        <div class="item-parent">
          <div class="item-parent-img" style="background-image: url(\'/services/img/librivoxaudio\')"></div>
          <div class="item-parent-ttl">The LibriVox Free Audiobook Collection</div>
        </div><!--/.item-parent-->
      </a>
      

      <div class="hidden-tiles views C C1" title="all-time views">
                  <nobr class="hidden-xs">15,787</nobr>
          <nobr class="hidden-sm hidden-md hidden-lg">16K</nobr>
              </div>



      
      <div class="C234">
                  <div
            class="
              item-ttl
                                          C C2
            "
          >
            <a href="/details/thirtyninesteps_2103_librivox" title="The Thirty-Nine Steps (Version 2)"
              data-event-click-tracking="GenericNonCollection|ItemTile">
                              <div class="tile-img">
                  <img class="item-img "
                    alt="The Thirty-Nine Steps (Version 2)"
                    source=/services/img/thirtyninesteps_2103_librivox                     style="height:180px">
                </div><!--/.tile-img-->
              
                            
              
              <div class="ttl">
                The Thirty-Nine Steps (Version 2)              </div>
            </a>
          </div>
                <div class="hidden-tiles pubdate C C3">
          <nobr class="hidden-xs">-</nobr>
          <nobr class="hidden-sm hidden-md hidden-lg">-</nobr>
        </div>
        <div class="by C C4">
                                                <span class="hidden-lists">by</span>
              <span class="byv"
                    title="John Buchan">John Buchan</span>
                                          </div><!--/.C4-->
      </div><!--/.C234-->

      <div class="statbar ">
        <div class="mt-icon C C5">
                                <span class="iconochive-audio"  aria-hidden="true"></span><span class="sr-only">audio</span>                  </div>

                  <h6 class="stat " title="all-time views">
            <span class="iconochive-eye"  aria-hidden="true"></span><span class="sr-only">eye</span>            <nobr>15,787</nobr>
          </h6>
        
                  <h6 class="stat">
            <span class="iconochive-favorite"  aria-hidden="true"></span><span class="sr-only">favorite</span>            0          </h6>

                      <h6 class="stat">
              <span class="iconochive-comment"  aria-hidden="true"></span><span class="sr-only">comment</span>              0            </h6>
                                  </div><!--/.statbar-->

          </div><!--/.item-ia-->


    <div class="details-ia hidden-tiles">
      <div class="C1"></div>
              <div class="C234">
          <span>LibriVox recording of The Thirty-Nine Steps (Version 2) by John Buchan. Read in English by Tom Haire. Richard Hannay thirsts for adventure. Down and out in early retirement in South London, Hannay bores of the easy life. When Franklin Scudder reveals a secret ploy to set all of Europe to arms, Hannay finds his cure. With experience, intelligence, and a good deal of luck, Richard Hannay peels the layers one step at a time. (Summary by Tom Haire) For further information, including links to online...</span><br/>                    Topics: librivox, audiobooks<br/>                            </div>
            <div class="C5"></div>
    </div>

    

    <div class="item-ia" data-id="alices_adventures_1003"
      data-mediatype="audio"
       data-year="2010">

            <a class="stealth" tabindex="-1" href="/details/librivoxaudio">
        <div class="item-parent">
          <div class="item-parent-img" style="background-image: url(\'/services/img/librivoxaudio\')"></div>
          <div class="item-parent-ttl">The LibriVox Free Audiobook Collection</div>
        </div><!--/.item-parent-->
      </a>
      

      <div class="hidden-tiles views C C1" title="all-time views">
                  <nobr class="hidden-xs">3.1<small>M</small></nobr>
          <nobr class="hidden-sm hidden-md hidden-lg">3.1M</nobr>
              </div>



      
      <div class="C234">
                  <div
            class="
              item-ttl
                                          C C2
            "
          >
            <a href="/details/alices_adventures_1003" title="Alice\'s Adventures in Wonderland"
              data-event-click-tracking="GenericNonCollection|ItemTile">
                              <div class="tile-img">
                  <img class="item-img "
                    alt="Alice\'s Adventures in Wonderland"
                    source=/services/img/alices_adventures_1003                     style="height:180px">
                </div><!--/.tile-img-->
              
                            
              
              <div class="ttl">
                Alice\'s Adventures in Wonderland              </div>
            </a>
          </div>
                <div class="hidden-tiles pubdate C C3">
          <nobr class="hidden-xs">Jan 26, 2016</nobr>
          <nobr class="hidden-sm hidden-md hidden-lg">01/16</nobr>
        </div>
        <div class="by C C4">
                                                <span class="hidden-lists">by</span>
              <span class="byv"
                    title="Lewis Carroll">Lewis Carroll</span>
                                          </div><!--/.C4-->
      </div><!--/.C234-->

      <div class="statbar ">
        <div class="mt-icon C C5">
                                <span class="iconochive-audio"  aria-hidden="true"></span><span class="sr-only">audio</span>                  </div>

                  <h6 class="stat " title="all-time views">
            <span class="iconochive-eye"  aria-hidden="true"></span><span class="sr-only">eye</span>            <nobr>3.1<small>M</small></nobr>
          </h6>
        
                  <h6 class="stat">
            <span class="iconochive-favorite"  aria-hidden="true"></span><span class="sr-only">favorite</span>            130          </h6>

                      <h6 class="stat">
              <span class="iconochive-comment"  aria-hidden="true"></span><span class="sr-only">comment</span>              2            </h6>
                                  </div><!--/.statbar-->

          </div><!--/.item-ia-->


    <div class="details-ia hidden-tiles">
      <div class="C1"></div>
              <div class="C234">
          <span>LibriVox recording of Alice\'s Adventures in Wonderland, by Lewis Carroll. Read by Kara Shallenberg. Alice\'s Adventures in Wonderland tells the story of a girl named Alice who falls down a rabbit hole into a fantasy world populated by peculiar and anthropomorphic creatures. The tale plays with logic in ways that have given the story lasting popularity with adults as well as children. It is considered to be one of the most characteristic examples of the &quot;literary nonsense&quot; genre, and...</span><br/>          <span alt="5.00 out of 5 stars" title="5.00 out of 5 stars"><span class="iconochive-favorite"  aria-hidden="true"></span><span class="sr-only">favorite</span><span class="iconochive-favorite"  aria-hidden="true"></span><span class="sr-only">favorite</span><span class="iconochive-favorite"  aria-hidden="true"></span><span class="sr-only">favorite</span><span class="iconochive-favorite"  aria-hidden="true"></span><span class="sr-only">favorite</span><span class="iconochive-favorite"  aria-hidden="true"></span><span class="sr-only">favorite</span></span> ( 2 reviews )<br/>          Topics: librivox, audiobooks, children, fantasy, adventure, carroll, fiction<br/>          Source: Librivox recording of a public-domain text<br/>                  </div>
            <div class="C5"></div>
    </div>

    

    <div class="item-ia" data-id="acrossmongolianplains_2103_librivox"
      data-mediatype="audio"
       data-year="2021">

            <a class="stealth" tabindex="-1" href="/details/librivoxaudio">
        <div class="item-parent">
          <div class="item-parent-img" style="background-image: url(\'/services/img/librivoxaudio\')"></div>
          <div class="item-parent-ttl">The LibriVox Free Audiobook Collection</div>
        </div><!--/.item-parent-->
      </a>
      

      <div class="hidden-tiles views C C1" title="all-time views">
                  <nobr class="hidden-xs">15,284</nobr>
          <nobr class="hidden-sm hidden-md hidden-lg">15K</nobr>
              </div>



      
      <div class="C234">
                  <div
            class="
              item-ttl
                                          C C2
            "
          >
            <a href="/details/acrossmongolianplains_2103_librivox" title="Across Mongolian Plains: A Naturalist\'s Account of China\'s \'Great Northwest\'"
              data-event-click-tracking="GenericNonCollection|ItemTile">
                              <div class="tile-img">
                  <img class="item-img "
                    alt="Across Mongolian Plains: A Naturalist\'s Account of China\'s \'Great Northwest\'"
                    source=/services/img/acrossmongolianplains_2103_librivox                     style="height:180px">
                </div><!--/.tile-img-->
              
                            
              
              <div class="ttl">
                Across Mongolian Plains: A Naturalist\'s Account of China\'s \'Great Northwest\'              </div>
            </a>
          </div>
                <div class="hidden-tiles pubdate C C3">
          <nobr class="hidden-xs">-</nobr>
          <nobr class="hidden-sm hidden-md hidden-lg">-</nobr>
        </div>
        <div class="by C C4">
                                                <span class="hidden-lists">by</span>
              <span class="byv"
                    title="Roy Chapman Andrews">Roy Chapman Andrews</span>
                                          </div><!--/.C4-->
      </div><!--/.C234-->

      <div class="statbar ">
        <div class="mt-icon C C5">
                                <span class="iconochive-audio"  aria-hidden="true"></span><span class="sr-only">audio</span>                  </div>

                  <h6 class="stat " title="all-time views">
            <span class="iconochive-eye"  aria-hidden="true"></span><span class="sr-only">eye</span>            <nobr>15,284</nobr>
          </h6>
        
                  <h6 class="stat">
            <span class="iconochive-favorite"  aria-hidden="true"></span><span class="sr-only">favorite</span>            0          </h6>

                      <h6 class="stat">
              <span class="iconochive-comment"  aria-hidden="true"></span><span class="sr-only">comment</span>              0            </h6>
                                  </div><!--/.statbar-->

          </div><!--/.item-ia-->


    <div class="details-ia hidden-tiles">
      <div class="C1"></div>
              <div class="C234">
          <span>LibriVox recording of Across Mongolian Plains: A Naturalist\'s Account of China\'s \'Great Northwest\' by Roy Chapman Andrews. Read in English by volunteer readers. An account of a 1918 journey to Northern China by famed adventurer/paleontologist Roy Chapman Andrews. Andrews, who was the inspiration for the many explorer hero characters (including Indiana Jones), wrote this book for the general public, excluding &quot;scientific details&quot; that they might find &quot;wearisome&quot;. - Summary by...</span><br/>                    Topics: librivox, audiobooks, culture, travel, adventure, animals, Hunting, memoir, china, mongolia<br/>                            </div>
            <div class="C5"></div>
    </div>

    

    <div class="item-ia" data-id="metamorphosis_librivox"
      data-mediatype="audio"
       data-year="2006">

            <a class="stealth" tabindex="-1" href="/details/librivoxaudio">
        <div class="item-parent">
          <div class="item-parent-img" style="background-image: url(\'/services/img/librivoxaudio\')"></div>
          <div class="item-parent-ttl">The LibriVox Free Audiobook Collection</div>
        </div><!--/.item-parent-->
      </a>
      

      <div class="hidden-tiles views C C1" title="all-time views">
                  <nobr class="hidden-xs">738,641</nobr>
          <nobr class="hidden-sm hidden-md hidden-lg">739K</nobr>
              </div>



      
      <div class="C234">
                  <div
            class="
              item-ttl
                                          C C2
            "
          >
            <a href="/details/metamorphosis_librivox" title="The Metamorphosis"
              data-event-click-tracking="GenericNonCollection|ItemTile">
                              <div class="tile-img">
                  <img class="item-img "
                    alt="The Metamorphosis"
                    source=/services/img/metamorphosis_librivox                     style="height:178px">
                </div><!--/.tile-img-->
              
                            
              
              <div class="ttl">
                The Metamorphosis              </div>
            </a>
          </div>
                <div class="hidden-tiles pubdate C C3">
          <nobr class="hidden-xs">Mar 15, 2021</nobr>
          <nobr class="hidden-sm hidden-md hidden-lg">03/21</nobr>
        </div>
        <div class="by C C4">
                                                <span class="hidden-lists">by</span>
              <span class="byv"
                    title="Franz Kafka">Franz Kafka</span>
                                          </div><!--/.C4-->
      </div><!--/.C234-->

      <div class="statbar ">
        <div class="mt-icon C C5">
                                <span class="iconochive-audio"  aria-hidden="true"></span><span class="sr-only">audio</span>                  </div>

                  <h6 class="stat " title="all-time views">
            <span class="iconochive-eye"  aria-hidden="true"></span><span class="sr-only">eye</span>            <nobr>738,641</nobr>
          </h6>
        
                  <h6 class="stat">
            <span class="iconochive-favorite"  aria-hidden="true"></span><span class="sr-only">favorite</span>            113          </h6>

                      <h6 class="stat">
              <span class="iconochive-comment"  aria-hidden="true"></span><span class="sr-only">comment</span>              5            </h6>
                                  </div><!--/.statbar-->

          </div><!--/.item-ia-->


    <div class="details-ia hidden-tiles">
      <div class="C1"></div>
              <div class="C234">
          <span>Librivox recording of The Metamorphosis by Franz Kafka, translated by Ian Johnston. Read by David Barnes The Metamorphosis (in German, Die Verwandlung, &quot;The Transformation&quot;) is a novella by Franz Kafka, first published in 1915, and arguably the most famous of his works along with the longer works The Trial and The Castle. The story begins with a traveling salesman, Gregor Samsa, waking to find himself transformed into a giant &quot;monstrous vermin&quot;. (Summary from Wikipedia). For...</span><br/>          <span alt="4.80 out of 5 stars" title="4.80 out of 5 stars"><span class="iconochive-favorite"  aria-hidden="true"></span><span class="sr-only">favorite</span><span class="iconochive-favorite"  aria-hidden="true"></span><span class="sr-only">favorite</span><span class="iconochive-favorite"  aria-hidden="true"></span><span class="sr-only">favorite</span><span class="iconochive-favorite"  aria-hidden="true"></span><span class="sr-only">favorite</span><span class="iconochive-favorite"  aria-hidden="true"></span><span class="sr-only">favorite</span></span> ( 5 reviews )<br/>          Topics: librivox, audiobook, literature, kafka, metamorphosis, verwandlung, samsa<br/>          Source: Librivox recording of a public-domain text<br/>                  </div>
            <div class="C5"></div>
    </div>

    

    <div class="item-ia" data-id="little_princess_krs"
      data-mediatype="audio"
       data-year="2007">

            <a class="stealth" tabindex="-1" href="/details/librivoxaudio">
        <div class="item-parent">
          <div class="item-parent-img" style="background-image: url(\'/services/img/librivoxaudio\')"></div>
          <div class="item-parent-ttl">The LibriVox Free Audiobook Collection</div>
        </div><!--/.item-parent-->
      </a>
      

      <div class="hidden-tiles views C C1" title="all-time views">
                  <nobr class="hidden-xs">1.5<small>M</small></nobr>
          <nobr class="hidden-sm hidden-md hidden-lg">1.5M</nobr>
              </div>



      
      <div class="C234">
                  <div
            class="
              item-ttl
                                          C C2
            "
          >
            <a href="/details/little_princess_krs" title="A Little Princess"
              data-event-click-tracking="GenericNonCollection|ItemTile">
                              <div class="tile-img">
                  <img class="item-img "
                    alt="A Little Princess"
                    source=/services/img/little_princess_krs                     style="height:180px">
                </div><!--/.tile-img-->
              
                            
              
              <div class="ttl">
                A Little Princess              </div>
            </a>
          </div>
                <div class="hidden-tiles pubdate C C3">
          <nobr class="hidden-xs">Mar 16, 2021</nobr>
          <nobr class="hidden-sm hidden-md hidden-lg">03/21</nobr>
        </div>
        <div class="by C C4">
                                                <span class="hidden-lists">by</span>
              <span class="byv"
                    title="Frances Hodgson Burnett">Frances Hodgson Burnett</span>
                                          </div><!--/.C4-->
      </div><!--/.C234-->

      <div class="statbar ">
        <div class="mt-icon C C5">
                                <span class="iconochive-audio"  aria-hidden="true"></span><span class="sr-only">audio</span>                  </div>

                  <h6 class="stat " title="all-time views">
            <span class="iconochive-eye"  aria-hidden="true"></span><span class="sr-only">eye</span>            <nobr>1.5<small>M</small></nobr>
          </h6>
        
                  <h6 class="stat">
            <span class="iconochive-favorite"  aria-hidden="true"></span><span class="sr-only">favorite</span>            47          </h6>

                      <h6 class="stat">
              <span class="iconochive-comment"  aria-hidden="true"></span><span class="sr-only">comment</span>              13            </h6>
                                  </div><!--/.statbar-->

          </div><!--/.item-ia-->


    <div class="details-ia hidden-tiles">
      <div class="C1"></div>
              <div class="C234">
          <span>LibriVox recording of A Little Princess, by Frances Hodgson Burnett. Read by Karen Savage. Sara is brought to Miss Minchin\'s Select Seminary for Young Ladies by her father, Captain Crewe, because the climate in India doesn\'t agree with children. This is the story of her time at Miss Minchin\'s. (Summary by Karen Savage) For further information, including links to online text, reader information, RSS feeds, CD cover or other formats (if available), please go to the LibriVox catalog page for this...</span><br/>          <span alt="4.18 out of 5 stars" title="4.18 out of 5 stars"><span class="iconochive-favorite"  aria-hidden="true"></span><span class="sr-only">favorite</span><span class="iconochive-favorite"  aria-hidden="true"></span><span class="sr-only">favorite</span><span class="iconochive-favorite"  aria-hidden="true"></span><span class="sr-only">favorite</span><span class="iconochive-favorite"  aria-hidden="true"></span><span class="sr-only">favorite</span></span> ( 13 reviews )<br/>          Topics: librivox, literature, audiobook, children, boarding school<br/>          Source: Librivox recording of a public-domain text<br/>                  </div>
            <div class="C5"></div>
    </div>

    

    <div class="item-ia" data-id="bleak_house_cl_librivox"
      data-mediatype="audio"
       data-year="2008">

            <a class="stealth" tabindex="-1" href="/details/librivoxaudio">
        <div class="item-parent">
          <div class="item-parent-img" style="background-image: url(\'/services/img/librivoxaudio\')"></div>
          <div class="item-parent-ttl">The LibriVox Free Audiobook Collection</div>
        </div><!--/.item-parent-->
      </a>
      

      <div class="hidden-tiles views C C1" title="all-time views">
                  <nobr class="hidden-xs">2.4<small>M</small></nobr>
          <nobr class="hidden-sm hidden-md hidden-lg">2.4M</nobr>
              </div>



      
      <div class="C234">
                  <div
            class="
              item-ttl
                                          C C2
            "
          >
            <a href="/details/bleak_house_cl_librivox" title="Bleak House"
              data-event-click-tracking="GenericNonCollection|ItemTile">
                              <div class="tile-img">
                  <img class="item-img "
                    alt="Bleak House"
                    source=/services/img/bleak_house_cl_librivox                     style="height:180px">
                </div><!--/.tile-img-->
              
                            
              
              <div class="ttl">
                Bleak House              </div>
            </a>
          </div>
                <div class="hidden-tiles pubdate C C3">
          <nobr class="hidden-xs">Aug 19, 2009</nobr>
          <nobr class="hidden-sm hidden-md hidden-lg">08/09</nobr>
        </div>
        <div class="by C C4">
                                                <span class="hidden-lists">by</span>
              <span class="byv"
                    title="Charles Dickens">Charles Dickens</span>
                                          </div><!--/.C4-->
      </div><!--/.C234-->

      <div class="statbar ">
        <div class="mt-icon C C5">
                                <span class="iconochive-audio"  aria-hidden="true"></span><span class="sr-only">audio</span>                  </div>

                  <h6 class="stat " title="all-time views">
            <span class="iconochive-eye"  aria-hidden="true"></span><span class="sr-only">eye</span>            <nobr>2.4<small>M</small></nobr>
          </h6>
        
                  <h6 class="stat">
            <span class="iconochive-favorite"  aria-hidden="true"></span><span class="sr-only">favorite</span>            52          </h6>

                      <h6 class="stat">
              <span class="iconochive-comment"  aria-hidden="true"></span><span class="sr-only">comment</span>              1            </h6>
                                  </div><!--/.statbar-->

          </div><!--/.item-ia-->


    <div class="details-ia hidden-tiles">
      <div class="C1"></div>
              <div class="C234">
          <span>Librivox recording of the Bleak House by Charles Dickens. Read by Cynthia Lyons. Bleak House is the ninth novel by Charles Dickens, published in 20 monthly parts between March 1852 and September 1853. It is widely held to be one of Dickens’ finest and most complete novels, containing one of the most vast, complex and engaging arrays of minor characters and sub-plots in his entire canon. Dickens tells all of these both through the narrative of the novel’s heroine, Esther Summerson, and as an...</span><br/>          <span alt="4.00 out of 5 stars" title="4.00 out of 5 stars"><span class="iconochive-favorite"  aria-hidden="true"></span><span class="sr-only">favorite</span><span class="iconochive-favorite"  aria-hidden="true"></span><span class="sr-only">favorite</span><span class="iconochive-favorite"  aria-hidden="true"></span><span class="sr-only">favorite</span><span class="iconochive-favorite"  aria-hidden="true"></span><span class="sr-only">favorite</span></span> ( 1 reviews )<br/>          Topics: librivox, literature, audiobook, Bleak House, Charles Dickens, Esther Summerson, Tulkinghorn, John...<br/>          Source: Librivox recording of a public-domain text<br/>                  </div>
            <div class="C5"></div>
    </div>

    

    <div class="item-ia" data-id="adventures_sherlock_holmes_rg_librivox"
      data-mediatype="audio"
       data-year="2010">

            <a class="stealth" tabindex="-1" href="/details/librivoxaudio">
        <div class="item-parent">
          <div class="item-parent-img" style="background-image: url(\'/services/img/librivoxaudio\')"></div>
          <div class="item-parent-ttl">The LibriVox Free Audiobook Collection</div>
        </div><!--/.item-parent-->
      </a>
      

      <div class="hidden-tiles views C C1" title="all-time views">
                  <nobr class="hidden-xs">3.1<small>M</small></nobr>
          <nobr class="hidden-sm hidden-md hidden-lg">3.1M</nobr>
              </div>



      
      <div class="C234">
                  <div
            class="
              item-ttl
                                          C C2
            "
          >
            <a href="/details/adventures_sherlock_holmes_rg_librivox" title="The Adventures of Sherlock Holmes (Version 2)"
              data-event-click-tracking="GenericNonCollection|ItemTile">
                              <div class="tile-img">
                  <img class="item-img "
                    alt="The Adventures of Sherlock Holmes (Version 2)"
                    source=/services/img/adventures_sherlock_holmes_rg_librivox                     style="height:180px">
                </div><!--/.tile-img-->
              
                            
              
              <div class="ttl">
                The Adventures of Sherlock Holmes (Version 2)              </div>
            </a>
          </div>
                <div class="hidden-tiles pubdate C C3">
          <nobr class="hidden-xs">Nov 15, 2017</nobr>
          <nobr class="hidden-sm hidden-md hidden-lg">11/17</nobr>
        </div>
        <div class="by C C4">
                                                <span class="hidden-lists">by</span>
              <span class="byv"
                    title="Sir Arthur Conan Doyle">Sir Arthur Conan Doyle</span>
                                          </div><!--/.C4-->
      </div><!--/.C234-->

      <div class="statbar ">
        <div class="mt-icon C C5">
                                <span class="iconochive-audio"  aria-hidden="true"></span><span class="sr-only">audio</span>                  </div>

                  <h6 class="stat " title="all-time views">
            <span class="iconochive-eye"  aria-hidden="true"></span><span class="sr-only">eye</span>            <nobr>3.1<small>M</small></nobr>
          </h6>
        
                  <h6 class="stat">
            <span class="iconochive-favorite"  aria-hidden="true"></span><span class="sr-only">favorite</span>            68          </h6>

                      <h6 class="stat">
              <span class="iconochive-comment"  aria-hidden="true"></span><span class="sr-only">comment</span>              5            </h6>
                                  </div><!--/.statbar-->

          </div><!--/.item-ia-->


    <div class="details-ia hidden-tiles">
      <div class="C1"></div>
              <div class="C234">
          <span>LibriVox recording of The Adventures of Sherlock Holmes , by Sir Arthur Conan Doyle. Read by Ruth Golding . A collection of twelve short stories featuring Conan Doyle\'s legendary detective, originally published as single stories in Strand Magazine and subsequently collected into a single volume. There is not always a crime committed nor a culprit to find, and when there is, Holmes does not invariably get his man. However, his extraordinary powers of deduction generally solve the mystery, often...</span><br/>          <span alt="5.00 out of 5 stars" title="5.00 out of 5 stars"><span class="iconochive-favorite"  aria-hidden="true"></span><span class="sr-only">favorite</span><span class="iconochive-favorite"  aria-hidden="true"></span><span class="sr-only">favorite</span><span class="iconochive-favorite"  aria-hidden="true"></span><span class="sr-only">favorite</span><span class="iconochive-favorite"  aria-hidden="true"></span><span class="sr-only">favorite</span><span class="iconochive-favorite"  aria-hidden="true"></span><span class="sr-only">favorite</span></span> ( 5 reviews )<br/>          Topics: librivox, audio book, mystery, sherlock holmes, crime, detective, short stories<br/>          Source: Librivox recording of a public-domain text<br/>                  </div>
            <div class="C5"></div>
    </div>

    

    <div class="item-ia" data-id="thumbs_02"
      data-mediatype="audio"
      >

            <a class="stealth" tabindex="-1" href="/details/librivoxaudiocovers">
        <div class="item-parent">
          <div class="item-parent-img" style="background-image: url(\'/services/img/librivoxaudiocovers\')"></div>
          <div class="item-parent-ttl">Librivoxaudio Covers</div>
        </div><!--/.item-parent-->
      </a>
      

      <div class="hidden-tiles views C C1" title="all-time views">
                  <nobr class="hidden-xs">6.9<small>M</small></nobr>
          <nobr class="hidden-sm hidden-md hidden-lg">6.9M</nobr>
              </div>



      
      <div class="C234">
                  <div
            class="
              item-ttl
                                          C C2
            "
          >
            <a href="/details/thumbs_02" title="Thumbs 02"
              data-event-click-tracking="GenericNonCollection|ItemTile">
                              <div class="tile-img">
                  <img class="item-img "
                    alt="Thumbs 02"
                    source=/services/img/thumbs_02                     style="height:180px">
                </div><!--/.tile-img-->
              
                            
              
              <div class="ttl">
                Thumbs 02              </div>
            </a>
          </div>
                <div class="hidden-tiles pubdate C C3">
          <nobr class="hidden-xs">-</nobr>
          <nobr class="hidden-sm hidden-md hidden-lg">-</nobr>
        </div>
        <div class="by C C4">
                                                <span class="hidden-lists">by</span>
              <span class="byv"
                    title="cover makers">cover makers</span>
                                          </div><!--/.C4-->
      </div><!--/.C234-->

      <div class="statbar ">
        <div class="mt-icon C C5">
                                <span class="iconochive-audio"  aria-hidden="true"></span><span class="sr-only">audio</span>                  </div>

                  <h6 class="stat " title="all-time views">
            <span class="iconochive-eye"  aria-hidden="true"></span><span class="sr-only">eye</span>            <nobr>6.9<small>M</small></nobr>
          </h6>
        
                  <h6 class="stat">
            <span class="iconochive-favorite"  aria-hidden="true"></span><span class="sr-only">favorite</span>            0          </h6>

                      <h6 class="stat">
              <span class="iconochive-comment"  aria-hidden="true"></span><span class="sr-only">comment</span>              0            </h6>
                                  </div><!--/.statbar-->

          </div><!--/.item-ia-->


    <div class="details-ia hidden-tiles">
      <div class="C1"></div>
              <div class="C234">
          <span>Images for LV projects 02</span><br/>                    Topic: images thumb nails<br/>                            </div>
            <div class="C5"></div>
    </div>

    

    <div class="item-ia" data-id="prideandprejudice_1005_librivox"
      data-mediatype="audio"
       data-year="2010">

            <a class="stealth" tabindex="-1" href="/details/librivoxaudio">
        <div class="item-parent">
          <div class="item-parent-img" style="background-image: url(\'/services/img/librivoxaudio\')"></div>
          <div class="item-parent-ttl">The LibriVox Free Audiobook Collection</div>
        </div><!--/.item-parent-->
      </a>
      

      <div class="hidden-tiles views C C1" title="all-time views">
                  <nobr class="hidden-xs">3.5<small>M</small></nobr>
          <nobr class="hidden-sm hidden-md hidden-lg">3.5M</nobr>
              </div>



      
      <div class="C234">
                  <div
            class="
              item-ttl
                                          C C2
            "
          >
            <a href="/details/prideandprejudice_1005_librivox" title="Pride and Prejudice (version 4)"
              data-event-click-tracking="GenericNonCollection|ItemTile">
                              <div class="tile-img">
                  <img class="item-img "
                    alt="Pride and Prejudice (version 4)"
                    source=/services/img/prideandprejudice_1005_librivox                     style="height:180px">
                </div><!--/.tile-img-->
              
                            
              
              <div class="ttl">
                Pride and Prejudice (version 4)              </div>
            </a>
          </div>
                <div class="hidden-tiles pubdate C C3">
          <nobr class="hidden-xs">Aug 28, 2020</nobr>
          <nobr class="hidden-sm hidden-md hidden-lg">08/20</nobr>
        </div>
        <div class="by C C4">
                                                <span class="hidden-lists">by</span>
              <span class="byv"
                    title="Jane Austen">Jane Austen</span>
                                          </div><!--/.C4-->
      </div><!--/.C234-->

      <div class="statbar ">
        <div class="mt-icon C C5">
                                <span class="iconochive-audio"  aria-hidden="true"></span><span class="sr-only">audio</span>                  </div>

                  <h6 class="stat " title="all-time views">
            <span class="iconochive-eye"  aria-hidden="true"></span><span class="sr-only">eye</span>            <nobr>3.5<small>M</small></nobr>
          </h6>
        
                  <h6 class="stat">
            <span class="iconochive-favorite"  aria-hidden="true"></span><span class="sr-only">favorite</span>            67          </h6>

                      <h6 class="stat">
              <span class="iconochive-comment"  aria-hidden="true"></span><span class="sr-only">comment</span>              9            </h6>
                                  </div><!--/.statbar-->

          </div><!--/.item-ia-->


    <div class="details-ia hidden-tiles">
      <div class="C1"></div>
              <div class="C234">
          <span>LibriVox recording of Pride and Prejudice , by Jane Austen. Read by Elizabeth Klett. Pride and Prejudice is Jane Austen\'s classic comic romance, in which the five Bennett sisters try to find that most elusive creature: a single man in possession of a large fortune. Sparks fly when sweet, pretty Jane meets their new neighbor, Mr. Bingley, but her sister Elizabeth is most offended by his haughty friend, Mr. Darcy. This is Austen at the height of her powers: the ironic narration, hilariously drawn...</span><br/>          <span alt="4.88 out of 5 stars" title="4.88 out of 5 stars"><span class="iconochive-favorite"  aria-hidden="true"></span><span class="sr-only">favorite</span><span class="iconochive-favorite"  aria-hidden="true"></span><span class="sr-only">favorite</span><span class="iconochive-favorite"  aria-hidden="true"></span><span class="sr-only">favorite</span><span class="iconochive-favorite"  aria-hidden="true"></span><span class="sr-only">favorite</span><span class="iconochive-favorite"  aria-hidden="true"></span><span class="sr-only">favorite</span></span> ( 9 reviews )<br/>          Topics: librivox, audio, austen, pride, prejudice, literature, romance<br/>          Source: Librivox recording of a public-domain text<br/>                  </div>
            <div class="C5"></div>
    </div>

    

    <div class="item-ia" data-id="letters_brides_0709_librivox"
      data-mediatype="audio"
       data-year="2007">

            <a class="stealth" tabindex="-1" href="/details/librivoxaudio">
        <div class="item-parent">
          <div class="item-parent-img" style="background-image: url(\'/services/img/librivoxaudio\')"></div>
          <div class="item-parent-ttl">The LibriVox Free Audiobook Collection</div>
        </div><!--/.item-parent-->
      </a>
      

      <div class="hidden-tiles views C C1" title="all-time views">
                  <nobr class="hidden-xs">2.1<small>M</small></nobr>
          <nobr class="hidden-sm hidden-md hidden-lg">2.1M</nobr>
              </div>



      
      <div class="C234">
                  <div
            class="
              item-ttl
                                          C C2
            "
          >
            <a href="/details/letters_brides_0709_librivox" title="Letters of Two Brides"
              data-event-click-tracking="GenericNonCollection|ItemTile">
                              <div class="tile-img">
                  <img class="item-img "
                    alt="Letters of Two Brides"
                    source=/services/img/letters_brides_0709_librivox                     style="height:180px">
                </div><!--/.tile-img-->
              
                            
              
              <div class="ttl">
                Letters of Two Brides              </div>
            </a>
          </div>
                <div class="hidden-tiles pubdate C C3">
          <nobr class="hidden-xs">-</nobr>
          <nobr class="hidden-sm hidden-md hidden-lg">-</nobr>
        </div>
        <div class="by C C4">
                                                <span class="hidden-lists">by</span>
              <span class="byv"
                    title="Honore de Balzac">Honore de Balzac</span>
                                          </div><!--/.C4-->
      </div><!--/.C234-->

      <div class="statbar ">
        <div class="mt-icon C C5">
                                <span class="iconochive-audio"  aria-hidden="true"></span><span class="sr-only">audio</span>                  </div>

                  <h6 class="stat " title="all-time views">
            <span class="iconochive-eye"  aria-hidden="true"></span><span class="sr-only">eye</span>            <nobr>2.1<small>M</small></nobr>
          </h6>
        
                  <h6 class="stat">
            <span class="iconochive-favorite"  aria-hidden="true"></span><span class="sr-only">favorite</span>            13          </h6>

                      <h6 class="stat">
              <span class="iconochive-comment"  aria-hidden="true"></span><span class="sr-only">comment</span>              0            </h6>
                                  </div><!--/.statbar-->

          </div><!--/.item-ia-->


    <div class="details-ia hidden-tiles">
      <div class="C1"></div>
              <div class="C234">
          <span>LibriVox recording of Letters of Two Brides, by Honore de Balzac. Letters of Two Brides is an epistolary novel. The two brides are Louise de Chaulieu (Madame Gaston) and Renée de Maucombe (Madame l\'Estorade). The women became friends during their education at a convent and upon leaving began a life-long correspondence. For a 17 year period, they exchange letters describing their lives. Michelle Crandall reads Renee\'s letters, and Kara Shallenberg reads Louise\'s. Letters from the men in their...</span><br/>                    Topics: librivox, literature, audiobooks, epistolary, letters, balzac<br/>          Source: Librivox recording of a public-domain text<br/>                  </div>
            <div class="C5"></div>
    </div>

    

    <div class="item-ia" data-id="penguin_island_ms_librivox"
      data-mediatype="audio"
       data-year="2007">

            <a class="stealth" tabindex="-1" href="/details/librivoxaudio">
        <div class="item-parent">
          <div class="item-parent-img" style="background-image: url(\'/services/img/librivoxaudio\')"></div>
          <div class="item-parent-ttl">The LibriVox Free Audiobook Collection</div>
        </div><!--/.item-parent-->
      </a>
      

      <div class="hidden-tiles views C C1" title="all-time views">
                  <nobr class="hidden-xs">2.1<small>M</small></nobr>
          <nobr class="hidden-sm hidden-md hidden-lg">2.1M</nobr>
              </div>



      
      <div class="C234">
                  <div
            class="
              item-ttl
                                          C C2
            "
          >
            <a href="/details/penguin_island_ms_librivox" title="Penguin Island"
              data-event-click-tracking="GenericNonCollection|ItemTile">
                              <div class="tile-img">
                  <img class="item-img "
                    alt="Penguin Island"
                    source=/services/img/penguin_island_ms_librivox                     style="height:180px">
                </div><!--/.tile-img-->
              
                            
              
              <div class="ttl">
                Penguin Island              </div>
            </a>
          </div>
                <div class="hidden-tiles pubdate C C3">
          <nobr class="hidden-xs">Aug 3, 2016</nobr>
          <nobr class="hidden-sm hidden-md hidden-lg">08/16</nobr>
        </div>
        <div class="by C C4">
                                                <span class="hidden-lists">by</span>
              <span class="byv"
                    title="Anatole France">Anatole France</span>
                                          </div><!--/.C4-->
      </div><!--/.C234-->

      <div class="statbar ">
        <div class="mt-icon C C5">
                                <span class="iconochive-audio"  aria-hidden="true"></span><span class="sr-only">audio</span>                  </div>

                  <h6 class="stat " title="all-time views">
            <span class="iconochive-eye"  aria-hidden="true"></span><span class="sr-only">eye</span>            <nobr>2.1<small>M</small></nobr>
          </h6>
        
                  <h6 class="stat">
            <span class="iconochive-favorite"  aria-hidden="true"></span><span class="sr-only">favorite</span>            21          </h6>

                      <h6 class="stat">
              <span class="iconochive-comment"  aria-hidden="true"></span><span class="sr-only">comment</span>              1            </h6>
                                  </div><!--/.statbar-->

          </div><!--/.item-ia-->


    <div class="details-ia hidden-tiles">
      <div class="C1"></div>
              <div class="C234">
          <span>LibriVox recording of Penguin Island, by Anatole France. Read by Michael Sirois. This novel (original French title -- L\'Île des Pingouins) is a satire on human nature. The first publication was in 1908. These penguins are mistaken for humans by the 97-year-old priest, Father Mael, because of his bad eyesight. He baptizes them, and once baptized, they have no choice but to become human. They take on human traits (build civilizations, go to war, etc.). The book is very funny and powerful....</span><br/>          <span alt="5.00 out of 5 stars" title="5.00 out of 5 stars"><span class="iconochive-favorite"  aria-hidden="true"></span><span class="sr-only">favorite</span><span class="iconochive-favorite"  aria-hidden="true"></span><span class="sr-only">favorite</span><span class="iconochive-favorite"  aria-hidden="true"></span><span class="sr-only">favorite</span><span class="iconochive-favorite"  aria-hidden="true"></span><span class="sr-only">favorite</span><span class="iconochive-favorite"  aria-hidden="true"></span><span class="sr-only">favorite</span></span> ( 1 reviews )<br/>          Topics: LibriVox, literature, audiobook, satire<br/>          Source: Librivox recording of a public-domain text<br/>                  </div>
            <div class="C5"></div>
    </div>

    

    <div class="item-ia" data-id="thumbs_01"
      data-mediatype="audio"
       data-year="2014">

            <a class="stealth" tabindex="-1" href="/details/librivoxaudiocovers">
        <div class="item-parent">
          <div class="item-parent-img" style="background-image: url(\'/services/img/librivoxaudiocovers\')"></div>
          <div class="item-parent-ttl">Librivoxaudio Covers</div>
        </div><!--/.item-parent-->
      </a>
      

      <div class="hidden-tiles views C C1" title="all-time views">
                  <nobr class="hidden-xs">6<small>M</small></nobr>
          <nobr class="hidden-sm hidden-md hidden-lg">6.0M</nobr>
              </div>



      
      <div class="C234">
                  <div
            class="
              item-ttl
                                          C C2
            "
          >
            <a href="/details/thumbs_01" title="Thumbs 01"
              data-event-click-tracking="GenericNonCollection|ItemTile">
                              <div class="tile-img">
                  <img class="item-img "
                    alt="Thumbs 01"
                    source=/services/img/thumbs_01                     style="height:180px">
                </div><!--/.tile-img-->
              
                            
              
              <div class="ttl">
                Thumbs 01              </div>
            </a>
          </div>
                <div class="hidden-tiles pubdate C C3">
          <nobr class="hidden-xs">-</nobr>
          <nobr class="hidden-sm hidden-md hidden-lg">-</nobr>
        </div>
        <div class="by C C4">
                                                <span class="hidden-lists">by</span>
              <span class="byv"
                    title="Cover makers">Cover makers</span>
                                          </div><!--/.C4-->
      </div><!--/.C234-->

      <div class="statbar ">
        <div class="mt-icon C C5">
                                <span class="iconochive-audio"  aria-hidden="true"></span><span class="sr-only">audio</span>                  </div>

                  <h6 class="stat " title="all-time views">
            <span class="iconochive-eye"  aria-hidden="true"></span><span class="sr-only">eye</span>            <nobr>6<small>M</small></nobr>
          </h6>
        
                  <h6 class="stat">
            <span class="iconochive-favorite"  aria-hidden="true"></span><span class="sr-only">favorite</span>            4          </h6>

                      <h6 class="stat">
              <span class="iconochive-comment"  aria-hidden="true"></span><span class="sr-only">comment</span>              0            </h6>
                                  </div><!--/.statbar-->

          </div><!--/.item-ia-->


    <div class="details-ia hidden-tiles">
      <div class="C1"></div>
              <div class="C234">
          <span>Images for LV projects 01</span><br/>                    Topic: images thumb nails<br/>                            </div>
            <div class="C5"></div>
    </div>

    

    <div class="item-ia" data-id="anthem_librivox"
      data-mediatype="audio"
       data-year="2007">

            <a class="stealth" tabindex="-1" href="/details/librivoxaudio">
        <div class="item-parent">
          <div class="item-parent-img" style="background-image: url(\'/services/img/librivoxaudio\')"></div>
          <div class="item-parent-ttl">The LibriVox Free Audiobook Collection</div>
        </div><!--/.item-parent-->
      </a>
      

      <div class="hidden-tiles views C C1" title="all-time views">
                  <nobr class="hidden-xs">2.5<small>M</small></nobr>
          <nobr class="hidden-sm hidden-md hidden-lg">2.5M</nobr>
              </div>



      
      <div class="C234">
                  <div
            class="
              item-ttl
                                          C C2
            "
          >
            <a href="/details/anthem_librivox" title="Anthem"
              data-event-click-tracking="GenericNonCollection|ItemTile">
                              <div class="tile-img">
                  <img class="item-img "
                    alt="Anthem"
                    source=/services/img/anthem_librivox                     style="height:180px">
                </div><!--/.tile-img-->
              
                            
              
              <div class="ttl">
                Anthem              </div>
            </a>
          </div>
                <div class="hidden-tiles pubdate C C3">
          <nobr class="hidden-xs">Jun 6, 2019</nobr>
          <nobr class="hidden-sm hidden-md hidden-lg">06/19</nobr>
        </div>
        <div class="by C C4">
                                                <span class="hidden-lists">by</span>
              <span class="byv"
                    title="Ayn Rand">Ayn Rand</span>
                                          </div><!--/.C4-->
      </div><!--/.C234-->

      <div class="statbar ">
        <div class="mt-icon C C5">
                                <span class="iconochive-audio"  aria-hidden="true"></span><span class="sr-only">audio</span>                  </div>

                  <h6 class="stat " title="all-time views">
            <span class="iconochive-eye"  aria-hidden="true"></span><span class="sr-only">eye</span>            <nobr>2.5<small>M</small></nobr>
          </h6>
        
                  <h6 class="stat">
            <span class="iconochive-favorite"  aria-hidden="true"></span><span class="sr-only">favorite</span>            65          </h6>

                      <h6 class="stat">
              <span class="iconochive-comment"  aria-hidden="true"></span><span class="sr-only">comment</span>              5            </h6>
                                  </div><!--/.statbar-->

          </div><!--/.item-ia-->


    <div class="details-ia hidden-tiles">
      <div class="C1"></div>
              <div class="C234">
          <span>LibriVox\'s Anthem by Ayn Rand. Read by Chere Theriot. Anthem is a dystopic science fiction story taking place at some unspecified future date. Mankind has entered another dark age as a result of what Rand saw as the weaknesses of socialistic thinking and economics. Technological advancement is now carefully planned (when it is allowed to occur, if at all) and the concept of individuality has been eliminated (for example, the word &quot;I&quot; has disappeared from the language). As is common in...</span><br/>          <span alt="4.20 out of 5 stars" title="4.20 out of 5 stars"><span class="iconochive-favorite"  aria-hidden="true"></span><span class="sr-only">favorite</span><span class="iconochive-favorite"  aria-hidden="true"></span><span class="sr-only">favorite</span><span class="iconochive-favorite"  aria-hidden="true"></span><span class="sr-only">favorite</span><span class="iconochive-favorite"  aria-hidden="true"></span><span class="sr-only">favorite</span></span> ( 5 reviews )<br/>          Topics: librivox, audiobooks, literature, philosophy, science fiction<br/>          Source: Librivox recording of a public-domain text<br/>                  </div>
            <div class="C5"></div>
    </div>

    

    <div class="item-ia" data-id="the_wee_man_2103.poem_librivox"
      data-mediatype="audio"
       data-year="2021">

            <a class="stealth" tabindex="-1" href="/details/librivoxaudio">
        <div class="item-parent">
          <div class="item-parent-img" style="background-image: url(\'/services/img/librivoxaudio\')"></div>
          <div class="item-parent-ttl">The LibriVox Free Audiobook Collection</div>
        </div><!--/.item-parent-->
      </a>
      

      <div class="hidden-tiles views C C1" title="all-time views">
                  <nobr class="hidden-xs">11,681</nobr>
          <nobr class="hidden-sm hidden-md hidden-lg">12K</nobr>
              </div>



      
      <div class="C234">
                  <div
            class="
              item-ttl
                                          C C2
            "
          >
            <a href="/details/the_wee_man_2103.poem_librivox" title="The Wee Man. - A Romance."
              data-event-click-tracking="GenericNonCollection|ItemTile">
                              <div class="tile-img">
                  <img class="item-img "
                    alt="The Wee Man. - A Romance."
                    source=/services/img/the_wee_man_2103.poem_librivox                     style="height:180px">
                </div><!--/.tile-img-->
              
                            
              
              <div class="ttl">
                The Wee Man. - A Romance.              </div>
            </a>
          </div>
                <div class="hidden-tiles pubdate C C3">
          <nobr class="hidden-xs">-</nobr>
          <nobr class="hidden-sm hidden-md hidden-lg">-</nobr>
        </div>
        <div class="by C C4">
                                                <span class="hidden-lists">by</span>
              <span class="byv"
                    title="Thomas Hood">Thomas Hood</span>
                                          </div><!--/.C4-->
      </div><!--/.C234-->

      <div class="statbar ">
        <div class="mt-icon C C5">
                                <span class="iconochive-audio"  aria-hidden="true"></span><span class="sr-only">audio</span>                  </div>

                  <h6 class="stat " title="all-time views">
            <span class="iconochive-eye"  aria-hidden="true"></span><span class="sr-only">eye</span>            <nobr>11,681</nobr>
          </h6>
        
                  <h6 class="stat">
            <span class="iconochive-favorite"  aria-hidden="true"></span><span class="sr-only">favorite</span>            0          </h6>

                      <h6 class="stat">
              <span class="iconochive-comment"  aria-hidden="true"></span><span class="sr-only">comment</span>              0            </h6>
                                  </div><!--/.statbar-->

          </div><!--/.item-ia-->


    <div class="details-ia hidden-tiles">
      <div class="C1"></div>
              <div class="C234">
          <span>LibriVox  volunteers bring you 13 recordings of The Wee Man - A Romance by Thomas Hood. This was the Fortnightly Poetry project for March 7, 2021. Read in English by Andrea Atwood; Bruce Kachuk; ChadH94; czandra; Garth Burton; Graham Scott; holtonhj64 ; Larry Wilson; LeeSalter; mleigh; nbvoices; Phil Schempf and yaumixx. Thomas Hood was an English poet, author and humorist, best known for poems such as &quot;The Bridge of Sighs&quot; and &quot;The Song of the Shirt&quot;. Hood wrote regularly...</span><br/>                    Topics: librivox, audiobooks, literature, poetry, humor, nautical<br/>                            </div>
            <div class="C5"></div>
    </div>

    

    <div class="item-ia" data-id="our_street_2103_librivox"
      data-mediatype="audio"
       data-year="2021">

            <a class="stealth" tabindex="-1" href="/details/librivoxaudio">
        <div class="item-parent">
          <div class="item-parent-img" style="background-image: url(\'/services/img/librivoxaudio\')"></div>
          <div class="item-parent-ttl">The LibriVox Free Audiobook Collection</div>
        </div><!--/.item-parent-->
      </a>
      

      <div class="hidden-tiles views C C1" title="all-time views">
                  <nobr class="hidden-xs">18,596</nobr>
          <nobr class="hidden-sm hidden-md hidden-lg">19K</nobr>
              </div>



      
      <div class="C234">
                  <div
            class="
              item-ttl
                                          C C2
            "
          >
            <a href="/details/our_street_2103_librivox" title="Our Street"
              data-event-click-tracking="GenericNonCollection|ItemTile">
                              <div class="tile-img">
                  <img class="item-img "
                    alt="Our Street"
                    source=/services/img/our_street_2103_librivox                     style="height:180px">
                </div><!--/.tile-img-->
              
                            
              
              <div class="ttl">
                Our Street              </div>
            </a>
          </div>
                <div class="hidden-tiles pubdate C C3">
          <nobr class="hidden-xs">Mar 31, 2021</nobr>
          <nobr class="hidden-sm hidden-md hidden-lg">03/21</nobr>
        </div>
        <div class="by C C4">
                                                <span class="hidden-lists">by</span>
              <span class="byv"
                    title="William Makepeace Thackeray">William Makepeace Thackeray</span>
                                          </div><!--/.C4-->
      </div><!--/.C234-->

      <div class="statbar ">
        <div class="mt-icon C C5">
                                <span class="iconochive-audio"  aria-hidden="true"></span><span class="sr-only">audio</span>                  </div>

                  <h6 class="stat " title="all-time views">
            <span class="iconochive-eye"  aria-hidden="true"></span><span class="sr-only">eye</span>            <nobr>18,596</nobr>
          </h6>
        
                  <h6 class="stat">
            <span class="iconochive-favorite"  aria-hidden="true"></span><span class="sr-only">favorite</span>            3          </h6>

                      <h6 class="stat">
              <span class="iconochive-comment"  aria-hidden="true"></span><span class="sr-only">comment</span>              1            </h6>
                                  </div><!--/.statbar-->

          </div><!--/.item-ia-->


    <div class="details-ia hidden-tiles">
      <div class="C1"></div>
              <div class="C234">
          <span>LibriVox recording of Our Street by William Makepeace Thackeray. Read in English by Kristina Rothe Written as an autobiographical sketch of a Mr. M.A. Titmarsh, Our Street is a tongue-in-cheek look at English society and the characters who live in the street where he finds himself. It is the second of five &quot;Christmas Books&quot; written by Thackeray under the pseudonym of M.A. Titmarsh. For further information, including links to online text, reader information, RSS feeds, CD cover or...</span><br/>          <span alt="5.00 out of 5 stars" title="5.00 out of 5 stars"><span class="iconochive-favorite"  aria-hidden="true"></span><span class="sr-only">favorite</span><span class="iconochive-favorite"  aria-hidden="true"></span><span class="sr-only">favorite</span><span class="iconochive-favorite"  aria-hidden="true"></span><span class="sr-only">favorite</span><span class="iconochive-favorite"  aria-hidden="true"></span><span class="sr-only">favorite</span><span class="iconochive-favorite"  aria-hidden="true"></span><span class="sr-only">favorite</span></span> ( 1 reviews )<br/>          Topics: librivox, audiobooks, society, observation<br/>                            </div>
            <div class="C5"></div>
    </div>

    

    <div class="item-ia" data-id="rival_pitchers_1402_thumb"
      data-mediatype="image"
       data-year="2014">

            <a class="stealth" tabindex="-1" href="/details/librivoxaudiocovers">
        <div class="item-parent">
          <div class="item-parent-img" style="background-image: url(\'/services/img/librivoxaudiocovers\')"></div>
          <div class="item-parent-ttl">Librivoxaudio Covers</div>
        </div><!--/.item-parent-->
      </a>
      

      <div class="hidden-tiles views C C1" title="all-time views">
                  <nobr class="hidden-xs">7.1<small>M</small></nobr>
          <nobr class="hidden-sm hidden-md hidden-lg">7.1M</nobr>
              </div>



      
      <div class="C234">
                  <div
            class="
              item-ttl
                                          C C2
            "
          >
            <a href="/details/rival_pitchers_1402_thumb" title="Thumbs 01A"
              data-event-click-tracking="GenericNonCollection|ItemTile">
                              <div class="tile-img">
                  <img class="item-img "
                    alt="Thumbs 01A"
                    source=/services/img/rival_pitchers_1402_thumb                     style="height:180px">
                </div><!--/.tile-img-->
              
                            
              
              <div class="ttl">
                Thumbs 01A              </div>
            </a>
          </div>
                <div class="hidden-tiles pubdate C C3">
          <nobr class="hidden-xs">-</nobr>
          <nobr class="hidden-sm hidden-md hidden-lg">-</nobr>
        </div>
        <div class="by C C4">
                                                                </div><!--/.C4-->
      </div><!--/.C234-->

      <div class="statbar ">
        <div class="mt-icon C C5">
                                <span class="iconochive-image"  aria-hidden="true"></span><span class="sr-only">image</span>                  </div>

                  <h6 class="stat " title="all-time views">
            <span class="iconochive-eye"  aria-hidden="true"></span><span class="sr-only">eye</span>            <nobr>7.1<small>M</small></nobr>
          </h6>
        
                  <h6 class="stat">
            <span class="iconochive-favorite"  aria-hidden="true"></span><span class="sr-only">favorite</span>            13          </h6>

                      <h6 class="stat">
              <span class="iconochive-comment"  aria-hidden="true"></span><span class="sr-only">comment</span>              0            </h6>
                                  </div><!--/.statbar-->

          </div><!--/.item-ia-->


    <div class="details-ia hidden-tiles">
      <div class="C1"></div>
              <div class="C234">
          <span>images used for items in collection</span><br/>                    Topic: librivox<br/>                            </div>
            <div class="C5"></div>
    </div>

    

    <div class="item-ia" data-id="timemachine_sjm_librivox"
      data-mediatype="audio"
       data-year="2011">

            <a class="stealth" tabindex="-1" href="/details/librivoxaudio">
        <div class="item-parent">
          <div class="item-parent-img" style="background-image: url(\'/services/img/librivoxaudio\')"></div>
          <div class="item-parent-ttl">The LibriVox Free Audiobook Collection</div>
        </div><!--/.item-parent-->
      </a>
      

      <div class="hidden-tiles views C C1" title="all-time views">
                  <nobr class="hidden-xs">1.8<small>M</small></nobr>
          <nobr class="hidden-sm hidden-md hidden-lg">1.8M</nobr>
              </div>



      
      <div class="C234">
                  <div
            class="
              item-ttl
                                          C C2
            "
          >
            <a href="/details/timemachine_sjm_librivox" title="The Time Machine (version 3)"
              data-event-click-tracking="GenericNonCollection|ItemTile">
                              <div class="tile-img">
                  <img class="item-img "
                    alt="The Time Machine (version 3)"
                    source=/services/img/timemachine_sjm_librivox                     style="height:180px">
                </div><!--/.tile-img-->
              
                            
              
              <div class="ttl">
                The Time Machine (version 3)              </div>
            </a>
          </div>
                <div class="hidden-tiles pubdate C C3">
          <nobr class="hidden-xs">Jul 4, 2019</nobr>
          <nobr class="hidden-sm hidden-md hidden-lg">07/19</nobr>
        </div>
        <div class="by C C4">
                                                <span class="hidden-lists">by</span>
              <span class="byv"
                    title="H. G. Wells">H. G. Wells</span>
                                          </div><!--/.C4-->
      </div><!--/.C234-->

      <div class="statbar ">
        <div class="mt-icon C C5">
                                <span class="iconochive-audio"  aria-hidden="true"></span><span class="sr-only">audio</span>                  </div>

                  <h6 class="stat " title="all-time views">
            <span class="iconochive-eye"  aria-hidden="true"></span><span class="sr-only">eye</span>            <nobr>1.8<small>M</small></nobr>
          </h6>
        
                  <h6 class="stat">
            <span class="iconochive-favorite"  aria-hidden="true"></span><span class="sr-only">favorite</span>            71          </h6>

                      <h6 class="stat">
              <span class="iconochive-comment"  aria-hidden="true"></span><span class="sr-only">comment</span>              2            </h6>
                                  </div><!--/.statbar-->

          </div><!--/.item-ia-->


    <div class="details-ia hidden-tiles">
      <div class="C1"></div>
              <div class="C234">
          <span>LibriVox recording of The Time Machine, by H.G. Wells. Read by Mark Nelson. H.G. Wells\' classic science fiction-fantasy story, in which a scientist known only as “The Time Traveller” tells the tale of his journey to the year 802,701 A.D. and beyond, where he witnesses the end of human civilization as we know it, as well as the beginning of the end of the world. This original time-travel story has been copied many times, but never improved upon. (Summary by Mark Nelson) For further...</span><br/>          <span alt="5.00 out of 5 stars" title="5.00 out of 5 stars"><span class="iconochive-favorite"  aria-hidden="true"></span><span class="sr-only">favorite</span><span class="iconochive-favorite"  aria-hidden="true"></span><span class="sr-only">favorite</span><span class="iconochive-favorite"  aria-hidden="true"></span><span class="sr-only">favorite</span><span class="iconochive-favorite"  aria-hidden="true"></span><span class="sr-only">favorite</span><span class="iconochive-favorite"  aria-hidden="true"></span><span class="sr-only">favorite</span></span> ( 2 reviews )<br/>          Topics: librivox, literature, audiobook, adventure, fantasy, fiction, science fiction, teen/young adult<br/>          Source: Librivox recording of a public-domain text<br/>                  </div>
            <div class="C5"></div>
    </div>

    

    <div class="item-ia" data-id="treasure_island_ap_librivox"
      data-mediatype="audio"
       data-year="2007">

            <a class="stealth" tabindex="-1" href="/details/librivoxaudio">
        <div class="item-parent">
          <div class="item-parent-img" style="background-image: url(\'/services/img/librivoxaudio\')"></div>
          <div class="item-parent-ttl">The LibriVox Free Audiobook Collection</div>
        </div><!--/.item-parent-->
      </a>
      

      <div class="hidden-tiles views C C1" title="all-time views">
                  <nobr class="hidden-xs">3.8<small>M</small></nobr>
          <nobr class="hidden-sm hidden-md hidden-lg">3.8M</nobr>
              </div>



      
      <div class="C234">
                  <div
            class="
              item-ttl
                                          C C2
            "
          >
            <a href="/details/treasure_island_ap_librivox" title="Treasure Island"
              data-event-click-tracking="GenericNonCollection|ItemTile">
                              <div class="tile-img">
                  <img class="item-img "
                    alt="Treasure Island"
                    source=/services/img/treasure_island_ap_librivox                     style="height:180px">
                </div><!--/.tile-img-->
              
                            
              
              <div class="ttl">
                Treasure Island              </div>
            </a>
          </div>
                <div class="hidden-tiles pubdate C C3">
          <nobr class="hidden-xs">Feb 15, 2021</nobr>
          <nobr class="hidden-sm hidden-md hidden-lg">02/21</nobr>
        </div>
        <div class="by C C4">
                                                <span class="hidden-lists">by</span>
              <span class="byv"
                    title="Robert Louis Stevenson">Robert Louis Stevenson</span>
                                          </div><!--/.C4-->
      </div><!--/.C234-->

      <div class="statbar ">
        <div class="mt-icon C C5">
                                <span class="iconochive-audio"  aria-hidden="true"></span><span class="sr-only">audio</span>                  </div>

                  <h6 class="stat " title="all-time views">
            <span class="iconochive-eye"  aria-hidden="true"></span><span class="sr-only">eye</span>            <nobr>3.8<small>M</small></nobr>
          </h6>
        
                  <h6 class="stat">
            <span class="iconochive-favorite"  aria-hidden="true"></span><span class="sr-only">favorite</span>            173          </h6>

                      <h6 class="stat">
              <span class="iconochive-comment"  aria-hidden="true"></span><span class="sr-only">comment</span>              22            </h6>
                                  </div><!--/.statbar-->

          </div><!--/.item-ia-->


    <div class="details-ia hidden-tiles">
      <div class="C1"></div>
              <div class="C234">
          <span>Librivox recording of Treasure Island by Robert Louis Stevenson. Read by Adrian Praetzellis. A mysterious map, pirates, and pieces of eight! When young Jim Hawkins finds a map to pirates’ gold he starts on an adventure that takes him from his English village to a desert island with the murderous Black Dog, half-mad Ben Gunn, and (of course) Long John Silver. Arr Jim lad! R.L. Stevenson (1850-1894) was born in Scotland and travelled extensively in California and the south Pacific. (Summary by...</span><br/>          <span alt="4.82 out of 5 stars" title="4.82 out of 5 stars"><span class="iconochive-favorite"  aria-hidden="true"></span><span class="sr-only">favorite</span><span class="iconochive-favorite"  aria-hidden="true"></span><span class="sr-only">favorite</span><span class="iconochive-favorite"  aria-hidden="true"></span><span class="sr-only">favorite</span><span class="iconochive-favorite"  aria-hidden="true"></span><span class="sr-only">favorite</span><span class="iconochive-favorite"  aria-hidden="true"></span><span class="sr-only">favorite</span></span> ( 22 reviews )<br/>          Topics: librivox, audiobooks, pirates, Stevenson, treasure, children\'s literature<br/>          Source: Librivox recording of a public-domain text<br/>                  </div>
            <div class="C5"></div>
    </div>

    

    <div class="item-ia" data-id="zuleika_dobson_tm_0907_librivox"
      data-mediatype="audio"
       data-year="2009">

            <a class="stealth" tabindex="-1" href="/details/librivoxaudio">
        <div class="item-parent">
          <div class="item-parent-img" style="background-image: url(\'/services/img/librivoxaudio\')"></div>
          <div class="item-parent-ttl">The LibriVox Free Audiobook Collection</div>
        </div><!--/.item-parent-->
      </a>
      

      <div class="hidden-tiles views C C1" title="all-time views">
                  <nobr class="hidden-xs">25,607</nobr>
          <nobr class="hidden-sm hidden-md hidden-lg">26K</nobr>
              </div>



      
      <div class="C234">
                  <div
            class="
              item-ttl
                                          C C2
            "
          >
            <a href="/details/zuleika_dobson_tm_0907_librivox" title="Zuleika Dobson"
              data-event-click-tracking="GenericNonCollection|ItemTile">
                              <div class="tile-img">
                  <img class="item-img "
                    alt="Zuleika Dobson"
                    source=/services/img/zuleika_dobson_tm_0907_librivox                     style="height:180px">
                </div><!--/.tile-img-->
              
                            
              
              <div class="ttl">
                Zuleika Dobson              </div>
            </a>
          </div>
                <div class="hidden-tiles pubdate C C3">
          <nobr class="hidden-xs">Mar 23, 2021</nobr>
          <nobr class="hidden-sm hidden-md hidden-lg">03/21</nobr>
        </div>
        <div class="by C C4">
                                                <span class="hidden-lists">by</span>
              <span class="byv"
                    title="Max Beerbohm">Max Beerbohm</span>
                                          </div><!--/.C4-->
      </div><!--/.C234-->

      <div class="statbar ">
        <div class="mt-icon C C5">
                                <span class="iconochive-audio"  aria-hidden="true"></span><span class="sr-only">audio</span>                  </div>

                  <h6 class="stat " title="all-time views">
            <span class="iconochive-eye"  aria-hidden="true"></span><span class="sr-only">eye</span>            <nobr>25,607</nobr>
          </h6>
        
                  <h6 class="stat">
            <span class="iconochive-favorite"  aria-hidden="true"></span><span class="sr-only">favorite</span>            2          </h6>

                      <h6 class="stat">
              <span class="iconochive-comment"  aria-hidden="true"></span><span class="sr-only">comment</span>              1            </h6>
                                  </div><!--/.statbar-->

          </div><!--/.item-ia-->


    <div class="details-ia hidden-tiles">
      <div class="C1"></div>
              <div class="C234">
          <span>LibriVox recording of Zuleika Dobson, by Max Beerbohm. Read by Termin Dyan. \'A wickedly funny 1911 satire on undergraduate life in Edwardian Oxford\' in which the entire student body of Oxford university including the young, handsome aristocrat the Duke of Dorset falls hopelessly in love with Zuleika who is visiting her grandfather, the warden of Judas college, and ultimately commit mass suicide at the end of \'Eights Week\' (Summary by Andy Minter) For further information, including links to...</span><br/>          <span alt="4.00 out of 5 stars" title="4.00 out of 5 stars"><span class="iconochive-favorite"  aria-hidden="true"></span><span class="sr-only">favorite</span><span class="iconochive-favorite"  aria-hidden="true"></span><span class="sr-only">favorite</span><span class="iconochive-favorite"  aria-hidden="true"></span><span class="sr-only">favorite</span><span class="iconochive-favorite"  aria-hidden="true"></span><span class="sr-only">favorite</span></span> ( 1 reviews )<br/>          Topics: audiobook, librivox, satire, oxford, suicide<br/>          Source: Librivox recording of a public-domain text<br/>                  </div>
            <div class="C5"></div>
    </div>

    

    <div class="item-ia" data-id="memoirs_holmes_0709_librivox"
      data-mediatype="audio"
       data-year="2007">

            <a class="stealth" tabindex="-1" href="/details/librivoxaudio">
        <div class="item-parent">
          <div class="item-parent-img" style="background-image: url(\'/services/img/librivoxaudio\')"></div>
          <div class="item-parent-ttl">The LibriVox Free Audiobook Collection</div>
        </div><!--/.item-parent-->
      </a>
      

      <div class="hidden-tiles views C C1" title="all-time views">
                  <nobr class="hidden-xs">3.2<small>M</small></nobr>
          <nobr class="hidden-sm hidden-md hidden-lg">3.2M</nobr>
              </div>



      
      <div class="C234">
                  <div
            class="
              item-ttl
                                          C C2
            "
          >
            <a href="/details/memoirs_holmes_0709_librivox" title="The Memoirs of Sherlock Holmes"
              data-event-click-tracking="GenericNonCollection|ItemTile">
                              <div class="tile-img">
                  <img class="item-img "
                    alt="The Memoirs of Sherlock Holmes"
                    source=/services/img/memoirs_holmes_0709_librivox                     style="height:180px">
                </div><!--/.tile-img-->
              
                            
              
              <div class="ttl">
                The Memoirs of Sherlock Holmes              </div>
            </a>
          </div>
                <div class="hidden-tiles pubdate C C3">
          <nobr class="hidden-xs">Jun 29, 2012</nobr>
          <nobr class="hidden-sm hidden-md hidden-lg">06/12</nobr>
        </div>
        <div class="by C C4">
                                                <span class="hidden-lists">by</span>
              <span class="byv"
                    title="Sir Arthur Conan Doyle">Sir Arthur Conan Doyle</span>
                                          </div><!--/.C4-->
      </div><!--/.C234-->

      <div class="statbar ">
        <div class="mt-icon C C5">
                                <span class="iconochive-audio"  aria-hidden="true"></span><span class="sr-only">audio</span>                  </div>

                  <h6 class="stat " title="all-time views">
            <span class="iconochive-eye"  aria-hidden="true"></span><span class="sr-only">eye</span>            <nobr>3.2<small>M</small></nobr>
          </h6>
        
                  <h6 class="stat">
            <span class="iconochive-favorite"  aria-hidden="true"></span><span class="sr-only">favorite</span>            70          </h6>

                      <h6 class="stat">
              <span class="iconochive-comment"  aria-hidden="true"></span><span class="sr-only">comment</span>              3            </h6>
                                  </div><!--/.statbar-->

          </div><!--/.item-ia-->


    <div class="details-ia hidden-tiles">
      <div class="C1"></div>
              <div class="C234">
          <span>LibriVox recording of The Memoirs of Sherlock Holmes, by Sir Arthur Conan Doyle. Sherlock Holmes is a fictional detective of the late 19th and early 20th centuries, who first appeared in publication in 1887. He was devised by Scottish author and doctor Sir Arthur Conan Doyle. A brilliant London-based detective, Holmes is famous for his prowess at using logic and astute observation to solve cases. He is perhaps the most famous fictional detective, and indeed one of the best known and most...</span><br/>          <span alt="2.67 out of 5 stars" title="2.67 out of 5 stars"><span class="iconochive-favorite"  aria-hidden="true"></span><span class="sr-only">favorite</span><span class="iconochive-favorite"  aria-hidden="true"></span><span class="sr-only">favorite</span><span class="iconochive-favorite"  aria-hidden="true"></span><span class="sr-only">favorite</span></span> ( 3 reviews )<br/>          Topics: librivox, audiobook, literature, adventure, mystery, doyle, sherlock holmes<br/>          Source: Librivox recording of a public-domain text<br/>                  </div>
            <div class="C5"></div>
    </div>

    

    <div class="item-ia" data-id="first_love_mg_librivox"
      data-mediatype="audio"
       data-year="2009">

            <a class="stealth" tabindex="-1" href="/details/librivoxaudio">
        <div class="item-parent">
          <div class="item-parent-img" style="background-image: url(\'/services/img/librivoxaudio\')"></div>
          <div class="item-parent-ttl">The LibriVox Free Audiobook Collection</div>
        </div><!--/.item-parent-->
      </a>
      

      <div class="hidden-tiles views C C1" title="all-time views">
                  <nobr class="hidden-xs">587,762</nobr>
          <nobr class="hidden-sm hidden-md hidden-lg">588K</nobr>
              </div>



      
      <div class="C234">
                  <div
            class="
              item-ttl
                                          C C2
            "
          >
            <a href="/details/first_love_mg_librivox" title="First Love"
              data-event-click-tracking="GenericNonCollection|ItemTile">
                              <div class="tile-img">
                  <img class="item-img "
                    alt="First Love"
                    source=/services/img/first_love_mg_librivox                     style="height:180px">
                </div><!--/.tile-img-->
              
                            
              
              <div class="ttl">
                First Love              </div>
            </a>
          </div>
                <div class="hidden-tiles pubdate C C3">
          <nobr class="hidden-xs">Feb 10, 2021</nobr>
          <nobr class="hidden-sm hidden-md hidden-lg">02/21</nobr>
        </div>
        <div class="by C C4">
                                                <span class="hidden-lists">by</span>
              <span class="byv"
                    title="Ivan Turgenev trans. Constance Garnett">Ivan Turgenev trans. Constance Garnett</span>
                                          </div><!--/.C4-->
      </div><!--/.C234-->

      <div class="statbar ">
        <div class="mt-icon C C5">
                                <span class="iconochive-audio"  aria-hidden="true"></span><span class="sr-only">audio</span>                  </div>

                  <h6 class="stat " title="all-time views">
            <span class="iconochive-eye"  aria-hidden="true"></span><span class="sr-only">eye</span>            <nobr>587,762</nobr>
          </h6>
        
                  <h6 class="stat">
            <span class="iconochive-favorite"  aria-hidden="true"></span><span class="sr-only">favorite</span>            13          </h6>

                      <h6 class="stat">
              <span class="iconochive-comment"  aria-hidden="true"></span><span class="sr-only">comment</span>              3            </h6>
                                  </div><!--/.statbar-->

          </div><!--/.item-ia-->


    <div class="details-ia hidden-tiles">
      <div class="C1"></div>
              <div class="C234">
          <span>LibriVox recording of First Love, by Ivan Turgenev, translated by Constance Garnett. Read by Martin Geeson. The title of the novella is almost an adequate summary in itself. The &quot;boy-meets-girl-then-loses-her&quot; story is universal but not, I think, banal - despite a surprise ending which notoriously turns out to be very little of a surprise. First Love is given its originality and poignancy by Turgenev\'s mastery of the piercing turning-point (akin to Joyce\'s &quot;epiphanies&quot;) that...</span><br/>          <span alt="4.67 out of 5 stars" title="4.67 out of 5 stars"><span class="iconochive-favorite"  aria-hidden="true"></span><span class="sr-only">favorite</span><span class="iconochive-favorite"  aria-hidden="true"></span><span class="sr-only">favorite</span><span class="iconochive-favorite"  aria-hidden="true"></span><span class="sr-only">favorite</span><span class="iconochive-favorite"  aria-hidden="true"></span><span class="sr-only">favorite</span><span class="iconochive-favorite"  aria-hidden="true"></span><span class="sr-only">favorite</span></span> ( 3 reviews )<br/>          Topics: librivox, audiobook, literature, love, romance, novella<br/>          Source: Librivox recording of a public-domain text<br/>                  </div>
            <div class="C5"></div>
    </div>

    

    <div class="item-ia" data-id="jane_eyre_ver03_0809_librivox"
      data-mediatype="audio"
       data-year="2008">

            <a class="stealth" tabindex="-1" href="/details/librivoxaudio">
        <div class="item-parent">
          <div class="item-parent-img" style="background-image: url(\'/services/img/librivoxaudio\')"></div>
          <div class="item-parent-ttl">The LibriVox Free Audiobook Collection</div>
        </div><!--/.item-parent-->
      </a>
      

      <div class="hidden-tiles views C C1" title="all-time views">
                  <nobr class="hidden-xs">3.3<small>M</small></nobr>
          <nobr class="hidden-sm hidden-md hidden-lg">3.3M</nobr>
              </div>



      
      <div class="C234">
                  <div
            class="
              item-ttl
                                          C C2
            "
          >
            <a href="/details/jane_eyre_ver03_0809_librivox" title="Jane Eyre (version 3)"
              data-event-click-tracking="GenericNonCollection|ItemTile">
                              <div class="tile-img">
                  <img class="item-img "
                    alt="Jane Eyre (version 3)"
                    source=/services/img/jane_eyre_ver03_0809_librivox                     style="height:180px">
                </div><!--/.tile-img-->
              
                            
              
              <div class="ttl">
                Jane Eyre (version 3)              </div>
            </a>
          </div>
                <div class="hidden-tiles pubdate C C3">
          <nobr class="hidden-xs">Aug 12, 2020</nobr>
          <nobr class="hidden-sm hidden-md hidden-lg">08/20</nobr>
        </div>
        <div class="by C C4">
                                                <span class="hidden-lists">by</span>
              <span class="byv"
                    title="Charlotte Brontë">Charlotte Brontë</span>
                                          </div><!--/.C4-->
      </div><!--/.C234-->

      <div class="statbar ">
        <div class="mt-icon C C5">
                                <span class="iconochive-audio"  aria-hidden="true"></span><span class="sr-only">audio</span>                  </div>

                  <h6 class="stat " title="all-time views">
            <span class="iconochive-eye"  aria-hidden="true"></span><span class="sr-only">eye</span>            <nobr>3.3<small>M</small></nobr>
          </h6>
        
                  <h6 class="stat">
            <span class="iconochive-favorite"  aria-hidden="true"></span><span class="sr-only">favorite</span>            92          </h6>

                      <h6 class="stat">
              <span class="iconochive-comment"  aria-hidden="true"></span><span class="sr-only">comment</span>              21            </h6>
                                  </div><!--/.statbar-->

          </div><!--/.item-ia-->


    <div class="details-ia hidden-tiles">
      <div class="C1"></div>
              <div class="C234">
          <span>LibriVox recording of Jane Eyre, by Charlotte Brontë. Read by Elizabeth Klett. Charlotte Bronte\'s classic novel Jane Eyre is narrated by the title character, an orphan who survives neglect and abuse to become a governess at the remote Thornfield Hall. She finds a kindred spirit in her employer, the mysterious and brooding Mr. Rochester, but he hides a terrible secret that threatens their chances of happiness. (Summary by Elizabeth Klett) For further information, including links to online text,...</span><br/>          <span alt="5.00 out of 5 stars" title="5.00 out of 5 stars"><span class="iconochive-favorite"  aria-hidden="true"></span><span class="sr-only">favorite</span><span class="iconochive-favorite"  aria-hidden="true"></span><span class="sr-only">favorite</span><span class="iconochive-favorite"  aria-hidden="true"></span><span class="sr-only">favorite</span><span class="iconochive-favorite"  aria-hidden="true"></span><span class="sr-only">favorite</span><span class="iconochive-favorite"  aria-hidden="true"></span><span class="sr-only">favorite</span></span> ( 21 reviews )<br/>          Topics: librivox, audiobook, classic, romance<br/>          Source: Librivox recording of a public-domain text<br/>                  </div>
            <div class="C5"></div>
    </div>

    

    <div class="item-ia" data-id="girl_boat_1109_librivox"
      data-mediatype="audio"
       data-year="2011">

            <a class="stealth" tabindex="-1" href="/details/librivoxaudio">
        <div class="item-parent">
          <div class="item-parent-img" style="background-image: url(\'/services/img/librivoxaudio\')"></div>
          <div class="item-parent-ttl">The LibriVox Free Audiobook Collection</div>
        </div><!--/.item-parent-->
      </a>
      

      <div class="hidden-tiles views C C1" title="all-time views">
                  <nobr class="hidden-xs">938,415</nobr>
          <nobr class="hidden-sm hidden-md hidden-lg">938K</nobr>
              </div>



      
      <div class="C234">
                  <div
            class="
              item-ttl
                                          C C2
            "
          >
            <a href="/details/girl_boat_1109_librivox" title="The Girl on the Boat"
              data-event-click-tracking="GenericNonCollection|ItemTile">
                              <div class="tile-img">
                  <img class="item-img "
                    alt="The Girl on the Boat"
                    source=/services/img/girl_boat_1109_librivox                     style="height:178px">
                </div><!--/.tile-img-->
              
                            
              
              <div class="ttl">
                The Girl on the Boat              </div>
            </a>
          </div>
                <div class="hidden-tiles pubdate C C3">
          <nobr class="hidden-xs">Mar 1, 2021</nobr>
          <nobr class="hidden-sm hidden-md hidden-lg">03/21</nobr>
        </div>
        <div class="by C C4">
                                                <span class="hidden-lists">by</span>
              <span class="byv"
                    title="P.G. Wodehouse">P.G. Wodehouse</span>
                                          </div><!--/.C4-->
      </div><!--/.C234-->

      <div class="statbar ">
        <div class="mt-icon C C5">
                                <span class="iconochive-audio"  aria-hidden="true"></span><span class="sr-only">audio</span>                  </div>

                  <h6 class="stat " title="all-time views">
            <span class="iconochive-eye"  aria-hidden="true"></span><span class="sr-only">eye</span>            <nobr>938,415</nobr>
          </h6>
        
                  <h6 class="stat">
            <span class="iconochive-favorite"  aria-hidden="true"></span><span class="sr-only">favorite</span>            17          </h6>

                      <h6 class="stat">
              <span class="iconochive-comment"  aria-hidden="true"></span><span class="sr-only">comment</span>              5            </h6>
                                  </div><!--/.statbar-->

          </div><!--/.item-ia-->


    <div class="details-ia hidden-tiles">
      <div class="C1"></div>
              <div class="C234">
          <span>LibriVox recording of The Girl on the Boat, by P.G. Wodehouse. Read by Kara Shallenberg . Also published as &quot;Three Men and a Maid&quot;. The maid of the title is red-haired, dog-loving Wilhelmina &quot;Billie&quot; Bennet, and the three men are Bream Mortimer, a long-time friend and admirer of Billie, Eustace Hignett, a lily-livered poet who is engaged to Billie at the opening of the tale, and Sam Marlowe, Eustace\'s dashing cousin, who falls for Billie at first sight. All four find...</span><br/>          <span alt="5.00 out of 5 stars" title="5.00 out of 5 stars"><span class="iconochive-favorite"  aria-hidden="true"></span><span class="sr-only">favorite</span><span class="iconochive-favorite"  aria-hidden="true"></span><span class="sr-only">favorite</span><span class="iconochive-favorite"  aria-hidden="true"></span><span class="sr-only">favorite</span><span class="iconochive-favorite"  aria-hidden="true"></span><span class="sr-only">favorite</span><span class="iconochive-favorite"  aria-hidden="true"></span><span class="sr-only">favorite</span></span> ( 5 reviews )<br/>          Topics: librivox, audiobook, fiction, humor, romance, teen, young adult, comedy, P.G. Wodehouse, Three Men...<br/>          Source: Librivox recording of a public-domain text<br/>                  </div>
            <div class="C5"></div>
    </div>

    

    <div class="item-ia" data-id="emma_solo_librivox"
      data-mediatype="audio"
       data-year="2006">

            <a class="stealth" tabindex="-1" href="/details/librivoxaudio">
        <div class="item-parent">
          <div class="item-parent-img" style="background-image: url(\'/services/img/librivoxaudio\')"></div>
          <div class="item-parent-ttl">The LibriVox Free Audiobook Collection</div>
        </div><!--/.item-parent-->
      </a>
      

      <div class="hidden-tiles views C C1" title="all-time views">
                  <nobr class="hidden-xs">3.7<small>M</small></nobr>
          <nobr class="hidden-sm hidden-md hidden-lg">3.7M</nobr>
              </div>



      
      <div class="C234">
                  <div
            class="
              item-ttl
                                          C C2
            "
          >
            <a href="/details/emma_solo_librivox" title="Emma"
              data-event-click-tracking="GenericNonCollection|ItemTile">
                              <div class="tile-img">
                  <img class="item-img "
                    alt="Emma"
                    source=/services/img/emma_solo_librivox                     style="height:180px">
                </div><!--/.tile-img-->
              
                            
              
              <div class="ttl">
                Emma              </div>
            </a>
          </div>
                <div class="hidden-tiles pubdate C C3">
          <nobr class="hidden-xs">Aug 28, 2020</nobr>
          <nobr class="hidden-sm hidden-md hidden-lg">08/20</nobr>
        </div>
        <div class="by C C4">
                                                <span class="hidden-lists">by</span>
              <span class="byv"
                    title="Jane Austen">Jane Austen</span>
                                          </div><!--/.C4-->
      </div><!--/.C234-->

      <div class="statbar ">
        <div class="mt-icon C C5">
                                <span class="iconochive-audio"  aria-hidden="true"></span><span class="sr-only">audio</span>                  </div>

                  <h6 class="stat " title="all-time views">
            <span class="iconochive-eye"  aria-hidden="true"></span><span class="sr-only">eye</span>            <nobr>3.7<small>M</small></nobr>
          </h6>
        
                  <h6 class="stat">
            <span class="iconochive-favorite"  aria-hidden="true"></span><span class="sr-only">favorite</span>            91          </h6>

                      <h6 class="stat">
              <span class="iconochive-comment"  aria-hidden="true"></span><span class="sr-only">comment</span>              2            </h6>
                                  </div><!--/.statbar-->

          </div><!--/.item-ia-->


    <div class="details-ia hidden-tiles">
      <div class="C1"></div>
              <div class="C234">
          <span>LibriVox recording of Emma, by Jane Austen. Read by Sherry Crowther. (Vol. 1 Ch. 4 and Vol. 2 Ch. 11 read by Kara Shallenberg) Sherry reads Jane Austen’s sparkling comedy of manners with wit and vivacity, and brings the characters to life. Mr. Woodhouse worries and frets, Miss Bates chatters on, and Emma blithely manipulates and misunderstands her friends and family until she finally learns her lesson! (Summary by Kara) For further information, including links to online text, reader...</span><br/>          <span alt="4.00 out of 5 stars" title="4.00 out of 5 stars"><span class="iconochive-favorite"  aria-hidden="true"></span><span class="sr-only">favorite</span><span class="iconochive-favorite"  aria-hidden="true"></span><span class="sr-only">favorite</span><span class="iconochive-favorite"  aria-hidden="true"></span><span class="sr-only">favorite</span><span class="iconochive-favorite"  aria-hidden="true"></span><span class="sr-only">favorite</span></span> ( 2 reviews )<br/>          Topics: librivox, literature, audiobook, austen, emma, comedy, regency, england<br/>          Source: Librivox recording of a public-domain text<br/>                  </div>
            <div class="C5"></div>
    </div>

    

    <div class="item-ia" data-id="romeoandjuliet_ss_0901_librivox"
      data-mediatype="audio"
       data-year="2009">

            <a class="stealth" tabindex="-1" href="/details/librivoxaudio">
        <div class="item-parent">
          <div class="item-parent-img" style="background-image: url(\'/services/img/librivoxaudio\')"></div>
          <div class="item-parent-ttl">The LibriVox Free Audiobook Collection</div>
        </div><!--/.item-parent-->
      </a>
      

      <div class="hidden-tiles views C C1" title="all-time views">
                  <nobr class="hidden-xs">1.8<small>M</small></nobr>
          <nobr class="hidden-sm hidden-md hidden-lg">1.8M</nobr>
              </div>



      
      <div class="C234">
                  <div
            class="
              item-ttl
                                          C C2
            "
          >
            <a href="/details/romeoandjuliet_ss_0901_librivox" title="Romeo and Juliet"
              data-event-click-tracking="GenericNonCollection|ItemTile">
                              <div class="tile-img">
                  <img class="item-img "
                    alt="Romeo and Juliet"
                    source=/services/img/romeoandjuliet_ss_0901_librivox                     style="height:180px">
                </div><!--/.tile-img-->
              
                            
              
              <div class="ttl">
                Romeo and Juliet              </div>
            </a>
          </div>
                <div class="hidden-tiles pubdate C C3">
          <nobr class="hidden-xs">-</nobr>
          <nobr class="hidden-sm hidden-md hidden-lg">-</nobr>
        </div>
        <div class="by C C4">
                                                <span class="hidden-lists">by</span>
              <span class="byv"
                    title="William Shakespeare">William Shakespeare</span>
                                          </div><!--/.C4-->
      </div><!--/.C234-->

      <div class="statbar ">
        <div class="mt-icon C C5">
                                <span class="iconochive-audio"  aria-hidden="true"></span><span class="sr-only">audio</span>                  </div>

                  <h6 class="stat " title="all-time views">
            <span class="iconochive-eye"  aria-hidden="true"></span><span class="sr-only">eye</span>            <nobr>1.8<small>M</small></nobr>
          </h6>
        
                  <h6 class="stat">
            <span class="iconochive-favorite"  aria-hidden="true"></span><span class="sr-only">favorite</span>            19          </h6>

                      <h6 class="stat">
              <span class="iconochive-comment"  aria-hidden="true"></span><span class="sr-only">comment</span>              0            </h6>
                                  </div><!--/.statbar-->

          </div><!--/.item-ia-->


    <div class="details-ia hidden-tiles">
      <div class="C1"></div>
              <div class="C234">
          <span>Librivox recording of Romeo and Juliet by William Shakespeare. Read by Sam Stinson . Romeo and Juliet is an early tragedy by William Shakespeare about two teenage &quot;star-cross\'d lovers&quot; whose &quot;untimely deaths&quot; ultimately unite their feuding households. The play has been highly praised by literary critics for its language and dramatic effect. It was among Shakespeare\'s most popular plays during his lifetime and, along with Hamlet, is one of his most frequently performed plays....</span><br/>                    Topics: librivox, literature, audiobook, William Shakespeare, Romeo, Juliet, drama, play, tragedy, tragic...<br/>          Source: Librivox recording of a public-domain text<br/>                  </div>
            <div class="C5"></div>
    </div>

    

    <div class="item-ia" data-id="adventuressherlockholmes_v4_1501_librivox"
      data-mediatype="audio"
       data-year="2015">

            <a class="stealth" tabindex="-1" href="/details/librivoxaudio">
        <div class="item-parent">
          <div class="item-parent-img" style="background-image: url(\'/services/img/librivoxaudio\')"></div>
          <div class="item-parent-ttl">The LibriVox Free Audiobook Collection</div>
        </div><!--/.item-parent-->
      </a>
      

      <div class="hidden-tiles views C C1" title="all-time views">
                  <nobr class="hidden-xs">1.4<small>M</small></nobr>
          <nobr class="hidden-sm hidden-md hidden-lg">1.4M</nobr>
              </div>



      
      <div class="C234">
                  <div
            class="
              item-ttl
                                          C C2
            "
          >
            <a href="/details/adventuressherlockholmes_v4_1501_librivox" title="The Adventures of Sherlock Holmes (version 4)"
              data-event-click-tracking="GenericNonCollection|ItemTile">
                              <div class="tile-img">
                  <img class="item-img "
                    alt="The Adventures of Sherlock Holmes (version 4)"
                    source=/services/img/adventuressherlockholmes_v4_1501_librivox                     style="height:180px">
                </div><!--/.tile-img-->
              
                            
              
              <div class="ttl">
                The Adventures of Sherlock Holmes (version 4)              </div>
            </a>
          </div>
                <div class="hidden-tiles pubdate C C3">
          <nobr class="hidden-xs">Jan 16, 2021</nobr>
          <nobr class="hidden-sm hidden-md hidden-lg">01/21</nobr>
        </div>
        <div class="by C C4">
                                                <span class="hidden-lists">by</span>
              <span class="byv"
                    title="Sir Arthur Conan Doyle">Sir Arthur Conan Doyle</span>
                                          </div><!--/.C4-->
      </div><!--/.C234-->

      <div class="statbar ">
        <div class="mt-icon C C5">
                                <span class="iconochive-audio"  aria-hidden="true"></span><span class="sr-only">audio</span>                  </div>

                  <h6 class="stat " title="all-time views">
            <span class="iconochive-eye"  aria-hidden="true"></span><span class="sr-only">eye</span>            <nobr>1.4<small>M</small></nobr>
          </h6>
        
                  <h6 class="stat">
            <span class="iconochive-favorite"  aria-hidden="true"></span><span class="sr-only">favorite</span>            60          </h6>

                      <h6 class="stat">
              <span class="iconochive-comment"  aria-hidden="true"></span><span class="sr-only">comment</span>              1            </h6>
                                  </div><!--/.statbar-->

          </div><!--/.item-ia-->


    <div class="details-ia hidden-tiles">
      <div class="C1"></div>
              <div class="C234">
          <span>LibriVox recording of The Adventures of Sherlock Holmes (version 4) by Sir Arthur Conan Doyle. Read in English by David Clarke The Adventures of Sherlock Holmes is a collection of 12 short stories that were originally illustrated by Sidney Paget. These are the first set of short stories that were published and followed the publishing of his first 2 novels, A Study in Scarlet and The Sign of the Four. - Summary by David Clarke For further information, including links to online text, reader...</span><br/>          <span alt="5.00 out of 5 stars" title="5.00 out of 5 stars"><span class="iconochive-favorite"  aria-hidden="true"></span><span class="sr-only">favorite</span><span class="iconochive-favorite"  aria-hidden="true"></span><span class="sr-only">favorite</span><span class="iconochive-favorite"  aria-hidden="true"></span><span class="sr-only">favorite</span><span class="iconochive-favorite"  aria-hidden="true"></span><span class="sr-only">favorite</span><span class="iconochive-favorite"  aria-hidden="true"></span><span class="sr-only">favorite</span></span> ( 1 reviews )<br/>          Topics: librivox, audiobooks, Sherlock Holmes, Detective, Crime<br/>                            </div>
            <div class="C5"></div>
    </div>

    

    <div class="item-ia" data-id="beneaththebanner_2103_librivox"
      data-mediatype="audio"
       data-year="2021">

            <a class="stealth" tabindex="-1" href="/details/librivoxaudio">
        <div class="item-parent">
          <div class="item-parent-img" style="background-image: url(\'/services/img/librivoxaudio\')"></div>
          <div class="item-parent-ttl">The LibriVox Free Audiobook Collection</div>
        </div><!--/.item-parent-->
      </a>
      

      <div class="hidden-tiles views C C1" title="all-time views">
                  <nobr class="hidden-xs">16,049</nobr>
          <nobr class="hidden-sm hidden-md hidden-lg">16K</nobr>
              </div>



      
      <div class="C234">
                  <div
            class="
              item-ttl
                                          C C2
            "
          >
            <a href="/details/beneaththebanner_2103_librivox" title="Beneath the Banner: Being Narratives of Noble Lives and Brave Deeds"
              data-event-click-tracking="GenericNonCollection|ItemTile">
                              <div class="tile-img">
                  <img class="item-img "
                    alt="Beneath the Banner: Being Narratives of Noble Lives and Brave Deeds"
                    source=/services/img/beneaththebanner_2103_librivox                     style="height:180px">
                </div><!--/.tile-img-->
              
                            
              
              <div class="ttl">
                Beneath the Banner: Being Narratives of Noble Lives and Brave Deeds              </div>
            </a>
          </div>
                <div class="hidden-tiles pubdate C C3">
          <nobr class="hidden-xs">-</nobr>
          <nobr class="hidden-sm hidden-md hidden-lg">-</nobr>
        </div>
        <div class="by C C4">
                                                <span class="hidden-lists">by</span>
              <span class="byv"
                    title="Frederick J. Cross">Frederick J. Cross</span>
                                          </div><!--/.C4-->
      </div><!--/.C234-->

      <div class="statbar ">
        <div class="mt-icon C C5">
                                <span class="iconochive-audio"  aria-hidden="true"></span><span class="sr-only">audio</span>                  </div>

                  <h6 class="stat " title="all-time views">
            <span class="iconochive-eye"  aria-hidden="true"></span><span class="sr-only">eye</span>            <nobr>16,049</nobr>
          </h6>
        
                  <h6 class="stat">
            <span class="iconochive-favorite"  aria-hidden="true"></span><span class="sr-only">favorite</span>            0          </h6>

                      <h6 class="stat">
              <span class="iconochive-comment"  aria-hidden="true"></span><span class="sr-only">comment</span>              0            </h6>
                                  </div><!--/.statbar-->

          </div><!--/.item-ia-->


    <div class="details-ia hidden-tiles">
      <div class="C1"></div>
              <div class="C234">
          <span>LibriVox recording of Beneath the Banner: Being Narratives of Noble Lives and Brave Deeds by Frederick J. Cross. Read in English by Lynda Marie Neilson. In this book are over 30 stories by various people about men and women who have done extraordinary things during and often before the time when similar products were invented. It is suitable for bedtime reading. Summary by Lynda Marie Neilson For further information, including links to online text, reader information, RSS feeds, CD cover or...</span><br/>                    Topics: librivox, audiobooks, invention<br/>                            </div>
            <div class="C5"></div>
    </div>

    

    <div class="item-ia" data-id="grimm_fairy_tales_1202_librivox"
      data-mediatype="audio"
       data-year="2012">

            <a class="stealth" tabindex="-1" href="/details/librivoxaudio">
        <div class="item-parent">
          <div class="item-parent-img" style="background-image: url(\'/services/img/librivoxaudio\')"></div>
          <div class="item-parent-ttl">The LibriVox Free Audiobook Collection</div>
        </div><!--/.item-parent-->
      </a>
      

      <div class="hidden-tiles views C C1" title="all-time views">
                  <nobr class="hidden-xs">2.6<small>M</small></nobr>
          <nobr class="hidden-sm hidden-md hidden-lg">2.6M</nobr>
              </div>



      
      <div class="C234">
                  <div
            class="
              item-ttl
                                          C C2
            "
          >
            <a href="/details/grimm_fairy_tales_1202_librivox" title="Grimm\'s Fairy Tales (version 2)"
              data-event-click-tracking="GenericNonCollection|ItemTile">
                              <div class="tile-img">
                  <img class="item-img "
                    alt="Grimm\'s Fairy Tales (version 2)"
                    source=/services/img/grimm_fairy_tales_1202_librivox                     style="height:180px">
                </div><!--/.tile-img-->
              
                            
              
              <div class="ttl">
                Grimm\'s Fairy Tales (version 2)              </div>
            </a>
          </div>
                <div class="hidden-tiles pubdate C C3">
          <nobr class="hidden-xs">Jul 31, 2017</nobr>
          <nobr class="hidden-sm hidden-md hidden-lg">07/17</nobr>
        </div>
        <div class="by C C4">
                                                <span class="hidden-lists">by</span>
              <span class="byv"
                    title="Jacob &amp; Wilhelm Grimm">Jacob &amp; Wilhelm Grimm</span>
                                          </div><!--/.C4-->
      </div><!--/.C234-->

      <div class="statbar ">
        <div class="mt-icon C C5">
                                <span class="iconochive-audio"  aria-hidden="true"></span><span class="sr-only">audio</span>                  </div>

                  <h6 class="stat " title="all-time views">
            <span class="iconochive-eye"  aria-hidden="true"></span><span class="sr-only">eye</span>            <nobr>2.6<small>M</small></nobr>
          </h6>
        
                  <h6 class="stat">
            <span class="iconochive-favorite"  aria-hidden="true"></span><span class="sr-only">favorite</span>            102          </h6>

                      <h6 class="stat">
              <span class="iconochive-comment"  aria-hidden="true"></span><span class="sr-only">comment</span>              2            </h6>
                                  </div><!--/.statbar-->

          </div><!--/.item-ia-->


    <div class="details-ia hidden-tiles">
      <div class="C1"></div>
              <div class="C234">
          <span>LibriVox recording of Grimm\'s Fairy Tales (version 2), by Jacob &amp; Wilhelm Grimm. Read by Bob Neufeld. Children\'s and Household Tales (German: Kinder- und Hausmärchen) is a collection of German origin fairy tales first published in 1812 by Jacob and Wilhelm Grimm, the Brothers Grimm. The collection is commonly known today as Grimms\' Fairy Tales (German: Grimms Märchen). ( Summary by Wikipedia ) For further information, including links to online text, reader information, RSS feeds, CD cover...</span><br/>          <span alt="5.00 out of 5 stars" title="5.00 out of 5 stars"><span class="iconochive-favorite"  aria-hidden="true"></span><span class="sr-only">favorite</span><span class="iconochive-favorite"  aria-hidden="true"></span><span class="sr-only">favorite</span><span class="iconochive-favorite"  aria-hidden="true"></span><span class="sr-only">favorite</span><span class="iconochive-favorite"  aria-hidden="true"></span><span class="sr-only">favorite</span><span class="iconochive-favorite"  aria-hidden="true"></span><span class="sr-only">favorite</span></span> ( 2 reviews )<br/>          Topics: librivox, audiobook, children, fairy tales, fiction, short stories, Grimm, Grimms\' Fairy Tales<br/>          Source: Librivox recording of a public-domain text<br/>                  </div>
            <div class="C5"></div>
    </div>

    

    <div class="item-ia" data-id="necessityofatheism_1205_librivox"
      data-mediatype="audio"
       data-year="2012">

            <a class="stealth" tabindex="-1" href="/details/librivoxaudio">
        <div class="item-parent">
          <div class="item-parent-img" style="background-image: url(\'/services/img/librivoxaudio\')"></div>
          <div class="item-parent-ttl">The LibriVox Free Audiobook Collection</div>
        </div><!--/.item-parent-->
      </a>
      

      <div class="hidden-tiles views C C1" title="all-time views">
                  <nobr class="hidden-xs">172,972</nobr>
          <nobr class="hidden-sm hidden-md hidden-lg">173K</nobr>
              </div>



      
      <div class="C234">
                  <div
            class="
              item-ttl
                                          C C2
            "
          >
            <a href="/details/necessityofatheism_1205_librivox" title="The Necessity of Atheism"
              data-event-click-tracking="GenericNonCollection|ItemTile">
                              <div class="tile-img">
                  <img class="item-img "
                    alt="The Necessity of Atheism"
                    source=/services/img/necessityofatheism_1205_librivox                     style="height:180px">
                </div><!--/.tile-img-->
              
                            
              
              <div class="ttl">
                The Necessity of Atheism              </div>
            </a>
          </div>
                <div class="hidden-tiles pubdate C C3">
          <nobr class="hidden-xs">Mar 24, 2021</nobr>
          <nobr class="hidden-sm hidden-md hidden-lg">03/21</nobr>
        </div>
        <div class="by C C4">
                                                <span class="hidden-lists">by</span>
              <span class="byv"
                    title="David Marshall Brooks">David Marshall Brooks</span>
                                          </div><!--/.C4-->
      </div><!--/.C234-->

      <div class="statbar ">
        <div class="mt-icon C C5">
                                <span class="iconochive-audio"  aria-hidden="true"></span><span class="sr-only">audio</span>                  </div>

                  <h6 class="stat " title="all-time views">
            <span class="iconochive-eye"  aria-hidden="true"></span><span class="sr-only">eye</span>            <nobr>172,972</nobr>
          </h6>
        
                  <h6 class="stat">
            <span class="iconochive-favorite"  aria-hidden="true"></span><span class="sr-only">favorite</span>            13          </h6>

                      <h6 class="stat">
              <span class="iconochive-comment"  aria-hidden="true"></span><span class="sr-only">comment</span>              2            </h6>
                                  </div><!--/.statbar-->

          </div><!--/.item-ia-->


    <div class="details-ia hidden-tiles">
      <div class="C1"></div>
              <div class="C234">
          <span>LibriVox recording of The Necessity of Atheism by David Marshall Brooks. Read by Wesseling Plain speaking is necessary in any discussion of religion, for if the freethinker attacks the religious dogmas with hesitation, the orthodox believer assumes that it is with regret that the freethinker would remove the crutch that supports the orthodox. And all religious beliefs are &quot;crutches&quot; hindering the free locomotive efforts of an advancing humanity. There are no problems related to human...</span><br/>          <span alt="3.00 out of 5 stars" title="3.00 out of 5 stars"><span class="iconochive-favorite"  aria-hidden="true"></span><span class="sr-only">favorite</span><span class="iconochive-favorite"  aria-hidden="true"></span><span class="sr-only">favorite</span><span class="iconochive-favorite"  aria-hidden="true"></span><span class="sr-only">favorite</span></span> ( 2 reviews )<br/>          Topics: librivox, audiobooks, nonfiction, atheism, humanism, religion, freethinkers, spirituality, church,...<br/>          Source: Librivox recording of a public-domain text<br/>                  </div>
            <div class="C5"></div>
    </div>

    

    <div class="item-ia" data-id="robinson_crusoe_librivox"
      data-mediatype="audio"
       data-year="2006">

            <a class="stealth" tabindex="-1" href="/details/librivoxaudio">
        <div class="item-parent">
          <div class="item-parent-img" style="background-image: url(\'/services/img/librivoxaudio\')"></div>
          <div class="item-parent-ttl">The LibriVox Free Audiobook Collection</div>
        </div><!--/.item-parent-->
      </a>
      

      <div class="hidden-tiles views C C1" title="all-time views">
                  <nobr class="hidden-xs">2.9<small>M</small></nobr>
          <nobr class="hidden-sm hidden-md hidden-lg">2.9M</nobr>
              </div>



      
      <div class="C234">
                  <div
            class="
              item-ttl
                                          C C2
            "
          >
            <a href="/details/robinson_crusoe_librivox" title="The Life and Strange Surprising Adventures of Robinson Crusoe of York, Mariner"
              data-event-click-tracking="GenericNonCollection|ItemTile">
                              <div class="tile-img">
                  <img class="item-img "
                    alt="The Life and Strange Surprising Adventures of Robinson Crusoe of York, Mariner"
                    source=/services/img/robinson_crusoe_librivox                     style="height:180px">
                </div><!--/.tile-img-->
              
                            
              
              <div class="ttl">
                The Life and Strange Surprising Adventures of Robinson Crusoe of York, Mariner              </div>
            </a>
          </div>
                <div class="hidden-tiles pubdate C C3">
          <nobr class="hidden-xs">Jul 4, 2020</nobr>
          <nobr class="hidden-sm hidden-md hidden-lg">07/20</nobr>
        </div>
        <div class="by C C4">
                                                <span class="hidden-lists">by</span>
              <span class="byv"
                    title="Daniel Defoe">Daniel Defoe</span>
                                          </div><!--/.C4-->
      </div><!--/.C234-->

      <div class="statbar ">
        <div class="mt-icon C C5">
                                <span class="iconochive-audio"  aria-hidden="true"></span><span class="sr-only">audio</span>                  </div>

                  <h6 class="stat " title="all-time views">
            <span class="iconochive-eye"  aria-hidden="true"></span><span class="sr-only">eye</span>            <nobr>2.9<small>M</small></nobr>
          </h6>
        
                  <h6 class="stat">
            <span class="iconochive-favorite"  aria-hidden="true"></span><span class="sr-only">favorite</span>            65          </h6>

                      <h6 class="stat">
              <span class="iconochive-comment"  aria-hidden="true"></span><span class="sr-only">comment</span>              3            </h6>
                                  </div><!--/.statbar-->

          </div><!--/.item-ia-->


    <div class="details-ia hidden-tiles">
      <div class="C1"></div>
              <div class="C234">
          <span>LibriVox recording of Robinson Crusoe by Daniel Defoe. Read by Denny Sayers. Daniel Defoe\'s The Life and Strange Surprizing Adventures of Robinson Crusoe of York, Mariner (1719) is considered by many the first English novel. Based on the real-life experiences of the castaway Alexander Selkirk, the book has had a perrenial appeal among readers of all ages - especially the young adult reading public - who continue to find inspiration in the inventive resourcefulness of its hero, sole survivor of...</span><br/>          <span alt="4.67 out of 5 stars" title="4.67 out of 5 stars"><span class="iconochive-favorite"  aria-hidden="true"></span><span class="sr-only">favorite</span><span class="iconochive-favorite"  aria-hidden="true"></span><span class="sr-only">favorite</span><span class="iconochive-favorite"  aria-hidden="true"></span><span class="sr-only">favorite</span><span class="iconochive-favorite"  aria-hidden="true"></span><span class="sr-only">favorite</span><span class="iconochive-favorite"  aria-hidden="true"></span><span class="sr-only">favorite</span></span> ( 3 reviews )<br/>          Topics: librivox, literature, audiobook, adventure<br/>          Source: Librivox recording of a public-domain text<br/>                  </div>
            <div class="C5"></div>
    </div>

    

    <div class="item-ia" data-id="grammairemllelili_2103_librivox"
      data-mediatype="audio"
       data-year="2021">

            <a class="stealth" tabindex="-1" href="/details/librivoxaudio">
        <div class="item-parent">
          <div class="item-parent-img" style="background-image: url(\'/services/img/librivoxaudio\')"></div>
          <div class="item-parent-ttl">The LibriVox Free Audiobook Collection</div>
        </div><!--/.item-parent-->
      </a>
      

      <div class="hidden-tiles views C C1" title="all-time views">
                  <nobr class="hidden-xs">14,892</nobr>
          <nobr class="hidden-sm hidden-md hidden-lg">15K</nobr>
              </div>



      
      <div class="C234">
                  <div
            class="
              item-ttl
                                          C C2
            "
          >
            <a href="/details/grammairemllelili_2103_librivox" title="La Grammaire de Mademoiselle Lili"
              data-event-click-tracking="GenericNonCollection|ItemTile">
                              <div class="tile-img">
                  <img class="item-img "
                    alt="La Grammaire de Mademoiselle Lili"
                    source=/services/img/grammairemllelili_2103_librivox                     style="height:180px">
                </div><!--/.tile-img-->
              
                            
              
              <div class="ttl">
                La Grammaire de Mademoiselle Lili              </div>
            </a>
          </div>
                <div class="hidden-tiles pubdate C C3">
          <nobr class="hidden-xs">-</nobr>
          <nobr class="hidden-sm hidden-md hidden-lg">-</nobr>
        </div>
        <div class="by C C4">
                                                <span class="hidden-lists">by</span>
              <span class="byv"
                    title="Jean Macé">Jean Macé</span>
                                          </div><!--/.C4-->
      </div><!--/.C234-->

      <div class="statbar ">
        <div class="mt-icon C C5">
                                <span class="iconochive-audio"  aria-hidden="true"></span><span class="sr-only">audio</span>                  </div>

                  <h6 class="stat " title="all-time views">
            <span class="iconochive-eye"  aria-hidden="true"></span><span class="sr-only">eye</span>            <nobr>14,892</nobr>
          </h6>
        
                  <h6 class="stat">
            <span class="iconochive-favorite"  aria-hidden="true"></span><span class="sr-only">favorite</span>            1          </h6>

                      <h6 class="stat">
              <span class="iconochive-comment"  aria-hidden="true"></span><span class="sr-only">comment</span>              0            </h6>
                                  </div><!--/.statbar-->

          </div><!--/.item-ia-->


    <div class="details-ia hidden-tiles">
      <div class="C1"></div>
              <div class="C234">
          <span>LibriVox recording of La Grammaire de Mademoiselle Lili by Jean Macé. Read in French by Ezwa. Les rudiments de la grammaire française, art de parler et d\'écrire correctement dans la langue de Molière, sont ici mis à la portée d\'une petite fille. French grammar or the art of speaking and writing in that language, made very plain to a little girl. - Summary by Ezwa For further information, including links to online text, reader information, RSS feeds, CD cover or other formats (if...</span><br/>                    Topics: librivox, audiobooks, French, français, grammar, enfants, grammaire française<br/>                            </div>
            <div class="C5"></div>
    </div>

    

    <div class="item-ia" data-id="return_holmes_0708_librivox"
      data-mediatype="audio"
       data-year="2007">

            <a class="stealth" tabindex="-1" href="/details/librivoxaudio">
        <div class="item-parent">
          <div class="item-parent-img" style="background-image: url(\'/services/img/librivoxaudio\')"></div>
          <div class="item-parent-ttl">The LibriVox Free Audiobook Collection</div>
        </div><!--/.item-parent-->
      </a>
      

      <div class="hidden-tiles views C C1" title="all-time views">
                  <nobr class="hidden-xs">3<small>M</small></nobr>
          <nobr class="hidden-sm hidden-md hidden-lg">3.0M</nobr>
              </div>



      
      <div class="C234">
                  <div
            class="
              item-ttl
                                          C C2
            "
          >
            <a href="/details/return_holmes_0708_librivox" title="The Return of Sherlock Holmes"
              data-event-click-tracking="GenericNonCollection|ItemTile">
                              <div class="tile-img">
                  <img class="item-img "
                    alt="The Return of Sherlock Holmes"
                    source=/services/img/return_holmes_0708_librivox                     style="height:180px">
                </div><!--/.tile-img-->
              
                            
              
              <div class="ttl">
                The Return of Sherlock Holmes              </div>
            </a>
          </div>
                <div class="hidden-tiles pubdate C C3">
          <nobr class="hidden-xs">Sep 3, 2009</nobr>
          <nobr class="hidden-sm hidden-md hidden-lg">09/09</nobr>
        </div>
        <div class="by C C4">
                                                <span class="hidden-lists">by</span>
              <span class="byv"
                    title="Sir Arthur Conan Doyle">Sir Arthur Conan Doyle</span>
                                          </div><!--/.C4-->
      </div><!--/.C234-->

      <div class="statbar ">
        <div class="mt-icon C C5">
                                <span class="iconochive-audio"  aria-hidden="true"></span><span class="sr-only">audio</span>                  </div>

                  <h6 class="stat " title="all-time views">
            <span class="iconochive-eye"  aria-hidden="true"></span><span class="sr-only">eye</span>            <nobr>3<small>M</small></nobr>
          </h6>
        
                  <h6 class="stat">
            <span class="iconochive-favorite"  aria-hidden="true"></span><span class="sr-only">favorite</span>            106          </h6>

                      <h6 class="stat">
              <span class="iconochive-comment"  aria-hidden="true"></span><span class="sr-only">comment</span>              2            </h6>
                                  </div><!--/.statbar-->

          </div><!--/.item-ia-->


    <div class="details-ia hidden-tiles">
      <div class="C1"></div>
              <div class="C234">
          <span>LibriVox recording of The Return of Sherlock Holmes, by Sir Arthur Conan Doyle. Having left Sherlock Holmes apparently deceased at the conclusion of The Final Problem (in The Memoirs of Sherlock Holmes), we now find that he is alive after all! In this collection, first published in 1905, the great detective causes Watson to faint (The Empty House), demonstrates that cryptography is elementary (The Dancing Men), and gets engaged (Charles Augustus Milverton). Join in the fun as Holmes deduces his...</span><br/>          <span alt="4.50 out of 5 stars" title="4.50 out of 5 stars"><span class="iconochive-favorite"  aria-hidden="true"></span><span class="sr-only">favorite</span><span class="iconochive-favorite"  aria-hidden="true"></span><span class="sr-only">favorite</span><span class="iconochive-favorite"  aria-hidden="true"></span><span class="sr-only">favorite</span><span class="iconochive-favorite"  aria-hidden="true"></span><span class="sr-only">favorite</span><span class="iconochive-favorite"  aria-hidden="true"></span><span class="sr-only">favorite</span></span> ( 2 reviews )<br/>          Topics: librivox, literature, audiobooks, mystery, detective, holmes, doyle, short story<br/>          Source: Librivox recording of a public-domain text<br/>                  </div>
            <div class="C5"></div>
    </div>

    

    <div class="item-ia" data-id="thumb06"
      data-mediatype="audio"
       data-year="2015">

            <a class="stealth" tabindex="-1" href="/details/librivoxaudiocovers">
        <div class="item-parent">
          <div class="item-parent-img" style="background-image: url(\'/services/img/librivoxaudiocovers\')"></div>
          <div class="item-parent-ttl">Librivoxaudio Covers</div>
        </div><!--/.item-parent-->
      </a>
      

      <div class="hidden-tiles views C C1" title="all-time views">
                  <nobr class="hidden-xs">3.6<small>M</small></nobr>
          <nobr class="hidden-sm hidden-md hidden-lg">3.6M</nobr>
              </div>



      
      <div class="C234">
                  <div
            class="
              item-ttl
                                          C C2
            "
          >
            <a href="/details/thumb06" title="Thumbs 06"
              data-event-click-tracking="GenericNonCollection|ItemTile">
                              <div class="tile-img">
                  <img class="item-img "
                    alt="Thumbs 06"
                    source=/services/img/thumb06                     style="height:180px">
                </div><!--/.tile-img-->
              
                            
              
              <div class="ttl">
                Thumbs 06              </div>
            </a>
          </div>
                <div class="hidden-tiles pubdate C C3">
          <nobr class="hidden-xs">-</nobr>
          <nobr class="hidden-sm hidden-md hidden-lg">-</nobr>
        </div>
        <div class="by C C4">
                                                <span class="hidden-lists">by</span>
              <span class="byv"
                    title="LV covermakers">LV covermakers</span>
                                          </div><!--/.C4-->
      </div><!--/.C234-->

      <div class="statbar ">
        <div class="mt-icon C C5">
                                <span class="iconochive-audio"  aria-hidden="true"></span><span class="sr-only">audio</span>                  </div>

                  <h6 class="stat " title="all-time views">
            <span class="iconochive-eye"  aria-hidden="true"></span><span class="sr-only">eye</span>            <nobr>3.6<small>M</small></nobr>
          </h6>
        
                  <h6 class="stat">
            <span class="iconochive-favorite"  aria-hidden="true"></span><span class="sr-only">favorite</span>            2          </h6>

                      <h6 class="stat">
              <span class="iconochive-comment"  aria-hidden="true"></span><span class="sr-only">comment</span>              0            </h6>
                                  </div><!--/.statbar-->

          </div><!--/.item-ia-->


    <div class="details-ia hidden-tiles">
      <div class="C1"></div>
              <div class="C234">
          <span>Thumb images for LibriVox Projects</span><br/>                    Topic: cover images<br/>                            </div>
            <div class="C5"></div>
    </div>

    

    <div class="item-ia" data-id="romeo_and_juliet_librivox"
      data-mediatype="audio"
       data-year="2006">

            <a class="stealth" tabindex="-1" href="/details/librivoxaudio">
        <div class="item-parent">
          <div class="item-parent-img" style="background-image: url(\'/services/img/librivoxaudio\')"></div>
          <div class="item-parent-ttl">The LibriVox Free Audiobook Collection</div>
        </div><!--/.item-parent-->
      </a>
      

      <div class="hidden-tiles views C C1" title="all-time views">
                  <nobr class="hidden-xs">2.5<small>M</small></nobr>
          <nobr class="hidden-sm hidden-md hidden-lg">2.5M</nobr>
              </div>



      
      <div class="C234">
                  <div
            class="
              item-ttl
                                          C C2
            "
          >
            <a href="/details/romeo_and_juliet_librivox" title="Romeo and Juliet"
              data-event-click-tracking="GenericNonCollection|ItemTile">
                              <div class="tile-img">
                  <img class="item-img "
                    alt="Romeo and Juliet"
                    source=/services/img/romeo_and_juliet_librivox                     style="height:180px">
                </div><!--/.tile-img-->
              
                            
              
              <div class="ttl">
                Romeo and Juliet              </div>
            </a>
          </div>
                <div class="hidden-tiles pubdate C C3">
          <nobr class="hidden-xs">-</nobr>
          <nobr class="hidden-sm hidden-md hidden-lg">-</nobr>
        </div>
        <div class="by C C4">
                                                <span class="hidden-lists">by</span>
              <span class="byv"
                    title="William Shakespeare">William Shakespeare</span>
                                          </div><!--/.C4-->
      </div><!--/.C234-->

      <div class="statbar ">
        <div class="mt-icon C C5">
                                <span class="iconochive-audio"  aria-hidden="true"></span><span class="sr-only">audio</span>                  </div>

                  <h6 class="stat " title="all-time views">
            <span class="iconochive-eye"  aria-hidden="true"></span><span class="sr-only">eye</span>            <nobr>2.5<small>M</small></nobr>
          </h6>
        
                  <h6 class="stat">
            <span class="iconochive-favorite"  aria-hidden="true"></span><span class="sr-only">favorite</span>            61          </h6>

                      <h6 class="stat">
              <span class="iconochive-comment"  aria-hidden="true"></span><span class="sr-only">comment</span>              0            </h6>
                                  </div><!--/.statbar-->

          </div><!--/.item-ia-->


    <div class="details-ia hidden-tiles">
      <div class="C1"></div>
              <div class="C234">
          <span>Librivox recording of Romeo and Juliet, by William Shakespeare. Read by Becky Crackel. Romeo and Juliet is perhaps the most famous of Shakespeare\'s plays and is thought to be the most famous love story in Western history. It concerns the fate of two very young lovers who would do anything to be together. The Montagues and the Capulets of Verona, Italy, are in the midst of a long-standing feud when Romeo Montague drops in on a masquerade party at the Capulets\'. While there he meets and woos the...</span><br/>                    Topics: librivox, audiobook, drama<br/>          Source: Librivox recording of a public-domain text<br/>                  </div>
            <div class="C5"></div>
    </div>

    

    <div class="item-ia" data-id="tale_two_cities_librivox"
      data-mediatype="audio"
       data-year="2006">

            <a class="stealth" tabindex="-1" href="/details/librivoxaudio">
        <div class="item-parent">
          <div class="item-parent-img" style="background-image: url(\'/services/img/librivoxaudio\')"></div>
          <div class="item-parent-ttl">The LibriVox Free Audiobook Collection</div>
        </div><!--/.item-parent-->
      </a>
      

      <div class="hidden-tiles views C C1" title="all-time views">
                  <nobr class="hidden-xs">3.8<small>M</small></nobr>
          <nobr class="hidden-sm hidden-md hidden-lg">3.8M</nobr>
              </div>



      
      <div class="C234">
                  <div
            class="
              item-ttl
                                          C C2
            "
          >
            <a href="/details/tale_two_cities_librivox" title="A Tale of Two Cities"
              data-event-click-tracking="GenericNonCollection|ItemTile">
                              <div class="tile-img">
                  <img class="item-img "
                    alt="A Tale of Two Cities"
                    source=/services/img/tale_two_cities_librivox                     style="height:180px">
                </div><!--/.tile-img-->
              
                            
              
              <div class="ttl">
                A Tale of Two Cities              </div>
            </a>
          </div>
                <div class="hidden-tiles pubdate C C3">
          <nobr class="hidden-xs">Dec 1, 2020</nobr>
          <nobr class="hidden-sm hidden-md hidden-lg">12/20</nobr>
        </div>
        <div class="by C C4">
                                                <span class="hidden-lists">by</span>
              <span class="byv"
                    title="Charles Dickens">Charles Dickens</span>
                                          </div><!--/.C4-->
      </div><!--/.C234-->

      <div class="statbar ">
        <div class="mt-icon C C5">
                                <span class="iconochive-audio"  aria-hidden="true"></span><span class="sr-only">audio</span>                  </div>

                  <h6 class="stat " title="all-time views">
            <span class="iconochive-eye"  aria-hidden="true"></span><span class="sr-only">eye</span>            <nobr>3.8<small>M</small></nobr>
          </h6>
        
                  <h6 class="stat">
            <span class="iconochive-favorite"  aria-hidden="true"></span><span class="sr-only">favorite</span>            158          </h6>

                      <h6 class="stat">
              <span class="iconochive-comment"  aria-hidden="true"></span><span class="sr-only">comment</span>              6            </h6>
                                  </div><!--/.statbar-->

          </div><!--/.item-ia-->


    <div class="details-ia hidden-tiles">
      <div class="C1"></div>
              <div class="C234">
          <span>LibriVox recording of A Tale of Two Cities, by Charles Dickens. A Tale of Two Cities (1859) is a historical novel by Charles Dickens; it is moreover a moral novel strongly concerned with themes of guilt, shame, redemption and patriotism. The plot centers on the years leading up to French Revolution and culminates in the Jacobin Reign of Terror. It tells the story of two men, Charles Darnay and Sydney Carton, who look very alike but are entirely different in character. (Summary from wikipedia)...</span><br/>          <span alt="3.00 out of 5 stars" title="3.00 out of 5 stars"><span class="iconochive-favorite"  aria-hidden="true"></span><span class="sr-only">favorite</span><span class="iconochive-favorite"  aria-hidden="true"></span><span class="sr-only">favorite</span><span class="iconochive-favorite"  aria-hidden="true"></span><span class="sr-only">favorite</span></span> ( 6 reviews )<br/>          Topics: librivox, audiobook, literature, dickens<br/>          Source: Librivox recording of a public-domain text<br/>                  </div>
            <div class="C5"></div>
    </div>

    

    <div class="item-ia" data-id="librivoxcdcoverart34"
      data-mediatype="audio"
      >

            <a class="stealth" tabindex="-1" href="/details/librivoxaudiocovers">
        <div class="item-parent">
          <div class="item-parent-img" style="background-image: url(\'/services/img/librivoxaudiocovers\')"></div>
          <div class="item-parent-ttl">Librivoxaudio Covers</div>
        </div><!--/.item-parent-->
      </a>
      

      <div class="hidden-tiles views C C1" title="all-time views">
                  <nobr class="hidden-xs">3.4<small>M</small></nobr>
          <nobr class="hidden-sm hidden-md hidden-lg">3.4M</nobr>
              </div>



      
      <div class="C234">
                  <div
            class="
              item-ttl
                                          C C2
            "
          >
            <a href="/details/librivoxcdcoverart34" title="LibrivoxCdCoverArt34"
              data-event-click-tracking="GenericNonCollection|ItemTile">
                              <div class="tile-img">
                  <img class="item-img "
                    alt="LibrivoxCdCoverArt34"
                    source=/services/img/librivoxcdcoverart34                     style="height:180px">
                </div><!--/.tile-img-->
              
                            
              
              <div class="ttl">
                LibrivoxCdCoverArt34              </div>
            </a>
          </div>
                <div class="hidden-tiles pubdate C C3">
          <nobr class="hidden-xs">-</nobr>
          <nobr class="hidden-sm hidden-md hidden-lg">-</nobr>
        </div>
        <div class="by C C4">
                                                                </div><!--/.C4-->
      </div><!--/.C234-->

      <div class="statbar ">
        <div class="mt-icon C C5">
                                <span class="iconochive-audio"  aria-hidden="true"></span><span class="sr-only">audio</span>                  </div>

                  <h6 class="stat " title="all-time views">
            <span class="iconochive-eye"  aria-hidden="true"></span><span class="sr-only">eye</span>            <nobr>3.4<small>M</small></nobr>
          </h6>
        
                  <h6 class="stat">
            <span class="iconochive-favorite"  aria-hidden="true"></span><span class="sr-only">favorite</span>            14          </h6>

                      <h6 class="stat">
              <span class="iconochive-comment"  aria-hidden="true"></span><span class="sr-only">comment</span>              0            </h6>
                                  </div><!--/.statbar-->

          </div><!--/.item-ia-->


    <div class="details-ia hidden-tiles">
      <div class="C1"></div>
              <div class="C234">
          <span>A thirty-fourth collection of CD cover art, created by volunteers for some of our LibriVox Audio Books. We\'ll add more covers as our volunteers create them, so please check back. Each cover can be downloaded as a .pdf to print out and insert into a jewel case, or as a 300x300px .jpg for your iTunes Album Art. Each thumbnail is linked to the catalog page where the links to the cover files can be found. This is just one of many LibriVox cover art pages. You\'ll find a complete list on our top page...</span><br/>                    Topics: librivox, audiobook, cover art, album art<br/>                            </div>
            <div class="C5"></div>
    </div>

    

    <div class="item-ia" data-id="uncle_toms_cabin_librivox"
      data-mediatype="audio"
       data-year="2006">

            <a class="stealth" tabindex="-1" href="/details/librivoxaudio">
        <div class="item-parent">
          <div class="item-parent-img" style="background-image: url(\'/services/img/librivoxaudio\')"></div>
          <div class="item-parent-ttl">The LibriVox Free Audiobook Collection</div>
        </div><!--/.item-parent-->
      </a>
      

      <div class="hidden-tiles views C C1" title="all-time views">
                  <nobr class="hidden-xs">3.9<small>M</small></nobr>
          <nobr class="hidden-sm hidden-md hidden-lg">3.9M</nobr>
              </div>



      
      <div class="C234">
                  <div
            class="
              item-ttl
                                          C C2
            "
          >
            <a href="/details/uncle_toms_cabin_librivox" title="Uncle Tom\'s Cabin"
              data-event-click-tracking="GenericNonCollection|ItemTile">
                              <div class="tile-img">
                  <img class="item-img "
                    alt="Uncle Tom\'s Cabin"
                    source=/services/img/uncle_toms_cabin_librivox                     style="height:180px">
                </div><!--/.tile-img-->
              
                            
              
              <div class="ttl">
                Uncle Tom\'s Cabin              </div>
            </a>
          </div>
                <div class="hidden-tiles pubdate C C3">
          <nobr class="hidden-xs">Apr 1, 2019</nobr>
          <nobr class="hidden-sm hidden-md hidden-lg">04/19</nobr>
        </div>
        <div class="by C C4">
                                                <span class="hidden-lists">by</span>
              <span class="byv"
                    title="Harriet Beecher Stowe">Harriet Beecher Stowe</span>
                                          </div><!--/.C4-->
      </div><!--/.C234-->

      <div class="statbar ">
        <div class="mt-icon C C5">
                                <span class="iconochive-audio"  aria-hidden="true"></span><span class="sr-only">audio</span>                  </div>

                  <h6 class="stat " title="all-time views">
            <span class="iconochive-eye"  aria-hidden="true"></span><span class="sr-only">eye</span>            <nobr>3.9<small>M</small></nobr>
          </h6>
        
                  <h6 class="stat">
            <span class="iconochive-favorite"  aria-hidden="true"></span><span class="sr-only">favorite</span>            175          </h6>

                      <h6 class="stat">
              <span class="iconochive-comment"  aria-hidden="true"></span><span class="sr-only">comment</span>              13            </h6>
                                  </div><!--/.statbar-->

          </div><!--/.item-ia-->


    <div class="details-ia hidden-tiles">
      <div class="C1"></div>
              <div class="C234">
          <span>Librivox recording of Uncle Tom\'s Cabin by Harriet Beecher Stowe. Read by John Greenman. Among the most &quot;banned&quot; books in the United States, Uncle Tom’s Cabin; or, Life Among the Lowly is a novel by American author Harriet Beecher Stowe which treats slavery as a central theme. Stowe was a Connecticut-born teacher at the Hartford Female Academy and an active abolitionist. The novel is believed to have had a profound effect on the North’s view of slavery. In fact, when he met...</span><br/>          <span alt="4.92 out of 5 stars" title="4.92 out of 5 stars"><span class="iconochive-favorite"  aria-hidden="true"></span><span class="sr-only">favorite</span><span class="iconochive-favorite"  aria-hidden="true"></span><span class="sr-only">favorite</span><span class="iconochive-favorite"  aria-hidden="true"></span><span class="sr-only">favorite</span><span class="iconochive-favorite"  aria-hidden="true"></span><span class="sr-only">favorite</span><span class="iconochive-favorite"  aria-hidden="true"></span><span class="sr-only">favorite</span></span> ( 13 reviews )<br/>          Topics: librivox, audiobook, literature, stowe, uncle tom<br/>          Source: Librivox recording of a public-domain text<br/>                  </div>
            <div class="C5"></div>
    </div>

    

    <div class="item-ia" data-id="solo_pride_librivox"
      data-mediatype="audio"
       data-year="2006">

            <a class="stealth" tabindex="-1" href="/details/librivoxaudio">
        <div class="item-parent">
          <div class="item-parent-img" style="background-image: url(\'/services/img/librivoxaudio\')"></div>
          <div class="item-parent-ttl">The LibriVox Free Audiobook Collection</div>
        </div><!--/.item-parent-->
      </a>
      

      <div class="hidden-tiles views C C1" title="all-time views">
                  <nobr class="hidden-xs">4.6<small>M</small></nobr>
          <nobr class="hidden-sm hidden-md hidden-lg">4.6M</nobr>
              </div>



      
      <div class="C234">
                  <div
            class="
              item-ttl
                                          C C2
            "
          >
            <a href="/details/solo_pride_librivox" title="Pride and Prejudice (version 2)"
              data-event-click-tracking="GenericNonCollection|ItemTile">
                              <div class="tile-img">
                  <img class="item-img "
                    alt="Pride and Prejudice (version 2)"
                    source=/services/img/solo_pride_librivox                     style="height:180px">
                </div><!--/.tile-img-->
              
                            
              
              <div class="ttl">
                Pride and Prejudice (version 2)              </div>
            </a>
          </div>
                <div class="hidden-tiles pubdate C C3">
          <nobr class="hidden-xs">Oct 3, 2007</nobr>
          <nobr class="hidden-sm hidden-md hidden-lg">10/07</nobr>
        </div>
        <div class="by C C4">
                                                <span class="hidden-lists">by</span>
              <span class="byv"
                    title="Jane Austen">Jane Austen</span>
                                          </div><!--/.C4-->
      </div><!--/.C234-->

      <div class="statbar ">
        <div class="mt-icon C C5">
                                <span class="iconochive-audio"  aria-hidden="true"></span><span class="sr-only">audio</span>                  </div>

                  <h6 class="stat " title="all-time views">
            <span class="iconochive-eye"  aria-hidden="true"></span><span class="sr-only">eye</span>            <nobr>4.6<small>M</small></nobr>
          </h6>
        
                  <h6 class="stat">
            <span class="iconochive-favorite"  aria-hidden="true"></span><span class="sr-only">favorite</span>            34          </h6>

                      <h6 class="stat">
              <span class="iconochive-comment"  aria-hidden="true"></span><span class="sr-only">comment</span>              5            </h6>
                                  </div><!--/.statbar-->

          </div><!--/.item-ia-->


    <div class="details-ia hidden-tiles">
      <div class="C1"></div>
              <div class="C234">
          <span>Librivox recording of Pride and Prejudice, by Jane Austen. Read by Annie Coleman . Jane Austen\'s classic novel chronicles the events in the lives of the Bennet family. Take a family with five unmarried daughters and a lack of wealth, throw in a new wealthy neighbor or two, plus a whole regiment of soldiers in town, and add a heaping spoonful of pride and a pinch of prejudice. Mix it all together and you get a story full of tears and laughter, embarrassment and pride, and, of course, love....</span><br/>          <span alt="4.80 out of 5 stars" title="4.80 out of 5 stars"><span class="iconochive-favorite"  aria-hidden="true"></span><span class="sr-only">favorite</span><span class="iconochive-favorite"  aria-hidden="true"></span><span class="sr-only">favorite</span><span class="iconochive-favorite"  aria-hidden="true"></span><span class="sr-only">favorite</span><span class="iconochive-favorite"  aria-hidden="true"></span><span class="sr-only">favorite</span><span class="iconochive-favorite"  aria-hidden="true"></span><span class="sr-only">favorite</span></span> ( 5 reviews )<br/>          Topics: librivox, audiobook, literature<br/>          Source: http://www.gutenberg.org/etext/1342<br/>                  </div>
            <div class="C5"></div>
    </div>

    

    <div class="item-ia" data-id="great_expectations_mfs_0812_librivox"
      data-mediatype="audio"
       data-year="2008">

            <a class="stealth" tabindex="-1" href="/details/librivoxaudio">
        <div class="item-parent">
          <div class="item-parent-img" style="background-image: url(\'/services/img/librivoxaudio\')"></div>
          <div class="item-parent-ttl">The LibriVox Free Audiobook Collection</div>
        </div><!--/.item-parent-->
      </a>
      

      <div class="hidden-tiles views C C1" title="all-time views">
                  <nobr class="hidden-xs">3.1<small>M</small></nobr>
          <nobr class="hidden-sm hidden-md hidden-lg">3.1M</nobr>
              </div>



      
      <div class="C234">
                  <div
            class="
              item-ttl
                                          C C2
            "
          >
            <a href="/details/great_expectations_mfs_0812_librivox" title="Great Expectations"
              data-event-click-tracking="GenericNonCollection|ItemTile">
                              <div class="tile-img">
                  <img class="item-img "
                    alt="Great Expectations"
                    source=/services/img/great_expectations_mfs_0812_librivox                     style="height:180px">
                </div><!--/.tile-img-->
              
                            
              
              <div class="ttl">
                Great Expectations              </div>
            </a>
          </div>
                <div class="hidden-tiles pubdate C C3">
          <nobr class="hidden-xs">Feb 23, 2021</nobr>
          <nobr class="hidden-sm hidden-md hidden-lg">02/21</nobr>
        </div>
        <div class="by C C4">
                                                <span class="hidden-lists">by</span>
              <span class="byv"
                    title="Charles Dickens">Charles Dickens</span>
                                          </div><!--/.C4-->
      </div><!--/.C234-->

      <div class="statbar ">
        <div class="mt-icon C C5">
                                <span class="iconochive-audio"  aria-hidden="true"></span><span class="sr-only">audio</span>                  </div>

                  <h6 class="stat " title="all-time views">
            <span class="iconochive-eye"  aria-hidden="true"></span><span class="sr-only">eye</span>            <nobr>3.1<small>M</small></nobr>
          </h6>
        
                  <h6 class="stat">
            <span class="iconochive-favorite"  aria-hidden="true"></span><span class="sr-only">favorite</span>            137          </h6>

                      <h6 class="stat">
              <span class="iconochive-comment"  aria-hidden="true"></span><span class="sr-only">comment</span>              8            </h6>
                                  </div><!--/.statbar-->

          </div><!--/.item-ia-->


    <div class="details-ia hidden-tiles">
      <div class="C1"></div>
              <div class="C234">
          <span>This is a LibriVox recording of Great Expectations, read by Mark F. Smith. This classic tale tells of an orphan, Pip, who through a series of strange circumstances first finds a trade as a blacksmith\'s apprentice and then learns that he has &quot;great expectations&quot; of a future inheritance from an anonymous benefactor. He soon learns to live the profligate life of a gentleman as he gradually sheds his associations with the gentle souls of his past, Joe (the blacksmith) and Biddy (a...</span><br/>          <span alt="4.75 out of 5 stars" title="4.75 out of 5 stars"><span class="iconochive-favorite"  aria-hidden="true"></span><span class="sr-only">favorite</span><span class="iconochive-favorite"  aria-hidden="true"></span><span class="sr-only">favorite</span><span class="iconochive-favorite"  aria-hidden="true"></span><span class="sr-only">favorite</span><span class="iconochive-favorite"  aria-hidden="true"></span><span class="sr-only">favorite</span><span class="iconochive-favorite"  aria-hidden="true"></span><span class="sr-only">favorite</span></span> ( 8 reviews )<br/>          Topics: Audiobook, LibriVox, Fiction, England<br/>          Source: Librivox recording of a public-domain text<br/>                  </div>
            <div class="C5"></div>
    </div>

    

    <div class="item-ia" data-id="obedienceofchristianman_2103_librivox"
      data-mediatype="audio"
       data-year="2021">

            <a class="stealth" tabindex="-1" href="/details/librivoxaudio">
        <div class="item-parent">
          <div class="item-parent-img" style="background-image: url(\'/services/img/librivoxaudio\')"></div>
          <div class="item-parent-ttl">The LibriVox Free Audiobook Collection</div>
        </div><!--/.item-parent-->
      </a>
      

      <div class="hidden-tiles views C C1" title="all-time views">
                  <nobr class="hidden-xs">8,691</nobr>
          <nobr class="hidden-sm hidden-md hidden-lg">8.7K</nobr>
              </div>



      
      <div class="C234">
                  <div
            class="
              item-ttl
                                          C C2
            "
          >
            <a href="/details/obedienceofchristianman_2103_librivox" title="The Obedience of a Christian Man"
              data-event-click-tracking="GenericNonCollection|ItemTile">
                              <div class="tile-img">
                  <img class="item-img "
                    alt="The Obedience of a Christian Man"
                    source=/services/img/obedienceofchristianman_2103_librivox                     style="height:180px">
                </div><!--/.tile-img-->
              
                            
              
              <div class="ttl">
                The Obedience of a Christian Man              </div>
            </a>
          </div>
                <div class="hidden-tiles pubdate C C3">
          <nobr class="hidden-xs">-</nobr>
          <nobr class="hidden-sm hidden-md hidden-lg">-</nobr>
        </div>
        <div class="by C C4">
                                                <span class="hidden-lists">by</span>
              <span class="byv"
                    title="William Tyndale">William Tyndale</span>
                                          </div><!--/.C4-->
      </div><!--/.C234-->

      <div class="statbar ">
        <div class="mt-icon C C5">
                                <span class="iconochive-audio"  aria-hidden="true"></span><span class="sr-only">audio</span>                  </div>

                  <h6 class="stat " title="all-time views">
            <span class="iconochive-eye"  aria-hidden="true"></span><span class="sr-only">eye</span>            <nobr>8,691</nobr>
          </h6>
        
                  <h6 class="stat">
            <span class="iconochive-favorite"  aria-hidden="true"></span><span class="sr-only">favorite</span>            0          </h6>

                      <h6 class="stat">
              <span class="iconochive-comment"  aria-hidden="true"></span><span class="sr-only">comment</span>              0            </h6>
                                  </div><!--/.statbar-->

          </div><!--/.item-ia-->


    <div class="details-ia hidden-tiles">
      <div class="C1"></div>
              <div class="C234">
          <span>LibriVox recording of The Obedience of a Christian Man by William Tyndale. Read in English by David Ronald &quot;The obedience of a Christian man&quot; begins by contrasting the life of a true Christian to those holding high positions within the Romish Church. A scathing attack against the Popes, Cardinals and Bishops living in luxury, who also refrain from teaching Scripture and would rather attach themselves to &quot;Doctors&quot; who often contradict themselves. Tyndale compares these men to...</span><br/>                    Topics: librivox, audiobooks, Christianity, church history, Reformation, reformers<br/>                            </div>
            <div class="C5"></div>
    </div>

    

    <div class="item-ia" data-id="pride_prejudice_krs_librivox"
      data-mediatype="audio"
       data-year="2007">

            <a class="stealth" tabindex="-1" href="/details/librivoxaudio">
        <div class="item-parent">
          <div class="item-parent-img" style="background-image: url(\'/services/img/librivoxaudio\')"></div>
          <div class="item-parent-ttl">The LibriVox Free Audiobook Collection</div>
        </div><!--/.item-parent-->
      </a>
      

      <div class="hidden-tiles views C C1" title="all-time views">
                  <nobr class="hidden-xs">5.8<small>M</small></nobr>
          <nobr class="hidden-sm hidden-md hidden-lg">5.8M</nobr>
              </div>



      
      <div class="C234">
                  <div
            class="
              item-ttl
                                          C C2
            "
          >
            <a href="/details/pride_prejudice_krs_librivox" title="Pride and Prejudice (version 3)"
              data-event-click-tracking="GenericNonCollection|ItemTile">
                              <div class="tile-img">
                  <img class="item-img "
                    alt="Pride and Prejudice (version 3)"
                    source=/services/img/pride_prejudice_krs_librivox                     style="height:180px">
                </div><!--/.tile-img-->
              
                            
              
              <div class="ttl">
                Pride and Prejudice (version 3)              </div>
            </a>
          </div>
                <div class="hidden-tiles pubdate C C3">
          <nobr class="hidden-xs">Aug 20, 2020</nobr>
          <nobr class="hidden-sm hidden-md hidden-lg">08/20</nobr>
        </div>
        <div class="by C C4">
                                                <span class="hidden-lists">by</span>
              <span class="byv"
                    title="Jane Austen">Jane Austen</span>
                                          </div><!--/.C4-->
      </div><!--/.C234-->

      <div class="statbar ">
        <div class="mt-icon C C5">
                                <span class="iconochive-audio"  aria-hidden="true"></span><span class="sr-only">audio</span>                  </div>

                  <h6 class="stat " title="all-time views">
            <span class="iconochive-eye"  aria-hidden="true"></span><span class="sr-only">eye</span>            <nobr>5.8<small>M</small></nobr>
          </h6>
        
                  <h6 class="stat">
            <span class="iconochive-favorite"  aria-hidden="true"></span><span class="sr-only">favorite</span>            151          </h6>

                      <h6 class="stat">
              <span class="iconochive-comment"  aria-hidden="true"></span><span class="sr-only">comment</span>              17            </h6>
                                  </div><!--/.statbar-->

          </div><!--/.item-ia-->


    <div class="details-ia hidden-tiles">
      <div class="C1"></div>
              <div class="C234">
          <span>LibriVox recording of Pride and Prejudice by Jane Austen. Read by Karen Savage. Pride and Prejudice is the most famous of Jane Austen’s novels, and its opening is one of the most famous lines in English literature - “It is a truth universally acknowledged, that a single man in possession of a good fortune, must be in want of a wife.” Its manuscript was first written between 1796 and 1797, and was initially called First Impressions, but was never published under that title. Following...</span><br/>          <span alt="4.25 out of 5 stars" title="4.25 out of 5 stars"><span class="iconochive-favorite"  aria-hidden="true"></span><span class="sr-only">favorite</span><span class="iconochive-favorite"  aria-hidden="true"></span><span class="sr-only">favorite</span><span class="iconochive-favorite"  aria-hidden="true"></span><span class="sr-only">favorite</span><span class="iconochive-favorite"  aria-hidden="true"></span><span class="sr-only">favorite</span></span> ( 17 reviews )<br/>          Topics: librivox, literature, audiobook, austen, romance, humour<br/>          Source: Librivox recording of a public-domain text<br/>                  </div>
            <div class="C5"></div>
    </div>

    

    <div class="item-ia" data-id="alexander_great_ld_librivox"
      data-mediatype="audio"
       data-year="2007">

            <a class="stealth" tabindex="-1" href="/details/librivoxaudio">
        <div class="item-parent">
          <div class="item-parent-img" style="background-image: url(\'/services/img/librivoxaudio\')"></div>
          <div class="item-parent-ttl">The LibriVox Free Audiobook Collection</div>
        </div><!--/.item-parent-->
      </a>
      

      <div class="hidden-tiles views C C1" title="all-time views">
                  <nobr class="hidden-xs">1.9<small>M</small></nobr>
          <nobr class="hidden-sm hidden-md hidden-lg">1.9M</nobr>
              </div>



      
      <div class="C234">
                  <div
            class="
              item-ttl
                                          C C2
            "
          >
            <a href="/details/alexander_great_ld_librivox" title="Alexander the Great"
              data-event-click-tracking="GenericNonCollection|ItemTile">
                              <div class="tile-img">
                  <img class="item-img "
                    alt="Alexander the Great"
                    source=/services/img/alexander_great_ld_librivox                     style="height:180px">
                </div><!--/.tile-img-->
              
                            
              
              <div class="ttl">
                Alexander the Great              </div>
            </a>
          </div>
                <div class="hidden-tiles pubdate C C3">
          <nobr class="hidden-xs">May 12, 2015</nobr>
          <nobr class="hidden-sm hidden-md hidden-lg">05/15</nobr>
        </div>
        <div class="by C C4">
                                                <span class="hidden-lists">by</span>
              <span class="byv"
                    title="Jacob Abbott">Jacob Abbott</span>
                                          </div><!--/.C4-->
      </div><!--/.C234-->

      <div class="statbar ">
        <div class="mt-icon C C5">
                                <span class="iconochive-audio"  aria-hidden="true"></span><span class="sr-only">audio</span>                  </div>

                  <h6 class="stat " title="all-time views">
            <span class="iconochive-eye"  aria-hidden="true"></span><span class="sr-only">eye</span>            <nobr>1.9<small>M</small></nobr>
          </h6>
        
                  <h6 class="stat">
            <span class="iconochive-favorite"  aria-hidden="true"></span><span class="sr-only">favorite</span>            63          </h6>

                      <h6 class="stat">
              <span class="iconochive-comment"  aria-hidden="true"></span><span class="sr-only">comment</span>              4            </h6>
                                  </div><!--/.statbar-->

          </div><!--/.item-ia-->


    <div class="details-ia hidden-tiles">
      <div class="C1"></div>
              <div class="C234">
          <span>Alexander the Great was one of the most successful military commanders in history, and was undefeated in battle. By the time of his death, he had conquered most of the world known to the ancient Greeks. Alexander the Great is one of many biographies aimed at young people written by Jacob Abbott and his brother. The biographies are written in such a way that makes them appealing and easily accessible to everyone. - Written by Wikipedia and Lizzie Driver For further information, including links...</span><br/>          <span alt="4.25 out of 5 stars" title="4.25 out of 5 stars"><span class="iconochive-favorite"  aria-hidden="true"></span><span class="sr-only">favorite</span><span class="iconochive-favorite"  aria-hidden="true"></span><span class="sr-only">favorite</span><span class="iconochive-favorite"  aria-hidden="true"></span><span class="sr-only">favorite</span><span class="iconochive-favorite"  aria-hidden="true"></span><span class="sr-only">favorite</span></span> ( 4 reviews )<br/>          Topics: librivox, literature, audiobook, History, biography, alexander<br/>          Source: Librivox recording of a public-domain text<br/>                  </div>
            <div class="C5"></div>
    </div>

    

    <div class="item-ia" data-id="huckleberry_mfs_librivox"
      data-mediatype="audio"
       data-year="2007">

            <a class="stealth" tabindex="-1" href="/details/librivoxaudio">
        <div class="item-parent">
          <div class="item-parent-img" style="background-image: url(\'/services/img/librivoxaudio\')"></div>
          <div class="item-parent-ttl">The LibriVox Free Audiobook Collection</div>
        </div><!--/.item-parent-->
      </a>
      

      <div class="hidden-tiles views C C1" title="all-time views">
                  <nobr class="hidden-xs">3.9<small>M</small></nobr>
          <nobr class="hidden-sm hidden-md hidden-lg">3.9M</nobr>
              </div>



      
      <div class="C234">
                  <div
            class="
              item-ttl
                                          C C2
            "
          >
            <a href="/details/huckleberry_mfs_librivox" title="Adventures of Huckleberry Finn (version 02)"
              data-event-click-tracking="GenericNonCollection|ItemTile">
                              <div class="tile-img">
                  <img class="item-img "
                    alt="Adventures of Huckleberry Finn (version 02)"
                    source=/services/img/huckleberry_mfs_librivox                     style="height:180px">
                </div><!--/.tile-img-->
              
                            
              
              <div class="ttl">
                Adventures of Huckleberry Finn (version 02)              </div>
            </a>
          </div>
                <div class="hidden-tiles pubdate C C3">
          <nobr class="hidden-xs">Feb 11, 2021</nobr>
          <nobr class="hidden-sm hidden-md hidden-lg">02/21</nobr>
        </div>
        <div class="by C C4">
                                                <span class="hidden-lists">by</span>
              <span class="byv"
                    title="Mark Twain">Mark Twain</span>
                                          </div><!--/.C4-->
      </div><!--/.C234-->

      <div class="statbar ">
        <div class="mt-icon C C5">
                                <span class="iconochive-audio"  aria-hidden="true"></span><span class="sr-only">audio</span>                  </div>

                  <h6 class="stat " title="all-time views">
            <span class="iconochive-eye"  aria-hidden="true"></span><span class="sr-only">eye</span>            <nobr>3.9<small>M</small></nobr>
          </h6>
        
                  <h6 class="stat">
            <span class="iconochive-favorite"  aria-hidden="true"></span><span class="sr-only">favorite</span>            65          </h6>

                      <h6 class="stat">
              <span class="iconochive-comment"  aria-hidden="true"></span><span class="sr-only">comment</span>              8            </h6>
                                  </div><!--/.statbar-->

          </div><!--/.item-ia-->


    <div class="details-ia hidden-tiles">
      <div class="C1"></div>
              <div class="C234">
          <span>LibriVox recording of The Adventures of Huckleberry Finn (version 02). Read by Mark F. Smith. In The Adventures of Huckleberry Finn, Mark Twain creates an entertaining adventure of Middle America in the 1800\'s - afloat on a raft on the Mississippi River. Huck escapes his civilized life when he arranges his own &quot;murder&quot; and turns back into the backwoods, downriver yokel he started as, and in the process springing a slave, Jim, from bondage. Huck and Jim experience life as a series of...</span><br/>          <span alt="4.43 out of 5 stars" title="4.43 out of 5 stars"><span class="iconochive-favorite"  aria-hidden="true"></span><span class="sr-only">favorite</span><span class="iconochive-favorite"  aria-hidden="true"></span><span class="sr-only">favorite</span><span class="iconochive-favorite"  aria-hidden="true"></span><span class="sr-only">favorite</span><span class="iconochive-favorite"  aria-hidden="true"></span><span class="sr-only">favorite</span></span> ( 8 reviews )<br/>          Topics: librivox, literature, audiobooks, twain, adventure, satire, finn, humor<br/>          Source: Librivox recording of a public-domain text<br/>                  </div>
            <div class="C5"></div>
    </div>

    </div><!--/.results-->        <center class="more_search">
          <a class="btn btn-info btn-sm" style="visibility:hidden"
            onclick="return AJS.more_search(this,\'/details/librivoxaudio?&sort=-week&page=\',1)" href="#">MORE RESULTS</a><br/>
          <span class="more-search-fetching">
            Fetching more results
            <img src="/images/loading.gif" alt="Fetching more results"/>
          </span>
                    <noscript>
                          <a href="/details/librivoxaudio?&sort=-week&page=2" type="button" class="page-next">Next Page</a>
                      </noscript>
        </center>
              </div>
              </div>

    </div><!--.columns-items-->
  </div><!--/.row-->

          <script>archive_setup.push(function() { AJS.date_switcher(\'&nbsp;<a href="/details/librivoxaudio?sort=-publicdate" rel="nofollow"><div class="date_switcher">Date Archived</div></a> <a href="/details/librivoxaudio?sort=-date" rel="nofollow"><div class="date_switcher">Date Published</div></a> <a href="/details/librivoxaudio?sort=-reviewdate" rel="nofollow"><div class="date_switcher in">Date Reviewed</div></a> <a href="/details/librivoxaudio?sort=-addeddate" rel="nofollow"><div class="date_switcher">Date Added</div></a> \'); })</script>
                  </div>
      </div>


  <script type="text/javascript">
    archive_setup.push(function(){
      AJS.lists_v_tiles_setup(\'collection\');

      
      $(\'div.ikind\').css({visibility:\'visible\'});

              AJS.popState(\'\');
      
      AJS.tiler();

      $(window).on(\'resize  orientationchange\', function(evt){
        clearTimeout(AJS.tiles_wrap_throttler)
        AJS.tiles_wrap_throttler = setTimeout(AJS.tiler, 250)
      });

      // register for scroll updates (for infinite search results)
      $(window).scroll(AJS.scrolled);
    });
  </script>
    <script>
  archive_setup.push(function() {
    
    
    AJS.addNotes(\'\');

    $(window).on(\'resize  orientationchange\', function(evt) {
      clearTimeout(AJS.plotter_throttler);
      AJS.plotter_throttler = setTimeout(AJS.plotter, 250)
    });
  });
</script>



<div class="container container-ia nopad">
    <div id="tabby-about" class="tabby-data hidden row">
    <div class="row">
      <div class="col-sm-7" style="margin-bottom:50px;">
        <div class="about-box">
          <div class="micro-label">DESCRIPTION</div>
          <p>LibriVox - founded in 2005 - is a community of volunteers from all over the world who record public domain texts: poetry, short stories, whole books, even dramatic works, in many different languages. 

All LibriVox recordings are in the public domain in the USA and available as free downloads on the internet. If you are not in the USA, please check your country\'s copyright law before downloading.

<p>Please visit the <a href="http://librivox.org" rel="nofollow">LibriVox website</a> where you can <a href="http://librivox.org/search">search</a> for books that interest you. You can search or browse by title, author, genre, language or reader (and, though not yet fully developed, by keyword), and you can look for all solo recordings by a particular reader, or their contributions to group recordings.

<p>Our goal is to make all public domain books, in any language, available as free audiobooks. Would you like to help us to reach our goal? We always welcome new readers, prooflisteners, cover artists, or simply suggestions for books to read.

<p>If you would appreciate suggestions for books to listen to, check out our monthly feature <em>the staff picks</em> where on the first day of each month, 10 books from the catalog are highlighted. You can find the list for this and the previous months on our <a href=https://librivox.org/category/monthly-picks/>blog</a>. 

<p>For more information, or to volunteer, please visit <a href="http://librivox.org" rel="nofollow">LibriVox.org</a>.

<br><br>
<center><form style="margin:0;padding:0;" action="/searchresults.php" id="searchform" method="post">
  <b>Search Librivox on Internet Archive:</b>
  <input size="25" name="search" value="" style="font-size: 8pt"/>
  <input style="vertical-align:bottom; text-align:center; width:21px; height:21px; border:0px" name="gobutton" type="image" id="gobutton" value="Find" src="/images/go-button-gateway.gif"/>
  <input type="hidden" name="collection" value="librivoxaudio"/>
  <input type="hidden" name="limit" value="100"/>
  <input type="hidden" name="start" value="0"/>
  <input type="hidden" name="searchAll" value="yes"/>
  <input type="hidden" name="submit" value="this was submitted"/>
</form></center>
<br>
                    <br class="clearfix" clear="all"/>
        </div>

        
        <div class="about-box">
          <div class="micro-label">ACTIVITY</div>
          <div class="activity-box">
            <h2 style="font-weight:100">
              <a class="stealth" href="/details/librivoxaudio&sort=-reviewdate"><span class="iconochive-comment"  aria-hidden="true"></span><span class="sr-only">comment</span> <span
                 id="activity-reviewsN"></span></a>
            </h2>
          </div>
                      <div class="activity-box">
              <h2 style="font-weight:100">
                <a class="stealth" href="#forum" onclick="$(\'#tabby-forum-finder\').click()"><span class="iconochive-comments"  aria-hidden="true"></span><span class="sr-only">comments</span> <span
                   id="activity-forumN"></span></a>
              </h2>
            </div>
                    <br class="clearfix" clear="all"/>
        </div>

        <!-- Metadata -->
        <div class="about-box item-details-metadata">
          <h4>Collection Info</h4>
          
        <div class="metadata-expandable-list row" role="list">
                  <dl class="metadata-definition">
          <dt>Addeddate</dt>
    <dd
      class=""
          >2006-03-07 20:43:07</dd>
        </dl>
                      <dl class="metadata-definition">
          <dt>Collection</dt>
    <dd
      class=""
          >audio_bookspoetry<br>audio</dd>
        </dl>
                      <dl class="metadata-definition">
          <dt>Identifier</dt>
    <dd
      class=""
          >librivoxaudio</dd>
        </dl>
                      <dl class="metadata-definition">
          <dt>Mediatype</dt>
    <dd
      class=""
          >collection</dd>
        </dl>
                      <dl class="metadata-definition">
          <dt>Nav_order</dt>
    <dd
      class=""
          >10</dd>
        </dl>
                      <dl class="metadata-definition">
          <dt>Num_top_ba</dt>
    <dd
      class=""
          >20</dd>
        </dl>
                      <dl class="metadata-definition">
          <dt>Publicdate</dt>
    <dd
      class=""
          >2006-03-07 12:43:43</dd>
        </dl>
                      <dl class="metadata-definition">
          <dt>Title</dt>
    <dd
      class=""
          >The LibriVox Free Audiobook Collection</dd>
        </dl>
          
          </div>

            </div>

      </div><!--/.col-sm-7-->
      <div class="col-sm-5" style="margin-bottom:50px;">
        <div class="about-box created-by">
          <div class="topinblock"
               style="text-align:center; border-right:1px solid #ccc; padding:0 25px;margin-right:25px;">
            <div class="micro-label" style="margin-bottom:2px">Created on</div>
            <div style="font-size:18px;line-height:1.0;">
              March 7<br> 2006            </div>
          </div><div class="topinblock">
                                          <div class="items_list person">        <div class="items_list_img">
          <a
            href="/details/@tracey_pooh"
            style="background-image: url(\'/services/img/@tracey_pooh\');"
            aria-hidden="true"
            data-event-click-tracking="ItemList|ItemListLink"
          ></a>
        </div>
        <div><a class="stealth boxy-label" data-event-click-tracking="ItemList|ItemListLink" href="/details/@tracey_pooh">tracey pooh</a><br/><small>Archivist</small></div></div>                                    </div>
        </div>

                <div class="about-box" style="margin-top:0">
          <div class="micro-label">ADDITIONAL CONTRIBUTORS</div>

                    <div class="hr"></div>
            <div class="items_list person">        <div class="items_list_img">
          <a
            href="/details/@bonniereal"
            style="background-image: url(\'/images/person2.png\');"
            aria-hidden="true"
            data-event-click-tracking="ItemList|ItemListLink"
          ></a>
        </div>
        <div><a class="stealth boxy-label" data-event-click-tracking="ItemList|ItemListLink" href="/details/@bonniereal">BonnieReal</a><br/><small>Member</small></div></div>                    <div class="hr"></div>
            <div class="items_list person">        <div class="items_list_img">
          <a
            href="/details/@brewster"
            style="background-image: url(\'/services/img/@brewster\');"
            aria-hidden="true"
            data-event-click-tracking="ItemList|ItemListLink"
          ></a>
        </div>
        <div><a class="stealth boxy-label" data-event-click-tracking="ItemList|ItemListLink" href="/details/@brewster">brewster</a><br/><small>Archivist</small></div></div>                    <div class="hr"></div>
            <div class="items_list person">        <div class="items_list_img">
          <a
            href="/details/@jordonz"
            style="background-image: url(\'/images/person2.png\');"
            aria-hidden="true"
            data-event-click-tracking="ItemList|ItemListLink"
          ></a>
        </div>
        <div><a class="stealth boxy-label" data-event-click-tracking="ItemList|ItemListLink" href="/details/@jordonz">jordonz</a><br/><small>Member</small></div></div>                    <div class="hr"></div>
            <div class="items_list person">        <div class="items_list_img">
          <a
            href="/details/@ewingrr"
            style="background-image: url(\'/images/person2.png\');"
            aria-hidden="true"
            data-event-click-tracking="ItemList|ItemListLink"
          ></a>
        </div>
        <div><a class="stealth boxy-label" data-event-click-tracking="ItemList|ItemListLink" href="/details/@ewingrr">ewingrr</a><br/><small>Member</small></div></div>                    <div class="hr"></div>
            <div class="items_list person">        <div class="items_list_img">
          <a
            href="/details/@arossi"
            style="background-image: url(\'/services/img/@arossi\');"
            aria-hidden="true"
            data-event-click-tracking="ItemList|ItemListLink"
          ></a>
        </div>
        <div><a class="stealth boxy-label" data-event-click-tracking="ItemList|ItemListLink" href="/details/@arossi">ARossi</a><br/><small>Archivist</small></div></div>                    <div class="hr"></div>
            <div class="items_list person">        <div class="items_list_img">
          <a
            href="/details/@librivoxbooks"
            style="background-image: url(\'/services/img/@librivoxbooks\');"
            aria-hidden="true"
            data-event-click-tracking="ItemList|ItemListLink"
          ></a>
        </div>
        <div><a class="stealth boxy-label" data-event-click-tracking="ItemList|ItemListLink" href="/details/@librivoxbooks">librivoxbooks</a><br/><small>Archivist</small></div></div>                    <div class="hr"></div>
            <div class="items_list person">        <div class="items_list_img">
          <a
            href="/details/@cheifet"
            style="background-image: url(\'/images/person2.png\');"
            aria-hidden="true"
            data-event-click-tracking="ItemList|ItemListLink"
          ></a>
        </div>
        <div><a class="stealth boxy-label" data-event-click-tracking="ItemList|ItemListLink" href="/details/@cheifet">cheifet</a><br/><small>Archivist</small></div></div>                  </div>
        
        <div class="grafs about-box">
          <div>
            VIEWS &mdash;
            <a href="https://blog.archive.org/2018/12/19/new-views-stats-for-the-new-year/">
              About the New Statistics
            </a>
          </div>
          <p>Total Views 1,549,165,533</p>
          <div id="grafs_views_api" class="grafs-content" data-id="librivoxaudio"></div>
          <div id="cviews_legend" class="grafs-legend"> </div>
        </div>

        <div class="grafs about-box">
        <div>DISCONTINUED VIEWS</div>
          <p class="grafs-deprecated">Total Views 1,549,165,533</p>
          <div id="grafs1" class="grafs-content" data-id="librivoxaudio"></div>
        </div>

        <div class="grafs about-box">
          <div>ITEMS</div>
          <p>Total Items 15,336</p>
          <div id="grafs2" class="grafs-content" data-id="librivoxaudio"></div>
        </div>

                <section
          class="grafs about-box js-top-regions-table"
          data-caption="Top Regions (Last 30 Days)"
          data-identifier="librivoxaudio"
          data-days="30"
          data-limit="10"
        >
                    <h3 class="micro-label">TOP REGIONS (LAST 30 DAYS)</h3>
          <p class="grafs-content js-top-regions-message">(data not available)</p>
        </section>

        
      </div><!--/.col-sm-5-->
    </div><!--/.row-->
  </div><!--/#.tabby-about-->
  
      <div id="tabby-forum" class="tabby-data hidden row">
              <div class="box">
      <h1><span style="float:right"><a href="/iathreads/post-new.php?forum=librivoxaudio"><span style="font-weight:bold">New Post</span></a></span>LibriVox <a target="_blank" title="Subscribe to or unsubscribe from this forum"
                  alt="Subscribe to or unsubscribe from this forum" href="/iathreads/forum-subscribe.php?forum=librivoxaudio"><span class="iconochive-email"  aria-hidden="true"></span><span class="sr-only">email</span></a> <a class="label label-success" alt="RSS feed of most recent posts to this forum"
                    title="RSS feed of most recent posts to this forum"
                    href="/iathreads/posts-display-new.php?forum=librivoxaudio&amp;mode=rss"><span class="iconochive-rss"  aria-hidden="true"></span><span class="sr-only">rss</span> RSS</a></h1>
    
    <!-- NOTE: extra div required by IE bec. table width=100% is set -->
    <div>
      <table class="forumTable  table table-striped table-condensed table-hover">
                  <tr class="backColor1 forumRowHead">
                          <td>Subject</td>
                          <td>Poster</td>
                          <td>Replies</td>
                          <td>Date</td>
                      </tr>
                  <tr valign="top"
        class="eve forumRow">
        <td>
                    <a href="/post/1112452">
            sorting by views broken          </a>
                  </td>

                  <td>
            <a href="/iathreads/forum-display.php?poster=Basquetteur">
              Basquetteur            </a>
          </td>
        
        
                  <td>
            1          </td>
        
        
                  <td>
            <nobr class="hidden-sm hidden-xs">Jan 9, 2021 3:58am</nobr>
            <span class="hidden-md hidden-lg smalldate">Jan 9, 2021 3:58am</span>
          </td>
              </tr>
          <tr valign="top"
        class="odd forumRow">
        <td>
          &nbsp;&nbsp;          <a href="/post/1112455">
            Re: sorting by views broken          </a>
                  </td>

                  <td>
            <a href="/iathreads/forum-display.php?poster=Jeff%20Kaplan">
              Jeff Kaplan            </a>
          </td>
        
        
                  <td>
            0          </td>
        
        
                  <td>
            <nobr class="hidden-sm hidden-xs">Jan 9, 2021 12:00pm</nobr>
            <span class="hidden-md hidden-lg smalldate">Jan 9, 2021 12:00pm</span>
          </td>
              </tr>
          <tr valign="top"
        class="eve forumRow">
        <td>
                    <a href="/post/1109264">
            download location          </a>
                  </td>

                  <td>
            <a href="/iathreads/forum-display.php?poster=hawaiianlungs">
              hawaiianlungs            </a>
          </td>
        
        
                  <td>
            0          </td>
        
        
                  <td>
            <nobr class="hidden-sm hidden-xs">Aug 3, 2020 5:02pm</nobr>
            <span class="hidden-md hidden-lg smalldate">Aug 3, 2020 5:02pm</span>
          </td>
              </tr>
          <tr valign="top"
        class="odd forumRow">
        <td>
                    <a href="/post/1105193">
            numbers of views seem stuck at zero since first January in new uploads          </a>
                  </td>

                  <td>
            <a href="/iathreads/forum-display.php?poster=Basquetteur">
              Basquetteur            </a>
          </td>
        
        
                  <td>
            5          </td>
        
        
                  <td>
            <nobr class="hidden-sm hidden-xs">Jan 8, 2020 1:02pm</nobr>
            <span class="hidden-md hidden-lg smalldate">Jan 8, 2020 1:02pm</span>
          </td>
              </tr>
          <tr valign="top"
        class="eve forumRow">
        <td>
          &nbsp;&nbsp;          <a href="/post/1105259">
            Re: numbers of views seem stuck at zero since first January in new uploads          </a>
                  </td>

                  <td>
            <a href="/iathreads/forum-display.php?poster=%D9%87%D9%86%D8%A7%D9%83">
              هناك            </a>
          </td>
        
        
                  <td>
            0          </td>
        
        
                  <td>
            <nobr class="hidden-sm hidden-xs">Jan 11, 2020 8:40am</nobr>
            <span class="hidden-md hidden-lg smalldate">Jan 11, 2020 8:40am</span>
          </td>
              </tr>
          <tr valign="top"
        class="odd forumRow">
        <td>
                    <a href="/post/1098811">
            Suggestions for \'23          </a>
                  </td>

                  <td>
            <a href="/iathreads/forum-display.php?poster=MPDMedia">
              MPDMedia            </a>
          </td>
        
        
                  <td>
            0          </td>
        
        
                  <td>
            <nobr class="hidden-sm hidden-xs">Jan 28, 2019 12:53pm</nobr>
            <span class="hidden-md hidden-lg smalldate">Jan 28, 2019 12:53pm</span>
          </td>
              </tr>
          <tr valign="top"
        class="eve forumRow">
        <td>
                    <a href="/post/1097830">
            Incorrect inconsistent record of number of views          </a>
                  </td>

                  <td>
            <a href="/iathreads/forum-display.php?poster=jothi20">
              jothi20            </a>
          </td>
        
        
                  <td>
            1          </td>
        
        
                  <td>
            <nobr class="hidden-sm hidden-xs">Dec 20, 2018 9:04pm</nobr>
            <span class="hidden-md hidden-lg smalldate">Dec 20, 2018 9:04pm</span>
          </td>
              </tr>
          <tr valign="top"
        class="odd forumRow">
        <td>
          &nbsp;&nbsp;          <a href="/post/1098141">
            Re: Incorrect inconsistent record of number of views          </a>
                  </td>

                  <td>
            <a href="/iathreads/forum-display.php?poster=Basquetteur">
              Basquetteur            </a>
          </td>
        
        
                  <td>
            2          </td>
        
        
                  <td>
            <nobr class="hidden-sm hidden-xs">Jan 4, 2019 12:58am</nobr>
            <span class="hidden-md hidden-lg smalldate">Jan 4, 2019 12:58am</span>
          </td>
              </tr>
          <tr valign="top"
        class="eve forumRow">
        <td>
          &nbsp;&nbsp;&nbsp;&nbsp;          <a href="/post/1098142">
            Re: Incorrect inconsistent record of number of views          </a>
                  </td>

                  <td>
            <a href="/iathreads/forum-display.php?poster=jothi20">
              jothi20            </a>
          </td>
        
        
                  <td>
            1          </td>
        
        
                  <td>
            <nobr class="hidden-sm hidden-xs">Jan 4, 2019 3:21am</nobr>
            <span class="hidden-md hidden-lg smalldate">Jan 4, 2019 3:21am</span>
          </td>
              </tr>
          <tr valign="top"
        class="odd forumRow">
        <td>
          &nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;          <a href="/post/1098168">
            Re: Incorrect inconsistent record of number of views          </a>
                  </td>

                  <td>
            <a href="/iathreads/forum-display.php?poster=Jeff%20Kaplan">
              Jeff Kaplan            </a>
          </td>
        
        
                  <td>
            0          </td>
        
        
                  <td>
            <nobr class="hidden-sm hidden-xs">Jan 4, 2019 9:30pm</nobr>
            <span class="hidden-md hidden-lg smalldate">Jan 4, 2019 9:30pm</span>
          </td>
              </tr>
          <tr valign="top"
        class="eve forumRow">
        <td>
          &nbsp;&nbsp;&nbsp;&nbsp;          <a href="/post/1098167">
            Re: Incorrect inconsistent record of number of views          </a>
                  </td>

                  <td>
            <a href="/iathreads/forum-display.php?poster=Jeff%20Kaplan">
              Jeff Kaplan            </a>
          </td>
        
        
                  <td>
            0          </td>
        
        
                  <td>
            <nobr class="hidden-sm hidden-xs">Jan 4, 2019 9:30pm</nobr>
            <span class="hidden-md hidden-lg smalldate">Jan 4, 2019 9:30pm</span>
          </td>
              </tr>
          <tr valign="top"
        class="odd forumRow">
        <td>
                    <a href="/post/1094083">
            Tarzan of the Lost Books          </a>
                  </td>

                  <td>
            <a href="/iathreads/forum-display.php?poster=stargazer1701a">
              stargazer1701a            </a>
          </td>
        
        
                  <td>
            1          </td>
        
        
                  <td>
            <nobr class="hidden-sm hidden-xs">Aug 18, 2018 5:26am</nobr>
            <span class="hidden-md hidden-lg smalldate">Aug 18, 2018 5:26am</span>
          </td>
              </tr>
          <tr valign="top"
        class="eve forumRow">
        <td>
          &nbsp;&nbsp;          <a href="/post/1094095">
            Re: Tarzan of the Lost Books          </a>
                  </td>

                  <td>
            <a href="/iathreads/forum-display.php?poster=librivoxbooks">
              librivoxbooks            </a>
          </td>
        
        
                  <td>
            1          </td>
        
        
                  <td>
            <nobr class="hidden-sm hidden-xs">Aug 19, 2018 5:04am</nobr>
            <span class="hidden-md hidden-lg smalldate">Aug 19, 2018 5:04am</span>
          </td>
              </tr>
          <tr valign="top"
        class="odd forumRow">
        <td>
          &nbsp;&nbsp;&nbsp;&nbsp;          <a href="/post/1094154">
            Re: Tarzan of the Lost Books          </a>
                  </td>

                  <td>
            <a href="/iathreads/forum-display.php?poster=stargazer1701a">
              stargazer1701a            </a>
          </td>
        
        
                  <td>
            0          </td>
        
        
                  <td>
            <nobr class="hidden-sm hidden-xs">Aug 21, 2018 5:16am</nobr>
            <span class="hidden-md hidden-lg smalldate">Aug 21, 2018 5:16am</span>
          </td>
              </tr>
          <tr valign="top"
        class="eve forumRow">
        <td>
                    <a href="/post/1091704">
            extra files playing          </a>
                  </td>

                  <td>
            <a href="/iathreads/forum-display.php?poster=librivoxbooks">
              librivoxbooks            </a>
          </td>
        
        
                  <td>
            1          </td>
        
        
                  <td>
            <nobr class="hidden-sm hidden-xs">Jun 12, 2018 4:28pm</nobr>
            <span class="hidden-md hidden-lg smalldate">Jun 12, 2018 4:28pm</span>
          </td>
              </tr>
          <tr valign="top"
        class="odd forumRow">
        <td>
          &nbsp;&nbsp;          <a href="/post/1091706">
            Re: extra files playing          </a>
                  </td>

                  <td>
            <a href="/iathreads/forum-display.php?poster=librivoxbooks">
              librivoxbooks            </a>
          </td>
        
        
                  <td>
            0          </td>
        
        
                  <td>
            <nobr class="hidden-sm hidden-xs">Jun 13, 2018 12:08am</nobr>
            <span class="hidden-md hidden-lg smalldate">Jun 13, 2018 12:08am</span>
          </td>
              </tr>
          <tr valign="top"
        class="eve forumRow">
        <td>
                    <a href="/post/1089471">
            no metadata          </a>
                  </td>

                  <td>
            <a href="/iathreads/forum-display.php?poster=librivoxbooks">
              librivoxbooks            </a>
          </td>
        
        
                  <td>
            1          </td>
        
        
                  <td>
            <nobr class="hidden-sm hidden-xs">Apr 9, 2018 10:39pm</nobr>
            <span class="hidden-md hidden-lg smalldate">Apr 9, 2018 10:39pm</span>
          </td>
              </tr>
          <tr valign="top"
        class="odd forumRow">
        <td>
          &nbsp;&nbsp;          <a href="/post/1089837">
            Re: no metadata          </a>
                  </td>

                  <td>
            <a href="/iathreads/forum-display.php?poster=librivoxbooks">
              librivoxbooks            </a>
          </td>
        
        
                  <td>
            0          </td>
        
        
                  <td>
            <nobr class="hidden-sm hidden-xs">Apr 25, 2018 9:29pm</nobr>
            <span class="hidden-md hidden-lg smalldate">Apr 25, 2018 9:29pm</span>
          </td>
              </tr>
          <tr valign="top"
        class="eve forumRow">
        <td>
                    <a href="/post/1089330">
            downloading list ?          </a>
                  </td>

                  <td>
            <a href="/iathreads/forum-display.php?poster=librivoxbooks">
              librivoxbooks            </a>
          </td>
        
        
                  <td>
            1          </td>
        
        
                  <td>
            <nobr class="hidden-sm hidden-xs">Apr 3, 2018 11:51pm</nobr>
            <span class="hidden-md hidden-lg smalldate">Apr 3, 2018 11:51pm</span>
          </td>
              </tr>
          <tr valign="top"
        class="odd forumRow">
        <td>
          &nbsp;&nbsp;          <a href="/post/1089811">
            Re: downloading list ?          </a>
                  </td>

                  <td>
            <a href="/iathreads/forum-display.php?poster=librivoxbooks">
              librivoxbooks            </a>
          </td>
        
        
                  <td>
            0          </td>
        
        
                  <td>
            <nobr class="hidden-sm hidden-xs">Apr 24, 2018 1:20am</nobr>
            <span class="hidden-md hidden-lg smalldate">Apr 24, 2018 1:20am</span>
          </td>
              </tr>
          <tr valign="top"
        class="eve forumRow">
        <td>
                    <a href="/post/1089315">
            librivox Apple audio files          </a>
                  </td>

                  <td>
            <a href="/iathreads/forum-display.php?poster=Arthur%20Thornton">
              Arthur Thornton            </a>
          </td>
        
        
                  <td>
            1          </td>
        
        
                  <td>
            <nobr class="hidden-sm hidden-xs">Apr 3, 2018 7:10am</nobr>
            <span class="hidden-md hidden-lg smalldate">Apr 3, 2018 7:10am</span>
          </td>
              </tr>
          <tr valign="top"
        class="odd forumRow">
        <td>
          &nbsp;&nbsp;          <a href="/post/1089329">
            Re: librivox Apple audio files          </a>
                  </td>

                  <td>
            <a href="/iathreads/forum-display.php?poster=librivoxbooks">
              librivoxbooks            </a>
          </td>
        
        
                  <td>
            1          </td>
        
        
                  <td>
            <nobr class="hidden-sm hidden-xs">Apr 4, 2018 2:59am</nobr>
            <span class="hidden-md hidden-lg smalldate">Apr 4, 2018 2:59am</span>
          </td>
              </tr>
          <tr valign="top"
        class="eve forumRow">
        <td>
          &nbsp;&nbsp;&nbsp;&nbsp;          <a href="/post/1089335">
            Re: librivox Apple audio files          </a>
                  </td>

                  <td>
            <a href="/iathreads/forum-display.php?poster=Arthur%20Thornton">
              Arthur Thornton            </a>
          </td>
        
        
                  <td>
            0          </td>
        
        
                  <td>
            <nobr class="hidden-sm hidden-xs">Apr 4, 2018 2:55am</nobr>
            <span class="hidden-md hidden-lg smalldate">Apr 4, 2018 2:55am</span>
          </td>
              </tr>
          <tr valign="top"
        class="odd forumRow">
        <td>
                    <a href="/post/1087222">
            Oliver Twist torrent          </a>
                  </td>

                  <td>
            <a href="/iathreads/forum-display.php?poster=JamesCurran">
              JamesCurran            </a>
          </td>
        
        
                  <td>
            1          </td>
        
        
                  <td>
            <nobr class="hidden-sm hidden-xs">Jan 27, 2018 3:44pm</nobr>
            <span class="hidden-md hidden-lg smalldate">Jan 27, 2018 3:44pm</span>
          </td>
              </tr>
          <tr valign="top"
        class="eve forumRow">
        <td>
          &nbsp;&nbsp;          <a href="/post/1087233">
            Re: Oliver Twist torrent          </a>
                  </td>

                  <td>
            <a href="/iathreads/forum-display.php?poster=Jeff%20Kaplan">
              Jeff Kaplan            </a>
          </td>
        
        
                  <td>
            1          </td>
        
        
                  <td>
            <nobr class="hidden-sm hidden-xs">Jan 28, 2018 9:09am</nobr>
            <span class="hidden-md hidden-lg smalldate">Jan 28, 2018 9:09am</span>
          </td>
              </tr>
          <tr valign="top"
        class="odd forumRow">
        <td>
          &nbsp;&nbsp;&nbsp;&nbsp;          <a href="/post/1087245">
            Re: Oliver Twist torrent          </a>
                  </td>

                  <td>
            <a href="/iathreads/forum-display.php?poster=JamesCurran">
              JamesCurran            </a>
          </td>
        
        
                  <td>
            1          </td>
        
        
                  <td>
            <nobr class="hidden-sm hidden-xs">Jan 28, 2018 4:21pm</nobr>
            <span class="hidden-md hidden-lg smalldate">Jan 28, 2018 4:21pm</span>
          </td>
              </tr>
          <tr valign="top"
        class="eve forumRow">
        <td>
          &nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;          <a href="/post/1087247">
            Re: Oliver Twist torrent          </a>
                  </td>

                  <td>
            <a href="/iathreads/forum-display.php?poster=JamesCurran">
              JamesCurran            </a>
          </td>
        
        
                  <td>
            1          </td>
        
        
                  <td>
            <nobr class="hidden-sm hidden-xs">Jan 28, 2018 4:47pm</nobr>
            <span class="hidden-md hidden-lg smalldate">Jan 28, 2018 4:47pm</span>
          </td>
              </tr>
          <tr valign="top"
        class="odd forumRow">
        <td>
          &nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;          <a href="/post/1087249">
            Re: Oliver Twist torrent          </a>
                  </td>

                  <td>
            <a href="/iathreads/forum-display.php?poster=Jeff%20Kaplan">
              Jeff Kaplan            </a>
          </td>
        
        
                  <td>
            0          </td>
        
        
                  <td>
            <nobr class="hidden-sm hidden-xs">Jan 28, 2018 9:08pm</nobr>
            <span class="hidden-md hidden-lg smalldate">Jan 28, 2018 9:08pm</span>
          </td>
              </tr>
          <tr valign="top"
        class="eve forumRow">
        <td>
                    <a href="/post/1083713">
            Item not available          </a>
                  </td>

                  <td>
            <a href="/iathreads/forum-display.php?poster=twoturntwo">
              twoturntwo            </a>
          </td>
        
        
                  <td>
            1          </td>
        
        
                  <td>
            <nobr class="hidden-sm hidden-xs">Oct 9, 2017 3:24am</nobr>
            <span class="hidden-md hidden-lg smalldate">Oct 9, 2017 3:24am</span>
          </td>
              </tr>
          <tr valign="top"
        class="odd forumRow">
        <td>
          &nbsp;&nbsp;          <a href="/post/1083717">
            Re: Item not available          </a>
                  </td>

                  <td>
            <a href="/iathreads/forum-display.php?poster=Jeff%20Kaplan">
              Jeff Kaplan            </a>
          </td>
        
        
                  <td>
            1          </td>
        
        
                  <td>
            <nobr class="hidden-sm hidden-xs">Oct 9, 2017 8:00am</nobr>
            <span class="hidden-md hidden-lg smalldate">Oct 9, 2017 8:00am</span>
          </td>
              </tr>
          <tr valign="top"
        class="eve forumRow">
        <td>
          &nbsp;&nbsp;&nbsp;&nbsp;          <a href="/post/1083742">
            Re: Item not available          </a>
                  </td>

                  <td>
            <a href="/iathreads/forum-display.php?poster=twoturntwo">
              twoturntwo            </a>
          </td>
        
        
                  <td>
            0          </td>
        
        
                  <td>
            <nobr class="hidden-sm hidden-xs">Oct 10, 2017 3:32am</nobr>
            <span class="hidden-md hidden-lg smalldate">Oct 10, 2017 3:32am</span>
          </td>
              </tr>
          <tr valign="top"
        class="odd forumRow">
        <td>
                    <a href="/post/1082748">
            William M Thackeray          </a>
                  </td>

                  <td>
            <a href="/iathreads/forum-display.php?poster=Diogenes46">
              Diogenes46            </a>
          </td>
        
        
                  <td>
            1          </td>
        
        
                  <td>
            <nobr class="hidden-sm hidden-xs">Sep 8, 2017 10:29am</nobr>
            <span class="hidden-md hidden-lg smalldate">Sep 8, 2017 10:29am</span>
          </td>
              </tr>
          <tr valign="top"
        class="eve forumRow">
        <td>
          &nbsp;&nbsp;          <a href="/post/1084114">
            Re: William M Thackeray          </a>
                  </td>

                  <td>
            <a href="/iathreads/forum-display.php?poster=librivoxbooks">
              librivoxbooks            </a>
          </td>
        
        
                  <td>
            0          </td>
        
        
                  <td>
            <nobr class="hidden-sm hidden-xs">Oct 19, 2017 8:21am</nobr>
            <span class="hidden-md hidden-lg smalldate">Oct 19, 2017 8:21am</span>
          </td>
              </tr>
          <tr valign="top"
        class="odd forumRow">
        <td>
                    <a href="/post/1077774">
            Tom Sawyer          </a>
                  </td>

                  <td>
            <a href="/iathreads/forum-display.php?poster=Diamner">
              Diamner            </a>
          </td>
        
        
                  <td>
            1          </td>
        
        
                  <td>
            <nobr class="hidden-sm hidden-xs">Jun 3, 2017 9:08pm</nobr>
            <span class="hidden-md hidden-lg smalldate">Jun 3, 2017 9:08pm</span>
          </td>
              </tr>
          <tr valign="top"
        class="eve forumRow">
        <td>
          &nbsp;&nbsp;          <a href="/post/1077819">
            Re: Tom Sawyer          </a>
                  </td>

                  <td>
            <a href="/iathreads/forum-display.php?poster=Jeff%20Kaplan">
              Jeff Kaplan            </a>
          </td>
        
        
                  <td>
            0          </td>
        
        
                  <td>
            <nobr class="hidden-sm hidden-xs">Jun 4, 2017 5:54pm</nobr>
            <span class="hidden-md hidden-lg smalldate">Jun 4, 2017 5:54pm</span>
          </td>
              </tr>
          <tr valign="top"
        class="odd forumRow">
        <td>
                    <a href="/post/1068781">
            The librivox collection seems disapppeared right now?          </a>
                  </td>

                  <td>
            <a href="/iathreads/forum-display.php?poster=Basquetteur">
              Basquetteur            </a>
          </td>
        
        
                  <td>
            1          </td>
        
        
                  <td>
            <nobr class="hidden-sm hidden-xs">Jan 30, 2017 3:04am</nobr>
            <span class="hidden-md hidden-lg smalldate">Jan 30, 2017 3:04am</span>
          </td>
              </tr>
          <tr valign="top"
        class="eve forumRow">
        <td>
          &nbsp;&nbsp;          <a href="/post/1068813">
            Re: The librivox collection seems disapppeared right now?          </a>
                  </td>

                  <td>
            <a href="/iathreads/forum-display.php?poster=librivoxbooks">
              librivoxbooks            </a>
          </td>
        
        
                  <td>
            0          </td>
        
        
                  <td>
            <nobr class="hidden-sm hidden-xs">Jan 30, 2017 1:38pm</nobr>
            <span class="hidden-md hidden-lg smalldate">Jan 30, 2017 1:38pm</span>
          </td>
              </tr>
          <tr valign="top"
        class="odd forumRow">
        <td>
                    <a href="/post/1068670">
            Ordeal of Elizabeth by Anonymous          </a>
                  </td>

                  <td>
            <a href="/iathreads/forum-display.php?poster=seventyeight">
              seventyeight            </a>
          </td>
        
        
                  <td>
            1          </td>
        
        
                  <td>
            <nobr class="hidden-sm hidden-xs">Jan 26, 2017 11:27pm</nobr>
            <span class="hidden-md hidden-lg smalldate">Jan 26, 2017 11:27pm</span>
          </td>
              </tr>
          <tr valign="top"
        class="eve forumRow">
        <td>
          &nbsp;&nbsp;          <a href="/post/1068698">
            Re: Ordeal of Elizabeth by Anonymous          </a>
                  </td>

                  <td>
            <a href="/iathreads/forum-display.php?poster=librivoxbooks">
              librivoxbooks            </a>
          </td>
        
        
                  <td>
            1          </td>
        
        
                  <td>
            <nobr class="hidden-sm hidden-xs">Jan 27, 2017 9:49am</nobr>
            <span class="hidden-md hidden-lg smalldate">Jan 27, 2017 9:49am</span>
          </td>
              </tr>
          <tr valign="top"
        class="odd forumRow">
        <td>
          &nbsp;&nbsp;&nbsp;&nbsp;          <a href="/post/1068920">
            Re: Ordeal of Elizabeth by Anonymous          </a>
                  </td>

                  <td>
            <a href="/iathreads/forum-display.php?poster=librivoxbooks">
              librivoxbooks            </a>
          </td>
        
        
                  <td>
            0          </td>
        
        
                  <td>
            <nobr class="hidden-sm hidden-xs">Feb 1, 2017 1:52am</nobr>
            <span class="hidden-md hidden-lg smalldate">Feb 1, 2017 1:52am</span>
          </td>
              </tr>
          <tr valign="top"
        class="eve forumRow">
        <td>
                    <a href="/post/1068519">
            number of views not aymore updated?          </a>
                  </td>

                  <td>
            <a href="/iathreads/forum-display.php?poster=Basquetteur">
              Basquetteur            </a>
          </td>
        
        
                  <td>
            1          </td>
        
        
                  <td>
            <nobr class="hidden-sm hidden-xs">Jan 24, 2017 12:08pm</nobr>
            <span class="hidden-md hidden-lg smalldate">Jan 24, 2017 12:08pm</span>
          </td>
              </tr>
          <tr valign="top"
        class="odd forumRow">
        <td>
          &nbsp;&nbsp;          <a href="/post/1068521">
            Re: number of views not aymore updated?          </a>
                  </td>

                  <td>
            <a href="/iathreads/forum-display.php?poster=Jeff%20Kaplan">
              Jeff Kaplan            </a>
          </td>
        
        
                  <td>
            0          </td>
        
        
                  <td>
            <nobr class="hidden-sm hidden-xs">Jan 24, 2017 12:23pm</nobr>
            <span class="hidden-md hidden-lg smalldate">Jan 24, 2017 12:23pm</span>
          </td>
              </tr>
          <tr valign="top"
        class="eve forumRow">
        <td>
                    <a href="/post/1067927">
            Are you doing something new ?          </a>
                  </td>

                  <td>
            <a href="/iathreads/forum-display.php?poster=librivoxbooks">
              librivoxbooks            </a>
          </td>
        
        
                  <td>
            1          </td>
        
        
                  <td>
            <nobr class="hidden-sm hidden-xs">Jan 12, 2017 1:01pm</nobr>
            <span class="hidden-md hidden-lg smalldate">Jan 12, 2017 1:01pm</span>
          </td>
              </tr>
          <tr valign="top"
        class="odd forumRow">
        <td>
          &nbsp;&nbsp;          <a href="/post/1067943">
            Re: Are you doing something new ?          </a>
                  </td>

                  <td>
            <a href="/iathreads/forum-display.php?poster=librivoxbooks">
              librivoxbooks            </a>
          </td>
        
        
                  <td>
            0          </td>
        
        
                  <td>
            <nobr class="hidden-sm hidden-xs">Jan 12, 2017 1:28pm</nobr>
            <span class="hidden-md hidden-lg smalldate">Jan 12, 2017 1:28pm</span>
          </td>
              </tr>
          <tr valign="top"
        class="eve forumRow">
        <td>
                    <a href="/post/1066383">
            Public Domain?          </a>
                  </td>

                  <td>
            <a href="/iathreads/forum-display.php?poster=picfixer">
              picfixer            </a>
          </td>
        
        
                  <td>
            1          </td>
        
        
                  <td>
            <nobr class="hidden-sm hidden-xs">Dec 9, 2016 9:11pm</nobr>
            <span class="hidden-md hidden-lg smalldate">Dec 9, 2016 9:11pm</span>
          </td>
              </tr>
          <tr valign="top"
        class="odd forumRow">
        <td>
          &nbsp;&nbsp;          <a href="/post/1068045">
            Re: Public Domain?          </a>
                  </td>

                  <td>
            <a href="/iathreads/forum-display.php?poster=librivoxbooks">
              librivoxbooks            </a>
          </td>
        
        
                  <td>
            1          </td>
        
        
                  <td>
            <nobr class="hidden-sm hidden-xs">Jan 14, 2017 1:42pm</nobr>
            <span class="hidden-md hidden-lg smalldate">Jan 14, 2017 1:42pm</span>
          </td>
              </tr>
          <tr valign="top"
        class="eve forumRow">
        <td>
          &nbsp;&nbsp;&nbsp;&nbsp;          <a href="/post/1068050">
            Re: Public Domain?          </a>
                  </td>

                  <td>
            <a href="/iathreads/forum-display.php?poster=picfixer">
              picfixer            </a>
          </td>
        
        
                  <td>
            0          </td>
        
        
                  <td>
            <nobr class="hidden-sm hidden-xs">Jan 14, 2017 9:33pm</nobr>
            <span class="hidden-md hidden-lg smalldate">Jan 14, 2017 9:33pm</span>
          </td>
              </tr>
          <tr valign="top"
        class="odd forumRow">
        <td>
                    <a href="/post/1065673">
            Problem locating author\'s work.          </a>
                  </td>

                  <td>
            <a href="/iathreads/forum-display.php?poster=Diogenes46">
              Diogenes46            </a>
          </td>
        
        
                  <td>
            1          </td>
        
        
                  <td>
            <nobr class="hidden-sm hidden-xs">Nov 18, 2016 8:08am</nobr>
            <span class="hidden-md hidden-lg smalldate">Nov 18, 2016 8:08am</span>
          </td>
              </tr>
          <tr valign="top"
        class="eve forumRow">
        <td>
          &nbsp;&nbsp;          <a href="/post/1065728">
            Re: Problem locating author\'s work.          </a>
                  </td>

                  <td>
            <a href="/iathreads/forum-display.php?poster=Jeff%20Kaplan">
              Jeff Kaplan            </a>
          </td>
        
        
                  <td>
            0          </td>
        
        
                  <td>
            <nobr class="hidden-sm hidden-xs">Nov 20, 2016 4:38pm</nobr>
            <span class="hidden-md hidden-lg smalldate">Nov 20, 2016 4:38pm</span>
          </td>
              </tr>
          <tr valign="top"
        class="odd forumRow">
        <td>
                    <a href="/post/1062726">
            Submitting subtitles for audio          </a>
                  </td>

                  <td>
            <a href="/iathreads/forum-display.php?poster=russ87">
              russ87            </a>
          </td>
        
        
                  <td>
            2          </td>
        
        
                  <td>
            <nobr class="hidden-sm hidden-xs">Aug 31, 2016 4:38am</nobr>
            <span class="hidden-md hidden-lg smalldate">Aug 31, 2016 4:38am</span>
          </td>
              </tr>
          <tr valign="top"
        class="eve forumRow">
        <td>
          &nbsp;&nbsp;          <a href="/post/1062886">
            Re: Submitting subtitles for audio          </a>
                  </td>

                  <td>
            <a href="/iathreads/forum-display.php?poster=librivoxbooks">
              librivoxbooks            </a>
          </td>
        
        
                  <td>
            0          </td>
        
        
                  <td>
            <nobr class="hidden-sm hidden-xs">Sep 2, 2016 5:04pm</nobr>
            <span class="hidden-md hidden-lg smalldate">Sep 2, 2016 5:04pm</span>
          </td>
              </tr>
          <tr valign="top"
        class="odd forumRow">
        <td>
          &nbsp;&nbsp;          <a href="/post/1063097">
            Re: Submitting subtitles for audio          </a>
                  </td>

                  <td>
            <a href="/iathreads/forum-display.php?poster=Readiance.org">
              Readiance.org            </a>
          </td>
        
        
                  <td>
            1          </td>
        
        
                  <td>
            <nobr class="hidden-sm hidden-xs">Sep 8, 2016 3:15pm</nobr>
            <span class="hidden-md hidden-lg smalldate">Sep 8, 2016 3:15pm</span>
          </td>
              </tr>
          <tr valign="top"
        class="eve forumRow">
        <td>
          &nbsp;&nbsp;&nbsp;&nbsp;          <a href="/post/1065185">
            Re: Submitting subtitles for audio          </a>
                  </td>

                  <td>
            <a href="/iathreads/forum-display.php?poster=russ87">
              russ87            </a>
          </td>
        
        
                  <td>
            1          </td>
        
        
                  <td>
            <nobr class="hidden-sm hidden-xs">Nov 6, 2016 2:30am</nobr>
            <span class="hidden-md hidden-lg smalldate">Nov 6, 2016 2:30am</span>
          </td>
              </tr>
          <tr valign="top"
        class="odd forumRow">
        <td>
          &nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;          <a href="/post/1065196">
            Re: Submitting subtitles for audio          </a>
                  </td>

                  <td>
            <a href="/iathreads/forum-display.php?poster=Readiance.org">
              Readiance.org            </a>
          </td>
        
        
                  <td>
            0          </td>
        
        
                  <td>
            <nobr class="hidden-sm hidden-xs">Nov 6, 2016 6:54am</nobr>
            <span class="hidden-md hidden-lg smalldate">Nov 6, 2016 6:54am</span>
          </td>
              </tr>
          <tr valign="top"
        class="eve forumRow">
        <td>
                    <a href="/post/1058531">
            Disappearing download          </a>
                  </td>

                  <td>
            <a href="/iathreads/forum-display.php?poster=Tom%20Pittsburgh">
              Tom Pittsburgh            </a>
          </td>
        
        
                  <td>
            2          </td>
        
        
                  <td>
            <nobr class="hidden-sm hidden-xs">Jun 4, 2016 6:33pm</nobr>
            <span class="hidden-md hidden-lg smalldate">Jun 4, 2016 6:33pm</span>
          </td>
              </tr>
          <tr valign="top"
        class="odd forumRow">
        <td>
          &nbsp;&nbsp;          <a href="/post/1058550">
            Re: Disappearing download          </a>
                  </td>

                  <td>
            <a href="/iathreads/forum-display.php?poster=Jeff%20Kaplan">
              Jeff Kaplan            </a>
          </td>
        
        
                  <td>
            1          </td>
        
        
                  <td>
            <nobr class="hidden-sm hidden-xs">Jun 5, 2016 9:55am</nobr>
            <span class="hidden-md hidden-lg smalldate">Jun 5, 2016 9:55am</span>
          </td>
              </tr>
          <tr valign="top"
        class="eve forumRow">
        <td>
          &nbsp;&nbsp;&nbsp;&nbsp;          <a href="/post/1058602">
            Re: Disappearing download          </a>
                  </td>

                  <td>
            <a href="/iathreads/forum-display.php?poster=Tom%20Pittsburgh">
              Tom Pittsburgh            </a>
          </td>
        
        
                  <td>
            1          </td>
        
        
                  <td>
            <nobr class="hidden-sm hidden-xs">Jun 6, 2016 3:04pm</nobr>
            <span class="hidden-md hidden-lg smalldate">Jun 6, 2016 3:04pm</span>
          </td>
              </tr>
          <tr valign="top"
        class="odd forumRow">
        <td>
          &nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;          <a href="/post/1058604">
            Re: Disappearing download          </a>
                  </td>

                  <td>
            <a href="/iathreads/forum-display.php?poster=Jeff%20Kaplan">
              Jeff Kaplan            </a>
          </td>
        
        
                  <td>
            0          </td>
        
        
                  <td>
            <nobr class="hidden-sm hidden-xs">Jun 6, 2016 4:52pm</nobr>
            <span class="hidden-md hidden-lg smalldate">Jun 6, 2016 4:52pm</span>
          </td>
              </tr>
          <tr valign="top"
        class="eve forumRow">
        <td>
          &nbsp;&nbsp;          <a href="/post/1058557">
            Re: Disappearing download          </a>
                  </td>

                  <td>
            <a href="/iathreads/forum-display.php?poster=librivoxbooks">
              librivoxbooks            </a>
          </td>
        
        
                  <td>
            0          </td>
        
        
                  <td>
            <nobr class="hidden-sm hidden-xs">Jun 5, 2016 4:57pm</nobr>
            <span class="hidden-md hidden-lg smalldate">Jun 5, 2016 4:57pm</span>
          </td>
              </tr>
          <tr valign="top"
        class="odd forumRow">
        <td>
                    <a href="/post/1054986">
            kindle format?          </a>
                  </td>

                  <td>
            <a href="/iathreads/forum-display.php?poster=mizdee">
              mizdee            </a>
          </td>
        
        
                  <td>
            1          </td>
        
        
                  <td>
            <nobr class="hidden-sm hidden-xs">Mar 27, 2016 9:14am</nobr>
            <span class="hidden-md hidden-lg smalldate">Mar 27, 2016 9:14am</span>
          </td>
              </tr>
          <tr valign="top"
        class="eve forumRow">
        <td>
          &nbsp;&nbsp;          <a href="/post/1057233">
            Re: kindle format?          </a>
                  </td>

                  <td>
            <a href="/iathreads/forum-display.php?poster=librivoxbooks">
              librivoxbooks            </a>
          </td>
        
        
                  <td>
            0          </td>
        
        
                  <td>
            <nobr class="hidden-sm hidden-xs">May 8, 2016 4:29am</nobr>
            <span class="hidden-md hidden-lg smalldate">May 8, 2016 4:29am</span>
          </td>
              </tr>
          <tr valign="top"
        class="odd forumRow">
        <td>
                    <a href="/post/1053663">
            file format          </a>
                  </td>

                  <td>
            <a href="/iathreads/forum-display.php?poster=Tokyo%20Yosh">
              Tokyo Yosh            </a>
          </td>
        
        
                  <td>
            1          </td>
        
        
                  <td>
            <nobr class="hidden-sm hidden-xs">Mar 5, 2016 4:09am</nobr>
            <span class="hidden-md hidden-lg smalldate">Mar 5, 2016 4:09am</span>
          </td>
              </tr>
          <tr valign="top"
        class="eve forumRow">
        <td>
          &nbsp;&nbsp;          <a href="/post/1053700">
            Re: file format          </a>
                  </td>

                  <td>
            <a href="/iathreads/forum-display.php?poster=librivoxbooks">
              librivoxbooks            </a>
          </td>
        
        
                  <td>
            1          </td>
        
        
                  <td>
            <nobr class="hidden-sm hidden-xs">Mar 6, 2016 4:15am</nobr>
            <span class="hidden-md hidden-lg smalldate">Mar 6, 2016 4:15am</span>
          </td>
              </tr>
          <tr valign="top"
        class="odd forumRow">
        <td>
          &nbsp;&nbsp;&nbsp;&nbsp;          <a href="/post/1053709">
            Re: file format          </a>
                  </td>

                  <td>
            <a href="/iathreads/forum-display.php?poster=Tokyo%20Yosh">
              Tokyo Yosh            </a>
          </td>
        
        
                  <td>
            1          </td>
        
        
                  <td>
            <nobr class="hidden-sm hidden-xs">Mar 6, 2016 7:33am</nobr>
            <span class="hidden-md hidden-lg smalldate">Mar 6, 2016 7:33am</span>
          </td>
              </tr>
          <tr valign="top"
        class="eve forumRow">
        <td>
          &nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;          <a href="/post/1057232">
            Re: file format          </a>
                  </td>

                  <td>
            <a href="/iathreads/forum-display.php?poster=librivoxbooks">
              librivoxbooks            </a>
          </td>
        
        
                  <td>
            1          </td>
        
        
                  <td>
            <nobr class="hidden-sm hidden-xs">May 8, 2016 4:27am</nobr>
            <span class="hidden-md hidden-lg smalldate">May 8, 2016 4:27am</span>
          </td>
              </tr>
          <tr valign="top"
        class="odd forumRow">
        <td>
          &nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;          <a href="/post/1057608">
            Re: file format          </a>
                  </td>

                  <td>
            <a href="/iathreads/forum-display.php?poster=Tokyo%20Yosh">
              Tokyo Yosh            </a>
          </td>
        
        
                  <td>
            0          </td>
        
        
                  <td>
            <nobr class="hidden-sm hidden-xs">May 17, 2016 8:16am</nobr>
            <span class="hidden-md hidden-lg smalldate">May 17, 2016 8:16am</span>
          </td>
              </tr>
          <tr valign="top"
        class="eve forumRow">
        <td>
                    <a href="/post/1051789">
            Post your audio book requests          </a>
                  </td>

                  <td>
            <a href="/iathreads/forum-display.php?poster=stargazer1701a">
              stargazer1701a            </a>
          </td>
        
        
                  <td>
            2          </td>
        
        
                  <td>
            <nobr class="hidden-sm hidden-xs">Jan 30, 2016 6:55am</nobr>
            <span class="hidden-md hidden-lg smalldate">Jan 30, 2016 6:55am</span>
          </td>
              </tr>
          <tr valign="top"
        class="odd forumRow">
        <td>
          &nbsp;&nbsp;          <a href="/post/1051792">
            Re: Post your audio book requests          </a>
                  </td>

                  <td>
            <a href="/iathreads/forum-display.php?poster=Jeff%20Kaplan">
              Jeff Kaplan            </a>
          </td>
        
        
                  <td>
            1          </td>
        
        
                  <td>
            <nobr class="hidden-sm hidden-xs">Jan 30, 2016 8:05am</nobr>
            <span class="hidden-md hidden-lg smalldate">Jan 30, 2016 8:05am</span>
          </td>
              </tr>
          <tr valign="top"
        class="eve forumRow">
        <td>
          &nbsp;&nbsp;&nbsp;&nbsp;          <a href="/post/1051796">
            Re: Post your audio book requests          </a>
                  </td>

                  <td>
            <a href="/iathreads/forum-display.php?poster=stargazer1701a">
              stargazer1701a            </a>
          </td>
        
        
                  <td>
            0          </td>
        
        
                  <td>
            <nobr class="hidden-sm hidden-xs">Jan 30, 2016 9:52am</nobr>
            <span class="hidden-md hidden-lg smalldate">Jan 30, 2016 9:52am</span>
          </td>
              </tr>
          <tr valign="top"
        class="odd forumRow">
        <td>
          &nbsp;&nbsp;          <a href="/post/1051817">
            Re: Post your audio book requests          </a>
                  </td>

                  <td>
            <a href="/iathreads/forum-display.php?poster=librivoxbooks">
              librivoxbooks            </a>
          </td>
        
        
                  <td>
            2          </td>
        
        
                  <td>
            <nobr class="hidden-sm hidden-xs">Jan 31, 2016 4:14am</nobr>
            <span class="hidden-md hidden-lg smalldate">Jan 31, 2016 4:14am</span>
          </td>
              </tr>
          <tr valign="top"
        class="eve forumRow">
        <td>
          &nbsp;&nbsp;&nbsp;&nbsp;          <a href="/post/1051829">
            Re: Post your audio book requests          </a>
                  </td>

                  <td>
            <a href="/iathreads/forum-display.php?poster=stargazer1701a">
              stargazer1701a            </a>
          </td>
        
        
                  <td>
            1          </td>
        
        
                  <td>
            <nobr class="hidden-sm hidden-xs">Jan 31, 2016 10:41am</nobr>
            <span class="hidden-md hidden-lg smalldate">Jan 31, 2016 10:41am</span>
          </td>
              </tr>
          <tr valign="top"
        class="odd forumRow">
        <td>
          &nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;          <a href="/post/1052026">
            Re: Post your audio book requests          </a>
                  </td>

                  <td>
            <a href="/iathreads/forum-display.php?poster=stargazer1701a">
              stargazer1701a            </a>
          </td>
        
        
                  <td>
            1          </td>
        
        
                  <td>
            <nobr class="hidden-sm hidden-xs">Feb 5, 2016 11:09am</nobr>
            <span class="hidden-md hidden-lg smalldate">Feb 5, 2016 11:09am</span>
          </td>
              </tr>
          <tr valign="top"
        class="eve forumRow">
        <td>
          &nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;          <a href="/post/1052054">
            Re: Post your audio book requests          </a>
                  </td>

                  <td>
            <a href="/iathreads/forum-display.php?poster=librivoxbooks">
              librivoxbooks            </a>
          </td>
        
        
                  <td>
            1          </td>
        
        
                  <td>
            <nobr class="hidden-sm hidden-xs">Feb 6, 2016 4:38am</nobr>
            <span class="hidden-md hidden-lg smalldate">Feb 6, 2016 4:38am</span>
          </td>
              </tr>
          <tr valign="top"
        class="odd forumRow">
        <td>
          &nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;          <a href="/post/1052067">
            Re: Post your audio book requests          </a>
                  </td>

                  <td>
            <a href="/iathreads/forum-display.php?poster=stargazer1701a">
              stargazer1701a            </a>
          </td>
        
        
                  <td>
            0          </td>
        
        
                  <td>
            <nobr class="hidden-sm hidden-xs">Feb 6, 2016 10:55am</nobr>
            <span class="hidden-md hidden-lg smalldate">Feb 6, 2016 10:55am</span>
          </td>
              </tr>
          <tr valign="top"
        class="eve forumRow">
        <td>
          &nbsp;&nbsp;&nbsp;&nbsp;          <a href="/post/1052723">
            Re: Post your audio book requests          </a>
                  </td>

                  <td>
            <a href="/iathreads/forum-display.php?poster=CCCCCCC">
              CCCCCCC            </a>
          </td>
        
        
                  <td>
            1          </td>
        
        
                  <td>
            <nobr class="hidden-sm hidden-xs">Feb 18, 2016 4:05pm</nobr>
            <span class="hidden-md hidden-lg smalldate">Feb 18, 2016 4:05pm</span>
          </td>
              </tr>
          <tr valign="top"
        class="odd forumRow">
        <td>
          &nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;          <a href="/post/1057234">
            Re: Post your audio book requests          </a>
                  </td>

                  <td>
            <a href="/iathreads/forum-display.php?poster=librivoxbooks">
              librivoxbooks            </a>
          </td>
        
        
                  <td>
            0          </td>
        
        
                  <td>
            <nobr class="hidden-sm hidden-xs">May 8, 2016 4:33am</nobr>
            <span class="hidden-md hidden-lg smalldate">May 8, 2016 4:33am</span>
          </td>
              </tr>
          </table>
              <br/><b><a href="/iathreads/forum-display.php?forum=librivoxaudio&limit=40">View more forum posts</a></b>          </div>
          </div>
            </div><!--/#.tabby-forum-->
  </div><!--/.container-ia-->
  
  <script type="text/javascript">
archive_setup.push(function() {
    });
</script>
        </div><!--/.container-->
              </main>
    </div><!--/#wrap-->
    
    
    <!-- Timing ...
     rendered on: www23.us.archive.org
 seconds diff sec               message   stack(file:line:function)
=========================================================
  0.0000   0.0000         petabox start   var/cache/petabox/petabox/www/sf/details.php:1:require
                                             |common/ia:66:require_once
                                             |setup.php:383:log
  0.0072   0.0072      redis_read start   var/cache/petabox/petabox/www/sf/details.php:62:getItem
                                             |details.php:183:getItem
                                             |common/Item.inc:77:parseMetadata
                                             |Item.inc:132:get_obj
                                             |Metadata.inc:477:_get_obj
                                             |Metadata.inc:507:run_pipeline
                                             |Metadata.inc:1352:read
                                             |Metadata/AdapterPipeline.inc:256:_read
                                             |AdapterPipeline.inc:292:pipeline
                                             |AdapterPipeline.inc:377:fetch
                                             |AdapterPipeline.inc:639:fetch
                                             |RecordServer.inc:148:execute
                                             |RecordServer/FetchRecordOp.inc:57:log
  0.0098   0.0026     redis_read finish   var/cache/petabox/petabox/www/sf/details.php:62:getItem
                                             |details.php:183:getItem
                                             |common/Item.inc:77:parseMetadata
                                             |Item.inc:132:get_obj
                                             |Metadata.inc:477:_get_obj
                                             |Metadata.inc:507:run_pipeline
                                             |Metadata.inc:1352:read
                                             |Metadata/AdapterPipeline.inc:256:_read
                                             |AdapterPipeline.inc:292:pipeline
                                             |AdapterPipeline.inc:377:fetch
                                             |AdapterPipeline.inc:639:fetch
                                             |RecordServer.inc:148:execute
                                             |RecordServer/FetchRecordOp.inc:63:log
  0.0479   0.0381   begin session_start   var/cache/petabox/petabox/www/sf/details.php:62:getItem
                                             |details.php:197:include
                                             |collection.php:223:head
                                             |common/Nav.inc:129:__construct
                                             |Nav.inc:221:session_start
                                             |Cookies.inc:56:log
  0.0481   0.0002    done session_start   var/cache/petabox/petabox/www/sf/details.php:62:getItem
                                             |details.php:197:include
                                             |collection.php:223:head
                                             |common/Nav.inc:129:__construct
                                             |Nav.inc:221:session_start
                                             |Cookies.inc:66:log
  0.0645   0.0164              bug dump   var/cache/petabox/petabox/www/sf/details.php:62:getItem
                                             |details.php:197:include
                                             |collection.php:278:footer
                                             |common/setup.php:152:footer
                                             |Nav.inc:1143:dump
                                             |Bug.inc:102:log
    -->
    <script type="text/javascript">
if (window.archive_analytics) {
  window.archive_analytics.send_pageview_on_load(window.archive_analytics);
  window.archive_analytics.process_url_events(window.location);
  var vs = window.archive_analytics.get_data_packets();
  for (var i in vs) {
    vs[i][\'cache_bust\']=Math.random();
    vs[i][\'server_ms\']=64;
    vs[i][\'server_name\']="www23.us.archive.org";
      }

  if (document.querySelectorAll(\'.more_search\').length) {
    window.archive_analytics.send_scroll_fetch_base_event();
  }
}
</script>
              <img src="//analytics.archive.org/0.gif?kind=track_js&track_js_case=control&cache_bust=2070962250" alt="" />
          <noscript>
        <img src="//analytics.archive.org/0.gif?kind=track_js&track_js_case=disabled&cache_bust=69246456" />
      </noscript>
          <script>
        document.addEventListener(\'DOMContentLoaded\', function() {
          if (typeof AJS === \'undefined\') {
            return;
          }
          AJS.createTrackingImage(\'in_page_executes\');
        });
      </script>
      </div>
  </body>
</html>
    '
];
